@@ -22,9 +22,12 @@
 #include "ash/display/screen_orientation_controller.h"
 #include "ash/focus_cycler.h"
 #include "ash/frame/non_client_frame_view_ash.h"
+#include "ash/game_dashboard/game_dashboard_controller.h"
 #include "ash/ime/ime_controller_impl.h"
 #include "ash/keyboard/keyboard_controller_impl.h"
 #include "ash/media/media_controller_impl.h"
+#include "ash/public/cpp/ambient/ambient_client.h"
+#include "ash/public/cpp/app_types_util.h"
 #include "ash/public/cpp/assistant/assistant_state.h"
 #include "ash/public/cpp/new_window_delegate.h"
 #include "ash/public/cpp/projector/projector_controller.h"
@@ -60,6 +63,8 @@
 #include "ash/wm/overview/overview_controller.h"
 #include "ash/wm/overview/overview_session.h"
 #include "ash/wm/screen_pinning_controller.h"
+#include "ash/wm/tablet_mode/tablet_mode_multitask_menu_event_handler.h"
+#include "ash/wm/tablet_mode/tablet_mode_window_manager.h"
 #include "ash/wm/window_cycle/window_cycle_controller.h"
 #include "ash/wm/window_state.h"
 #include "ash/wm/window_util.h"
@@ -91,19 +96,12 @@
 #include "ui/gfx/geometry/point.h"
 #include "ui/views/widget/widget.h"
 #include "ui/views/window/frame_caption_button.h"
+#include "ui/wm/core/window_animations.h"
 #include "ui/wm/core/window_util.h"
 
 // Keep the functions in this file in alphabetical order.
 namespace ash {
 
-const char kAccessibilityHighContrastShortcut[] =
-    "Accessibility.Shortcuts.CrosHighContrast";
-const char kAccessibilitySpokenFeedbackShortcut[] =
-    "Accessibility.Shortcuts.CrosSpokenFeedback";
-const char kAccessibilityScreenMagnifierShortcut[] =
-    "Accessibility.Shortcuts.CrosScreenMagnifier";
-const char kAccessibilityDockedMagnifierShortcut[] =
-    "Accessibility.Shortcuts.CrosDockedMagnifier";
 const char kAccelWindowSnap[] = "Ash.Accelerators.WindowSnap";
 const char kAccelRotation[] = "Ash.Accelerators.Rotation.Usage";
 const char kAccelActivateDeskByIndex[] = "Ash.Accelerators.ActivateDeskByIndex";
@@ -484,38 +482,44 @@ bool CanShowStylusTools() {
 }
 
 bool CanStartAmbientMode() {
-  return features::IsAmbientModeEnabled();
+  return AmbientClient::Get() && AmbientClient::Get()->IsAmbientModeAllowed();
 }
 
 bool CanSwapPrimaryDisplay() {
   return display::Screen::GetScreen()->GetNumDisplays() > 1;
 }
 
-bool CanToggleCalendar() {
-  return features::IsCalendarViewEnabled();
-}
-
 bool CanToggleDictation() {
   return Shell::Get()->accessibility_controller()->dictation().enabled();
 }
 
 bool CanToggleFloatingWindow() {
-  if (!chromeos::wm::features::IsFloatWindowEnabled()) {
+  if (!chromeos::wm::features::IsWindowLayoutMenuEnabled()) {
+    return false;
+  }
+  return window_util::GetActiveWindow() != nullptr;
+}
+
+bool CanToggleGameDashboard() {
+  if (!features::IsGameDashboardEnabled()) {
     return false;
   }
   aura::Window* window = window_util::GetActiveWindow();
-  return window && chromeos::wm::CanFloatWindow(window);
+  return window && GameDashboardController::CanStart(window);
 }
 
 bool CanToggleMultitaskMenu() {
-  if (!chromeos::wm::features::IsFloatWindowEnabled() ||
-      Shell::Get()->tablet_mode_controller()->InTabletMode()) {
+  if (!chromeos::wm::features::IsWindowLayoutMenuEnabled()) {
     return false;
   }
   aura::Window* window = window_util::GetActiveWindow();
   if (!window) {
     return false;
   }
+  if (Shell::Get()->tablet_mode_controller()->InTabletMode()) {
+    // In tablet mode, the window just has to be able to maximize.
+    return WindowState::Get(window)->CanMaximize();
+  }
   // If the active window has a visible size button, the menu can be opened.
   if (auto* size_button = GetFrameSizeButton(window);
       size_button && size_button->GetVisible()) {
@@ -658,10 +662,6 @@ void DisableCapsLock() {
   Shell::Get()->ime_controller()->SetCapsLockEnabled(false);
 }
 
-void DumpCalendarModel() {
-  Shell::Get()->system_tray_model()->calendar_model()->DebugDump();
-}
-
 void FocusCameraPreview() {
   auto* camera_controller = CaptureModeController::Get()->camera_controller();
   DCHECK(camera_controller);
@@ -903,6 +903,12 @@ void PowerPressed(bool pressed) {
       pressed, base::TimeTicks());
 }
 
+void RecordVolumeSource() {
+  base::UmaHistogramEnumeration(
+      CrasAudioHandler::kOutputVolumeChangedSourceHistogramName,
+      CrasAudioHandler::AudioSettingsChangeSource::kAccelerator);
+}
+
 void RemoveCurrentDesk() {
   if (window_util::IsAnyWindowDragged())
     return;
@@ -1072,6 +1078,7 @@ void ToggleAssignToAllDesk() {
   if (!active_window)
     return;
 
+  // TODO(b/267363112): Allow a floated window to be assigned to all desks.
   // Only children of the desk container should have their assigned to all
   // desks state toggled to avoid interfering with special windows like
   // always-on-top windows, floated windows, etc.
@@ -1145,6 +1152,9 @@ void ToggleAssistant() {
     case AssistantAllowedState::DISALLOWED_BY_KIOSK_MODE:
       // No need to show toast in KIOSK mode.
       return;
+    case AssistantAllowedState::DISALLOWED_BY_NO_BINARY:
+      // No need to show toast.
+      return;
     case AssistantAllowedState::ALLOWED:
       // Nothing need to do if allowed.
       break;
@@ -1200,9 +1210,6 @@ void ToggleDockedMagnifier() {
   const bool is_shortcut_enabled =
       IsAccessibilityShortcutEnabled(prefs::kDockedMagnifierEnabled);
 
-  base::UmaHistogramBoolean(kAccessibilityDockedMagnifierShortcut,
-                            is_shortcut_enabled);
-
   Shell* shell = Shell::Get();
 
   RemoveDockedMagnifierNotification();
@@ -1240,10 +1247,16 @@ void ToggleDockedMagnifier() {
 }
 
 void ToggleFloating() {
-  DCHECK(chromeos::wm::features::IsFloatWindowEnabled());
+  DCHECK(chromeos::wm::features::IsWindowLayoutMenuEnabled());
   aura::Window* window = window_util::GetActiveWindow();
   DCHECK(window);
-  DCHECK(chromeos::wm::CanFloatWindow(window));
+  // `CanFloatWindow` check is placed here rather than
+  // `CanToggleFloatingWindow` as otherwise the bounce would not behave
+  // properly.
+  if (!chromeos::wm::CanFloatWindow(window)) {
+    wm::AnimateWindow(window, wm::WINDOW_ANIMATION_TYPE_BOUNCE);
+    return;
+  }
   Shell::Get()->float_controller()->ToggleFloat(window);
   base::RecordAction(base::UserMetricsAction("Accel_Toggle_Floating"));
 }
@@ -1265,9 +1278,6 @@ void ToggleFullscreenMagnifier() {
   const bool is_shortcut_enabled = IsAccessibilityShortcutEnabled(
       prefs::kAccessibilityScreenMagnifierEnabled);
 
-  base::UmaHistogramBoolean(kAccessibilityScreenMagnifierShortcut,
-                            is_shortcut_enabled);
-
   Shell* shell = Shell::Get();
 
   RemoveFullscreenMagnifierNotification();
@@ -1304,13 +1314,22 @@ void ToggleFullscreenMagnifier() {
   }
 }
 
+void ToggleGameDashboard() {
+  DCHECK(features::IsGameDashboardEnabled());
+  aura::Window* window = window_util::GetActiveWindow();
+  DCHECK(window);
+  auto* controller = Shell::Get()->game_dashboard_controller();
+  if (!controller->IsActive(window)) {
+    controller->Start(window);
+  } else {
+    controller->ToggleMenu(window);
+  }
+}
+
 void ToggleHighContrast() {
   const bool is_shortcut_enabled =
       IsAccessibilityShortcutEnabled(prefs::kAccessibilityHighContrastEnabled);
 
-  base::UmaHistogramBoolean(kAccessibilityHighContrastShortcut,
-                            is_shortcut_enabled);
-
   Shell* shell = Shell::Get();
 
   RemoveHighContrastNotification();
@@ -1347,9 +1366,6 @@ void ToggleSpokenFeedback() {
   const bool is_shortcut_enabled = IsAccessibilityShortcutEnabled(
       prefs::kAccessibilitySpokenFeedbackEnabled);
 
-  base::UmaHistogramBoolean(kAccessibilitySpokenFeedbackShortcut,
-                            is_shortcut_enabled);
-
   Shell* shell = Shell::Get();
   const bool old_value =
       shell->accessibility_controller()->spoken_feedback().enabled();
@@ -1455,9 +1471,18 @@ void ToggleMirrorMode() {
 }
 
 void ToggleMultitaskMenu() {
-  DCHECK(chromeos::wm::features::IsFloatWindowEnabled());
+  DCHECK(chromeos::wm::features::IsWindowLayoutMenuEnabled());
   aura::Window* window = window_util::GetActiveWindow();
   DCHECK(window);
+  if (auto* tablet_mode_controller = Shell::Get()->tablet_mode_controller();
+      tablet_mode_controller->InTabletMode()) {
+    auto* tablet_mode_event_handler =
+        tablet_mode_controller->tablet_mode_window_manager()
+            ->tablet_mode_multitask_menu_event_handler();
+    // Does nothing if the menu is already shown.
+    tablet_mode_event_handler->ShowMultitaskMenu(window);
+    return;
+  }
   auto* frame_view = NonClientFrameViewAsh::Get(window);
   if (!frame_view) {
     // If `window` doesn't have a frame, it must be the multitask menu and have
