@@ -87,6 +87,8 @@ ASH_EXPORT bool CanToggleDictation();
 
 ASH_EXPORT bool CanToggleFloatingWindow();
 
+ASH_EXPORT bool CanToggleGameDashboard();
+
 ASH_EXPORT bool CanToggleMultitaskMenu();
 
 ASH_EXPORT bool CanToggleOverview();
@@ -132,9 +134,6 @@ ASH_EXPORT void CycleUser(CycleUserDirection direction);
 // Disables caps-lock.
 ASH_EXPORT void DisableCapsLock();
 
-// Logs a dump of CalendarModel internal data.
-ASH_EXPORT void DumpCalendarModel();
-
 // Focuses the camera preview if it is present.
 ASH_EXPORT void FocusCameraPreview();
 
@@ -234,6 +233,9 @@ ASH_EXPORT void OpenHelp();
 // Presses power button.
 ASH_EXPORT void PowerPressed(bool pressed);
 
+// Records when the user changes the output volume via keyboard to metrics.
+ASH_EXPORT void RecordVolumeSource();
+
 // Removes the current desk.
 ASH_EXPORT void RemoveCurrentDesk();
 
@@ -318,6 +320,9 @@ ASH_EXPORT void ToggleFullscreen();
 // Turns the fullscreen magnifier mode on or off.
 ASH_EXPORT void ToggleFullscreenMagnifier();
 
+// Toggles the game dashboard on the current window.
+ASH_EXPORT void ToggleGameDashboard();
+
 // Turns the high contrast mode on or off.
 ASH_EXPORT void ToggleHighContrast();
 
