@@ -23,6 +23,7 @@
 #include "ash/public/cpp/accelerators.h"
 #include "base/files/file_path.h"
 #include "base/gtest_prod_util.h"
+#include "base/timer/timer.h"
 #include "ui/base/accelerators/accelerator.h"
 #include "ui/base/accelerators/accelerator_map.h"
 #include "ui/base/ime/ash/input_method_manager.h"
@@ -42,7 +43,8 @@ class ExitWarningHandler;
 class ASH_EXPORT AcceleratorControllerImpl
     : public ui::AcceleratorTarget,
       public AcceleratorController,
-      public input_method::InputMethodManager::Observer {
+      public input_method::InputMethodManager::Observer,
+      public AshAcceleratorConfiguration::Observer {
  public:
   // TestApi is used for tests to get internal implementation details.
   class TestApi {
@@ -61,6 +63,9 @@ class ASH_EXPORT AcceleratorControllerImpl
     // Registers the specified accelerators.
     void RegisterAccelerators(base::span<const AcceleratorData> accelerators);
 
+    // Start observing changes made to the ash accelerator list.
+    void ObserveAcceleratorUpdates();
+
     // Returns whether the action for this accelerator is enabled.
     bool IsActionForAcceleratorEnabled(const ui::Accelerator& accelerator);
 
@@ -111,6 +116,9 @@ class ASH_EXPORT AcceleratorControllerImpl
                           Profile* profile,
                           bool show_message) override;
 
+  // AshAcceleratorConfiguration::Observer overrides:
+  void OnAcceleratorsUpdated() override;
+
   // Registers global keyboard accelerators for the specified target. If
   // multiple targets are registered for any given accelerator, a target
   // registered later has higher priority.
@@ -206,6 +214,9 @@ class ASH_EXPORT AcceleratorControllerImpl
       AcceleratorAction action,
       const ui::Accelerator& accelerator) const;
 
+  // Records when the user changes the output volume via keyboard to metrics.
+  void RecordVolumeSource();
+
   std::unique_ptr<ui::AcceleratorManager> accelerator_manager_;
 
   // A tracker for the current and previous accelerators.
@@ -246,6 +257,10 @@ class ASH_EXPORT AcceleratorControllerImpl
 
   // Prevents the processing of all KB shortcuts in the controller.
   bool prevent_processing_accelerators_ = false;
+
+  // Timer used to prevent the input gain from recording each time the user
+  // presses a volume key while setting the desired volume.
+  base::DelayTimer output_volume_metric_delay_timer_;
 };
 
 }  // namespace ash
