@@ -95,6 +95,21 @@ TEST_F(PartialMagnifierControllerTest, ActiveOnPointerDown) {
   EXPECT_FALSE(GetTestApi().host_widget());
 }
 
+// The magnifier should disappear after a pointer is cancelled while enabled.
+TEST_F(PartialMagnifierControllerTest, InactiveOnPointerCancelled) {
+  ui::test::EventGenerator* event_generator = GetEventGenerator();
+  event_generator->EnterPenPointerMode();
+
+  // While enabled the magnifier is disactivated when the pointer is cancelled.
+  GetController()->SetEnabled(true);
+  event_generator->PressTouch();
+  EXPECT_TRUE(GetTestApi().is_active());
+  EXPECT_TRUE(GetTestApi().host_widget());
+  event_generator->CancelTouch();
+  EXPECT_FALSE(GetTestApi().is_active());
+  EXPECT_FALSE(GetTestApi().host_widget());
+}
+
 // Verifies that nothing bad happens if a second display is disconnected while
 // the magnifier is active.
 TEST_F(PartialMagnifierControllerTest, MultipleDisplays) {
