@@ -9,6 +9,11 @@
 #include <utility>
 #include <vector>
 
+#include "ash/ambient/ambient_constants.h"
+#include "ash/ambient/ambient_managed_slideshow_ui_launcher.h"
+#include "ash/ambient/ambient_ui_launcher.h"
+#include "ash/ambient/ambient_ui_settings.h"
+#include "ash/ambient/ambient_video_ui_launcher.h"
 #include "ash/ambient/ambient_weather_controller.h"
 #include "ash/ambient/metrics/ambient_multi_screen_metrics_recorder.h"
 #include "ash/ambient/model/ambient_animation_photo_config.h"
@@ -23,6 +28,7 @@
 #include "ash/ambient/ui/ambient_view_delegate.h"
 #include "ash/ambient/util/ambient_util.h"
 #include "ash/assistant/model/assistant_interaction_model.h"
+#include "ash/constants/ambient_theme.h"
 #include "ash/constants/ash_features.h"
 #include "ash/login/ui/lock_screen.h"
 #include "ash/public/cpp/ambient/ambient_backend_controller.h"
@@ -43,9 +49,13 @@
 #include "base/feature_list.h"
 #include "base/functional/bind.h"
 #include "base/functional/callback_helpers.h"
+#include "base/logging.h"
 #include "base/memory/weak_ptr.h"
+#include "base/metrics/user_metrics.h"
+#include "base/path_service.h"
 #include "base/time/time.h"
 #include "base/timer/timer.h"
+#include "base/values.h"
 #include "build/buildflag.h"
 #include "cc/paint/skottie_wrapper.h"
 #include "chromeos/ash/components/assistant/buildflags.h"
@@ -119,15 +129,42 @@ PrefService* GetPrimaryUserPrefService() {
   return Shell::Get()->session_controller()->GetPrimaryUserPrefService();
 }
 
-bool IsAmbientModeEnabled() {
-  if (!AmbientClient::Get()->IsAmbientModeAllowed())
+bool IsUserAmbientModeEnabled() {
+  if (!AmbientClient::Get()->IsAmbientModeAllowed()) {
     return false;
+  }
 
   auto* pref_service = GetPrimaryUserPrefService();
   return pref_service &&
          pref_service->GetBoolean(ambient::prefs::kAmbientModeEnabled);
 }
 
+bool IsAmbientModeAllowed() {
+  return ash::features::IsAmbientModeManagedScreensaverEnabled() ||
+         AmbientClient::Get()->IsAmbientModeAllowed();
+}
+
+bool IsAmbientModeManagedScreensaverEnabled() {
+  // TODO(fahadmansoor): Consider adding additional client side checks to
+  // keep behavior consistent with the consumer ambient mode.
+  auto* pref_service = GetPrimaryUserPrefService();
+  return ash::features::IsAmbientModeManagedScreensaverEnabled() &&
+         pref_service &&
+         pref_service->GetBoolean(
+             ambient::prefs::kAmbientModeManagedScreensaverEnabled);
+}
+
+bool IsAmbientModeEnabled() {
+  return IsUserAmbientModeEnabled() || IsAmbientModeManagedScreensaverEnabled();
+}
+
+// Get the cache root path for ambient mode.
+base::FilePath GetCacheRootPath() {
+  base::FilePath home_dir;
+  CHECK(base::PathService::Get(base::DIR_HOME, &home_dir));
+  return home_dir.Append(FILE_PATH_LITERAL(kAmbientModeDirectoryName));
+}
+
 class AmbientWidgetDelegate : public views::WidgetDelegate {
  public:
   AmbientWidgetDelegate() {
@@ -140,51 +177,64 @@ class AmbientWidgetDelegate : public views::WidgetDelegate {
 
 // static
 void AmbientController::RegisterProfilePrefs(PrefRegistrySimple* registry) {
-  if (features::IsAmbientModeEnabled()) {
-    registry->RegisterStringPref(ash::ambient::prefs::kAmbientBackdropClientId,
-                                 std::string());
+  registry->RegisterStringPref(ash::ambient::prefs::kAmbientBackdropClientId,
+                               std::string());
 
-    // Do not sync across devices to allow different usages for different
-    // devices.
-    registry->RegisterBooleanPref(ash::ambient::prefs::kAmbientModeEnabled,
-                                  false);
+  // Do not sync across devices to allow different usages for different
+  // devices.
+  registry->RegisterBooleanPref(ash::ambient::prefs::kAmbientModeEnabled,
+                                false);
 
-    // Used to upload usage metrics. Derived from |AmbientSettings| when
-    // settings are successfully saved by the user. This pref is not displayed
-    // to the user.
-    registry->RegisterIntegerPref(
-        ash::ambient::prefs::kAmbientModePhotoSourcePref,
-        static_cast<int>(ash::ambient::AmbientModePhotoSource::kUnset));
+  // Used to upload usage metrics. Derived from |AmbientSettings| when
+  // settings are successfully saved by the user. This pref is not displayed
+  // to the user.
+  registry->RegisterIntegerPref(
+      ash::ambient::prefs::kAmbientModePhotoSourcePref,
+      static_cast<int>(ash::ambient::AmbientModePhotoSource::kUnset));
 
-    // Used to control the number of seconds of inactivity on lock screen before
-    // showing Ambient mode. This pref is not displayed to the user. Registered
-    // as integer rather than TimeDelta to work with prefs_util.
-    registry->RegisterIntegerPref(
-        ambient::prefs::kAmbientModeLockScreenInactivityTimeoutSeconds,
-        kLockScreenInactivityTimeout.InSeconds());
+  // Used to control the number of seconds of inactivity on lock screen before
+  // showing Ambient mode. This pref is not displayed to the user. Registered
+  // as integer rather than TimeDelta to work with prefs_util.
+  registry->RegisterIntegerPref(
+      ambient::prefs::kAmbientModeLockScreenInactivityTimeoutSeconds,
+      kLockScreenInactivityTimeout.InSeconds());
 
-    // Used to control the number of seconds to lock the session after starting
-    // Ambient mode. This pref is not displayed to the user. Registered as
-    // integer rather than TimeDelta to work with prefs_util.
-    registry->RegisterIntegerPref(
-        ambient::prefs::kAmbientModeLockScreenBackgroundTimeoutSeconds,
-        kLockScreenBackgroundTimeout.InSeconds());
+  // Used to control the number of seconds to lock the session after starting
+  // Ambient mode. This pref is not displayed to the user. Registered as
+  // integer rather than TimeDelta to work with prefs_util.
+  registry->RegisterIntegerPref(
+      ambient::prefs::kAmbientModeLockScreenBackgroundTimeoutSeconds,
+      kLockScreenBackgroundTimeout.InSeconds());
 
-    // Used to control the photo refresh interval in Ambient mode. This pref is
-    // not displayed to the user. Registered as integer rather than TimeDelta to
-    // work with prefs_util.
-    registry->RegisterIntegerPref(
-        ambient::prefs::kAmbientModePhotoRefreshIntervalSeconds,
-        kPhotoRefreshInterval.InSeconds());
+  // Used to control the photo refresh interval in Ambient mode. This pref is
+  // not displayed to the user. Registered as integer rather than TimeDelta to
+  // work with prefs_util.
+  registry->RegisterIntegerPref(
+      ambient::prefs::kAmbientModePhotoRefreshIntervalSeconds,
+      kPhotoRefreshInterval.InSeconds());
 
-    registry->RegisterIntegerPref(
-        ambient::prefs::kAmbientAnimationTheme,
-        static_cast<int>(kDefaultAmbientAnimationTheme));
+  // |ambient::prefs::kAmbientTheme| is for legacy purposes only. It is being
+  // migrated to |ambient::prefs::kAmbientUiSettings|, which is the newer
+  // version of these settings.
+  registry->RegisterIntegerPref(ambient::prefs::kAmbientTheme,
+                                static_cast<int>(kDefaultAmbientTheme));
+  registry->RegisterDictionaryPref(ambient::prefs::kAmbientUiSettings,
+                                   base::Value::Dict());
 
-    registry->RegisterDoublePref(
-        ambient::prefs::kAmbientModeAnimationPlaybackSpeed,
-        kAnimationPlaybackSpeed);
-  }
+  registry->RegisterDoublePref(
+      ambient::prefs::kAmbientModeAnimationPlaybackSpeed,
+      kAnimationPlaybackSpeed);
+
+  registry->RegisterBooleanPref(
+      ash::ambient::prefs::kAmbientModeManagedScreensaverEnabled, false);
+
+  registry->RegisterIntegerPref(
+      ambient::prefs::kAmbientModeManagedScreensaverIdleTimeoutSeconds,
+      kManagedScreensaverInactivityTimeout.InSeconds());
+
+  registry->RegisterIntegerPref(
+      ambient::prefs::kAmbientModeManagedScreensaverImageDisplayIntervalSeconds,
+      kManagedScreensaverImageRefreshInterval.InSeconds());
 }
 
 AmbientController::AmbientController(
@@ -239,12 +289,11 @@ void AmbientController::OnAmbientUiVisibilityChanged(
     case AmbientUiVisibility::kClosed: {
       bool ambient_ui_was_rendering =
           Shell::GetPrimaryRootWindowController()->HasAmbientWidget();
-      CloseAllWidgets(close_widgets_immediately_);
 
       // TODO(wutao): This will clear the image cache currently. It will not
       // work with `kHidden` if the token has expired and ambient mode is shown
       // again.
-      StopRefreshingImages();
+      StopScreensaver();
 
       // Should do nothing if the wake lock has already been released.
       ReleaseWakeLock();
@@ -262,7 +311,7 @@ void AmbientController::OnAmbientUiVisibilityChanged(
       // ambient mode has just started.
       if (start_time_) {
         auto elapsed = base::Time::Now() - start_time_.value();
-        AmbientAnimationTheme theme = GetCurrentTheme();
+        AmbientTheme theme = GetCurrentUiSettings().theme();
         DVLOG(2) << "Exit ambient mode. Elapsed time: " << elapsed;
         ambient::RecordAmbientModeTimeElapsed(
             elapsed, Shell::Get()->IsInTabletMode(), theme);
@@ -322,7 +371,9 @@ void AmbientController::OnLockStateChanged(bool locked) {
 
   // Reset image failures to allow retrying ambient mode after lock state
   // changes.
-  GetAmbientBackendModel()->ResetImageFailures();
+  if (GetAmbientBackendModel()) {
+    GetAmbientBackendModel()->ResetImageFailures();
+  }
 
   // We have 3 options to manage the token for lock screen. Here use option 1.
   // 1. Request only one time after entering lock screen. We will use it once
@@ -353,8 +404,7 @@ void AmbientController::OnLockStateChanged(bool locked) {
 
 void AmbientController::OnActiveUserPrefServiceChanged(
     PrefService* pref_service) {
-  if (!AmbientClient::Get()->IsAmbientModeAllowed() ||
-      GetPrimaryUserPrefService() != pref_service) {
+  if (!IsAmbientModeAllowed() || GetPrimaryUserPrefService() != pref_service) {
     return;
   }
 
@@ -372,6 +422,16 @@ void AmbientController::OnActiveUserPrefServiceChanged(
                           weak_ptr_factory_.GetWeakPtr()));
 
   OnEnabledPrefChanged();
+
+  if (ash::features::IsAmbientModeManagedScreensaverEnabled()) {
+    pref_change_registrar_->Add(
+        ambient::prefs::kAmbientModeManagedScreensaverEnabled,
+        base::BindRepeating(
+            &AmbientController::OnManagedScreensaverEnabledPrefChanged,
+            weak_ptr_factory_.GetWeakPtr()));
+
+    OnManagedScreensaverEnabledPrefChanged();
+  }
 }
 
 void AmbientController::OnPowerStatusChanged() {
@@ -411,7 +471,8 @@ void AmbientController::ScreenIdleStateChanged(
       return;
 
     // Do not show UI if loading images was unsuccessful.
-    if (GetAmbientBackendModel()->ImageLoadingFailed()) {
+    if (GetAmbientBackendModel() &&
+        GetAmbientBackendModel()->ImageLoadingFailed()) {
       VLOG(1) << "Skipping ambient mode activation due to prior failure";
       GetAmbientBackendModel()->ResetImageFailures();
       return;
@@ -468,8 +529,8 @@ void AmbientController::OnAuthScanDone(
 
 void AmbientController::OnUserActivity(const ui::Event* event) {
   // The following events are handled separately so that we can consume them.
-  if (event->IsMouseEvent() || event->IsTouchEvent() || event->IsKeyEvent() ||
-      event->IsFlingScrollEvent()) {
+  if (IsShown() && (event->IsMouseEvent() || event->IsTouchEvent() ||
+                    event->IsKeyEvent() || event->IsFlingScrollEvent())) {
     return;
   }
   // While |kPreview| is loading, don't |DismissUI| on user activity.
@@ -493,19 +554,17 @@ void AmbientController::OnKeyEvent(ui::KeyEvent* event) {
 }
 
 void AmbientController::OnMouseEvent(ui::MouseEvent* event) {
-  // Prevent dispatching mouse event to the windows behind screen saver.
-  event->StopPropagation();
   // |DismissUI| on actual mouse move only if the screen saver widget is shown
   // (images are downloaded).
   if (event->type() == ui::ET_MOUSE_MOVED) {
-    if (last_mouse_event_was_move_ &&
-        Shell::GetPrimaryRootWindowController()->HasAmbientWidget()) {
-      DismissUI();
-    }
+    MaybeDismissUIOnMouseMove();
     last_mouse_event_was_move_ = true;
     return;
   }
 
+  // Prevent dispatching mouse event to the windows behind screen saver.
+  // Let move event pass through, so that it clears hover states.
+  event->StopPropagation();
   if (event->IsAnyButton()) {
     DismissUI();
   }
@@ -551,6 +610,7 @@ void AmbientController::StartScreenSaverPreview() {
   }
 
   ambient_ui_model_.SetUiVisibility(AmbientUiVisibility::kPreview);
+  base::RecordAction(base::UserMetricsAction(kScreenSaverPreviewUserAction));
 }
 
 void AmbientController::ShowHiddenUi() {
@@ -579,6 +639,9 @@ void AmbientController::CloseUi(bool immediately) {
 
   close_widgets_immediately_ = immediately;
   ambient_ui_model_.SetUiVisibility(AmbientUiVisibility::kClosed);
+  if (!Shell::Get()->IsInTabletMode()) {
+    Shell::Get()->cursor_manager()->ShowCursor();
+  }
 }
 
 void AmbientController::ToggleInSessionUi() {
@@ -638,57 +701,127 @@ void AmbientController::CloseAllWidgets(bool immediately) {
   }
 }
 
+void AmbientController::AddManagedScreensaverPolicyPrefObservers() {
+  pref_change_registrar_->Add(
+      ambient::prefs::kAmbientModeManagedScreensaverIdleTimeoutSeconds,
+      base::BindRepeating(
+          &AmbientController::
+              OnManagedScreensaverLockScreenIdleTimeoutPrefChanged,
+          weak_ptr_factory_.GetWeakPtr()));
+
+  pref_change_registrar_->Add(
+      ambient::prefs::kAmbientModeManagedScreensaverImageDisplayIntervalSeconds,
+      base::BindRepeating(
+          &AmbientController::
+              OnManagedScreensaverPhotoRefreshIntervalPrefChanged,
+          weak_ptr_factory_.GetWeakPtr()));
+
+  OnManagedScreensaverLockScreenIdleTimeoutPrefChanged();
+  OnManagedScreensaverPhotoRefreshIntervalPrefChanged();
+}
+
+void AmbientController::RemoveAmbientModeSettingsPrefObservers() {
+  for (const auto* pref_name :
+       {ambient::prefs::kAmbientModeLockScreenBackgroundTimeoutSeconds,
+        ambient::prefs::kAmbientModeLockScreenInactivityTimeoutSeconds,
+        ambient::prefs::kAmbientModePhotoRefreshIntervalSeconds,
+        ambient::prefs::kAmbientUiSettings,
+        ambient::prefs::kAmbientModeAnimationPlaybackSpeed,
+        ambient::prefs::kAmbientModeManagedScreensaverIdleTimeoutSeconds,
+        ambient::prefs::
+            kAmbientModeManagedScreensaverImageDisplayIntervalSeconds}) {
+    if (pref_change_registrar_->IsObserved(pref_name)) {
+      pref_change_registrar_->Remove(pref_name);
+    }
+  }
+}
+
+void AmbientController::OnManagedScreensaverLockScreenIdleTimeoutPrefChanged() {
+  DCHECK(GetPrimaryUserPrefService());
+  ambient_ui_model_.SetLockScreenInactivityTimeout(
+      base::Seconds(GetPrimaryUserPrefService()->GetInteger(
+          ambient::prefs::kAmbientModeManagedScreensaverIdleTimeoutSeconds)));
+}
+
+void AmbientController::OnManagedScreensaverPhotoRefreshIntervalPrefChanged() {
+  DCHECK(GetPrimaryUserPrefService());
+  ambient_ui_model_.SetPhotoRefreshInterval(
+      base::Seconds(GetPrimaryUserPrefService()->GetInteger(
+          ambient::prefs::
+              kAmbientModeManagedScreensaverImageDisplayIntervalSeconds)));
+}
+
+void AmbientController::OnManagedScreensaverEnabledPrefChanged() {
+  ResetAmbientControllerResources();
+  OnEnabledPrefChanged();
+
+  if (IsAmbientModeManagedScreensaverEnabled()) {
+    RemoveAmbientModeSettingsPrefObservers();
+    AddManagedScreensaverPolicyPrefObservers();
+    return;
+  }
+}
+
+void AmbientController::AddAmbientModeUserSettingsPolicyPrefObservers() {
+  pref_change_registrar_->Add(
+      ambient::prefs::kAmbientModeLockScreenInactivityTimeoutSeconds,
+      base::BindRepeating(
+          &AmbientController::OnLockScreenInactivityTimeoutPrefChanged,
+          weak_ptr_factory_.GetWeakPtr()));
+
+  pref_change_registrar_->Add(
+      ambient::prefs::kAmbientModeLockScreenBackgroundTimeoutSeconds,
+      base::BindRepeating(
+          &AmbientController::OnLockScreenBackgroundTimeoutPrefChanged,
+          weak_ptr_factory_.GetWeakPtr()));
+
+  pref_change_registrar_->Add(
+      ambient::prefs::kAmbientModePhotoRefreshIntervalSeconds,
+      base::BindRepeating(&AmbientController::OnPhotoRefreshIntervalPrefChanged,
+                          weak_ptr_factory_.GetWeakPtr()));
+
+  pref_change_registrar_->Add(
+      ambient::prefs::kAmbientUiSettings,
+      base::BindRepeating(&AmbientController::OnAmbientUiSettingsChanged,
+                          weak_ptr_factory_.GetWeakPtr()));
+
+  pref_change_registrar_->Add(
+      ambient::prefs::kAmbientModeAnimationPlaybackSpeed,
+      base::BindRepeating(&AmbientController::OnAnimationPlaybackSpeedChanged,
+                          weak_ptr_factory_.GetWeakPtr()));
+
+  // Trigger the callbacks manually the first time to init AmbientUiModel.
+  OnLockScreenInactivityTimeoutPrefChanged();
+  OnLockScreenBackgroundTimeoutPrefChanged();
+  OnPhotoRefreshIntervalPrefChanged();
+  OnAnimationPlaybackSpeedChanged();
+}
+
 void AmbientController::OnEnabledPrefChanged() {
   if (IsAmbientModeEnabled()) {
+    if (is_initialized_) {
+      LOG(WARNING) << "Ambient mode is already enabled";
+      return;
+    }
     DVLOG(1) << "Ambient mode enabled";
+    // TODO(b/274165045): Remove this temporary way of circulating the video
+    // theme throughout the system once the hub supports the video theme. This
+    // is just for experimentation purposes until then.
+    SetUiSettingsForExperimentation();
 
-    pref_change_registrar_->Add(
-        ambient::prefs::kAmbientModeLockScreenInactivityTimeoutSeconds,
-        base::BindRepeating(
-            &AmbientController::OnLockScreenInactivityTimeoutPrefChanged,
-            weak_ptr_factory_.GetWeakPtr()));
+    AddAmbientModeUserSettingsPolicyPrefObservers();
 
-    pref_change_registrar_->Add(
-        ambient::prefs::kAmbientModeLockScreenBackgroundTimeoutSeconds,
-        base::BindRepeating(
-            &AmbientController::OnLockScreenBackgroundTimeoutPrefChanged,
-            weak_ptr_factory_.GetWeakPtr()));
-
-    pref_change_registrar_->Add(
-        ambient::prefs::kAmbientModePhotoRefreshIntervalSeconds,
-        base::BindRepeating(
-            &AmbientController::OnPhotoRefreshIntervalPrefChanged,
-            weak_ptr_factory_.GetWeakPtr()));
-
-    pref_change_registrar_->Add(
-        ambient::prefs::kAmbientAnimationTheme,
-        base::BindRepeating(&AmbientController::OnAnimationThemePrefChanged,
-                            weak_ptr_factory_.GetWeakPtr()));
-
-    pref_change_registrar_->Add(
-        ambient::prefs::kAmbientModeAnimationPlaybackSpeed,
-        base::BindRepeating(&AmbientController::OnAnimationPlaybackSpeedChanged,
-                            weak_ptr_factory_.GetWeakPtr()));
-
-    // Trigger the callbacks manually the first time to init AmbientUiModel.
-    OnLockScreenInactivityTimeoutPrefChanged();
-    OnLockScreenBackgroundTimeoutPrefChanged();
-    OnPhotoRefreshIntervalPrefChanged();
-    OnAnimationThemePrefChanged();
-    OnAnimationPlaybackSpeedChanged();
-
-    DCHECK(AmbientClient::Get());
-    ambient_photo_controller_ = std::make_unique<AmbientPhotoController>(
-        *AmbientClient::Get(), access_token_controller_, delegate_,
-        // The type of photo config specified here is actually irrelevant as it
-        // always gets reset with the correct configuration anyways in
-        // StartRefreshingImages() before ambient mode starts.
-        CreateAmbientSlideshowPhotoConfig());
+    photo_cache_ = AmbientPhotoCache::Create(
+        GetCacheRootPath().Append(
+            FILE_PATH_LITERAL(kAmbientModeCacheDirectoryName)),
+        *AmbientClient::Get(), access_token_controller_);
+    backup_photo_cache_ = AmbientPhotoCache::Create(
+        GetCacheRootPath().Append(
+            FILE_PATH_LITERAL(kAmbientModeBackupCacheDirectoryName)),
+        *AmbientClient::Get(), access_token_controller_);
+    CreateUiLauncher();
 
     ambient_ui_model_observer_.Observe(&ambient_ui_model_);
-
-    ambient_backend_model_observer_.Observe(GetAmbientBackendModel());
-
     auto* power_manager_client = chromeos::PowerManagerClient::Get();
     DCHECK(power_manager_client);
     power_manager_client_observer_.Observe(power_manager_client);
@@ -698,35 +831,34 @@ void AmbientController::OnEnabledPrefChanged() {
 
     ambient_animation_progress_tracker_ =
         std::make_unique<AmbientAnimationProgressTracker>();
+
+    is_initialized_ = true;
   } else {
     DVLOG(1) << "Ambient mode disabled";
-
-    CloseUi();
-
-    ambient_animation_progress_tracker_.reset();
-
-    for (const auto* pref_name :
-         {ambient::prefs::kAmbientModeLockScreenBackgroundTimeoutSeconds,
-          ambient::prefs::kAmbientModeLockScreenInactivityTimeoutSeconds,
-          ambient::prefs::kAmbientModePhotoRefreshIntervalSeconds,
-          ambient::prefs::kAmbientAnimationTheme,
-          ambient::prefs::kAmbientModeAnimationPlaybackSpeed}) {
-      if (pref_change_registrar_->IsObserved(pref_name))
-        pref_change_registrar_->Remove(pref_name);
-    }
-
-    ambient_ui_model_observer_.Reset();
-    ambient_backend_model_observer_.Reset();
-    power_manager_client_observer_.Reset();
-
-    if (fingerprint_observer_receiver_.is_bound())
-      fingerprint_observer_receiver_.reset();
-
-    ambient_photo_controller_.reset();
-    current_theme_from_pref_.reset();
+    ResetAmbientControllerResources();
   }
 }
 
+void AmbientController::ResetAmbientControllerResources() {
+  CloseUi();
+
+  ambient_animation_progress_tracker_.reset();
+
+  RemoveAmbientModeSettingsPrefObservers();
+
+  ambient_ui_model_observer_.Reset();
+  power_manager_client_observer_.Reset();
+
+  DestroyUiLauncher();
+  backup_photo_cache_.reset();
+  photo_cache_.reset();
+
+  if (fingerprint_observer_receiver_.is_bound()) {
+    fingerprint_observer_receiver_.reset();
+  }
+  is_initialized_ = false;
+}
+
 void AmbientController::OnLockScreenInactivityTimeoutPrefChanged() {
   auto* pref_service = GetPrimaryUserPrefService();
   if (!pref_service)
@@ -757,51 +889,31 @@ void AmbientController::OnPhotoRefreshIntervalPrefChanged() {
           ambient::prefs::kAmbientModePhotoRefreshIntervalSeconds)));
 }
 
-void AmbientController::OnAnimationThemePrefChanged() {
-  absl::optional<AmbientAnimationTheme> previous_theme_from_pref =
-      current_theme_from_pref_;
-  DCHECK(GetPrimaryUserPrefService());
-  int current_theme_as_int = GetPrimaryUserPrefService()->GetInteger(
-      ambient::prefs::kAmbientAnimationTheme);
-  // Gracefully handle pref having invalid value in case pref storage is
-  // corrupted somehow.
-  if (current_theme_as_int < 0 ||
-      current_theme_as_int >
-          static_cast<int>(AmbientAnimationTheme::kMaxValue)) {
-    LOG(WARNING) << "Loaded invalid ambient theme from pref storage: "
-                 << current_theme_as_int << ". Default to "
-                 << ToString(kDefaultAmbientAnimationTheme);
-    current_theme_as_int = static_cast<int>(kDefaultAmbientAnimationTheme);
-  }
-  current_theme_from_pref_ =
-      static_cast<AmbientAnimationTheme>(current_theme_as_int);
+void AmbientController::OnAmbientUiSettingsChanged() {
+  DVLOG(4) << "AmbientUiSettings changed to "
+           << GetCurrentUiSettings().ToString();
+  // For a given topic category, the topics downloaded from IMAX and saved to
+  // cache differ from theme to theme:
+  // 1) Slideshow mode keeps primary/related photos paired within a topic,
+  //    whereas animated themes split the photos into 2 separate topics.
+  // 2) The resolution of the photos downloaded from FIFE may differ between
+  //    themes, depending on the image assets' sizes in the animation file.
+  // For this reason, it is better to not re-use the cache when switching
+  // between themes.
+  //
+  // There are corner cases here where the theme may change and the program
+  // crashes before the cache gets cleared below. This is intentionally not
+  // accounted for because it's not worth the added complexity. If this
+  // should happen, re-using the cache will still work without fatal behavior.
+  // The UI may just not be optimal. Furthermore, the cache gradually gets
+  // overwritten with topics reflecting the new theme anyways, so ambient mode
+  // should not be stuck with a mismatched cache indefinitely.
+  CHECK(photo_cache_);
+  photo_cache_->Clear();
 
-  if (previous_theme_from_pref.has_value()) {
-    DVLOG(4) << "AmbientAnimationTheme changed from "
-             << ToString(*previous_theme_from_pref) << " to "
-             << ToString(*current_theme_from_pref_);
-    // For a given topic category, the topics downloaded from IMAX and saved to
-    // cache differ from theme to theme:
-    // 1) Slideshow mode keeps primary/related photos paired within a topic,
-    //    whereas animated themes split the photos into 2 separate topics.
-    // 2) The resolution of the photos downloaded from FIFE may differ between
-    //    themes, depending on the image assets' sizes in the animation file.
-    // For this reason, it is better to not re-use the cache when switching
-    // between themes.
-    //
-    // There are corner cases here where the theme may change and the program
-    // crashes before the cache gets cleared below. This is intentionally not
-    // accounted for because it's not worth the added complexity. If this
-    // should happen, re-using the cache will still work without fatal behavior.
-    // The UI may just not be optimal. Furthermore, the cache gradually gets
-    // overwritten with topics reflecting the new theme anyways, so ambient mode
-    // should not be stuck with a mismatched cache indefinitely.
-    DCHECK(ambient_photo_controller_);
-    ambient_photo_controller_->ClearCache();
-  } else {
-    DVLOG(4) << "AmbientAnimationTheme initialized to "
-             << ToString(*current_theme_from_pref_);
-  }
+  // The |AmbientUiLauncher| implementation to use is largely dependent on
+  // the current |AmbientUiSettings|, so this needs to be recreated.
+  CreateUiLauncher();
 }
 
 void AmbientController::OnAnimationPlaybackSpeedChanged() {
@@ -814,6 +926,14 @@ void AmbientController::OnAnimationPlaybackSpeedChanged() {
 void AmbientController::RequestAccessToken(
     AmbientAccessTokenController::AccessTokenCallback callback,
     bool may_refresh_token_on_lock) {
+  // Do not request access tokens when the ambient mode is in the managed mode
+  // as we do not want to rely on any user information .
+  if (IsAmbientModeManagedScreensaverEnabled()) {
+    // Consume the callback to be resilient against dependencies on the callback
+    // in the future.
+    std::move(callback).Run("", "");
+    return;
+  }
   access_token_controller_.RequestAccessToken(std::move(callback),
                                               may_refresh_token_on_lock);
 }
@@ -841,6 +961,15 @@ void AmbientController::DismissUI() {
 }
 
 AmbientBackendModel* AmbientController::GetAmbientBackendModel() {
+  if (ambient_ui_launcher_) {
+    // This can legitimately be null. Some ambient UIs do not use photos at all
+    // and hence, do not have an active |AmbientBackendModel|.
+    // TODO(b/274164306): Move |AmbientBackendModel| references completely out
+    // of |AmbientController|. The business logic should be migrated elsewhere
+    // (likely somewhere within an |AmbientUiLauncher| implementation).
+    return ambient_ui_launcher_->GetAmbientBackendModel();
+  }
+
   DCHECK(ambient_photo_controller_);
   return ambient_photo_controller_->ambient_backend_model();
 }
@@ -860,12 +989,22 @@ void AmbientController::OnImagesFailed() {
 
 std::unique_ptr<views::Widget> AmbientController::CreateWidget(
     aura::Window* container) {
-  AmbientAnimationTheme current_theme = GetCurrentTheme();
-  auto container_view = std::make_unique<AmbientContainerView>(
-      &delegate_, ambient_animation_progress_tracker_.get(),
-      AmbientAnimationStaticResources::Create(current_theme,
-                                              /*serializable=*/true),
-      multi_screen_metrics_recorder_.get(), frame_rate_controller_.get());
+  AmbientTheme current_theme = GetCurrentUiSettings().theme();
+  std::unique_ptr<AmbientContainerView> container_view;
+  if (ambient_ui_launcher_) {
+    container_view = std::make_unique<AmbientContainerView>(
+        current_theme, ambient_ui_launcher_->CreateView(),
+        multi_screen_metrics_recorder_.get());
+  } else {
+    // TODO(b/274164306): Everything should use
+    // |AmbientUiLauncher::CreateView()| when slideshow and animation themes
+    // are migrated to AmbientUiLauncher.
+    container_view = std::make_unique<AmbientContainerView>(
+        &delegate_, ambient_animation_progress_tracker_.get(),
+        AmbientAnimationStaticResources::Create(current_theme,
+                                                /*serializable=*/true),
+        multi_screen_metrics_recorder_.get(), frame_rate_controller_.get());
+  }
   auto* widget_delegate = new AmbientWidgetDelegate();
   widget_delegate->SetInitiallyFocusedView(container_view.get());
 
@@ -909,6 +1048,9 @@ std::unique_ptr<views::Widget> AmbientController::CreateWidget(
 }
 
 void AmbientController::CreateAndShowWidgets() {
+  if (ambient_ui_model_.ui_visibility() == AmbientUiVisibility::kPreview) {
+    preview_widget_created_at_ = base::Time::Now();
+  }
   // Hide cursor.
   Shell::Get()->cursor_manager()->HideCursor();
   for (auto* root_window_controller :
@@ -924,12 +1066,12 @@ void AmbientController::StartRefreshingImages() {
   // model/controller with the appropriate config each time before calling
   // StartScreenUpdate().
   DCHECK(!ambient_photo_controller_->IsScreenUpdateActive());
-  AmbientAnimationTheme current_theme = GetCurrentTheme();
+  AmbientTheme current_theme = GetCurrentUiSettings().theme();
   DVLOG(4) << "Loaded ambient theme " << ToString(current_theme);
 
   AmbientPhotoConfig photo_config;
   std::unique_ptr<AmbientTopicQueue::Delegate> topic_queue_delegate;
-  if (current_theme == AmbientAnimationTheme::kSlideshow) {
+  if (current_theme == AmbientTheme::kSlideshow) {
     photo_config = CreateAmbientSlideshowPhotoConfig();
     topic_queue_delegate =
         std::make_unique<AmbientTopicQueueSlideshowDelegate>();
@@ -948,15 +1090,21 @@ void AmbientController::StartRefreshingImages() {
   ambient_photo_controller_->StartScreenUpdate(std::move(topic_queue_delegate));
 }
 
-void AmbientController::StopRefreshingImages() {
+void AmbientController::StopScreensaver() {
+  CloseAllWidgets(close_widgets_immediately_);
+  if (ambient_ui_launcher_) {
+    ambient_ui_launcher_->Finalize();
+    return;
+  }
   DCHECK(ambient_photo_controller_);
   ambient_photo_controller_->StopScreenUpdate();
 }
 
 void AmbientController::MaybeStartScreenSaver() {
   // The screensaver may have already been started.
-  if (ambient_photo_controller_->IsScreenUpdateActive())
+  if (IsUiLauncherActive()) {
     return;
+  }
 
   if (!user_activity_observer_.IsObserving())
     user_activity_observer_.Observe(ui::UserActivityDetector::Get());
@@ -965,18 +1113,107 @@ void AmbientController::MaybeStartScreenSaver() {
   AssistantInteractionController::Get()->GetModel()->AddObserver(this);
 
   multi_screen_metrics_recorder_ =
-      std::make_unique<AmbientMultiScreenMetricsRecorder>(GetCurrentTheme());
+      std::make_unique<AmbientMultiScreenMetricsRecorder>(
+          GetCurrentUiSettings().theme());
   frame_rate_controller_ =
       std::make_unique<AmbientAnimationFrameRateController>(
           Shell::Get()->frame_throttling_controller());
 
   Shell::Get()->AddPreTargetHandler(this);
-  StartRefreshingImages();
+  if (ambient_ui_launcher_) {
+    ambient_ui_launcher_->Initialize(
+        base::BindOnce(&AmbientController::CreateAndShowWidgets,
+                       weak_ptr_factory_.GetWeakPtr()));
+  } else {
+    StartRefreshingImages();
+  }
 }
 
-AmbientAnimationTheme AmbientController::GetCurrentTheme() const {
-  DCHECK(current_theme_from_pref_);
-  return *current_theme_from_pref_;
+AmbientUiSettings AmbientController::GetCurrentUiSettings() const {
+  CHECK(GetPrimaryUserPrefService());
+  return AmbientUiSettings::ReadFromPrefService(*GetPrimaryUserPrefService());
+}
+
+void AmbientController::SetUiSettingsForExperimentation() {
+  if (features::IsTimeOfDayScreenSaverEnabled()) {
+    CHECK(GetPrimaryUserPrefService());
+    AmbientUiSettings(AmbientTheme::kVideo,
+                      features::kTimeOfDayScreenSaverVideo.Get())
+        .WriteToPrefService(*GetPrimaryUserPrefService());
+  }
+}
+
+void AmbientController::MaybeDismissUIOnMouseMove() {
+  // If the move was not an actual mouse move event or the screen saver widget
+  // is not shown yet (images are not downloaded), don't dismiss.
+  if (!last_mouse_event_was_move_ ||
+      !Shell::GetPrimaryRootWindowController()->HasAmbientWidget()) {
+    return;
+  }
+
+  // In preview mode, don't dismiss until the timer stops running (avoids
+  // accidental dismissal).
+  if (ambient_ui_model_.ui_visibility() == AmbientUiVisibility::kPreview) {
+    auto elapsed = base::Time::Now() - preview_widget_created_at_;
+    if (elapsed < kDismissPreviewOnMouseMoveDelay) {
+      return;
+    }
+  }
+  DismissUI();
+}
+
+void AmbientController::CreateUiLauncher() {
+  if (IsUiLauncherActive()) {
+    // There are no known use cases where the AmbientUiSettings selected by the
+    // user can change while in the middle of an ambient session, but this is
+    // handled gracefully just in case.
+    LOG(DFATAL) << "Cannot reset the AmbientUiLauncher while it is active";
+    return;
+  }
+
+  DestroyUiLauncher();
+
+  if (IsAmbientModeManagedScreensaverEnabled()) {
+    ambient_ui_launcher_ =
+        std::make_unique<AmbientManagedSlideshowUiLauncher>(&delegate_);
+  } else if (GetCurrentUiSettings().theme() == AmbientTheme::kVideo) {
+    ambient_ui_launcher_ =
+        std::make_unique<AmbientVideoUiLauncher>(GetPrimaryUserPrefService());
+  } else {
+    // TODO(b/274164306): Remove when slideshow and animation themes are
+    // migrated to AmbientUiLauncher.
+    CHECK(photo_cache_);
+    CHECK(backup_photo_cache_);
+    ambient_photo_controller_ = std::make_unique<AmbientPhotoController>(
+        *photo_cache_, *backup_photo_cache_, delegate_,
+        // The type of photo config specified here is actually irrelevant as
+        // it always gets reset with the correct configuration anyways in
+        // StartRefreshingImages() before ambient mode starts.
+        CreateAmbientSlideshowPhotoConfig());
+    // The new UiLauncher API adds backend model observers in its
+    // implementation and thus the observer is not required when using the new
+    // codepath.
+    // TODO(esum) Get rid the ambient_backend_model_observer_ and
+    // corresponding methods once other photo controllers are migrated to the
+    // new API.
+    ambient_backend_model_observer_.Observe(GetAmbientBackendModel());
+  }
+}
+
+void AmbientController::DestroyUiLauncher() {
+  ambient_ui_launcher_.reset();
+  // TODO(b/274164306): Remove when slideshow and animation themes are migrated
+  // to AmbientUiLauncher.
+  ambient_backend_model_observer_.Reset();
+  ambient_photo_controller_.reset();
+}
+
+bool AmbientController::IsUiLauncherActive() const {
+  return (ambient_ui_launcher_ && ambient_ui_launcher_->IsActive()) ||
+         // TODO(b/274164306): Remove when slideshow and animation themes are
+         // migrated to AmbientUiLauncher.
+         (ambient_photo_controller_ &&
+          ambient_photo_controller_->IsScreenUpdateActive());
 }
 
 }  // namespace ash
