@@ -10,14 +10,16 @@
 #include <vector>
 
 #include "ash/ambient/ambient_access_token_controller.h"
+#include "ash/ambient/ambient_photo_cache.h"
 #include "ash/ambient/ambient_photo_controller.h"
+#include "ash/ambient/ambient_ui_launcher.h"
 #include "ash/ambient/ambient_view_delegate_impl.h"
 #include "ash/ambient/model/ambient_backend_model.h"
 #include "ash/ambient/model/ambient_backend_model_observer.h"
 #include "ash/ambient/ui/ambient_view_delegate.h"
 #include "ash/ash_export.h"
 #include "ash/assistant/model/assistant_interaction_model_observer.h"
-#include "ash/constants/ambient_animation_theme.h"
+#include "ash/constants/ambient_theme.h"
 #include "ash/public/cpp/ambient/ambient_ui_model.h"
 #include "ash/public/cpp/screen_backlight_observer.h"
 #include "ash/public/cpp/session/session_observer.h"
@@ -48,12 +50,16 @@ class PrefRegistrySimple;
 
 namespace ash {
 
+// Delay for dismissing screensaver preview on mouse move.
+constexpr base::TimeDelta kDismissPreviewOnMouseMoveDelay = base::Seconds(3);
+
 class AmbientAnimationFrameRateController;
 class AmbientAnimationProgressTracker;
 class AmbientBackendController;
 class AmbientContainerView;
 class AmbientMultiScreenMetricsRecorder;
 class AmbientPhotoController;
+class AmbientUiSettings;
 class AmbientWeatherController;
 
 // Class to handle all ambient mode functionalities.
@@ -105,6 +111,7 @@ class ASH_EXPORT AmbientController
       override;
   void OnSessionFailed() override {}
   void OnRestarted() override {}
+  void OnStatusChanged(device::mojom::BiometricsManagerStatus state) override {}
   void OnEnrollScanDone(device::mojom::ScanResult scan_result,
                         bool enroll_session_complete,
                         int percent_complete) override {}
@@ -147,8 +154,8 @@ class ASH_EXPORT AmbientController
     return ambient_backend_controller_.get();
   }
 
-  AmbientPhotoController* ambient_photo_controller() {
-    return ambient_photo_controller_.get();
+  AmbientUiLauncher* ambient_ui_launcher() {
+    return ambient_ui_launcher_.get();
   }
 
   AmbientWeatherController* ambient_weather_controller() {
@@ -159,6 +166,8 @@ class ASH_EXPORT AmbientController
 
   AmbientViewDelegate* ambient_view_delegate() { return &delegate_; }
 
+  AmbientPhotoCache* ambient_photo_cache() { return photo_cache_.get(); }
+
   void set_backend_controller_for_testing(
       std::unique_ptr<AmbientBackendController> backend_controller) {
     ambient_backend_controller_ = std::move(backend_controller);
@@ -171,6 +180,14 @@ class ASH_EXPORT AmbientController
                            BindsObserversWhenAmbientEnabled);
   FRIEND_TEST_ALL_PREFIXES(AmbientControllerTest, BindsObserversWhenAmbientOn);
 
+  AmbientPhotoController* ambient_photo_controller() {
+    return ambient_photo_controller_.get();
+  }
+
+  AmbientPhotoCache* get_backup_photo_cache_for_testing() {
+    return backup_photo_cache_.get();
+  }
+
   // Hide or close Ambient mode UI.
   void DismissUI();
 
@@ -183,9 +200,11 @@ class ASH_EXPORT AmbientController
   void CreateAndShowWidgets();
 
   void StartRefreshingImages();
-  void StopRefreshingImages();
+  void StopScreensaver();
   void MaybeStartScreenSaver();
-  AmbientAnimationTheme GetCurrentTheme() const;
+  void MaybeDismissUIOnMouseMove();
+  AmbientUiSettings GetCurrentUiSettings() const;
+  void SetUiSettingsForExperimentation();
 
   // Invoked when the auto-show timer in |InactivityMonitor| gets fired after
   // device being inactive for a specific amount of time.
@@ -200,14 +219,33 @@ class ASH_EXPORT AmbientController
 
   void CloseAllWidgets(bool immediately);
 
+  // Removes any and all ambient mode ui model related settings pref observers
+  void RemoveAmbientModeSettingsPrefObservers();
+
+  // Adds/Removes managed pref observers
+  void AddManagedScreensaverPolicyPrefObservers();
+  void AddAmbientModeUserSettingsPolicyPrefObservers();
+
   // Invoked when the Ambient mode prefs state changes.
   void OnEnabledPrefChanged();
   void OnLockScreenInactivityTimeoutPrefChanged();
   void OnLockScreenBackgroundTimeoutPrefChanged();
   void OnPhotoRefreshIntervalPrefChanged();
-  void OnAnimationThemePrefChanged();
+  void OnAmbientUiSettingsChanged();
   void OnAnimationPlaybackSpeedChanged();
 
+  // Resets the resources allocated by the ambient controller.
+  void ResetAmbientControllerResources();
+
+  // Invoked when preferences change via policy updates.
+  void OnManagedScreensaverEnabledPrefChanged();
+  void OnManagedScreensaverLockScreenIdleTimeoutPrefChanged();
+  void OnManagedScreensaverPhotoRefreshIntervalPrefChanged();
+
+  void CreateUiLauncher();
+  void DestroyUiLauncher();
+  bool IsUiLauncherActive() const;
+
   AmbientAccessTokenController* access_token_controller_for_testing() {
     return &access_token_controller_;
   }
@@ -217,6 +255,8 @@ class ASH_EXPORT AmbientController
 
   AmbientAccessTokenController access_token_controller_;
   std::unique_ptr<AmbientBackendController> ambient_backend_controller_;
+  std::unique_ptr<AmbientPhotoCache> photo_cache_;
+  std::unique_ptr<AmbientPhotoCache> backup_photo_cache_;
   std::unique_ptr<AmbientPhotoController> ambient_photo_controller_;
   std::unique_ptr<AmbientWeatherController> ambient_weather_controller_;
   std::unique_ptr<AmbientAnimationProgressTracker>
@@ -252,6 +292,9 @@ class ASH_EXPORT AmbientController
   // Used to record Ambient mode engagement metrics.
   absl::optional<base::Time> start_time_ = absl::nullopt;
 
+  // Records the time when preview widgets are created.
+  base::Time preview_widget_created_at_;
+
   base::OneShotTimer delayed_lock_timer_;
 
   mojo::Remote<device::mojom::Fingerprint> fingerprint_;
@@ -275,12 +318,13 @@ class ASH_EXPORT AmbientController
   // TODO(safarli): Remove this workaround when b/266234711 is fixed.
   bool last_mouse_event_was_move_ = false;
 
-  // Not set until the AmbientAnimationTheme is initially read from pref
-  // storage when ambient mode is enabled.
-  absl::optional<AmbientAnimationTheme> current_theme_from_pref_;
+  // Flag used to prevent multiple calls to OnEnabledPrefChanged initializing
+  // the controller.
+  bool is_initialized_ = false;
 
   std::unique_ptr<AmbientMultiScreenMetricsRecorder>
       multi_screen_metrics_recorder_;
+  std::unique_ptr<AmbientUiLauncher> ambient_ui_launcher_;
 
   base::WeakPtrFactory<AmbientController> weak_ptr_factory_{this};
 };
