@@ -8,22 +8,30 @@
 #include <string>
 #include <utility>
 
+#include "ash/ambient/ambient_constants.h"
+#include "ash/ambient/ambient_managed_photo_controller.h"
+#include "ash/ambient/ambient_ui_settings.h"
 #include "ash/ambient/test/ambient_ash_test_base.h"
 #include "ash/ambient/ui/ambient_container_view.h"
 #include "ash/ambient/ui/ambient_view_ids.h"
 #include "ash/assistant/assistant_interaction_controller_impl.h"
 #include "ash/assistant/model/assistant_interaction_model.h"
-#include "ash/constants/ambient_animation_theme.h"
+#include "ash/constants/ambient_theme.h"
+#include "ash/constants/ambient_video.h"
 #include "ash/constants/ash_features.h"
 #include "ash/public/cpp/ambient/ambient_metrics.h"
 #include "ash/public/cpp/ambient/ambient_prefs.h"
 #include "ash/public/cpp/ambient/ambient_ui_model.h"
 #include "ash/public/cpp/ambient/fake_ambient_backend_controller_impl.h"
 #include "ash/public/cpp/assistant/controller/assistant_interaction_controller.h"
+#include "ash/public/cpp/personalization_app/time_of_day_paths.h"
+#include "ash/public/cpp/test/in_process_image_decoder.h"
 #include "ash/root_window_controller.h"
 #include "ash/shell.h"
 #include "ash/system/power/power_status.h"
+#include "ash/test/test_ash_web_view.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
+#include "base/files/scoped_temp_dir.h"
 #include "base/functional/callback.h"
 #include "base/location.h"
 #include "base/ranges/algorithm.h"
@@ -33,6 +41,7 @@
 #include "base/task/sequenced_task_runner.h"
 #include "base/test/bind.h"
 #include "base/test/metrics/histogram_tester.h"
+#include "base/test/metrics/user_action_tester.h"
 #include "base/test/scoped_feature_list.h"
 #include "base/test/scoped_run_loop_timeout.h"
 #include "base/time/time.h"
@@ -43,6 +52,7 @@
 #include "chromeos/dbus/power/power_manager_client.h"
 #include "chromeos/dbus/power_manager/power_supply_properties.pb.h"
 #include "chromeos/dbus/power_manager/suspend.pb.h"
+#include "net/base/url_util.h"
 #include "ui/events/event.h"
 #include "ui/events/keycodes/keyboard_codes_posix.h"
 #include "ui/events/platform/platform_event_source.h"
@@ -141,39 +151,44 @@ class AmbientControllerTest : public AmbientAshTestBase {
   }
 
   base::test::ScopedFeatureList feature_list_;
+
+ protected:
+  base::UserActionTester user_action_tester_;
 };
 
-// Tests for behavior that are agnostic to the AmbientAnimationTheme selected by
+// Tests for behavior that are agnostic to the AmbientUiSettings selected by
 // the user should use this test harness.
 //
 // Currently there are test cases that actually fall under this category but
 // do not use this test fixture. This is done purely for time constraint reasons
 // (it takes a lot of compute time to repeat every single one of these test
 // cases).
-class AmbientControllerTestForAnyTheme
+class AmbientControllerTestForAnyUiSettings
     : public AmbientControllerTest,
-      public ::testing::WithParamInterface<AmbientAnimationTheme> {
+      public ::testing::WithParamInterface<AmbientUiSettings> {
  protected:
   void SetUp() override {
     AmbientControllerTest::SetUp();
-    SetAmbientAnimationTheme(GetParam());
+    SetAmbientUiSettings(GetParam());
   }
 };
 
 INSTANTIATE_TEST_SUITE_P(
-    SlideshowAndAnimationTheme,
-    AmbientControllerTestForAnyTheme,
-    // Only one lottie-animated theme is sufficient here. The main goal here is
-    // to make sure that fundamental behavior holds for both the slideshow and
-    // lottie-animated codepaths.
-    testing::Values(AmbientAnimationTheme::kSlideshow
+    AllUiSettings,
+    AmbientControllerTestForAnyUiSettings,
+    // Only one lottie-animated theme and video is
+    // sufficient here. The main goal here is to make sure
+    // that fundamental behavior holds for all themes.
+    testing::Values(AmbientUiSettings(AmbientTheme::kSlideshow),
+                    AmbientUiSettings(AmbientTheme::kVideo,
+                                      AmbientVideo::kNewMexico)
 #if BUILDFLAG(HAS_ASH_AMBIENT_ANIMATION_RESOURCES)
-                    ,
-                    AmbientAnimationTheme::kFeelTheBreeze
+                        ,
+                    AmbientUiSettings(AmbientTheme::kFeelTheBreeze)
 #endif  // BUILDFLAG(HAS_ASH_AMBIENT_ANIMATION_RESOURCES)
-                    ));
+                        ));
 
-TEST_P(AmbientControllerTestForAnyTheme, ShowAmbientScreenUponLock) {
+TEST_P(AmbientControllerTestForAnyUiSettings, ShowAmbientScreenUponLock) {
   LockScreen();
   // Lockscreen will not immediately show Ambient mode.
   EXPECT_FALSE(ambient_controller()->IsShown());
@@ -193,7 +208,8 @@ TEST_P(AmbientControllerTestForAnyTheme, ShowAmbientScreenUponLock) {
   EXPECT_FALSE(ambient_controller()->IsShown());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, NotShowAmbientWhenPrefNotEnabled) {
+TEST_P(AmbientControllerTestForAnyUiSettings,
+       NotShowAmbientWhenPrefNotEnabled) {
   SetAmbientModeEnabled(false);
 
   LockScreen();
@@ -215,7 +231,7 @@ TEST_P(AmbientControllerTestForAnyTheme, NotShowAmbientWhenPrefNotEnabled) {
   EXPECT_FALSE(ambient_controller()->IsShown());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, HideAmbientScreen) {
+TEST_P(AmbientControllerTestForAnyUiSettings, HideAmbientScreen) {
   LockScreen();
   FastForwardToLockScreenTimeout();
   FastForwardTiny();
@@ -237,7 +253,7 @@ TEST_P(AmbientControllerTestForAnyTheme, HideAmbientScreen) {
   EXPECT_FALSE(ambient_controller()->IsShown());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, CloseAmbientScreenUponUnlock) {
+TEST_P(AmbientControllerTestForAnyUiSettings, CloseAmbientScreenUponUnlock) {
   LockScreen();
   FastForwardToLockScreenTimeout();
   FastForwardTiny();
@@ -257,7 +273,7 @@ TEST_P(AmbientControllerTestForAnyTheme, CloseAmbientScreenUponUnlock) {
   EXPECT_TRUE(GetContainerViews().empty());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme,
+TEST_P(AmbientControllerTestForAnyUiSettings,
        CloseAmbientScreenUponUnlockSecondaryUser) {
   // Simulate the login screen.
   ClearLogin();
@@ -348,7 +364,7 @@ TEST_F(AmbientControllerTest, NotShowAmbientWhenLockSecondaryUser) {
   EXPECT_TRUE(GetContainerViews().empty());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme,
+TEST_P(AmbientControllerTestForAnyUiSettings,
        ShouldRequestAccessTokenWhenLockingScreen) {
   EXPECT_FALSE(IsAccessTokenRequestPending());
 
@@ -375,7 +391,7 @@ TEST_F(AmbientControllerTest, ShouldNotRequestAccessTokenWhenPrefNotEnabled) {
   EXPECT_FALSE(IsAccessTokenRequestPending());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, ShouldReturnCachedAccessToken) {
+TEST_P(AmbientControllerTestForAnyUiSettings, ShouldReturnCachedAccessToken) {
   EXPECT_FALSE(IsAccessTokenRequestPending());
 
   // Lock the screen will request a token.
@@ -656,7 +672,8 @@ TEST_F(AmbientControllerTest,
 }
 
 // TODO(cowmoo): find a way to simulate events to trigger |UserActivityDetector|
-TEST_P(AmbientControllerTestForAnyTheme, ShouldDismissContainerViewOnEvents) {
+TEST_P(AmbientControllerTestForAnyUiSettings,
+       ShouldDismissContainerViewOnEvents) {
   std::vector<std::unique_ptr<ui::Event>> events;
 
   for (auto mouse_event_type : {ui::ET_MOUSE_PRESSED, ui::ET_MOUSE_MOVED}) {
@@ -701,7 +718,7 @@ TEST_P(AmbientControllerTestForAnyTheme, ShouldDismissContainerViewOnEvents) {
   }
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, ShouldDismissAndThenComesBack) {
+TEST_P(AmbientControllerTestForAnyUiSettings, ShouldDismissAndThenComesBack) {
   LockScreen();
   FastForwardToLockScreenTimeout();
   FastForwardTiny();
@@ -716,7 +733,8 @@ TEST_P(AmbientControllerTestForAnyTheme, ShouldDismissAndThenComesBack) {
   EXPECT_TRUE(WidgetsVisible());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, ShouldDismissContainerViewOnKeyEvent) {
+TEST_P(AmbientControllerTestForAnyUiSettings,
+       ShouldDismissContainerViewOnKeyEvent) {
   // Without user interaction, should show ambient mode.
   ShowAmbientScreen();
   EXPECT_TRUE(WidgetsVisible());
@@ -1020,7 +1038,7 @@ TEST_F(AmbientControllerTest, HandlesPhotoDownloadOutage) {
   EXPECT_FALSE(ambient_controller()->IsShown());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, HideCursor) {
+TEST_P(AmbientControllerTestForAnyUiSettings, HideCursor) {
   auto* cursor_manager = Shell::Get()->cursor_manager();
   LockScreen();
 
@@ -1041,7 +1059,7 @@ TEST_P(AmbientControllerTestForAnyTheme, HideCursor) {
   EXPECT_FALSE(ambient_controller()->IsShown());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, ShowsOnMultipleDisplays) {
+TEST_P(AmbientControllerTestForAnyUiSettings, ShowsOnMultipleDisplays) {
   UpdateDisplay("800x600,800x600");
   FastForwardTiny();
 
@@ -1050,10 +1068,19 @@ TEST_P(AmbientControllerTestForAnyTheme, ShowsOnMultipleDisplays) {
   auto* screen = display::Screen::GetScreen();
   EXPECT_EQ(screen->GetNumDisplays(), 2);
   EXPECT_EQ(GetContainerViews().size(), 2u);
-  AmbientViewID expected_child_view_id =
-      GetParam() == AmbientAnimationTheme::kSlideshow
-          ? AmbientViewID::kAmbientPhotoView
-          : AmbientViewID::kAmbientAnimationView;
+  AmbientViewID expected_child_view_id;
+  switch (GetParam().theme()) {
+    case AmbientTheme::kVideo:
+      expected_child_view_id = kAmbientVideoWebView;
+      break;
+    case AmbientTheme::kSlideshow:
+      expected_child_view_id = AmbientViewID::kAmbientPhotoView;
+      break;
+    case AmbientTheme::kFeelTheBreeze:
+    case AmbientTheme::kFloatOnBy:
+      expected_child_view_id = AmbientViewID::kAmbientAnimationView;
+      break;
+  }
   EXPECT_TRUE(GetContainerViews().front()->GetViewByID(expected_child_view_id));
   EXPECT_TRUE(GetContainerViews().back()->GetViewByID(expected_child_view_id));
   // Check that each root controller has an ambient widget.
@@ -1062,7 +1089,7 @@ TEST_P(AmbientControllerTestForAnyTheme, ShowsOnMultipleDisplays) {
                 ctrl->ambient_widget_for_testing()->IsVisible());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, RespondsToDisplayAdded) {
+TEST_P(AmbientControllerTestForAnyUiSettings, RespondsToDisplayAdded) {
   // UpdateDisplay triggers a rogue MouseEvent that cancels Ambient mode when
   // testing with Xvfb. A corresponding MouseEvent is not fired on a real device
   // when an external display is added. Ignore this MouseEvent for testing.
@@ -1093,7 +1120,7 @@ TEST_P(AmbientControllerTestForAnyTheme, RespondsToDisplayAdded) {
       old_should_ignore_events);
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, HandlesDisplayRemoved) {
+TEST_P(AmbientControllerTestForAnyUiSettings, HandlesDisplayRemoved) {
   UpdateDisplay("800x600,800x600");
   FastForwardTiny();
 
@@ -1237,7 +1264,7 @@ TEST_F(AmbientControllerTest, BindsObserversWhenAmbientOn) {
   EXPECT_FALSE(ctrl->power_status_observer_.IsObserving());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme,
+TEST_P(AmbientControllerTestForAnyUiSettings,
        ShowDismissAmbientScreenUponAssistantQuery) {
   // Without user interaction, should show ambient mode.
   ShowAmbientScreen();
@@ -1264,7 +1291,7 @@ TEST_P(AmbientControllerTestForAnyTheme,
 
 TEST_F(AmbientControllerTest,
        ANIMATION_TEST_WITH_RESOURCES(RendersCorrectView)) {
-  SetAmbientAnimationTheme(AmbientAnimationTheme::kFeelTheBreeze);
+  SetAmbientTheme(AmbientTheme::kFeelTheBreeze);
 
   LockScreen();
   FastForwardToLockScreenTimeout();
@@ -1277,7 +1304,7 @@ TEST_F(AmbientControllerTest,
       GetContainerView()->GetViewByID(AmbientViewID::kAmbientAnimationView));
 
   UnlockScreen();
-  SetAmbientAnimationTheme(AmbientAnimationTheme::kSlideshow);
+  SetAmbientTheme(AmbientTheme::kSlideshow);
 
   LockScreen();
   FastForwardToLockScreenTimeout();
@@ -1290,7 +1317,7 @@ TEST_F(AmbientControllerTest,
       GetContainerView()->GetViewByID(AmbientViewID::kAmbientAnimationView));
 
   UnlockScreen();
-  SetAmbientAnimationTheme(AmbientAnimationTheme::kFeelTheBreeze);
+  SetAmbientTheme(AmbientTheme::kFeelTheBreeze);
 
   LockScreen();
   FastForwardToLockScreenTimeout();
@@ -1305,7 +1332,7 @@ TEST_F(AmbientControllerTest,
 
 TEST_F(AmbientControllerTest,
        ANIMATION_TEST_WITH_RESOURCES(ClearsCacheWhenSwitchingThemes)) {
-  SetAmbientAnimationTheme(AmbientAnimationTheme::kSlideshow);
+  SetAmbientTheme(AmbientTheme::kSlideshow);
 
   LockScreen();
   FastForwardToLockScreenTimeout();
@@ -1315,7 +1342,7 @@ TEST_F(AmbientControllerTest,
   ASSERT_FALSE(GetCachedFiles().empty());
 
   UnlockScreen();
-  SetAmbientAnimationTheme(AmbientAnimationTheme::kFeelTheBreeze);
+  SetAmbientTheme(AmbientTheme::kFeelTheBreeze);
 
   // Mimic a network outage where no photos can be downloaded. Since the cache
   // should have been cleared when we switched ambient animation themes, the
@@ -1328,7 +1355,7 @@ TEST_F(AmbientControllerTest,
   EXPECT_TRUE(GetCachedFiles().empty());
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, MetricsEngagementTime) {
+TEST_P(AmbientControllerTestForAnyUiSettings, MetricsEngagementTime) {
   // TODO(esum): Find a better way of fast forwarding time for lottie animations
   // in unit tests. Currently, the whole compositor stack is being used in this
   // test harness and there is no good way to control the frame rate, so
@@ -1358,7 +1385,8 @@ TEST_P(AmbientControllerTestForAnyTheme, MetricsEngagementTime) {
       "Ash.AmbientMode.EngagementTime.ClamshellMode", kExpectedEngagementTime,
       1);
   histogram_tester.ExpectTimeBucketCount(
-      base::StrCat({"Ash.AmbientMode.EngagementTime.", ToString(GetParam())}),
+      base::StrCat(
+          {"Ash.AmbientMode.EngagementTime.", ToString(GetParam().theme())}),
       kExpectedEngagementTime, 1);
 
   // Now do the same sequence in tablet mode.
@@ -1378,11 +1406,12 @@ TEST_P(AmbientControllerTestForAnyTheme, MetricsEngagementTime) {
   histogram_tester.ExpectTimeBucketCount(
       "Ash.AmbientMode.EngagementTime.TabletMode", kExpectedEngagementTime, 1);
   histogram_tester.ExpectTimeBucketCount(
-      base::StrCat({"Ash.AmbientMode.EngagementTime.", ToString(GetParam())}),
+      base::StrCat(
+          {"Ash.AmbientMode.EngagementTime.", ToString(GetParam().theme())}),
       kExpectedEngagementTime, 2);
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, MetricsStartupTime) {
+TEST_P(AmbientControllerTestForAnyUiSettings, MetricsStartupTime) {
   base::HistogramTester histogram_tester;
   LockScreen();
   FastForwardToLockScreenTimeout();
@@ -1390,7 +1419,9 @@ TEST_P(AmbientControllerTestForAnyTheme, MetricsStartupTime) {
   ASSERT_TRUE(ambient_controller()->IsShown());
 
   histogram_tester.ExpectTotalCount(
-      base::StrCat({"Ash.AmbientMode.StartupTime.", ToString(GetParam())}), 1);
+      base::StrCat(
+          {"Ash.AmbientMode.StartupTime.", ToString(GetParam().theme())}),
+      1);
 
   UnlockScreen();
   ASSERT_FALSE(ambient_controller()->IsShown());
@@ -1401,12 +1432,14 @@ TEST_P(AmbientControllerTestForAnyTheme, MetricsStartupTime) {
   ASSERT_TRUE(ambient_controller()->IsShown());
 
   histogram_tester.ExpectTotalCount(
-      base::StrCat({"Ash.AmbientMode.StartupTime.", ToString(GetParam())}), 2);
+      base::StrCat(
+          {"Ash.AmbientMode.StartupTime.", ToString(GetParam().theme())}),
+      2);
 }
 
 TEST_F(AmbientControllerTest,
        ANIMATION_TEST_WITH_RESOURCES(MetricsStartupTimeSuspendAfterTimeMax)) {
-  SetAmbientAnimationTheme(AmbientAnimationTheme::kSlideshow);
+  SetAmbientTheme(AmbientTheme::kSlideshow);
   base::HistogramTester histogram_tester;
   LockScreen();
   FastForwardToLockScreenTimeout();
@@ -1424,7 +1457,7 @@ TEST_F(AmbientControllerTest,
 
 TEST_F(AmbientControllerTest,
        ANIMATION_TEST_WITH_RESOURCES(MetricsStartupTimeScreenOffAfterTimeMax)) {
-  SetAmbientAnimationTheme(AmbientAnimationTheme::kSlideshow);
+  SetAmbientTheme(AmbientTheme::kSlideshow);
   base::HistogramTester histogram_tester;
   LockScreen();
   FastForwardToLockScreenTimeout();
@@ -1440,7 +1473,18 @@ TEST_F(AmbientControllerTest,
   UnlockScreen();
 }
 
-TEST_P(AmbientControllerTestForAnyTheme, MetricsStartupTimeFailedToStart) {
+TEST_P(AmbientControllerTestForAnyUiSettings, MetricsStartupTimeFailedToStart) {
+  switch (GetParam().theme()) {
+    case AmbientTheme::kVideo:
+      // Video themes have no dependency on backend photos, so we cannot test
+      // failure to start ambient mode by simulating an IMAX outage. Video
+      // themes should always start unless there is a design oversight or bug.
+      GTEST_SKIP();
+    case AmbientTheme::kSlideshow:
+    case AmbientTheme::kFeelTheBreeze:
+    case AmbientTheme::kFloatOnBy:
+      break;
+  }
   // Simulate IMAX outage that doesn't return any photos.
   backend_controller()->SetFetchScreenUpdateInfoResponseSize(0);
 
@@ -1452,16 +1496,20 @@ TEST_P(AmbientControllerTestForAnyTheme, MetricsStartupTimeFailedToStart) {
 
   UnlockScreen();
   histogram_tester.ExpectUniqueTimeSample(
-      base::StrCat({"Ash.AmbientMode.StartupTime.", ToString(GetParam())}),
+      base::StrCat({"Ash.AmbientMode.StartupTime.", GetParam().ToString()}),
       base::Minutes(1), 1);
 }
 
 TEST_F(AmbientControllerTest, ShouldStartScreenSaverPreview) {
+  ASSERT_EQ(0,
+            user_action_tester_.GetActionCount(kScreenSaverPreviewUserAction));
   ambient_controller()->StartScreenSaverPreview();
   FastForwardToLockScreenTimeout();
   FastForwardTiny();
   EXPECT_TRUE(ambient_controller()->IsShown());
   EXPECT_FALSE(IsLocked());
+  EXPECT_EQ(1,
+            user_action_tester_.GetActionCount(kScreenSaverPreviewUserAction));
 }
 
 TEST_F(AmbientControllerTest,
@@ -1517,6 +1565,19 @@ TEST_F(AmbientControllerTest, ShouldDismissScreenSaverPreviewOnMouseClick) {
   EXPECT_FALSE(ambient_controller()->IsShown());
 }
 
+TEST_F(AmbientControllerTest, MaybeDismissUIOnMouseMove) {
+  ambient_controller()->StartScreenSaverPreview();
+  EXPECT_TRUE(ambient_controller()->IsShown());
+
+  GetEventGenerator()->MoveMouseTo(gfx::Point(5, 5), /*count=*/2);
+  EXPECT_TRUE(ambient_controller()->IsShown());
+
+  task_environment()->FastForwardBy(kDismissPreviewOnMouseMoveDelay);
+  FastForwardTiny();
+  GetEventGenerator()->MoveMouseTo(gfx::Point(5, 5), /*count=*/2);
+  EXPECT_FALSE(ambient_controller()->IsShown());
+}
+
 TEST_F(AmbientControllerTest, ShouldDismissScreenSaverPreviewOnTouch) {
   ambient_controller()->StartScreenSaverPreview();
   EXPECT_TRUE(ambient_controller()->IsShown());
@@ -1531,4 +1592,219 @@ TEST_F(AmbientControllerTest, ShouldDismissScreenSaverPreviewOnTouch) {
   EXPECT_FALSE(ambient_controller()->IsShown());
 }
 
+class AmbientControllerForManagedScreensaver : public AmbientAshTestBase {
+ protected:
+  void SetUp() override {
+    scoped_feature_list_.InitAndEnableFeature(
+        ash::features::kAmbientModeManagedScreensaver);
+    AmbientAshTestBase::SetUp();
+
+    GetSessionControllerClient()->set_show_lock_screen_views(true);
+    CreateTestData();
+  }
+
+  void CreateTestData() {
+    bool success = temp_dir_.CreateUniqueTempDir();
+    ASSERT_TRUE(success);
+    base::FilePath image_1 =
+        temp_dir_.GetPath().Append(FILE_PATH_LITERAL("IMAGE_1.jpg"));
+    CreateTestImageJpegFile(image_1, 4, 4, SK_ColorRED);
+    base::FilePath image_2 =
+        temp_dir_.GetPath().Append(FILE_PATH_LITERAL("IMAGE_2.jpg"));
+    CreateTestImageJpegFile(image_2, 8, 8, SK_ColorGREEN);
+
+    image_file_paths_.push_back(image_1);
+    image_file_paths_.push_back(image_2);
+  }
+
+  void SimulateScreensaverStart() {
+    LockScreen();
+    FastForwardToLockScreenTimeout();
+    FastForwardTiny();
+    EXPECT_TRUE(ambient_controller()->IsShown());
+  }
+  base::test::ScopedFeatureList scoped_feature_list_;
+  InProcessImageDecoder decoder_;
+  std::vector<base::FilePath> image_file_paths_;
+  base::ScopedTempDir temp_dir_;
+};
+
+TEST_F(AmbientControllerForManagedScreensaver,
+       ScreensaverIsShownWithEnoughImages) {
+  SetAmbientModeManagedScreensaverEnabled(true);
+
+  managed_photo_controller()->UpdateImageFilePaths(image_file_paths_);
+  SimulateScreensaverStart();
+
+  ASSERT_TRUE(GetContainerView());
+  EXPECT_TRUE(
+      GetContainerView()->GetViewByID(AmbientViewID::kAmbientPhotoView));
+  GetEventGenerator()->ClickLeftButton();
+  EXPECT_FALSE(ambient_controller()->IsShown());
+  FastForwardToLockScreenTimeout();
+  EXPECT_TRUE(ambient_controller()->IsShown());
+  UnlockScreen();
+  EXPECT_FALSE(ambient_controller()->IsShown());
+
+  ASSERT_FALSE(GetContainerView());
+}
+
+TEST_F(AmbientControllerForManagedScreensaver,
+       ScreensaverIsNotShownWithoutImages) {
+  SetAmbientModeManagedScreensaverEnabled(true);
+  LockScreen();
+  FastForwardToLockScreenTimeout();
+  FastForwardTiny();
+
+  EXPECT_TRUE(ambient_controller()->IsShown());
+  ASSERT_FALSE(GetContainerView());
+  UnlockScreen();
+  EXPECT_FALSE(ambient_controller()->IsShown());
+}
+
+TEST_F(AmbientControllerForManagedScreensaver,
+       UiLauncherIsNullWhenManagedAmbientModeIsDisabled) {
+  SetAmbientModeEnabled(false);
+  SetAmbientModeManagedScreensaverEnabled(false);
+
+  ASSERT_FALSE(ambient_controller()->ambient_ui_launcher());
+
+  EXPECT_FALSE(ambient_controller()->IsShown());
+}
+
+TEST_F(AmbientControllerForManagedScreensaver,
+       DisablingManagedAmbientModeFallsbackToUserAmbientModeIfEnabled) {
+  SetAmbientModeEnabled(true);
+  SetAmbientModeManagedScreensaverEnabled(true);
+  managed_photo_controller()->UpdateImageFilePaths(image_file_paths_);
+  SimulateScreensaverStart();
+  ASSERT_TRUE(GetContainerView());
+  EXPECT_TRUE(
+      GetContainerView()->GetViewByID(AmbientViewID::kAmbientPhotoView));
+  SetAmbientModeManagedScreensaverEnabled(false);
+  DisableBackupCacheDownloads();
+  UnlockScreen();
+  LockScreen();
+  FastForwardToLockScreenTimeout();
+  FastForwardTiny();
+  EXPECT_TRUE(ambient_controller()->IsShown());
+  ASSERT_TRUE(GetContainerView());
+  EXPECT_TRUE(
+      GetContainerView()->GetViewByID(AmbientViewID::kAmbientPhotoView));
+  UnlockScreen();
+  EXPECT_FALSE(ambient_controller()->IsShown());
+}
+
+TEST_F(AmbientControllerForManagedScreensaver,
+       LaunchingManagedAmbientModeAfterAmbientModeWorksAsExpected) {
+  SetAmbientModeEnabled(/*enabled=*/true);
+  ASSERT_FALSE(ambient_controller()->ambient_ui_launcher());
+  SetAmbientModeManagedScreensaverEnabled(/*enabled=*/true);
+  ASSERT_TRUE(ambient_controller()->ambient_ui_launcher());
+
+  managed_photo_controller()->UpdateImageFilePaths(image_file_paths_);
+
+  SimulateScreensaverStart();
+  UnlockScreen();
+  EXPECT_FALSE(ambient_controller()->IsShown());
+}
+
+TEST_F(AmbientControllerForManagedScreensaver,
+       LaunchingAmbientModeAfterManagedAmbientModeWorksAsExpected) {
+  SetAmbientModeEnabled(/*enabled=*/false);
+  SetAmbientModeManagedScreensaverEnabled(/*enabled=*/true);
+  SetAmbientModeEnabled(/*enabled=*/true);
+
+  managed_photo_controller()->UpdateImageFilePaths(image_file_paths_);
+
+  SimulateScreensaverStart();
+  UnlockScreen();
+  EXPECT_FALSE(ambient_controller()->IsShown());
+}
+
+TEST_F(AmbientControllerForManagedScreensaver, PrefObserverUpdatesUiModel) {
+  SetAmbientModeManagedScreensaverEnabled(/*enabled=*/true);
+  ASSERT_TRUE(ambient_controller()->ambient_ui_launcher());
+  PrefService* pref_service =
+      Shell::Get()->session_controller()->GetActivePrefService();
+  AmbientUiModel* ui_model = ambient_controller()->ambient_ui_model();
+  constexpr size_t kExpectedIdleTimeout = 55;
+  constexpr size_t kExpectedPhotoRefreshInterval = 77;
+  pref_service->SetInteger(
+      ambient::prefs::kAmbientModeManagedScreensaverIdleTimeoutSeconds,
+      kExpectedIdleTimeout);
+  EXPECT_EQ(base::Seconds(kExpectedIdleTimeout),
+            ui_model->lock_screen_inactivity_timeout());
+  pref_service->SetInteger(
+      ambient::prefs::kAmbientModeManagedScreensaverImageDisplayIntervalSeconds,
+      kExpectedPhotoRefreshInterval);
+  EXPECT_EQ(base::Seconds(kExpectedPhotoRefreshInterval),
+            ui_model->photo_refresh_interval());
+}
+
+TEST_F(AmbientControllerTest, RendersCorrectViewForVideo) {
+  SetAmbientUiSettings(
+      AmbientUiSettings(AmbientTheme::kVideo, AmbientVideo::kNewMexico));
+
+  LockScreen();
+  FastForwardToLockScreenTimeout();
+  FastForwardTiny();
+
+  ASSERT_TRUE(GetContainerView());
+  const TestAshWebView* web_view = static_cast<const TestAshWebView*>(
+      GetContainerView()->GetViewByID(kAmbientVideoWebView));
+  ASSERT_TRUE(web_view);
+  EXPECT_TRUE(web_view->current_url().SchemeIsFile());
+  EXPECT_EQ(web_view->current_url().path(),
+            personalization_app::GetTimeOfDaySrcDir()
+                .Append(personalization_app::kAmbientVideoHtml)
+                .value());
+  std::string video_path_requested;
+  ASSERT_TRUE(net::GetValueForKeyInQuery(web_view->current_url(), "video_src",
+                                         &video_path_requested));
+  GURL video_src_url(video_path_requested);
+  EXPECT_TRUE(video_src_url.SchemeIsFile());
+  EXPECT_EQ(video_src_url.path(),
+            personalization_app::GetTimeOfDayVideosDir()
+                .Append(personalization_app::kTimeOfDayNewMexicoVideo)
+                .value());
+
+  UnlockScreen();
+  SetAmbientTheme(AmbientTheme::kSlideshow);
+
+  LockScreen();
+  FastForwardToLockScreenTimeout();
+  FastForwardTiny();
+
+  ASSERT_TRUE(GetContainerView());
+  EXPECT_TRUE(
+      GetContainerView()->GetViewByID(AmbientViewID::kAmbientPhotoView));
+
+  UnlockScreen();
+  SetAmbientUiSettings(
+      AmbientUiSettings(AmbientTheme::kVideo, AmbientVideo::kClouds));
+
+  LockScreen();
+  FastForwardToLockScreenTimeout();
+  FastForwardTiny();
+
+  ASSERT_TRUE(GetContainerView());
+  web_view = static_cast<const TestAshWebView*>(
+      GetContainerView()->GetViewByID(kAmbientVideoWebView));
+  ASSERT_TRUE(web_view);
+  EXPECT_TRUE(web_view->current_url().SchemeIsFile());
+  EXPECT_EQ(web_view->current_url().path(),
+            personalization_app::GetTimeOfDaySrcDir()
+                .Append(personalization_app::kAmbientVideoHtml)
+                .value());
+  ASSERT_TRUE(net::GetValueForKeyInQuery(web_view->current_url(), "video_src",
+                                         &video_path_requested));
+  video_src_url = GURL(video_path_requested);
+  EXPECT_TRUE(video_src_url.SchemeIsFile());
+  EXPECT_EQ(video_src_url.path(),
+            personalization_app::GetTimeOfDayVideosDir()
+                .Append(personalization_app::kTimeOfDayCloudsVideo)
+                .value());
+}
+
 }  // namespace ash
