@@ -16,7 +16,6 @@
 #include "ash/ambient/ambient_weather_controller.h"
 #include "ash/ambient/model/ambient_backend_model.h"
 #include "ash/public/cpp/ambient/ambient_backend_controller.h"
-#include "ash/public/cpp/ambient/ambient_client.h"
 #include "ash/public/cpp/ambient/proto/photo_cache_entry.pb.h"
 #include "ash/public/cpp/image_downloader.h"
 #include "ash/shell.h"
@@ -29,7 +28,6 @@
 #include "base/functional/callback.h"
 #include "base/guid.h"
 #include "base/hash/sha1.h"
-#include "base/path_service.h"
 #include "base/rand_util.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_util.h"
@@ -71,32 +69,17 @@ const std::array<const char*, 2>& GetBackupPhotoUrls() {
       ->GetBackupPhotoUrls();
 }
 
-// Get the cache root path for ambient mode.
-base::FilePath GetCacheRootPath() {
-  base::FilePath home_dir;
-  CHECK(base::PathService::Get(base::DIR_HOME, &home_dir));
-  return home_dir.Append(FILE_PATH_LITERAL(kAmbientModeDirectoryName));
-}
-
 }  // namespace
 
 AmbientPhotoController::AmbientPhotoController(
-    AmbientClient& ambient_client,
-    AmbientAccessTokenController& access_token_controller,
+    AmbientPhotoCache& photo_cache,
+    AmbientPhotoCache& backup_photo_cache,
     AmbientViewDelegate& view_delegate,
     AmbientPhotoConfig photo_config)
     : ambient_backend_model_(std::move(photo_config)),
       resume_fetch_image_backoff_(&kResumeFetchImageBackoffPolicy),
-      photo_cache_(AmbientPhotoCache::Create(
-          GetCacheRootPath().Append(
-              FILE_PATH_LITERAL(kAmbientModeCacheDirectoryName)),
-          ambient_client,
-          access_token_controller)),
-      backup_photo_cache_(AmbientPhotoCache::Create(
-          GetCacheRootPath().Append(
-              FILE_PATH_LITERAL(kAmbientModeBackupCacheDirectoryName)),
-          ambient_client,
-          access_token_controller)),
+      photo_cache_(&photo_cache),
+      backup_photo_cache_(&backup_photo_cache),
       task_runner_(
           base::ThreadPool::CreateSequencedTaskRunner(GetTaskTraits())) {
   scoped_view_delegate_observation_.Observe(&view_delegate);
@@ -114,7 +97,9 @@ void AmbientPhotoController::Init(
   num_topics_prepared_ = 0;
   is_actively_preparing_topic_ = false;
   ambient_topic_queue_ = std::make_unique<AmbientTopicQueue>(
-      /*topic_fetch_limit=*/kMaxNumberOfCachedImages,
+      /*topic_fetch_limit=*/ambient_backend_model_.photo_config().IsEmpty()
+          ? 0
+          : kMaxNumberOfCachedImages,
       /*topic_fetch_size=*/kTopicsBatchSize, kTopicFetchInterval,
       ambient_backend_model_.photo_config().should_split_topics,
       std::move(topic_queue_delegate),
@@ -166,24 +151,25 @@ void AmbientPhotoController::OnMarkerHit(AmbientPhotoConfig::Marker marker) {
   }
 
   DVLOG(3) << "UI event " << marker << " triggering topic refresh";
-  if (state_ == State::kInactive) {
-    LOG(DFATAL) << "Received unexpected UI marker " << marker
-                << " while inactive";
-    return;
-  }
-
-  bool is_still_preparing_topics = state_ != State::kWaitingForNextMarker;
-  state_ = State::kPreparingNextTopicSet;
-  num_topics_prepared_ = 0;
-  if (is_still_preparing_topics) {
-    // The controller is still in the middle of preparing a topic from the
-    // previous set (i.e. waiting on a callback or timer to fire). Resetting
-    // |num_topics_prepared_| to 0 above is enough, and the topic currently
-    // being prepared will count towards the next set.
-    DVLOG(4) << "Did not finished preparing current topic set in time. "
-                "Starting new set...";
-  } else {
-    StartPreparingNextTopic();
+  switch (state_) {
+    case State::kInactive:
+      LOG(DFATAL) << "Received unexpected UI marker " << marker
+                  << " while inactive";
+      break;
+    case State::kPreparingNextTopicSet:
+      // The controller is still in the middle of preparing a topic from the
+      // previous set (i.e. waiting on a callback or timer to fire). Resetting
+      // |num_topics_prepared_| to 0 is enough, and the topic currently being
+      // prepared will count towards the next set.
+      DVLOG(4) << "Did not finished preparing current topic set in time. "
+                  "Starting new set...";
+      num_topics_prepared_ = 0;
+      break;
+    case State::kWaitingForNextMarker:
+      state_ = State::kPreparingNextTopicSet;
+      num_topics_prepared_ = 0;
+      StartPreparingNextTopic();
+      break;
   }
 }
 
@@ -194,11 +180,6 @@ void AmbientPhotoController::FetchWeather() {
       ->FetchWeather();
 }
 
-void AmbientPhotoController::ClearCache() {
-  DCHECK(photo_cache_);
-  photo_cache_->Clear();
-}
-
 void AmbientPhotoController::ScheduleFetchBackupImages() {
   DVLOG(3) << __func__;
   if (backup_photo_refresh_timer_.IsRunning())
@@ -530,6 +511,14 @@ void AmbientPhotoController::FetchBackupImagesForTesting() {
 
 void AmbientPhotoController::StartPreparingNextTopic() {
   DCHECK_EQ(state_, State::kPreparingNextTopicSet);
+  if (ambient_backend_model_.photo_config().IsEmpty()) {
+    DVLOG(1) << "No photos should be written to model";
+    // This may not be necessary because a config like this probably doesn't
+    // have any photo refresh markers anyways. However, it's more technically
+    // correct to be in this state instead of |kPreparingNextTopicSet|.
+    state_ = State::kWaitingForNextMarker;
+    return;
+  }
   DCHECK(!is_actively_preparing_topic_)
       << "Preparing multiple topics simultaneously is not currently supported";
   is_actively_preparing_topic_ = true;
