@@ -11,6 +11,7 @@
 
 #include "ash/ambient/ambient_constants.h"
 #include "ash/ambient/ambient_controller.h"
+#include "ash/ambient/ambient_photo_cache.h"
 #include "ash/ambient/ambient_weather_controller.h"
 #include "ash/ambient/model/ambient_animation_photo_config.h"
 #include "ash/ambient/model/ambient_backend_model.h"
@@ -20,6 +21,7 @@
 #include "ash/ambient/test/ambient_ash_test_base.h"
 #include "ash/ambient/test/ambient_test_util.h"
 #include "ash/ambient/test/ambient_topic_queue_test_delegate.h"
+#include "ash/ambient/test/mock_ambient_backend_model_observer.h"
 #include "ash/public/cpp/ambient/ambient_backend_controller.h"
 #include "ash/public/cpp/ambient/fake_ambient_backend_controller_impl.h"
 #include "ash/public/cpp/ambient/proto/photo_cache_entry.pb.h"
@@ -51,20 +53,12 @@ namespace ash {
 using ::testing::AnyOf;
 using ::testing::Contains;
 using ::testing::Eq;
+using ::testing::IsEmpty;
 using ::testing::Not;
 using ::testing::Pointwise;
 using ::testing::SizeIs;
 
 namespace {
-class MockAmbientBackendModelObserver : public AmbientBackendModelObserver {
- public:
-  MockAmbientBackendModelObserver() = default;
-  ~MockAmbientBackendModelObserver() override = default;
-
-  // AmbientBackendModelObserver:
-  MOCK_METHOD(void, OnImageAdded, (), (override));
-  MOCK_METHOD(void, OnImagesReady, (), (override));
-};
 
 bool AreBackedBySameImage(const PhotoWithDetails& topic_l,
                           const PhotoWithDetails& topic_r) {
@@ -229,6 +223,19 @@ class AmbientPhotoControllerAnimationTest : public AmbientPhotoControllerTest {
   }
 };
 
+// No topics should be prepared at all; the screensaver doesn't have photos in
+// it. AmbientPhotoController should be completely idle and
+// AmbientBackendModel::ImagesReady() should be true immediately.
+class AmbientPhotoControllerEmptyConfigTest
+    : public AmbientPhotoControllerTest {
+ protected:
+  void SetUp() override {
+    AmbientPhotoControllerTest::SetUp();
+    photo_controller()->ambient_backend_model()->SetPhotoConfig(
+        AmbientPhotoConfig());
+  }
+};
+
 // Test that topics are downloaded when starting screen update.
 TEST_F(AmbientPhotoControllerTest, ShouldStartToDownloadTopics) {
   auto topics =
@@ -656,7 +663,7 @@ TEST_F(AmbientPhotoControllerTest, UsesBackupCacheAfterPrimaryCacheCleared) {
   // photos from the last "screen update". ClearCache() should only clear the
   // primary cache, leaving photos in the backup cache to use.
   ASSERT_FALSE(GetBackupCachedFiles().empty());
-  photo_controller()->ClearCache();
+  ambient_controller()->ambient_photo_cache()->Clear();
   // Simulate an IMAX failure to leave the photo controller no choice but to
   // resort to the backup cache.
   backend_controller()->SetFetchScreenUpdateInfoResponseSize(0);
@@ -865,4 +872,16 @@ TEST_F(AmbientPhotoControllerAnimationTest,
   EXPECT_THAT(photos_after, Pointwise(BackedBySameImage(), photos_before));
 }
 
+TEST_F(AmbientPhotoControllerEmptyConfigTest, CallsOnImagesReadyImmediately) {
+  photo_controller()->StartScreenUpdate(
+      std::make_unique<AmbientTopicQueueTestDelegate>());
+  RunUntilImagesReady();
+  EXPECT_THAT(photo_controller()->ambient_backend_model()->all_decoded_topics(),
+              IsEmpty());
+  task_environment()->FastForwardBy(base::Minutes(1));
+  EXPECT_TRUE(photo_controller()->ambient_backend_model()->ImagesReady());
+  EXPECT_THAT(photo_controller()->ambient_backend_model()->all_decoded_topics(),
+              IsEmpty());
+}
+
 }  // namespace ash
