@@ -33,6 +33,8 @@ class AmbientBackendControllerImpl : public AmbientBackendController {
       bool show_pair_personal_portraits,
       const gfx::Size& screen_size,
       OnScreenUpdateInfoFetchedCallback callback) override;
+  void FetchPreviewImages(const gfx::Size& preview_size,
+                          OnPreviewImagesFetchedCallback callback) override;
   void GetSettings(GetSettingsCallback callback) override;
   void UpdateSettings(const AmbientSettings& settings,
                       UpdateSettingsCallback callback) override;
@@ -49,13 +51,6 @@ class AmbientBackendControllerImpl : public AmbientBackendController {
   void FetchWeather(FetchWeatherCallback callback) override;
   const std::array<const char*, 2>& GetBackupPhotoUrls() const override;
 
-  void GetGooglePhotosAlbumsPreview(
-      const std::vector<std::string>& album_ids,
-      int preview_width,
-      int preview_height,
-      int num_previews,
-      GetGooglePhotosAlbumsPreviewCallback callback) override;
-
  private:
   using BackdropClientConfig = chromeos::ambient::BackdropClientConfig;
   void RequestAccessToken(AmbientClient::GetAccessTokenCallback callback);
@@ -111,20 +106,6 @@ class AmbientBackendControllerImpl : public AmbientBackendController {
 
   void OnSettingsAndAlbumsFetched(OnSettingsAndAlbumsFetchedCallback callback);
 
-  void StartToGetGooglePhotosAlbumsPreview(
-      const std::vector<std::string>& album_ids,
-      int preview_width,
-      int preview_height,
-      int num_previews,
-      GetGooglePhotosAlbumsPreviewCallback callback,
-      const std::string& gaia_id,
-      const std::string& access_token);
-
-  void OnGetGooglePhotosAlbumsPreview(
-      GetGooglePhotosAlbumsPreviewCallback callback,
-      std::unique_ptr<BackdropURLLoader> backdrop_url_loader,
-      std::unique_ptr<std::string> response);
-
   // Temporary store for FetchSettingsAndAlbums() when |GetSettingsCallback|
   // called. |settings_| will be absl::nullopt if server returns with error.
   absl::optional<ash::AmbientSettings> settings_;
