@@ -8,7 +8,9 @@
 #include <memory>
 
 #include "ash/ambient/model/ambient_animation_photo_provider.h"
+#include "ash/ambient/ui/glanceable_info_view.h"
 #include "ash/ambient/ui/jitter_calculator.h"
+#include "ash/ambient/ui/media_string_view.h"
 #include "ash/ash_export.h"
 #include "base/memory/weak_ptr.h"
 #include "base/scoped_observation.h"
@@ -39,7 +41,9 @@ class AmbientViewDelegateImpl;
 
 class ASH_EXPORT AmbientAnimationView : public views::View,
                                         public lottie::AnimationObserver,
-                                        public views::ViewObserver {
+                                        public views::ViewObserver,
+                                        public GlanceableInfoView::Delegate,
+                                        public MediaStringView::Delegate {
  public:
   METADATA_HEADER(AmbientAnimationView);
 
@@ -53,6 +57,8 @@ class ASH_EXPORT AmbientAnimationView : public views::View,
   AmbientAnimationView& operator=(AmbientAnimationView&) = delete;
   ~AmbientAnimationView() override;
 
+  JitterCalculator* GetJitterCalculatorForTesting();
+
  private:
   void Init(AmbientMultiScreenMetricsRecorder* multi_screen_metrics_recorder);
 
@@ -61,6 +67,12 @@ class ASH_EXPORT AmbientAnimationView : public views::View,
   void OnViewBoundsChanged(View* observed_view) override;
   void OnViewAddedToWidget(View* observed_view) override;
 
+  // GlanceableInfoView::Delegate:
+  SkColor GetTimeTemperatureFontColor() override;
+
+  // MediaStringView::Delegate:
+  MediaStringView::Settings GetSettings() override;
+
   void StartPlayingAnimation();
   void StartThroughputTracking();
   void RestartThroughputTracking();
