@@ -53,6 +53,10 @@ gfx::Rect AppListFolderItem::GetTargetIconRectInFolderForItem(
 // static
 const char AppListFolderItem::kItemType[] = "FolderItem";
 
+AppListFolderItem* AppListFolderItem::AsFolderItem() {
+  return this;
+}
+
 const char* AppListFolderItem::GetItemType() const {
   return AppListFolderItem::kItemType;
 }
