@@ -4,6 +4,7 @@
 
 #include "ash/app_list/model/app_list_item.h"
 
+#include "ash/app_list/model/app_list_folder_item.h"
 #include "ash/app_list/model/app_list_item_observer.h"
 #include "ash/public/cpp/app_list/app_list_config_provider.h"
 #include "ui/gfx/image/image_skia.h"
@@ -33,6 +34,10 @@ AppListItem::~AppListItem() {
     observer.ItemBeingDestroyed();
 }
 
+AppListFolderItem* AppListItem::AsFolderItem() {
+  return nullptr;
+}
+
 void AppListItem::SetIcon(AppListConfigType config_type,
                           const gfx::ImageSkia& icon) {
   per_config_icons_[config_type] = icon;
