@@ -1,4 +1,4 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -32,26 +32,6 @@ void SearchBoxModel::SetSearchEngineIsGoogle(bool is_google) {
     observer.SearchEngineChanged();
 }
 
-void SearchBoxModel::Update(const std::u16string& text,
-                            bool initiated_by_user) {
-  if (text_ == text)
-    return;
-
-  if (initiated_by_user) {
-    if (text_.empty() && !text.empty()) {
-      UMA_HISTOGRAM_ENUMERATION("Apps.AppListSearchCommenced", 1, 2);
-      base::RecordAction(base::UserMetricsAction("AppList_EnterSearch"));
-    } else if (!text_.empty() && text.empty()) {
-      // The user ended a search interaction. Reset search start time.
-      base::RecordAction(base::UserMetricsAction("AppList_LeaveSearch"));
-    }
-  }
-
-  text_ = text;
-  for (auto& observer : observers_)
-    observer.Update();
-}
-
 void SearchBoxModel::AddObserver(SearchBoxModelObserver* observer) {
   observers_.AddObserver(observer);
 }
