@@ -18,6 +18,7 @@
 #include "ui/compositor/layer_animation_observer.h"
 #include "ui/views/context_menu_controller.h"
 #include "ui/views/controls/button/button.h"
+#include "ui/views/controls/image_view.h"
 
 namespace gfx {
 class Point;
@@ -133,6 +134,15 @@ class ASH_EXPORT AppListItemView : public views::Button,
   // `app_list_config_`.
   void UpdateAppListConfig(const AppListConfig* app_list_config);
 
+  // Updates the currently dragged AppListItemView to update the `folder_icon_`.
+  void UpdateDraggedItem(const AppListItem* dragged_item);
+
+  // Updates and repaints the icon view, which could be either `icon_` or
+  // `folder_icon_`.
+  // For `icon_`, update the image icon from AppListItem if `update_item_icon`
+  // is true.
+  void UpdateIconView(bool update_item_icon);
+
   // Sets the icon of this image.
   void SetIcon(const gfx::ImageSkia& icon);
 
@@ -143,8 +153,6 @@ class ASH_EXPORT AppListItemView : public views::Button,
 
   void CancelContextMenu();
 
-  gfx::Point GetDragImageOffset();
-
   void SetAsAttemptedFolderTarget(bool is_target_folder);
 
   // Sets focus without a11y announcements or focus ring.
@@ -161,6 +169,9 @@ class ASH_EXPORT AppListItemView : public views::Button,
   // ending, so the runner of the drag should call this.
   void OnSyncDragEnd();
 
+  // Returns the view that draws the item view icon.
+  views::View* GetIconView() const;
+
   // Returns the icon bounds relative to AppListItemView.
   gfx::Rect GetIconBounds() const;
 
@@ -258,13 +269,19 @@ class ASH_EXPORT AppListItemView : public views::Button,
   bool has_pending_row_change() { return has_pending_row_change_; }
   void reset_has_pending_row_change() { has_pending_row_change_ = false; }
 
+  const ui::Layer* icon_background_layer_for_test() const {
+    return icon_background_layer_.layer();
+  }
+  bool is_icon_extended_for_test() const { return is_icon_extended_; }
+  absl::optional<size_t> item_counter_count_for_test() const;
+
  private:
+  class FolderIconView;
+
   friend class AppListItemViewTest;
   friend class AppListMainViewTest;
   friend class test::AppsGridViewTest;
 
-  class IconImageView;
-
   enum UIState {
     UI_STATE_NORMAL,              // Normal UI (icon + label)
     UI_STATE_DRAGGING,            // Dragging UI (scaled icon only)
@@ -289,27 +306,21 @@ class ASH_EXPORT AppListItemView : public views::Button,
     kStarted,
   };
 
-  // gfx::AnimationDelegate:
-  void AnimationProgressed(const gfx::Animation* animation) override;
-
   // Callback used when a menu is closed.
   void OnMenuClosed();
 
-  // Get icon from |item_| and schedule background processing.
-  void UpdateIcon();
-
-  // Update the tooltip text from |item_|.
-  void UpdateTooltip();
-
   void SetUIState(UIState state);
 
   // Scales up app icon if |scale_up| is true; otherwise, scale it back to
   // normal size.
   void ScaleAppIcon(bool scale_up);
 
-  // Scale app icon to |scale_factor| without animation.
+  // Scales app icon to |scale_factor| without animation.
   void ScaleIconImmediatly(float scale_factor);
 
+  // Updates the bounds of the icon background layer.
+  void UpdateBackgroundLayerBounds();
+
   // Sets |touch_dragging_| flag and updates UI.
   void SetTouchDragging(bool touch_dragging);
   // Sets |mouse_dragging_| flag and updates UI. Only to be called on
@@ -341,7 +352,6 @@ class ASH_EXPORT AppListItemView : public views::Button,
 
   // views::Button overrides:
   bool ShouldEnterPushedState(const ui::Event& event) override;
-  void PaintButtonContents(gfx::Canvas* canvas) override;
 
   // views::View overrides:
   void Layout() override;
@@ -372,16 +382,24 @@ class ASH_EXPORT AppListItemView : public views::Button,
   // ui::ImplicitAnimationObserver:
   void OnImplicitAnimationsCompleted() override;
 
-  // Returns the radius of preview circle.
-  int GetPreviewCircleRadius() const;
-
-  // Creates dragged view hover animation if it does not exist.
-  void CreateDraggedViewHoverAnimation();
-
   // Calculates the transform between the icon scaled by |icon_scale| and the
   // normal size icon.
   gfx::Transform GetScaleTransform(float icon_scale);
 
+  // Updates the icon extended state if another app is dragged onto this item
+  // view, which could be either an app or a folder. `extend_icon` is true if
+  // the icon background is going to extend, shrink the background otherwise.
+  // `animate` specifies if the visual update should be animated or not.
+  void SetBackgroundExtendedState(bool extend_icon, bool animate);
+
+  // Ensures that the layer where the icon background is painted on is created.
+  void EnsureIconBackgroundLayer();
+
+  void OnExtendingAnimationEnded(bool extend_icon);
+
+  // Returns the layer that paints the icon background.
+  ui::Layer* GetIconBackgroundLayer();
+
   // The app list config used to layout this view. The initial values is set
   // during view construction, but can be changed by calling
   // `UpdateAppListConfig()`.
@@ -402,8 +420,22 @@ class ASH_EXPORT AppListItemView : public views::Button,
   // AppListControllerImpl by another name.
   AppListViewDelegate* const view_delegate_;
 
-  IconImageView* icon_ = nullptr;  // Strongly typed child view.
-  views::Label* title_ = nullptr;  // Strongly typed child view.
+  // Set to true if the ImageSkia icon in AppListItem is drawn. The refreshed
+  // folder icons are directly drawn on FolderIconView instead of using the
+  // AppListItem icon.
+  const bool use_item_icon_;
+
+  // NOTE: Only one of `icon_` and `folder_icon_` is used for an item view.
+  // The icon view that uses the ImageSkia in AppListItem to draw the icon.
+  views::ImageView* icon_ = nullptr;
+  // The folder icon view used for refreshed folders.
+  FolderIconView* folder_icon_ = nullptr;
+
+  views::Label* title_ = nullptr;
+
+  // The background layer added under the `icon_` layer to paint the background
+  // of the icon.
+  ui::LayerOwner icon_background_layer_;
 
   // Draws a dot next to the title for newly installed apps.
   views::View* new_install_dot_ = nullptr;
@@ -429,9 +461,6 @@ class ASH_EXPORT AppListItemView : public views::Button,
   // Whether AppsGridView is in cardified state.
   bool in_cardified_grid_ = false;
 
-  // The animation that runs when dragged view enters or exits this view.
-  std::unique_ptr<gfx::SlideAnimation> dragged_view_hover_animation_;
-
   // The radius of preview circle for non-folder item.
   int preview_circle_radius_ = 0;
 
@@ -482,6 +511,14 @@ class ASH_EXPORT AppListItemView : public views::Button,
   // determine if the focus should be restored on context menu close.
   bool focus_removed_by_context_menu_ = false;
 
+  // Whether the `icon_` is in the extended state, where a dragged view entered
+  // this item view.
+  bool is_icon_extended_ = false;
+
+  // Whether the icon background animation is being setup. Used to prevent the
+  // background layer from being deleted during setup.
+  bool setting_up_icon_animation_ = false;
+
   base::WeakPtrFactory<AppListItemView> weak_ptr_factory_{this};
 };
 
