@@ -5,6 +5,7 @@
 #include <memory>
 #include <string>
 #include <tuple>
+#include <vector>
 
 #include "ash/app_list/app_list_controller_impl.h"
 #include "ash/app_list/model/app_list_item.h"
@@ -21,16 +22,19 @@
 #include "ash/test/pixel/ash_pixel_test_init_params.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
 #include "base/strings/string_util.h"
+#include "base/test/scoped_feature_list.h"
 
 namespace ash {
 
-class AppListItemViewPixelTest : public AshTestBase,
-                                 public testing::WithParamInterface<
-                                     std::tuple</*use_tablet_mode=*/bool,
-                                                /*use_dense_ui=*/bool,
-                                                /*use_rtl=*/bool,
-                                                /*is_new_install=*/bool,
-                                                /*has_notification=*/bool>> {
+class AppListItemViewPixelTest
+    : public AshTestBase,
+      public testing::WithParamInterface<
+          std::tuple</*use_folder_icon_refresh=*/bool,
+                     /*use_tablet_mode=*/bool,
+                     /*use_dense_ui=*/bool,
+                     /*use_rtl=*/bool,
+                     /*is_new_install=*/bool,
+                     /*has_notification=*/bool>> {
  public:
   // AshTestBase:
   absl::optional<pixel_test::InitParams> CreatePixelTestInitParams()
@@ -47,6 +51,10 @@ class AppListItemViewPixelTest : public AshTestBase,
     // As per `app_list_config_provider.cc`, dense values are used for screens
     // with width OR height <= 675.
     UpdateDisplay(use_dense_ui() ? "800x600" : "1200x800");
+    if (use_folder_icon_refresh()) {
+      scoped_feature_list_.InitAndEnableFeature(
+          features::kAppCollectionFolderRefresh);
+    }
 
     app_list_test_model_ = std::make_unique<test::AppListTestModel>();
     search_model_ = std::make_unique<SearchModel>();
@@ -96,11 +104,7 @@ class AppListItemViewPixelTest : public AshTestBase,
   }
 
   AppListItemView* GetItemViewAt(size_t index) {
-    auto* const helper = GetAppListTestHelper();
-    if (use_tablet_mode()) {
-      return helper->GetRootPagedAppsGridView()->GetItemViewAt(index);
-    }
-    return helper->GetScrollableAppsGridView()->GetItemViewAt(index);
+    return GetAppsGridView()->GetItemViewAt(index);
   }
 
   std::string GenerateScreenshotName() {
@@ -114,27 +118,36 @@ class AppListItemViewPixelTest : public AshTestBase,
     return base::JoinString({"app_list_item_view", stringified_params}, ".");
   }
 
-  bool use_tablet_mode() const { return std::get<0>(GetParam()); }
-  bool use_dense_ui() const { return std::get<1>(GetParam()); }
-  bool use_rtl() const { return std::get<2>(GetParam()); }
-  bool is_new_install() const { return std::get<3>(GetParam()); }
-  bool has_notification() const { return std::get<4>(GetParam()); }
+  bool use_folder_icon_refresh() const { return std::get<0>(GetParam()); }
+  bool use_tablet_mode() const { return std::get<1>(GetParam()); }
+  bool use_dense_ui() const { return std::get<2>(GetParam()); }
+  bool use_rtl() const { return std::get<3>(GetParam()); }
+  bool is_new_install() const { return std::get<4>(GetParam()); }
+  bool has_notification() const { return std::get<5>(GetParam()); }
 
  protected:
   std::unique_ptr<test::AppListTestModel> app_list_test_model_;
   std::unique_ptr<SearchModel> search_model_;
+
+ private:
+  base::test::ScopedFeatureList scoped_feature_list_;
 };
 
 INSTANTIATE_TEST_SUITE_P(
     All,
     AppListItemViewPixelTest,
-    testing::Combine(/*use_tablet_mode=*/testing::Bool(),
+    testing::Combine(/*use_folder_icon_refresh=*/testing::Bool(),
+                     /*use_tablet_mode=*/testing::Bool(),
                      /*use_dense_ui=*/testing::Bool(),
                      /*use_rtl=*/testing::Bool(),
                      /*is_new_install=*/testing::Bool(),
                      /*has_notification=*/testing::Bool()));
 
 TEST_P(AppListItemViewPixelTest, AppListItemView) {
+  // Folder icon refresh doesn't change the app list item view.
+  if (use_folder_icon_refresh()) {
+    return;
+  }
   CreateAppListItem("App");
   CreateAppListItem("App with a loooooooong name");
 
@@ -153,14 +166,28 @@ TEST_P(AppListItemViewPixelTest, AppListFolderItemsLayoutInIcon) {
     return;
   }
 
-  // Set the maximum number of the items in a folder that we want to test to 4.
-  const int max_items_in_folder = 4;
+  // Reset any configs set by previous tests so that
+  // ItemIconInFolderIconMargin() in app_list_config.cc is correctly
+  // initialized. Can be removed if folder icon refresh is set as default.
+  AppListConfigProvider::Get().ResetForTesting();
+
+  // To test the item counter on folder icons, set the maximum number of the
+  // items in a folder to 5. For legacy folder icons, set the max items to 4 to
+  // reduce the revisions.
+  const int max_items_in_folder = use_folder_icon_refresh() ? 5 : 4;
   CreateFoldersContainingDifferentNumOfItems(max_items_in_folder);
   ShowAppList();
 
-  EXPECT_TRUE(GetPixelDiffer()->CompareUiComponentsOnPrimaryScreen(
-      GenerateScreenshotName(), /*revision_number=*/0, GetItemViewAt(0),
-      GetItemViewAt(1), GetItemViewAt(2), GetItemViewAt(3)));
+  if (use_folder_icon_refresh()) {
+    EXPECT_TRUE(GetPixelDiffer()->CompareUiComponentsOnPrimaryScreen(
+        GenerateScreenshotName(), /*revision_number=*/1, GetItemViewAt(0),
+        GetItemViewAt(1), GetItemViewAt(2), GetItemViewAt(3),
+        GetItemViewAt(4)));
+  } else {
+    EXPECT_TRUE(GetPixelDiffer()->CompareUiComponentsOnPrimaryScreen(
+        GenerateScreenshotName(), /*revision_number=*/0, GetItemViewAt(0),
+        GetItemViewAt(1), GetItemViewAt(2), GetItemViewAt(3)));
+  }
 }
 
 // Verifies the folder icon is extended when an app is dragged upon it.
@@ -171,8 +198,15 @@ TEST_P(AppListItemViewPixelTest, AppListFolderIconExtendedState) {
     return;
   }
 
-  // Set the maximum number of the items in a folder that we want to test to 4.
-  const int max_items_in_folder = 4;
+  // Reset any configs set by previous tests so that
+  // ItemIconInFolderIconMargin() in app_list_config.cc is correctly
+  // initialized. Can be removed if folder icon refresh is set as default.
+  AppListConfigProvider::Get().ResetForTesting();
+
+  // To test the item counter on folder icons, set the maximum number of the
+  // items in a folder to 5. For legacy folder icons, set the max items to 4 to
+  // reduce the revisions.
+  const int max_items_in_folder = use_folder_icon_refresh() ? 5 : 4;
   CreateFoldersContainingDifferentNumOfItems(max_items_in_folder);
   CreateAppListItem("App");
   ShowAppList();
@@ -189,9 +223,16 @@ TEST_P(AppListItemViewPixelTest, AppListFolderIconExtendedState) {
     GetItemViewAt(i)->OnDraggedViewEnter();
   }
 
-  EXPECT_TRUE(GetPixelDiffer()->CompareUiComponentsOnPrimaryScreen(
-      GenerateScreenshotName(), /*revision_number=*/0, GetItemViewAt(0),
-      GetItemViewAt(1), GetItemViewAt(2), GetItemViewAt(3)));
+  if (use_folder_icon_refresh()) {
+    EXPECT_TRUE(GetPixelDiffer()->CompareUiComponentsOnPrimaryScreen(
+        GenerateScreenshotName(), /*revision_number=*/1, GetItemViewAt(0),
+        GetItemViewAt(1), GetItemViewAt(2), GetItemViewAt(3),
+        GetItemViewAt(4)));
+  } else {
+    EXPECT_TRUE(GetPixelDiffer()->CompareUiComponentsOnPrimaryScreen(
+        GenerateScreenshotName(), /*revision_number=*/0, GetItemViewAt(0),
+        GetItemViewAt(1), GetItemViewAt(2), GetItemViewAt(3)));
+  }
 
   // Reset the states.
   for (int i = 0; i < max_items_in_folder; ++i) {
@@ -210,6 +251,11 @@ TEST_P(AppListItemViewPixelTest, DraggedAppListFolderIcon) {
     return;
   }
 
+  // Reset any configs set by previous tests so that
+  // ItemIconInFolderIconMargin() in app_list_config.cc is correctly
+  // initialized. Can be removed if folder icon refresh is set as default.
+  AppListConfigProvider::Get().ResetForTesting();
+
   // Set the maximum number of the items in a folder that we want to test to 4.
   const int max_items_in_folder = 4;
   CreateFoldersContainingDifferentNumOfItems(max_items_in_folder);
@@ -217,30 +263,41 @@ TEST_P(AppListItemViewPixelTest, DraggedAppListFolderIcon) {
 
   auto* event_generator = GetEventGenerator();
   AppsGridView* apps_grid_view = GetAppsGridView();
+  gfx::Point grid_center = apps_grid_view->GetBoundsInScreen().CenterPoint();
+
+  // Create a folder item view list for folders with different number of items.
+  // This is used instead of GetItemViewAt() to prevent reordering while
+  // dragging each folder.
+  std::vector<AppListItemView*> folder_list;
+  for (int i = 0; i < max_items_in_folder; ++i) {
+    folder_list.push_back(GetItemViewAt(i));
+  }
 
   for (int i = 0; i < max_items_in_folder; ++i) {
     gfx::Point folder_icon_center =
-        GetItemViewAt(i)->GetIconBoundsInScreen().CenterPoint();
+        folder_list[i]->GetIconBoundsInScreen().CenterPoint();
 
     // Start dragging the folder icon.
     if (use_tablet_mode()) {
       event_generator->PressTouch(folder_icon_center);
-      GetItemViewAt(i)->FireTouchDragTimerForTest();
-      event_generator->MoveTouchBy(0, 20);
+      folder_list[i]->FireTouchDragTimerForTest();
+      event_generator->MoveTouch(grid_center);
       std::unique_ptr<test::AppsGridViewTestApi> test_api =
           std::make_unique<test::AppsGridViewTestApi>(apps_grid_view);
       test_api->WaitForItemMoveAnimationDone();
     } else {
       event_generator->MoveMouseTo(folder_icon_center);
       event_generator->PressLeftButton();
-      GetItemViewAt(i)->FireMouseDragTimerForTest();
-      event_generator->MoveMouseBy(0, 20);
+      folder_list[i]->FireMouseDragTimerForTest();
+      event_generator->MoveMouseTo(grid_center);
     }
 
+    const int revision_number = use_folder_icon_refresh() ? 3 : 2;
+
     std::string filename = base::NumberToString(i + 1) + "_items_folder";
     EXPECT_TRUE(GetPixelDiffer()->CompareUiComponentsOnPrimaryScreen(
         base::JoinString({GenerateScreenshotName(), filename}, "."),
-        /*revision_number=*/0,
+        revision_number,
         apps_grid_view->app_drag_icon_proxy_for_test()->GetWidgetForTesting()));
 
     // Release the drag.
