@@ -29,9 +29,9 @@
 #include "ash/public/cpp/app_list/app_list_features.h"
 #include "ash/public/cpp/pagination/pagination_model.h"
 #include "ash/search_box/search_box_view_base.h"
-#include "base/bind.h"
-#include "base/callback.h"
 #include "base/files/file_path.h"
+#include "base/functional/bind.h"
+#include "base/functional/callback.h"
 #include "base/strings/string_util.h"
 #include "ui/aura/window.h"
 #include "ui/compositor/layer.h"
@@ -77,8 +77,6 @@ void AppListMainView::AddContentsViews() {
   contents_view->SetPaintToLayer(ui::LAYER_NOT_DRAWN);
   contents_view->layer()->SetMasksToBounds(true);
   contents_view_ = AddChildView(std::move(contents_view));
-
-  search_box_view_->set_contents_view(contents_view_);
 }
 
 void AppListMainView::ShowAppListWhenReady() {
@@ -88,7 +86,7 @@ void AppListMainView::ShowAppListWhenReady() {
       wm::GetActivationClient(
           app_list_view_->GetWidget()->GetNativeView()->GetRootWindow())
           ->GetActiveWindow();
-  if (app_list_view_->is_tablet_mode() && active_window)
+  if (active_window)
     GetWidget()->ShowInactive();
   else
     GetWidget()->Show();
@@ -105,14 +103,6 @@ PaginationModel* AppListMainView::GetAppsPaginationModel() {
       ->pagination_model();
 }
 
-void AppListMainView::NotifySearchBoxVisibilityChanged() {
-  // Repaint the AppListView's background which will repaint the background for
-  // the search box. This is needed because this view paints to a layer and
-  // won't propagate paints upward.
-  if (parent())
-    parent()->SchedulePaint();
-}
-
 const char* AppListMainView::GetClassName() const {
   return "AppListMainView";
 }
