@@ -26,6 +26,7 @@
 #include "base/timer/timer.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
 #include "ui/base/metadata/metadata_header_macros.h"
+#include "ui/compositor/layer_tree_owner.h"
 #include "ui/compositor/throughput_tracker.h"
 #include "ui/events/keycodes/keyboard_codes_posix.h"
 #include "ui/views/animation/animation_abort_handle.h"
@@ -370,6 +371,13 @@ class ASH_EXPORT AppsGridView : public views::View,
     return drag_icon_proxy_.get();
   }
 
+  ui::Layer* drag_image_layer_for_test() const {
+    if (!drag_image_layer_) {
+      return nullptr;
+    }
+    return drag_image_layer_->root();
+  }
+
  protected:
   friend AppsGridViewTest;
   friend ScrollableAppsGridViewTest;
@@ -929,8 +937,10 @@ class ASH_EXPORT AppsGridView : public views::View,
   void OnIdealBoundsAnimationDone();
 
   // Callback method to clean up the dragging state of the app list.
-  void EndDragCallback(const ui::DropTargetEvent& event,
-                       ui::mojom::DragOperation& output_drag_op);
+  void EndDragCallback(
+      const ui::DropTargetEvent& event,
+      ui::mojom::DragOperation& output_drag_op,
+      std::unique_ptr<ui::LayerTreeOwner> drag_image_layer_owner);
 
   class ScopedModelUpdate;
 
@@ -1063,6 +1073,10 @@ class ASH_EXPORT AppsGridView : public views::View,
   // The location when |current_ghost_view_| was shown.
   GridIndex current_ghost_location_;
 
+  // The layer that contains the icon image for the item under the drag cursor.
+  // Assigned before the dropping animation is scheduled. Not owned.
+  std::unique_ptr<ui::LayerTreeOwner> drag_image_layer_;
+
   struct OpenFolderInfo {
     std::string item_id;
     GridIndex grid_index;
