@@ -44,9 +44,7 @@ class ASH_EXPORT AssistantPageView : public AppListPage,
   void RequestFocus() override;
   void GetAccessibleNodeData(ui::AXNodeData* node_data) override;
   void ChildPreferredSizeChanged(views::View* child) override;
-  void ChildVisibilityChanged(views::View* child) override;
   void VisibilityChanged(views::View* starting_from, bool is_visible) override;
-  void OnWillBeShown() override;
   void OnAnimationStarted(AppListState from_state,
                           AppListState to_state) override;
   gfx::Size GetPreferredSearchBoxSize() const override;
@@ -56,9 +54,6 @@ class ASH_EXPORT AssistantPageView : public AppListPage,
       AppListState state,
       const gfx::Rect& contents_bounds,
       const gfx::Rect& search_box_bounds) const override;
-  void AnimateYPosition(AppListViewState target_view_state,
-                        const TransformAnimator& animator,
-                        float default_offset) override;
 
   // ui::EventHandler:
   void OnMouseEvent(ui::MouseEvent* event) override;
@@ -84,7 +79,6 @@ class ASH_EXPORT AssistantPageView : public AppListPage,
  private:
   void InitLayout();
   void UpdateBackground(bool in_tablet_mode);
-  void MaybeUpdateAppListState(int child_height);
 
   AssistantViewDelegate* const assistant_view_delegate_;
 
