@@ -1,4 +1,4 @@
-// Copyright 2019 The Chromium Authors. All rights reserved.
+// Copyright 2019 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -24,7 +24,7 @@ class AssistantNotificationControllerImpl;
 // expiry_time| field).
 class AssistantNotificationExpiryMonitor {
  public:
-  using AssistantNotification = chromeos::assistant::AssistantNotification;
+  using AssistantNotification = assistant::AssistantNotification;
 
   explicit AssistantNotificationExpiryMonitor(
       AssistantNotificationControllerImpl* controller);
