@@ -5,12 +5,14 @@
 #include "ash/capture_mode/capture_mode_controller.h"
 
 #include <utility>
+#include <vector>
 
 #include "ash/capture_mode/capture_mode_ash_notification_view.h"
 #include "ash/capture_mode/capture_mode_camera_controller.h"
 #include "ash/capture_mode/capture_mode_metrics.h"
 #include "ash/capture_mode/capture_mode_notification_view.h"
 #include "ash/capture_mode/capture_mode_session.h"
+#include "ash/capture_mode/capture_mode_types.h"
 #include "ash/capture_mode/capture_mode_util.h"
 #include "ash/constants/ash_features.h"
 #include "ash/constants/notifier_catalogs.h"
@@ -59,7 +61,9 @@
 #include "ui/message_center/message_center.h"
 #include "ui/message_center/public/cpp/notification.h"
 #include "ui/message_center/public/cpp/notification_delegate.h"
+#include "ui/message_center/public/cpp/notification_types.h"
 #include "ui/snapshot/snapshot.h"
+#include "ui/views/widget/widget.h"
 
 namespace ash {
 
@@ -71,6 +75,7 @@ CaptureModeController* g_instance = nullptr;
 // consecutive.
 constexpr base::TimeDelta kConsecutiveScreenshotThreshold = base::Seconds(5);
 
+constexpr char kScreenCaptureNotificationId[] = "capture_mode_notification";
 constexpr char kScreenCaptureStoppedNotificationId[] =
     "capture_mode_stopped_notification";
 constexpr char kScreenCaptureNotifierId[] = "ash.capture_mode_controller";
@@ -124,6 +129,30 @@ enum VideoNotificationButtonIndex {
   BUTTON_DELETE_VIDEO = 0,
 };
 
+// Returns the file extension for the given `recording_type`.
+std::string GetVideoExtension(RecordingType recording_type) {
+  switch (recording_type) {
+    case RecordingType::kGif:
+      return "gif";
+    case RecordingType::kWebM:
+      return "webm";
+  }
+}
+
+// Returns true if the given `recording_type` supports audio recording.
+bool SupportsAudioRecording(RecordingType recording_type) {
+  return recording_type == RecordingType::kWebM;
+}
+
+bool IsVideoFileExtensionSupported(const base::FilePath& video_file_path) {
+  for (const auto* const extension : {".webm", ".gif"}) {
+    if (video_file_path.MatchesExtension(extension)) {
+      return true;
+    }
+  }
+  return false;
+}
+
 // Returns the date extracted from |timestamp| as a string to be part of
 // captured file names. Note that naturally formatted dates includes slashes
 // (e.g. 2020/09/02), which will cause problems when used in file names since
@@ -170,10 +199,8 @@ base::FilePath SelectFilePathForCapturedFile(
 base::FilePath DoSaveFile(scoped_refptr<base::RefCountedMemory> data,
                           const base::FilePath& path) {
   DCHECK(data);
-  const int size = static_cast<int>(data->size());
-  DCHECK(size);
-  if (size != base::WriteFile(
-                  path, reinterpret_cast<const char*>(data->front()), size)) {
+  DCHECK(data->size());
+  if (!base::WriteFile(path, *data)) {
     LOG(ERROR) << "Failed to save file: " << path;
     return base::FilePath();
   }
@@ -208,6 +235,16 @@ void DeleteFileAsync(scoped_refptr<base::SequencedTaskRunner> task_runner,
                      path));
 }
 
+// Adds the given `notification` to the message center after it removes any
+// existing notification that has the same ID.
+void AddNotificationToMessageCenter(
+    std::unique_ptr<message_center::Notification> notification) {
+  auto* message_center = message_center::MessageCenter::Get();
+  message_center->RemoveNotification(notification->id(),
+                                     /*by_user=*/false);
+  message_center->AddNotification(std::move(notification));
+}
+
 // Shows a Capture Mode related notification with the given parameters.
 // |for_video_thumbnail| will be considered only if |optional_fields| contain
 // an image to show in the notification as a thumbnail for what was captured.
@@ -241,12 +278,7 @@ void ShowNotification(
                                            : kScreenShotNotificationType);
   }
 
-  // Remove the previous notification before showing the new one if there is
-  // any.
-  auto* message_center = message_center::MessageCenter::Get();
-  message_center->RemoveNotification(notification_id,
-                                     /*by_user=*/false);
-  message_center->AddNotification(std::move(notification));
+  AddNotificationToMessageCenter(std::move(notification));
 }
 
 // Shows a notification informing the user that a Capture Mode operation has
@@ -258,6 +290,24 @@ void ShowFailureNotification() {
                    /*optional_fields=*/{}, /*delegate=*/nullptr);
 }
 
+// Shows a notification that indicates to the user that the GIF file is being
+// processed and will be ready shortly.
+void ShowGifProgressNotification() {
+  message_center::RichNotificationData optional_fields;
+  optional_fields.progress = -1;  // Infinite progress.
+  optional_fields.never_timeout = true;
+  AddNotificationToMessageCenter(CreateSystemNotificationPtr(
+      message_center::NOTIFICATION_TYPE_PROGRESS, kScreenCaptureNotificationId,
+      l10n_util::GetStringUTF16(IDS_ASH_SCREEN_CAPTURE_GIF_PROGRESS_TITLE),
+      l10n_util::GetStringUTF16(IDS_ASH_SCREEN_CAPTURE_GIF_PROGRESS_MESSAGE),
+      l10n_util::GetStringUTF16(IDS_ASH_SCREEN_CAPTURE_DISPLAY_SOURCE), GURL(),
+      message_center::NotifierId(message_center::NotifierType::SYSTEM_COMPONENT,
+                                 kScreenCaptureNotifierId,
+                                 NotificationCatalogName::kScreenCapture),
+      optional_fields, /*delegate=*/nullptr, kCaptureModeIcon,
+      message_center::SystemNotificationWarningLevel::NORMAL));
+}
+
 // Returns the ID of the message or the title for the notification based on
 // |allowance| and |for_title|.
 int GetDisabledNotificationMessageId(CaptureAllowance allowance,
@@ -281,7 +331,7 @@ int GetDisabledNotificationMessageId(CaptureAllowance allowance,
 void ShowDisabledNotification(CaptureAllowance allowance) {
   DCHECK(allowance != CaptureAllowance::kAllowed);
   ShowNotification(
-      capture_mode_util::kScreenCaptureNotificationId,
+      kScreenCaptureNotificationId,
       GetDisabledNotificationMessageId(allowance, /*for_title=*/true),
       GetDisabledNotificationMessageId(allowance, /*for_title=*/false),
       /*optional_fields=*/{}, /*delegate=*/nullptr,
@@ -349,6 +399,10 @@ void EmitServiceRecordingStatus(recording::mojom::RecordingStatus status) {
     case RecordingStatus::kLowDriveFsQuota:
       RecordEndRecordingReason(EndRecordingReason::kLowDriveFsQuota);
       break;
+    case RecordingStatus::kVideoEncoderReconfigurationFailure:
+      RecordEndRecordingReason(
+          EndRecordingReason::kVideoEncoderReconfigurationFailure);
+      break;
   }
 }
 
@@ -368,6 +422,30 @@ base::FilePath GetTempDir() {
   return temp_dir;
 }
 
+int GetNotificationTitleIdForFile(const base::FilePath& file_path) {
+  if (file_path.MatchesExtension(".gif")) {
+    return IDS_ASH_SCREEN_CAPTURE_GIF_RECORDING_TITLE;
+  }
+
+  if (file_path.MatchesExtension(".webm")) {
+    return IDS_ASH_SCREEN_CAPTURE_RECORDING_TITLE;
+  }
+
+  DCHECK(file_path.MatchesExtension(".png"));
+  return IDS_ASH_SCREEN_CAPTURE_SCREENSHOT_TITLE;
+}
+
+// Returns the size of the file at the given `file_path` in KBs. Returns -1 when
+// a failure occurs.
+int GetFileSizeInKB(const base::FilePath& file_path) {
+  int64_t size_in_bytes = 0;
+  if (!base::GetFileSize(file_path, &size_in_bytes)) {
+    return -1;
+  }
+  // Convert the value to KBs.
+  return size_in_bytes / 1024;
+}
+
 }  // namespace
 
 CaptureModeController::CaptureModeController(
@@ -377,9 +455,8 @@ CaptureModeController::CaptureModeController(
           std::make_unique<CaptureModeCameraController>(delegate_.get())),
       blocking_task_runner_(base::ThreadPool::CreateSequencedTaskRunner(
           // A task priority of BEST_EFFORT is good enough for this runner,
-          // since it's used for blocking file IO such as saving the screenshots
-          // or the successive webm video chunks received from the recording
-          // service.
+          // since it's used for blocking file IO such as saving the
+          // screenshots.
           {base::MayBlock(), base::TaskPriority::BEST_EFFORT,
            base::TaskShutdownBehavior::SKIP_ON_SHUTDOWN})),
       num_consecutive_screenshots_scheduler_(
@@ -479,6 +556,12 @@ bool CaptureModeController::IsAudioCaptureDisabledByPolicy() const {
   return delegate_->IsAudioCaptureDisabledByPolicy();
 }
 
+bool CaptureModeController::IsAudioRecordingInProgress() const {
+  return video_recording_watcher_ &&
+         !video_recording_watcher_->is_shutting_down() &&
+         video_recording_watcher_->is_recording_audio();
+}
+
 void CaptureModeController::SetSource(CaptureModeSource source) {
   if (source == source_)
     return;
@@ -674,6 +757,12 @@ void CaptureModeController::PerformCapture() {
 }
 
 void CaptureModeController::EndVideoRecording(EndRecordingReason reason) {
+  if (!is_recording_in_progress()) {
+    // A user may click on the stop recording button multiple times while still
+    // in the process of hiding. See http://b/270625738.
+    return;
+  }
+
   RecordEndRecordingReason(reason);
   recording_service_remote_->StopRecording();
   TerminateRecordingUiElements();
@@ -773,6 +862,33 @@ gfx::Rect CaptureModeController::GetCaptureSurfaceConfineBounds() const {
   return gfx::Rect();
 }
 
+std::vector<aura::Window*>
+CaptureModeController::GetWindowsForCollisionAvoidance() const {
+  std::vector<aura::Window*> windows_to_be_avoided;
+  if (IsActive()) {
+    aura::Window* capture_bar_window =
+        capture_mode_session_->capture_mode_bar_widget()->GetNativeWindow();
+    windows_to_be_avoided.push_back(capture_bar_window);
+  }
+
+  auto* camera_preview_widget = camera_controller_->camera_preview_widget();
+  if (camera_preview_widget && camera_preview_widget->IsVisible()) {
+    windows_to_be_avoided.push_back(camera_preview_widget->GetNativeView());
+  }
+
+  if (video_recording_watcher_ &&
+      !video_recording_watcher_->is_shutting_down() &&
+      video_recording_watcher_->recording_source() !=
+          CaptureModeSource::kWindow) {
+    if (auto* key_combo_widget =
+            video_recording_watcher_->GetKeyComboWidgetIfVisible()) {
+      windows_to_be_avoided.push_back(key_combo_widget->GetNativeWindow());
+    }
+  }
+
+  return windows_to_be_avoided;
+}
+
 void CaptureModeController::OnRecordingEnded(
     recording::mojom::RecordingStatus status,
     const gfx::ImageSkia& thumbnail) {
@@ -797,9 +913,8 @@ void CaptureModeController::OnActiveUserSessionChanged(
 
   // Remove the previous notification when switching to another user.
   auto* message_center = message_center::MessageCenter::Get();
-  message_center->RemoveNotificationsForNotifierId(message_center::NotifierId(
-      message_center::NotifierType::SYSTEM_COMPONENT, kScreenCaptureNotifierId,
-      NotificationCatalogName::kScreenCapture));
+  message_center->RemoveNotification(kScreenCaptureNotificationId,
+                                     /*by_user=*/false);
 }
 
 void CaptureModeController::OnSessionStateChanged(
@@ -833,7 +948,9 @@ void CaptureModeController::MaybeRestoreCachedCaptureConfigurations() {
 
   type_ = cached_normal_session_configs_->type;
   source_ = cached_normal_session_configs_->source;
+  recording_type_ = cached_normal_session_configs_->recording_type;
   enable_audio_recording_ = cached_normal_session_configs_->audio_on;
+  enable_demo_tools_ = cached_normal_session_configs_->demo_tools_enabled;
   cached_normal_session_configs_.reset();
 }
 
@@ -973,7 +1090,8 @@ CaptureModeController::GetCaptureParams() const {
 void CaptureModeController::LaunchRecordingServiceAndStartRecording(
     const CaptureParams& capture_params,
     mojo::PendingReceiver<viz::mojom::FrameSinkVideoCaptureOverlay>
-        cursor_overlay) {
+        cursor_overlay,
+    bool should_record_audio) {
   DCHECK(!recording_service_remote_.is_bound())
       << "Should not launch a new recording service while one is already "
          "running.";
@@ -1006,10 +1124,10 @@ void CaptureModeController::LaunchRecordingServiceAndStartRecording(
   // is ok since the |audio_stream_factory| parameter in the recording service
   // APIs is optional, and can be not bound.
   mojo::PendingRemote<media::mojom::AudioStreamFactory> audio_stream_factory;
-  if (GetAudioRecordingEnabled()) {
+  if (should_record_audio) {
     delegate_->BindAudioStreamFactory(
         audio_stream_factory.InitWithNewPipeAndPassReceiver());
-    capture_mode_util::MaybeUpdateMicrophonePrivacyIndicator(/*mic_on=*/true);
+    capture_mode_util::MaybeUpdateCaptureModePrivacyIndicators();
   }
 
   // Only act as a `DriveFsQuotaDelegate` for the recording service if the video
@@ -1096,7 +1214,7 @@ void CaptureModeController::FinalizeRecording(bool success,
   const bool was_in_projector_mode =
       video_recording_watcher_->is_in_projector_mode();
   video_recording_watcher_.reset();
-  capture_mode_util::MaybeUpdateMicrophonePrivacyIndicator(/*mic_on=*/false);
+  capture_mode_util::MaybeUpdateCaptureModePrivacyIndicators();
 
   delegate_->StopObservingRestrictedContent(
       base::BindOnce(&CaptureModeController::OnDlpRestrictionCheckedAtVideoEnd,
@@ -1122,6 +1240,13 @@ void CaptureModeController::TerminateRecordingUiElements() {
   camera_controller_->MaybeRevertAutoCameraSelection();
 
   video_recording_watcher_->ShutDown();
+
+  // GIF files take a while to finalize and fully get written to disk. Therefore
+  // we show a notification to the user to let them know that the file will be
+  // ready shortly.
+  if (current_video_file_path_.MatchesExtension(".gif")) {
+    ShowGifProgressNotification();
+  }
 }
 
 void CaptureModeController::CaptureImage(const CaptureParams& capture_params,
@@ -1222,9 +1347,11 @@ void CaptureModeController::OnImageFileSaved(
   ShowPreviewNotification(file_saved_path, image, CaptureModeType::kImage);
   if (Shell::Get()->session_controller()->IsActiveUserSessionStarted())
     RecordSaveToLocation(GetSaveToOption(file_saved_path));
-  HoldingSpaceClient* client = HoldingSpaceController::Get()->client();
-  if (client)  // May be `nullptr` in tests.
-    client->AddScreenshot(file_saved_path);
+  // NOTE: Holding space `client` may be `nullptr` in tests.
+  if (auto* client = HoldingSpaceController::Get()->client()) {
+    client->AddScreenCapture(HoldingSpaceItem::Type::kScreenshot,
+                             file_saved_path);
+  }
 }
 
 void CaptureModeController::OnVideoFileSaved(
@@ -1237,18 +1364,29 @@ void CaptureModeController::OnVideoFileSaved(
   if (!success) {
     ShowFailureNotification();
   } else {
+    const bool is_gif = saved_video_file_path.MatchesExtension(".gif");
     if (!in_projector_mode) {
       ShowPreviewNotification(saved_video_file_path,
                               gfx::Image(video_thumbnail),
                               CaptureModeType::kVideo);
-      HoldingSpaceClient* client = HoldingSpaceController::Get()->client();
-      if (client)  // May be `nullptr` in tests.
-        client->AddScreenRecording(saved_video_file_path);
+      // NOTE: Holding space `client` may be `nullptr` in tests.
+      if (auto* client = HoldingSpaceController::Get()->client()) {
+        client->AddScreenCapture(
+            is_gif ? HoldingSpaceItem::Type::kScreenRecordingGif
+                   : HoldingSpaceItem::Type::kScreenRecording,
+            saved_video_file_path);
+      }
+
+      // We only record the file size histogram if it's not a projector-
+      // initiated recording.
+      blocking_task_runner_->PostTaskAndReplyWithResult(
+          FROM_HERE, base::BindOnce(&GetFileSizeInKB, saved_video_file_path),
+          base::BindOnce(&RecordVideoFileSizeKB, is_gif));
     }
     DCHECK(!recording_start_time_.is_null());
     RecordCaptureModeRecordTime(
-        (base::TimeTicks::Now() - recording_start_time_).InSeconds(),
-        in_projector_mode);
+        (base::TimeTicks::Now() - recording_start_time_), in_projector_mode,
+        is_gif);
   }
   if (Shell::Get()->session_controller()->IsActiveUserSessionStarted())
     RecordSaveToLocation(GetSaveToOption(saved_video_file_path));
@@ -1262,8 +1400,7 @@ void CaptureModeController::ShowPreviewNotification(
     const gfx::Image& preview_image,
     const CaptureModeType type) {
   const bool for_video = type == CaptureModeType::kVideo;
-  const int title_id = for_video ? IDS_ASH_SCREEN_CAPTURE_RECORDING_TITLE
-                                 : IDS_ASH_SCREEN_CAPTURE_SCREENSHOT_TITLE;
+  const int title_id = GetNotificationTitleIdForFile(screen_capture_path);
   const int message_id = for_video && low_disk_space_threshold_reached_
                              ? IDS_ASH_SCREEN_CAPTURE_LOW_STORAGE_SPACE_MESSAGE
                              : IDS_ASH_SCREEN_CAPTURE_MESSAGE;
@@ -1278,11 +1415,10 @@ void CaptureModeController::ShowPreviewNotification(
   optional_fields.buttons.push_back(delete_button);
 
   optional_fields.image = preview_image;
+  optional_fields.image_path = screen_capture_path;
 
   ShowNotification(
-      capture_mode_util::GetScreenCaptureNotificationIdForPath(
-          screen_capture_path),
-      title_id, message_id, optional_fields,
+      kScreenCaptureNotificationId, title_id, message_id, optional_fields,
       base::MakeRefCounted<message_center::HandleNotificationClickDelegate>(
           base::BindRepeating(&CaptureModeController::HandleNotificationClicked,
                               weak_ptr_factory_.GetWeakPtr(),
@@ -1331,9 +1467,7 @@ void CaptureModeController::HandleNotificationClicked(
   // to this function. The callback's state owns any passed-by-ref arguments,
   // such as |screen_capture_path| which we use in this function.
   message_center::MessageCenter::Get()->RemoveNotification(
-      capture_mode_util::GetScreenCaptureNotificationIdForPath(
-          screen_capture_path),
-      /*by_user=*/false);
+      kScreenCaptureNotificationId, /*by_user=*/false);
 }
 
 base::FilePath CaptureModeController::BuildImagePath() const {
@@ -1343,7 +1477,7 @@ base::FilePath CaptureModeController::BuildImagePath() const {
 
 base::FilePath CaptureModeController::BuildVideoPath() const {
   return BuildPathNoExtension(kVideoFileNameFmtStr, base::Time::Now())
-      .AddExtension("webm");
+      .AddExtension(GetVideoExtension(recording_type_));
 }
 
 base::FilePath CaptureModeController::BuildImagePathForDisplay(
@@ -1437,6 +1571,8 @@ void CaptureModeController::OnProjectorContainerFolderCreated(
     return;
   }
 
+  // Note that the extension `webm` is used here directly, since projector
+  // doesn't work with any other format.
   BeginVideoRecording(capture_params, /*for_projector=*/true,
                       file_path_no_extension.AddExtension("webm"));
 }
@@ -1447,7 +1583,7 @@ void CaptureModeController::BeginVideoRecording(
     const base::FilePath& video_file_path) {
   DCHECK_EQ(capture_mode_session_->is_in_projector_mode(), for_projector);
   DCHECK(!video_file_path.empty());
-  DCHECK(video_file_path.MatchesExtension(".webm"));
+  DCHECK(IsVideoFileExtensionSupported(video_file_path));
 
   if (!IsActive()) {
     // This function gets called asynchronously, and until it gets called, the
@@ -1477,13 +1613,15 @@ void CaptureModeController::BeginVideoRecording(
   // video.
   Stop();
 
+  const bool should_record_audio =
+      SupportsAudioRecording(recording_type_) && GetAudioRecordingEnabled();
   mojo::PendingRemote<viz::mojom::FrameSinkVideoCaptureOverlay>
       cursor_capture_overlay;
   auto cursor_overlay_receiver =
       cursor_capture_overlay.InitWithNewPipeAndPassReceiver();
   video_recording_watcher_ = std::make_unique<VideoRecordingWatcher>(
       this, capture_params.window, std::move(cursor_capture_overlay),
-      for_projector);
+      for_projector, should_record_audio);
 
   // We only paint the recorded area highlight for window and region captures.
   if (source_ != CaptureModeSource::kFullscreen)
@@ -1493,8 +1631,13 @@ void CaptureModeController::BeginVideoRecording(
   recording_start_time_ = base::TimeTicks::Now();
   current_video_file_path_ = video_file_path;
 
-  LaunchRecordingServiceAndStartRecording(capture_params,
-                                          std::move(cursor_overlay_receiver));
+  LaunchRecordingServiceAndStartRecording(
+      capture_params, std::move(cursor_overlay_receiver), should_record_audio);
+
+  // Intentionally record the metrics before
+  // `MaybeRestoreCachedCaptureConfigurations` as `enable_demo_tools_` may be
+  // overwritten otherwise.
+  RecordRecordingStartsWithDemoTools(enable_demo_tools_, for_projector);
 
   // Restore the capture mode configurations that include the `type_`, `source_`
   // and `enable_audio_recording_` after projector-inititated recording starts
@@ -1508,8 +1651,6 @@ void CaptureModeController::BeginVideoRecording(
       capture_params.window, capture_params.bounds,
       base::BindOnce(&CaptureModeController::InterruptVideoRecording,
                      weak_ptr_factory_.GetWeakPtr()));
-
-  RecordRecordingStartsWithDemoTools(enable_demo_tools_, for_projector);
 }
 
 void CaptureModeController::InterruptVideoRecording() {
@@ -1686,11 +1827,14 @@ void CaptureModeController::OnDlpRestrictionCheckedAtSessionInit(
     // Cache the normal capture mode configurations that will be used for
     // restoration when switching to the normal capture mode session if needed.
     cached_normal_session_configs_ =
-        CaptureSessionConfigs{type_, source_, enable_audio_recording_};
+        CaptureSessionConfigs{type_, source_, recording_type_,
+                              enable_audio_recording_, enable_demo_tools_};
 
     enable_audio_recording_ = true;
+    enable_demo_tools_ = true;
     SetType(CaptureModeType::kVideo);
     SetSource(CaptureModeSource::kFullscreen);
+    SetRecordingType(RecordingType::kWebM);
   }
 
   RecordCaptureModeEntryType(entry_type);
@@ -1722,6 +1866,12 @@ void CaptureModeController::OnDlpRestrictionCheckedAtVideoEnd(
   current_video_file_path_.clear();
 
   if (should_delete_file) {
+    // Remove any lingering notification, e.g. the GIF progress notification,
+    // before proceeding, since it no longer makes sense as the file will be
+    // deleted.
+    message_center::MessageCenter::Get()->RemoveNotification(
+        kScreenCaptureNotificationId, /*by_user=*/false);
+
     DeleteFileAsync(blocking_task_runner_, video_file_path,
                     std::move(on_file_deleted_callback_for_test_));
   } else {
@@ -1772,6 +1922,7 @@ void CaptureModeController::
   RecordCaptureModeEntryType(CaptureModeEntryType::kCaptureAllDisplays);
   RecordCaptureModeConfiguration(
       CaptureModeType::kImage, CaptureModeSource::kFullscreen,
+      recording_type_,  // This parameter will be ignored.
       /*audio_on=*/false, /*is_in_projector_mode=*/false);
 }
 
