@@ -5,9 +5,9 @@
 #include "ash/capture_mode/capture_mode_menu_toggle_button.h"
 
 #include "ash/capture_mode/capture_mode_constants.h"
+#include "ash/capture_mode/capture_mode_session_focus_cycler.h"
 #include "ash/capture_mode/capture_mode_util.h"
 #include "ash/style/ash_color_id.h"
-#include "ash/style/ash_color_provider.h"
 #include "ui/base/metadata/metadata_impl_macros.h"
 #include "ui/views/controls/button/toggle_button.h"
 #include "ui/views/controls/image_view.h"
@@ -34,6 +34,7 @@ CaptureModeMenuToggleButton::CaptureModeMenuToggleButton(
       toggle_button_(AddChildView(
           std::make_unique<views::ToggleButton>(std::move(callback)))) {
   toggle_button_->SetAccessibleName(label_text);
+  CaptureModeSessionFocusCycler::HighlightHelper::Install(toggle_button_);
   icon_view_->SetImageSize(capture_mode::kSettingsIconSize);
   icon_view_->SetPreferredSize(capture_mode::kSettingsIconSize);
   icon_view_->SetImage(
@@ -63,10 +64,6 @@ void CaptureModeMenuToggleButton::OnThemeChanged() {
       color_provider->GetColor(kColorAshSwitchTrackColorInactive));
 }
 
-views::View* CaptureModeMenuToggleButton::GetView() {
-  return this;
-}
-
 BEGIN_METADATA(CaptureModeMenuToggleButton, views::View)
 END_METADATA
 
