@@ -10,6 +10,7 @@
 
 #include "ash/accessibility/magnifier/magnifier_glass.h"
 #include "ash/ash_export.h"
+#include "ash/capture_mode/capture_label_view.h"
 #include "ash/capture_mode/capture_mode_toast_controller.h"
 #include "ash/capture_mode/capture_mode_types.h"
 #include "ash/capture_mode/folder_selection_dialog_controller.h"
@@ -18,7 +19,6 @@
 #include "base/containers/flat_set.h"
 #include "base/memory/weak_ptr.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
-#include "ui/aura/window.h"
 #include "ui/aura/window_observer.h"
 #include "ui/compositor/layer_delegate.h"
 #include "ui/compositor/layer_owner.h"
@@ -26,7 +26,6 @@
 #include "ui/events/event.h"
 #include "ui/events/event_handler.h"
 #include "ui/gfx/geometry/point.h"
-#include "ui/views/controls/button/button.h"
 #include "ui/views/widget/unique_widget_ptr.h"
 #include "ui/views/widget/widget.h"
 
@@ -41,6 +40,7 @@ class CaptureModeController;
 class CaptureModeSessionFocusCycler;
 class CaptureModeSettingsView;
 class CaptureWindowObserver;
+class RecordingTypeMenuView;
 class UserNudgeController;
 class WindowDimmer;
 
@@ -119,9 +119,10 @@ class ASH_EXPORT CaptureModeSession
   // Called when switching a capture type from another capture type.
   void A11yAlertCaptureType();
 
-  // Called when either the capture source or type changes.
+  // Called when either the capture source, type, or recording type changes.
   void OnCaptureSourceChanged(CaptureModeSource new_source);
   void OnCaptureTypeChanged(CaptureModeType new_type);
+  void OnRecordingTypeChanged();
 
   // When performing capture, or at the end of the 3-second count down, the DLP
   // manager is checked for any restricted content. The DLP manager may choose
@@ -136,8 +137,10 @@ class ASH_EXPORT CaptureModeSession
   // OnWaitingForDlpConfirmationStarted().
   void OnWaitingForDlpConfirmationEnded(bool reshow_uis);
 
-  // Called when the settings menu is toggled.
-  void SetSettingsMenuShown(bool shown);
+  // Called when the settings menu is toggled. If `by_key_event` is true, it
+  // means that the settings menu is being opened or closed as a result of a key
+  // event (e.g. pressing the space bar) on the settings button.
+  void SetSettingsMenuShown(bool shown, bool by_key_event = false);
 
   // Called when the user performs a capture. Records histograms related to this
   // session.
@@ -164,12 +167,12 @@ class ASH_EXPORT CaptureModeSession
 
   // Returns the current parent window for the on-capture-surface widgets such
   // as `CaptureModeCameraController::camera_preview_widget_` and
-  // `CaptureModeDemoToolsController::demo_tools_widget_` when capture mode
+  // `CaptureModeDemoToolsController::key_combo_widget_` when capture mode
   // session is active.
   aura::Window* GetOnCaptureSurfaceWidgetParentWindow() const;
 
   // Returns the confine bounds for the on-capture-surface widgets (such as the
-  // camera preview and demo tools widgets) when capture session is active.
+  // camera preview widget and key combo widget) when capture session is active.
   gfx::Rect GetCaptureSurfaceConfineBounds() const;
 
   // Returns the in-session target value that should be used for the visibility
@@ -294,6 +297,10 @@ class ASH_EXPORT CaptureModeSession
   // record button in the capture label view.
   void DoPerformCapture();
 
+  // Called when the drop-down button in the `capture_label_widget_` is pressed
+  // which toggles the recording type menu on and off.
+  void OnRecordingTypeDropDownButtonPressed(const ui::Event& event);
+
   // Gets the bounds of current window selected for |kWindow| capture source.
   gfx::Rect GetSelectedWindowBounds() const;
 
@@ -420,12 +427,21 @@ class ASH_EXPORT CaptureModeSession
   // camera preview's bounds and visibility.
   void MaybeUpdateCameraPreviewBounds();
 
-  // Returns true if the given `event` is targeted on the capture bar.
-  bool IsEventTargetedOnCaptureBar(const ui::LocatedEvent& event) const;
+  // Creates or distroys the recording type menu widget based on the given
+  // `shown` value. If `by_key_event` is true, it means that the recording type
+  // menu is being opened or closed as a result of a key event (e.g. pressing
+  // the space bar) on the recording type drop down button.
+  void SetRecordingTypeMenuShown(bool shown, bool by_key_event = false);
 
-  // Returns true if the given `event` is targeted on the setting menu if it
-  // exists.
-  bool IsEventTargetedOnSettingsMenu(const ui::LocatedEvent& event) const;
+  // Returns true if the given `screen_location` is on the drop down button in
+  // the `capture_label_widget_` which when clicked opens the recording type
+  // menu.
+  bool IsPointOnRecordingTypeDropDownButton(
+      const gfx::Point& screen_location) const;
+
+  // Updates the availability or bounds of the recording type menu widget
+  // according to the current state.
+  void MaybeUpdateRecordingTypeMenu();
 
   CaptureModeController* const controller_;
 
@@ -454,6 +470,12 @@ class ASH_EXPORT CaptureModeSession
   // starting capturing, the widget will transform into a 3-second countdown
   // timer.
   views::UniqueWidgetPtr capture_label_widget_;
+  CaptureLabelView* capture_label_view_ = nullptr;
+
+  // Widget that hosts the recording type menu, from which the user can pick the
+  // desired recording format type.
+  views::UniqueWidgetPtr recording_type_menu_widget_;
+  RecordingTypeMenuView* recording_type_menu_view_ = nullptr;
 
   // Magnifier glass used during a region capture session.
   MagnifierGlass magnifier_glass_;
