@@ -24,6 +24,7 @@ class CaptureModeBarView;
 class CaptureModeMenuGroup;
 class CaptureModeSession;
 class CaptureModeMenuToggleButton;
+class SystemShadow;
 
 // All the options in the CaptureMode settings view.
 enum CaptureSettingsOption {
@@ -169,6 +170,8 @@ class ASH_EXPORT CaptureModeSettingsView
   // If set, it will be called when the settings menu is refreshed.
   base::OnceClosure on_settings_menu_refreshed_callback_for_test_;
 
+  std::unique_ptr<SystemShadow> shadow_;
+
   base::WeakPtrFactory<CaptureModeSettingsView> weak_ptr_factory_{this};
 };
 
