@@ -4,6 +4,9 @@
 
 #include "ash/capture_mode/capture_mode_test_util.h"
 
+#include "ash/accessibility/a11y_feature_type.h"
+#include "ash/accessibility/accessibility_controller_impl.h"
+#include "ash/accessibility/autoclick/autoclick_controller.h"
 #include "ash/capture_mode/capture_mode_bar_view.h"
 #include "ash/capture_mode/capture_mode_controller.h"
 #include "ash/capture_mode/capture_mode_session_test_api.h"
@@ -16,7 +19,7 @@
 #include "ash/public/cpp/projector/speech_recognition_availability.h"
 #include "ash/shell.h"
 #include "ash/style/icon_button.h"
-#include "ash/wm/cursor_manager_chromeos.h"
+#include "ash/system/accessibility/autoclick_menu_bubble_controller.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller_test_api.h"
 #include "base/files/file_path.h"
 #include "base/files/file_util.h"
@@ -25,6 +28,7 @@
 #include "base/task/single_thread_task_runner.h"
 #include "base/test/bind.h"
 #include "testing/gtest/include/gtest/gtest.h"
+#include "ui/base/ime/constants.h"
 #include "ui/display/screen.h"
 #include "ui/events/test/event_generator.h"
 #include "ui/views/view.h"
@@ -32,6 +36,27 @@
 
 namespace ash {
 
+namespace {
+
+// Dispatch the simulated virtual key event to the WindowEventDispatcher.
+void DispatchVKEvent(ui::test::EventGenerator* event_generator,
+                     bool is_press,
+                     ui::KeyboardCode key_code,
+                     int flags,
+                     int source_device_id) {
+  ui::EventType type = is_press ? ui::ET_KEY_PRESSED : ui::ET_KEY_RELEASED;
+  ui::KeyEvent keyev(type, key_code, flags);
+
+  keyev.SetProperties({{
+      ui::kPropertyFromVK,
+      std::vector<uint8_t>(ui::kPropertyFromVKSize),
+  }});
+  keyev.set_source_device_id(source_device_id);
+  event_generator->Dispatch(&keyev);
+}
+
+}  // namespace
+
 CaptureModeController* StartCaptureSession(CaptureModeSource source,
                                            CaptureModeType type) {
   auto* controller = CaptureModeController::Get();
@@ -192,13 +217,51 @@ void SetDeviceScaleFactor(float dsf) {
   }
 }
 
+views::Widget* EnableAndGetAutoClickBubbleWidget() {
+  auto* autoclick_controller = Shell::Get()->autoclick_controller();
+  autoclick_controller->SetEnabled(true, /*show_confirmation_dialog=*/false);
+  Shell::Get()
+      ->accessibility_controller()
+      ->GetFeature(A11yFeatureType::kAutoclick)
+      .SetEnabled(true);
+
+  views::Widget* autoclick_bubble_widget =
+      autoclick_controller->GetMenuBubbleControllerForTesting()
+          ->GetBubbleWidgetForTesting();
+  EXPECT_TRUE(autoclick_bubble_widget->IsVisible());
+  return autoclick_bubble_widget;
+}
+
+void PressKeyOnVK(ui::test::EventGenerator* event_generator,
+                  ui::KeyboardCode key_code,
+                  int flags,
+                  int source_device_id) {
+  DispatchVKEvent(event_generator, /*is_press=*/true, key_code, flags,
+                  source_device_id);
+}
+
+void ReleaseKeyOnVK(ui::test::EventGenerator* event_generator,
+                    ui::KeyboardCode key_code,
+                    int flags,
+                    int source_device_id) {
+  DispatchVKEvent(event_generator, /*is_press=*/false, key_code, flags,
+                  source_device_id);
+}
+
+void PressAndReleaseKeyOnVK(ui::test::EventGenerator* event_generator,
+                            ui::KeyboardCode key_code,
+                            int flags,
+                            int source_device_id) {
+  PressKeyOnVK(event_generator, key_code, flags, source_device_id);
+  ReleaseKeyOnVK(event_generator, key_code, flags, source_device_id);
+}
+
 // -----------------------------------------------------------------------------
 // ProjectorCaptureModeIntegrationHelper:
 
 ProjectorCaptureModeIntegrationHelper::ProjectorCaptureModeIntegrationHelper() {
   scoped_feature_list_.InitWithFeatures(
-      /*enabled_features=*/{features::kProjector,
-                            features::kProjectorAnnotator},
+      /*enabled_features=*/{features::kProjector},
       /*disabled_features=*/{});
 }
 
