@@ -110,6 +110,24 @@ bool IsLayerStackedRightBelow(ui::Layer* layer, ui::Layer* sibling);
 // Sets the device scale factor for only the first available display.
 void SetDeviceScaleFactor(float dsf);
 
+// Enables the auto click accessibility feature, and returns the auto click
+// bubble widget.
+views::Widget* EnableAndGetAutoClickBubbleWidget();
+
+// Functions to simulate triggering key events from the virtual keyboard.
+void PressKeyOnVK(ui::test::EventGenerator* event_generator,
+                  ui::KeyboardCode key_code,
+                  int flags,
+                  int source_device_id = ui::ED_UNKNOWN_DEVICE);
+void ReleaseKeyOnVK(ui::test::EventGenerator* event_generator,
+                    ui::KeyboardCode key_code,
+                    int flags,
+                    int source_device_id = ui::ED_UNKNOWN_DEVICE);
+void PressAndReleaseKeyOnVK(ui::test::EventGenerator* event_generator,
+                            ui::KeyboardCode key_code,
+                            int flags = ui::EF_NONE,
+                            int source_device_id = ui::ED_UNKNOWN_DEVICE);
+
 // Defines a helper class to allow setting up and testing the Projector feature
 // in multiple test fixtures. Note that this helper initializes the Projector-
 // related features in its constructor, so test fixtures that use this should
