@@ -9,6 +9,7 @@
 #include "ash/capture_mode/capture_mode_constants.h"
 #include "ash/capture_mode/capture_mode_controller.h"
 #include "ash/capture_mode/capture_mode_session.h"
+#include "ash/capture_mode/capture_mode_types.h"
 #include "ash/capture_mode/stop_recording_button_tray.h"
 #include "ash/constants/ash_features.h"
 #include "ash/public/cpp/clipboard_history_controller.h"
@@ -46,11 +47,8 @@ constexpr int kBannerViewTopRadius = 0;
 constexpr int kBannerViewBottomRadius = 8;
 constexpr float kScaleUpFactor = 0.8f;
 
-// The app IDs used for the capture mode camera and microphone recording privacy
-// indicators.
-constexpr char kCameraPrivacyIndicatorId[] = "system-capture-mode-camera";
-constexpr char kMicrophonePrivacyIndicatorId[] =
-    "system-capture-mode-microphone";
+// The app ID used for the capture mode privacy indicators.
+constexpr char kCaptureModePrivacyIndicatorsId[] = "system-capture-mode";
 
 // Returns the target visibility of the camera preview, given the
 // `confine_bounds_short_side_length`. The out parameter
@@ -465,7 +463,7 @@ bool SetWidgetVisibility(views::Widget* widget,
 
 aura::Window* GetPreferredRootWindow(
     absl::optional<gfx::Point> location_in_screen) {
-  int64_t display_id =
+  const int64_t display_id =
       (location_in_screen
            ? display::Screen::GetScreen()->GetDisplayNearestPoint(
                  *location_in_screen)
@@ -475,7 +473,8 @@ aura::Window* GetPreferredRootWindow(
   // The Display object returned by `CursorManager::GetDisplay()` may be stale,
   // but will have the correct id.
   DCHECK_NE(display::kInvalidDisplayId, display_id);
-  return Shell::GetRootWindowForDisplayId(display_id);
+  auto* root = Shell::GetRootWindowForDisplayId(display_id);
+  return root ? root : Shell::GetPrimaryRootWindow();
 }
 
 void ConfigLabelView(views::Label* label_view) {
@@ -494,24 +493,22 @@ views::BoxLayout* CreateAndInitBoxLayoutForView(views::View* view) {
   return box_layout;
 }
 
-std::string GetScreenCaptureNotificationIdForPath(const base::FilePath& path) {
-  DCHECK(!path.empty());
-  return base::StringPrintf("%s-%s", kScreenCaptureNotificationId,
-                            path.BaseName().value().c_str());
-}
-
-void MaybeUpdateCameraPrivacyIndicator(bool camera_on) {
-  if (features::IsPrivacyIndicatorsEnabled()) {
-    UpdatePrivacyIndicatorsView(kCameraPrivacyIndicatorId, camera_on,
-                                /*is_microphone_used=*/false);
+void MaybeUpdateCaptureModePrivacyIndicators() {
+  if (!features::IsPrivacyIndicatorsEnabled()) {
+    return;
   }
-}
 
-void MaybeUpdateMicrophonePrivacyIndicator(bool mic_on) {
-  if (features::IsPrivacyIndicatorsEnabled()) {
-    UpdatePrivacyIndicatorsView(kMicrophonePrivacyIndicatorId,
-                                /*is_camera_used=*/false, mic_on);
-  }
+  auto* controller = CaptureModeController::Get();
+  const bool is_camera_used =
+      !!controller->camera_controller()->camera_preview_widget();
+  const bool is_microphone_used = controller->IsAudioRecordingInProgress();
+
+  UpdatePrivacyIndicators(
+      /*app_id=*/kCaptureModePrivacyIndicatorsId,
+      /*app_name=*/
+      l10n_util::GetStringUTF16(IDS_ASH_STATUS_TRAY_CAPTURE_MODE_BUTTON_LABEL),
+      is_camera_used, is_microphone_used, /*delegate=*/
+      base::MakeRefCounted<PrivacyIndicatorsNotificationDelegate>());
 }
 
 ui::ColorProvider* GetColorProviderForNativeTheme() {
@@ -533,4 +530,20 @@ gfx::Rect CalculateHighlightLayerBounds(const gfx::PointF& center_point,
                    highlight_layer_radius * 2, highlight_layer_radius * 2);
 }
 
+int GetNumberOfSupportedRecordingTypes(bool is_in_projector_mode) {
+  int total = 0;
+  for (const auto& type : {RecordingType::kGif, RecordingType::kWebM}) {
+    switch (type) {
+      case RecordingType::kGif:
+        total +=
+            features::IsGifRecordingEnabled() && !is_in_projector_mode ? 1 : 0;
+        break;
+      case RecordingType::kWebM:
+        total += 1;
+        break;
+    }
+  }
+  return total;
+}
+
 }  // namespace ash::capture_mode_util
