@@ -186,14 +186,9 @@ void ConfigLabelView(views::Label* label_view);
 // Initializes the box layout for the `view` in the settings menu.
 views::BoxLayout* CreateAndInitBoxLayoutForView(views::View* view);
 
-// Gets the notification ID of a screen capture given its filepath.
-ASH_EXPORT std::string GetScreenCaptureNotificationIdForPath(
-    const base::FilePath& path);
-
-// If the privacy indicators feature is enabled, the below functions update the
-// camera and microphone capture mode indicators according to the given values.
-void MaybeUpdateCameraPrivacyIndicator(bool camera_on);
-void MaybeUpdateMicrophonePrivacyIndicator(bool mic_on);
+// If the privacy indicators feature is enabled, the below function update the
+// camera and microphone capture mode indicators according to the current state.
+void MaybeUpdateCaptureModePrivacyIndicators();
 
 ui::ColorProvider* GetColorProviderForNativeTheme();
 
@@ -209,6 +204,10 @@ ASH_EXPORT gfx::Rect CalculateHighlightLayerBounds(
     const gfx::PointF& center_point,
     int highlight_layer_radius);
 
+// Returns the number of currently supported recording types. The value may
+// differ based on whether `is_in_projector_mode` is true or false.
+int GetNumberOfSupportedRecordingTypes(bool is_in_projector_mode);
+
 }  // namespace capture_mode_util
 
 }  // namespace ash
