@@ -42,6 +42,7 @@
 #include "ui/gfx/geometry/size_f.h"
 #include "ui/gfx/native_widget_types.h"
 #include "ui/gfx/scoped_canvas.h"
+#include "ui/views/widget/widget.h"
 #include "ui/wm/core/coordinate_conversion.h"
 #include "ui/wm/public/activation_client.h"
 
@@ -179,14 +180,16 @@ VideoRecordingWatcher::VideoRecordingWatcher(
     aura::Window* window_being_recorded,
     mojo::PendingRemote<viz::mojom::FrameSinkVideoCaptureOverlay>
         cursor_capture_overlay,
-    bool projector_mode)
+    bool projector_mode,
+    bool is_recording_audio)
     : controller_(controller),
       cursor_manager_(Shell::Get()->cursor_manager()),
       window_being_recorded_(window_being_recorded),
       current_root_(window_being_recorded->GetRootWindow()),
       recording_source_(controller_->source()),
       cursor_capture_overlay_remote_(std::move(cursor_capture_overlay)),
-      is_in_projector_mode_(projector_mode) {
+      is_in_projector_mode_(projector_mode),
+      is_recording_audio_(is_recording_audio) {
   DCHECK(controller_);
   DCHECK(window_being_recorded_);
   DCHECK(current_root_);
@@ -279,6 +282,7 @@ void VideoRecordingWatcher::ShutDown() {
   recording_overlay_controller_.reset();
   demo_tools_controller_.reset();
   dimmers_.clear();
+  ReleaseLayer();
 
   if (features::IsProjectorEnabled())
     ProjectorControllerImpl::Get()->OnRecordingEnded(is_in_projector_mode_);
@@ -327,6 +331,27 @@ gfx::Rect VideoRecordingWatcher::GetCaptureSurfaceConfineBounds() const {
   }
 }
 
+gfx::Rect VideoRecordingWatcher::GetEffectivePartialRegionBounds() const {
+  DCHECK_EQ(recording_source_, CaptureModeSource::kRegion);
+  // TODO(afakhry): Consider having the region to anchor to the nearest corner,
+  // so that screen rotation doesn't result in the apparent change of the region
+  // position. Discussion with PM/UX determined that this is a low priority for
+  // now.
+  gfx::Rect result = partial_region_bounds_;
+  result.AdjustToFit(current_root_->bounds());
+  return result;
+}
+
+const views::Widget* VideoRecordingWatcher::GetKeyComboWidgetIfVisible() const {
+  if (demo_tools_controller_) {
+    const auto* key_combo_widget = demo_tools_controller_->key_combo_widget();
+    if (key_combo_widget && key_combo_widget->IsVisible()) {
+      return key_combo_widget;
+    }
+  }
+  return nullptr;
+}
+
 void VideoRecordingWatcher::OnWindowParentChanged(aura::Window* window,
                                                   aura::Window* parent) {
   DCHECK_EQ(window, window_being_recorded_);
@@ -548,8 +573,9 @@ void VideoRecordingWatcher::OnMouseEvent(ui::MouseEvent* event) {
       if (camera_preview_view)
         camera_preview_view->MaybeBlurFocus(*event);
 
-      if (demo_tools_controller_)
+      if (demo_tools_controller_ && PointerHighlightingEnabled()) {
         demo_tools_controller_->PerformMousePressAnimation(location_in_window);
+      }
     }
       [[fallthrough]];
     case ui::ET_MOUSE_RELEASED:
@@ -563,10 +589,7 @@ void VideoRecordingWatcher::OnMouseEvent(ui::MouseEvent* event) {
 }
 
 void VideoRecordingWatcher::OnTouchEvent(ui::TouchEvent* event) {
-  if (demo_tools_controller_ && (event->type() == ui::ET_TOUCH_PRESSED ||
-                                 event->type() == ui::ET_TOUCH_RELEASED ||
-                                 event->type() == ui::ET_TOUCH_MOVED ||
-                                 event->type() == ui::ET_TOUCH_CANCELLED)) {
+  if (demo_tools_controller_ && PointerHighlightingEnabled()) {
     demo_tools_controller_->OnTouchEvent(
         event->type(), event->pointer_details().id,
         GetEventLocationInWindow(window_being_recorded_, *event));
@@ -590,17 +613,6 @@ void VideoRecordingWatcher::OnCursorCompositingStateChanged(bool enabled) {
           : GetCursorLocationInWindow(window_being_recorded_));
 }
 
-gfx::Rect VideoRecordingWatcher::GetEffectivePartialRegionBounds() const {
-  DCHECK_EQ(recording_source_, CaptureModeSource::kRegion);
-  // TODO(afakhry): Consider having the region to anchor to the nearest corner,
-  // so that screen rotation doesn't result in the apparent change of the region
-  // position. Discussion with PM/UX determined that this is a low priority for
-  // now.
-  gfx::Rect result = partial_region_bounds_;
-  result.AdjustToFit(current_root_->bounds());
-  return result;
-}
-
 bool VideoRecordingWatcher::IsWindowDimmedForTesting(
     aura::Window* window) const {
   return dimmers_.contains(window);
@@ -871,4 +883,9 @@ gfx::Rect VideoRecordingWatcher::GetOverlayWidgetBounds() const {
   return bounds;
 }
 
+bool VideoRecordingWatcher::PointerHighlightingEnabled() const {
+  return !(recording_overlay_controller_ &&
+           recording_overlay_controller_->is_enabled());
+}
+
 }  // namespace ash
