@@ -10,6 +10,7 @@
 #include <vector>
 
 #include "ash/accelerators/accelerator_controller_impl.h"
+#include "ash/clipboard/clipboard_history_item.h"
 #include "ash/clipboard/clipboard_history_menu_model_adapter.h"
 #include "ash/clipboard/clipboard_history_resource_manager.h"
 #include "ash/clipboard/clipboard_history_util.h"
@@ -26,6 +27,7 @@
 #include "ash/system/toast/toast_manager_impl.h"
 #include "ash/wm/window_util.h"
 #include "base/barrier_closure.h"
+#include "base/check.h"
 #include "base/check_op.h"
 #include "base/functional/bind.h"
 #include "base/functional/callback_forward.h"
@@ -42,8 +44,8 @@
 #include "base/task/single_thread_task_runner.h"
 #include "base/task/thread_pool.h"
 #include "base/unguessable_token.h"
-#include "base/values.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
+#include "ui/aura/window.h"
 #include "ui/aura/window_tree_host.h"
 #include "ui/base/accelerators/accelerator.h"
 #include "ui/base/clipboard/clipboard_data.h"
@@ -57,6 +59,7 @@
 #include "ui/base/models/simple_menu_model.h"
 #include "ui/base/webui/web_ui_util.h"
 #include "ui/chromeos/events/keyboard_capability.h"
+#include "ui/color/color_provider_source.h"
 #include "ui/events/event.h"
 #include "ui/events/event_constants.h"
 #include "ui/events/keycodes/keyboard_codes_posix.h"
@@ -68,15 +71,6 @@ namespace ash {
 
 namespace {
 
-constexpr char kImageDataKey[] = "imageData";
-constexpr char kTextDataKey[] = "textData";
-constexpr char kFormatDataKey[] = "displayFormat";
-
-constexpr char kPngFormat[] = "png";
-constexpr char kHtmlFormat[] = "html";
-constexpr char kTextFormat[] = "text";
-constexpr char kFileFormat[] = "file";
-
 ui::ClipboardNonBacked* GetClipboard() {
   auto* clipboard = ui::ClipboardNonBacked::GetForCurrentThread();
   DCHECK(clipboard);
@@ -281,6 +275,9 @@ ClipboardHistoryControllerImpl::~ClipboardHistoryControllerImpl() {
 }
 
 void ClipboardHistoryControllerImpl::Shutdown() {
+  if (IsMenuShowing()) {
+    context_menu_->Cancel(/*will_paste_item=*/false);
+  }
   nudge_controller_.reset();
 }
 
@@ -325,12 +322,21 @@ void ClipboardHistoryControllerImpl::RemoveObserver(
   observers_.RemoveObserver(observer);
 }
 
-void ClipboardHistoryControllerImpl::ShowMenu(
+bool ClipboardHistoryControllerImpl::ShowMenu(
     const gfx::Rect& anchor_rect,
     ui::MenuSourceType source_type,
     crosapi::mojom::ClipboardHistoryControllerShowSource show_source) {
+  return ShowMenu(anchor_rect, source_type, show_source,
+                  OnMenuClosingCallback());
+}
+
+bool ClipboardHistoryControllerImpl::ShowMenu(
+    const gfx::Rect& anchor_rect,
+    ui::MenuSourceType source_type,
+    crosapi::mojom::ClipboardHistoryControllerShowSource show_source,
+    OnMenuClosingCallback callback) {
   if (IsMenuShowing() || !CanShowMenu())
-    return;
+    return false;
 
   // Close the running context menu if any before showing the clipboard history
   // menu. Because the clipboard history menu should not be nested.
@@ -338,8 +344,9 @@ void ClipboardHistoryControllerImpl::ShowMenu(
   if (active_menu_instance)
     active_menu_instance->Cancel(views::MenuController::ExitType::kAll);
 
+  // `Unretained()` is safe because `this` owns `context_menu_`.
   context_menu_ = ClipboardHistoryMenuModelAdapter::Create(
-      menu_delegate_.get(),
+      menu_delegate_.get(), std::move(callback),
       base::BindRepeating(&ClipboardHistoryControllerImpl::OnMenuClosed,
                           base::Unretained(this)),
       clipboard_history_.get(), resource_manager_.get());
@@ -374,16 +381,57 @@ void ClipboardHistoryControllerImpl::ShowMenu(
   for (auto& observer : observers_) {
     observer.OnClipboardHistoryMenuShown(show_source);
   }
+  return true;
+}
+
+void ClipboardHistoryControllerImpl::GetHistoryValues(
+    GetHistoryValuesCallback callback) const {
+  // Map of `ClipboardHistoryItem` IDs to their corresponding bitmaps.
+  std::map<base::UnguessableToken, SkBitmap> bitmaps_to_be_encoded;
+  for (auto& item : clipboard_history_->GetItems()) {
+    if (item.display_format() == ClipboardHistoryItem::DisplayFormat::kPng) {
+      const auto& maybe_png = item.data().maybe_png();
+      if (!maybe_png.has_value()) {
+        // The clipboard contains an image which has not yet been encoded to a
+        // PNG.
+        auto maybe_bitmap = item.data().GetBitmapIfPngNotEncoded();
+        DCHECK(maybe_bitmap.has_value());
+        bitmaps_to_be_encoded.emplace(item.id(),
+                                      std::move(maybe_bitmap.value()));
+      }
+    }
+  }
+
+  // Map of `ClipboardHistoryItem` IDs to their encoded PNGs.
+  auto encoded_pngs = std::make_unique<
+      std::map<base::UnguessableToken, std::vector<uint8_t>>>();
+  auto* encoded_pngs_ptr = encoded_pngs.get();
+
+  // Post back to this sequence once all images have been encoded.
+  base::RepeatingClosure barrier = base::BarrierClosure(
+      bitmaps_to_be_encoded.size(),
+      base::BindPostTaskToCurrentDefault(base::BindOnce(
+          &ClipboardHistoryControllerImpl::GetHistoryValuesWithEncodedPNGs,
+          weak_ptr_factory_.GetMutableWeakPtr(), std::move(callback),
+          std::move(encoded_pngs))));
+
+  // Encode images on background threads.
+  for (auto id_and_bitmap : bitmaps_to_be_encoded) {
+    base::ThreadPool::PostTask(
+        FROM_HERE, base::BindOnce(&EncodeBitmapToPNG, barrier, encoded_pngs_ptr,
+                                  std::move(id_and_bitmap.first),
+                                  std::move(id_and_bitmap.second)));
+  }
+
+  if (!new_bitmap_to_write_while_encoding_for_test_.isNull()) {
+    ui::ScopedClipboardWriter scw(ui::ClipboardBuffer::kCopyPaste);
+    scw.WriteImage(new_bitmap_to_write_while_encoding_for_test_);
+    new_bitmap_to_write_while_encoding_for_test_.reset();
+  }
 }
 
 gfx::Rect ClipboardHistoryControllerImpl::GetMenuBoundsInScreenForTest() const {
-  return context_menu_->GetMenuBoundsInScreenForTest();
-}
-
-void ClipboardHistoryControllerImpl::GetHistoryValuesForTest(
-    GetHistoryValuesCallback callback) const {
-  GetHistoryValues(/*item_id_filter=*/std::set<std::string>(),
-                   std::move(callback));
+  return context_menu_->GetMenuBoundsInScreenForTest();  // IN-TEST
 }
 
 void ClipboardHistoryControllerImpl::BlockGetHistoryValuesForTest() {
@@ -414,68 +462,7 @@ ClipboardHistoryControllerImpl::CreateScopedPause() {
       clipboard_history_.get());
 }
 
-void ClipboardHistoryControllerImpl::GetHistoryValues(
-    const std::set<std::string>& item_id_filter,
-    GetHistoryValuesCallback callback) const {
-  // Map of ClipboardHistoryItem IDs to their corresponding bitmaps.
-  std::map<base::UnguessableToken, SkBitmap> bitmaps_to_be_encoded;
-  // Get the clipboard data for each clipboard history item.
-  for (auto& item : clipboard_history_->GetItems()) {
-    // If the |item_id_filter| contains values, then only return the clipboard
-    // items included in it.
-    if (!item_id_filter.empty() &&
-        item_id_filter.find(item.id().ToString()) == item_id_filter.end()) {
-      continue;
-    }
-
-    if (clipboard_history_util::CalculateDisplayFormat(item.data()) ==
-        clipboard_history_util::DisplayFormat::kPng) {
-      const auto& maybe_png = item.data().maybe_png();
-      if (!maybe_png.has_value()) {
-        // The clipboard contains an image which has not yet been encoded to a
-        // PNG.
-        auto maybe_bitmap = item.data().GetBitmapIfPngNotEncoded();
-        DCHECK(maybe_bitmap.has_value());
-        bitmaps_to_be_encoded.emplace(item.id(),
-                                      std::move(maybe_bitmap.value()));
-      }
-    }
-  }
-
-  // Map of ClipboardHistoryItem ID to its encoded PNG. Since encoding images
-  // may happen on separate threads, a lock is used to ensure thread-safe
-  // insertion into `encoded_pngs`.
-  auto encoded_pngs = std::make_unique<
-      std::map<base::UnguessableToken, std::vector<uint8_t>>>();
-  auto* encoded_pngs_ptr = encoded_pngs.get();
-
-  // Post back to this sequence once all images have been encoded.
-  base::RepeatingClosure barrier = base::BarrierClosure(
-      bitmaps_to_be_encoded.size(),
-      base::BindPostTask(
-          base::SequencedTaskRunner::GetCurrentDefault(),
-          base::BindOnce(
-              &ClipboardHistoryControllerImpl::GetHistoryValuesWithEncodedPNGs,
-              weak_ptr_factory_.GetMutableWeakPtr(), item_id_filter,
-              std::move(callback), std::move(encoded_pngs))));
-
-  // Encode images on background threads.
-  for (auto id_and_bitmap : bitmaps_to_be_encoded) {
-    base::ThreadPool::PostTask(
-        FROM_HERE, base::BindOnce(&EncodeBitmapToPNG, barrier, encoded_pngs_ptr,
-                                  std::move(id_and_bitmap.first),
-                                  std::move(id_and_bitmap.second)));
-  }
-
-  if (!new_bitmap_to_write_while_encoding_for_test_.isNull()) {
-    ui::ScopedClipboardWriter scw(ui::ClipboardBuffer::kCopyPaste);
-    scw.WriteImage(new_bitmap_to_write_while_encoding_for_test_);
-    new_bitmap_to_write_while_encoding_for_test_.reset();
-  }
-}
-
 void ClipboardHistoryControllerImpl::GetHistoryValuesWithEncodedPNGs(
-    const std::set<std::string>& item_id_filter,
     GetHistoryValuesCallback callback,
     std::unique_ptr<std::map<base::UnguessableToken, std::vector<uint8_t>>>
         encoded_pngs) {
@@ -487,13 +474,12 @@ void ClipboardHistoryControllerImpl::GetHistoryValuesWithEncodedPNGs(
         FROM_HERE,
         base::BindOnce(
             &ClipboardHistoryControllerImpl::GetHistoryValuesWithEncodedPNGs,
-            weak_ptr_factory_.GetWeakPtr(), item_id_filter, std::move(callback),
+            weak_ptr_factory_.GetWeakPtr(), std::move(callback),
             std::move(encoded_pngs)));
     return;
   }
 
-  base::Value item_results(base::Value::Type::LIST);
-  DCHECK(encoded_pngs);
+  std::vector<ClipboardHistoryItem> item_results;
 
   // Check after asynchronous PNG encoding finishes to make sure we have not
   // entered a state where clipboard history is disabled, e.g., a locked screen.
@@ -503,84 +489,30 @@ void ClipboardHistoryControllerImpl::GetHistoryValuesWithEncodedPNGs(
   }
 
   bool all_images_encoded = true;
-  // Get the clipboard data for each clipboard history item.
   for (auto& item : clipboard_history_->GetItems()) {
-    // If the |item_id_filter| contains values, then only return the clipboard
-    // items included in it.
-    if (!item_id_filter.empty() &&
-        item_id_filter.find(item.id().ToString()) == item_id_filter.end()) {
-      continue;
-    }
-
-    base::Value item_value(base::Value::Type::DICTIONARY);
-    switch (clipboard_history_util::CalculateDisplayFormat(item.data())) {
-      case clipboard_history_util::DisplayFormat::kPng: {
-        if (!item.data().maybe_png().has_value()) {
-          // The clipboard contains an image which has not yet been encoded to a
-          // PNG. Hopefully we just finished encoding and the PNG can be found
-          // in `encoded_pngs`, otherwise this item was added while other PNGs
-          // were being encoded.
-          auto png_it = encoded_pngs->find(item.id());
-          if (png_it == encoded_pngs->end()) {
-            // Can't find the encoded PNG. We'll need to restart
-            // GetHistoryValues from the top, but allow this for loop to finish
-            // to let PNGs we've already encoded get set to their appropriate
-            // clipboards, to avoid re-encoding.
-            all_images_encoded = false;
-          } else {
-            item.data().SetPngDataAfterEncoding(std::move(png_it->second));
-          }
-        }
-
-        const auto& maybe_png = item.data().maybe_png();
-        if (maybe_png.has_value()) {
-          item_value.SetKey(kImageDataKey, base::Value(webui::GetPngDataUrl(
-                                               maybe_png.value().data(),
-                                               maybe_png.value().size())));
-          item_value.SetKey(kFormatDataKey, base::Value(kPngFormat));
-        }
-        break;
-      }
-      case clipboard_history_util::DisplayFormat::kHtml: {
-        const SkBitmap& bitmap =
-            *(resource_manager_->GetImageModel(item).GetImage().ToSkBitmap());
-        item_value.SetKey(kImageDataKey,
-                          base::Value(webui::GetBitmapDataUrl(bitmap)));
-        item_value.SetKey(kFormatDataKey, base::Value(kHtmlFormat));
-        break;
-      }
-      case clipboard_history_util::DisplayFormat::kText:
-        item_value.SetKey(kTextDataKey, base::Value(item.data().text()));
-        item_value.SetKey(kFormatDataKey, base::Value(kTextFormat));
-        break;
-      case clipboard_history_util::DisplayFormat::kFile: {
-        std::string file_name =
-            base::UTF16ToUTF8(resource_manager_->GetLabel(item));
-        item_value.SetKey(kTextDataKey, base::Value(file_name));
-        ui::ImageModel image_model =
-            clipboard_history_util::GetIconForFileClipboardItem(item,
-                                                                file_name);
-        // TODO(b/252366283): Refactor so we don't use the RootWindow from
-        // Shell.
-        const ui::ColorProvider* color_provider =
-            ColorUtil::GetColorProviderSourceForWindow(
-                Shell::Get()->GetPrimaryRootWindow())
-                ->GetColorProvider();
-        std::string data_url = webui::GetBitmapDataUrl(
-            *image_model.Rasterize(color_provider).bitmap());
-        item_value.SetKey(kImageDataKey, base::Value(data_url));
-        item_value.SetKey(kFormatDataKey, base::Value(kFileFormat));
-        break;
+    if (item.display_format() == ClipboardHistoryItem::DisplayFormat::kPng &&
+        !item.data().maybe_png().has_value()) {
+      // The clipboard contains an image which has not yet been encoded to a
+      // PNG. Hopefully we just finished encoding and the PNG can be found
+      // in `encoded_pngs`; otherwise this item was added while other PNGs
+      // were being encoded.
+      auto png_it = encoded_pngs->find(item.id());
+      if (png_it == encoded_pngs->end()) {
+        // Can't find the encoded PNG. We'll need to restart
+        // `GetHistoryValues()` from the top, but allow this for loop to finish
+        // to let PNGs we've already encoded get set to their appropriate
+        // clipboards, to avoid re-encoding.
+        all_images_encoded = false;
+      } else {
+        item.data().SetPngDataAfterEncoding(std::move(png_it->second));
       }
     }
-    item_value.SetKey("id", base::Value(item.id().ToString()));
-    item_value.SetKey("timeCopied",
-                      base::Value(item.time_copied().ToJsTimeIgnoringNull()));
-    item_results.Append(std::move(item_value));
+
+    item_results.emplace_back(item);
   }
 
   if (!all_images_encoded) {
-    GetHistoryValues(item_id_filter, std::move(callback));
+    GetHistoryValues(std::move(callback));
     return;
   }
 
@@ -634,13 +566,13 @@ void ClipboardHistoryControllerImpl::OnClipboardHistoryItemAdded(
     const ClipboardHistoryItem& item,
     bool is_duplicate) {
   for (auto& observer : observers_)
-    observer.OnClipboardHistoryItemListAddedOrRemoved();
+    observer.OnClipboardHistoryItemsUpdated();
 }
 
 void ClipboardHistoryControllerImpl::OnClipboardHistoryItemRemoved(
     const ClipboardHistoryItem& item) {
   for (auto& observer : observers_)
-    observer.OnClipboardHistoryItemListAddedOrRemoved();
+    observer.OnClipboardHistoryItemsUpdated();
 }
 
 void ClipboardHistoryControllerImpl::OnClipboardHistoryCleared() {
@@ -649,7 +581,7 @@ void ClipboardHistoryControllerImpl::OnClipboardHistoryCleared() {
   weak_ptr_factory_.InvalidateWeakPtrs();
   if (!IsMenuShowing())
     return;
-  context_menu_->Cancel();
+  context_menu_->Cancel(/*will_paste_item=*/false);
 }
 
 void ClipboardHistoryControllerImpl::OnOperationConfirmed(bool copy) {
@@ -731,7 +663,7 @@ void ClipboardHistoryControllerImpl::OnOperationConfirmed(bool copy) {
 void ClipboardHistoryControllerImpl::OnCachedImageModelUpdated(
     const std::vector<base::UnguessableToken>& menu_item_ids) {
   for (auto& observer : observers_)
-    observer.OnClipboardHistoryItemsUpdated(menu_item_ids);
+    observer.OnClipboardHistoryItemsUpdated();
 }
 
 void ClipboardHistoryControllerImpl::ExecuteCommand(int command_id,
@@ -800,12 +732,18 @@ void ClipboardHistoryControllerImpl::PasteMenuItemData(
 
   // Deactivate ClipboardImageModelFactory prior to pasting to ensure that any
   // modifications to the clipboard for HTML rendering purposes are reversed.
-  ClipboardImageModelFactory::Get()->Deactivate();
+  // This factory may be nullptr in tests.
+  if (auto* clipboard_image_factory = ClipboardImageModelFactory::Get()) {
+    clipboard_image_factory->Deactivate();
+  }
 
   // Force close the context menu. Failure to do so before dispatching our
   // synthetic key event will result in the context menu consuming the event.
+  // When closing the menu, indicate that the menu is closing because of an
+  // imminent paste. Note that in some cases, this will indicate paste intent
+  // for pastes that ultimately fail. For now, this is an acceptable inaccuracy.
   DCHECK(context_menu_);
-  context_menu_->Cancel();
+  context_menu_->Cancel(/*will_paste_item=*/true);
 
   auto* active_window = window_util::GetActiveWindow();
   if (!active_window)
@@ -899,6 +837,7 @@ void ClipboardHistoryControllerImpl::PasteClipboardHistoryItem(
   ui::KeyEvent ctrl_release(ui::ET_KEY_RELEASED, ui::VKEY_CONTROL, ui::EF_NONE);
   host->DeliverEventToSink(&ctrl_release);
 
+  clipboard_history_util::RecordClipboardHistoryItemPasted(item);
   base::UmaHistogramEnumeration("Ash.ClipboardHistory.PasteType", paste_type);
 
   for (auto& observer : observers_)
@@ -998,7 +937,7 @@ void ClipboardHistoryControllerImpl::DeleteItemWithCommandId(int command_id) {
 
   // If the item to be deleted is the last one, close the whole menu.
   if (context_menu_->GetMenuItemsCount() == 1) {
-    context_menu_->Cancel();
+    context_menu_->Cancel(/*will_paste_item=*/false);
     return;
   }
 
