@@ -7,6 +7,7 @@
 #include "ash/clipboard/clipboard_history.h"
 #include "ash/clipboard/clipboard_history_util.h"
 #include "ash/clipboard/views/clipboard_history_item_view.h"
+#include "ash/public/cpp/clipboard_history_controller.h"
 #include "ash/public/cpp/clipboard_image_model_factory.h"
 #include "ash/wm/window_util.h"
 #include "base/functional/bind.h"
@@ -15,6 +16,7 @@
 #include "base/task/sequenced_task_runner.h"
 #include "ui/accessibility/ax_enums.mojom.h"
 #include "ui/base/l10n/l10n_util.h"
+#include "ui/base/models/simple_menu_model.h"
 #include "ui/base/ui_base_types.h"
 #include "ui/gfx/geometry/rect.h"
 #include "ui/strings/grit/ui_strings.h"
@@ -27,6 +29,36 @@
 
 namespace ash {
 
+// ClipboardHistoryMenuModelAdapter::MenuModelWithWillCloseCallback ------------
+
+// Utility class that allows `ClipboardHistoryMenuModelAdapter` to run a task
+// before its menu closes.
+class ClipboardHistoryMenuModelAdapter::MenuModelWithWillCloseCallback
+    : public ui::SimpleMenuModel {
+ public:
+  MenuModelWithWillCloseCallback(
+      ui::SimpleMenuModel::Delegate* delegate,
+      ClipboardHistoryController::OnMenuClosingCallback callback)
+      : ui::SimpleMenuModel(delegate), callback_(std::move(callback)) {}
+
+  // ui::SimpleMenuModel:
+  void MenuWillClose() override {
+    if (callback_) {
+      std::move(callback_).Run(will_paste_item_);
+    }
+
+    ui::SimpleMenuModel::MenuWillClose();
+  }
+
+  void set_will_paste_item(bool will_paste_item) {
+    will_paste_item_ = will_paste_item;
+  }
+
+ private:
+  ClipboardHistoryController::OnMenuClosingCallback callback_;
+  bool will_paste_item_ = false;
+};
+
 // ClipboardHistoryMenuModelAdapter::ScopedA11yIgnore --------------------------
 
 // The scoped class to disable a11y for all items views.
@@ -57,11 +89,13 @@ class ClipboardHistoryMenuModelAdapter::ScopedA11yIgnore {
 std::unique_ptr<ClipboardHistoryMenuModelAdapter>
 ClipboardHistoryMenuModelAdapter::Create(
     ui::SimpleMenuModel::Delegate* delegate,
+    ClipboardHistoryController::OnMenuClosingCallback on_menu_closing_callback,
     base::RepeatingClosure menu_closed_callback,
     const ClipboardHistory* clipboard_history,
     const ClipboardHistoryResourceManager* resource_manager) {
   return base::WrapUnique(new ClipboardHistoryMenuModelAdapter(
-      std::make_unique<ui::SimpleMenuModel>(delegate),
+      std::make_unique<MenuModelWithWillCloseCallback>(
+          delegate, std::move(on_menu_closing_callback)),
       std::move(menu_closed_callback), clipboard_history, resource_manager));
 }
 
@@ -97,7 +131,10 @@ void ClipboardHistoryMenuModelAdapter::Run(
   }
 
   // Start async rendering of HTML, if any exists.
-  ClipboardImageModelFactory::Get()->Activate();
+  // This factory may be nullptr in tests.
+  if (auto* clipboard_image_factory = ClipboardImageModelFactory::Get()) {
+    clipboard_image_factory->Activate();
+  }
 
   root_view_ = CreateMenu();
   root_view_->SetTitle(
@@ -115,7 +152,8 @@ bool ClipboardHistoryMenuModelAdapter::IsRunning() const {
   return menu_runner_ && menu_runner_->IsRunning();
 }
 
-void ClipboardHistoryMenuModelAdapter::Cancel() {
+void ClipboardHistoryMenuModelAdapter::Cancel(bool will_paste_item) {
+  model_->set_will_paste_item(will_paste_item);
   DCHECK(menu_runner_);
   menu_runner_->Cancel();
 }
@@ -283,7 +321,7 @@ views::MenuItemView* ClipboardHistoryMenuModelAdapter::GetMenuItemViewAtForTest(
 }
 
 ClipboardHistoryMenuModelAdapter::ClipboardHistoryMenuModelAdapter(
-    std::unique_ptr<ui::SimpleMenuModel> model,
+    std::unique_ptr<MenuModelWithWillCloseCallback> model,
     base::RepeatingClosure menu_closed_callback,
     const ClipboardHistory* clipboard_history,
     const ClipboardHistoryResourceManager* resource_manager)
@@ -395,7 +433,8 @@ views::MenuItemView* ClipboardHistoryMenuModelAdapter::AppendMenuItem(
 
   std::unique_ptr<ClipboardHistoryItemView> item_view =
       ClipboardHistoryItemView::CreateFromClipboardHistoryItem(
-          GetItemFromCommandId(command_id), resource_manager_, container);
+          GetItemFromCommandId(command_id).id(), clipboard_history_,
+          resource_manager_, container);
   item_view->Init();
   item_views_by_command_id_.insert(std::make_pair(command_id, item_view.get()));
   container->AddChildView(std::move(item_view));
@@ -411,7 +450,10 @@ void ClipboardHistoryMenuModelAdapter::OnMenuClosed(views::MenuItemView* menu) {
   // Because when hitting here, this instance is going to be destructed soon.
   weak_ptr_factory_.InvalidateWeakPtrs();
 
-  ClipboardImageModelFactory::Get()->Deactivate();
+  // This factory may be nullptr in tests.
+  if (auto* clipboard_image_factory = ClipboardImageModelFactory::Get()) {
+    clipboard_image_factory->Deactivate();
+  }
   const base::TimeDelta user_journey_time =
       base::TimeTicks::Now() - menu_open_time_;
   UMA_HISTOGRAM_TIMES("Ash.ClipboardHistory.ContextMenu.UserJourneyTime",
