@@ -6,7 +6,8 @@
 
 #include <array>
 
-#include "ash/clipboard/clipboard_history_util.h"
+#include "ash/clipboard/clipboard_history_item.h"
+#include "base/check.h"
 #include "ui/base/metadata/metadata_impl_macros.h"
 #include "ui/views/controls/image_view.h"
 #include "ui/views/view_class_properties.h"
@@ -23,9 +24,10 @@ constexpr auto kIconMargin = gfx::Insets::TLBR(0, 0, 0, 12);
 namespace ash {
 
 ClipboardHistoryFileItemView::ClipboardHistoryFileItemView(
-    const ClipboardHistoryItem* clipboard_history_item,
+    const base::UnguessableToken& item_id,
+    const ClipboardHistory* clipboard_history,
     views::MenuItemView* container)
-    : ClipboardHistoryTextItemView(clipboard_history_item, container) {}
+    : ClipboardHistoryTextItemView(item_id, clipboard_history, container) {}
 ClipboardHistoryFileItemView::~ClipboardHistoryFileItemView() = default;
 
 std::unique_ptr<ClipboardHistoryFileItemView::ContentsView>
@@ -33,12 +35,14 @@ ClipboardHistoryFileItemView::CreateContentsView() {
   auto contents_view = ClipboardHistoryTextItemView::CreateContentsView();
 
   // `file_icon` should be `contents_view`'s first child.
-  views::ImageView* file_icon = contents_view->AddChildViewAt(
-      std::make_unique<views::ImageView>(), /*index=*/0);
-  file_icon->SetImageSize(kIconSize);
-  file_icon->SetProperty(views::kMarginsKey, kIconMargin);
-  file_icon->SetImage(clipboard_history_util::GetIconForFileClipboardItem(
-      *clipboard_history_item(), base::UTF16ToUTF8(text())));
+  if (const auto* item = GetClipboardHistoryItem()) {
+    DCHECK(item->icon().has_value());
+    views::ImageView* file_icon = contents_view->AddChildViewAt(
+        std::make_unique<views::ImageView>(), /*index=*/0);
+    file_icon->SetImageSize(kIconSize);
+    file_icon->SetProperty(views::kMarginsKey, kIconMargin);
+    file_icon->SetImage(item->icon().value());
+  }
 
   return contents_view;
 }
