@@ -24,9 +24,6 @@ BASE_DECLARE_FEATURE(kEnableArcNearbyShareFuseBox);
 BASE_DECLARE_FEATURE(kEnableArcVmDataMigration);
 BASE_DECLARE_FEATURE(kEnableLazyWebViewInit);
 BASE_DECLARE_FEATURE(kEnablePerVmCoreScheduling);
-BASE_DECLARE_FEATURE(kEnableTokenBootstrapEndpoint);
-BASE_DECLARE_FEATURE(kEnableTTSCaching);
-BASE_DECLARE_FEATURE(kEnableTTSCacheSetup);
 BASE_DECLARE_FEATURE(kEnableUnifiedAudioFocusFeature);
 BASE_DECLARE_FEATURE(kEnableUnmanagedToManagedTransitionFeature);
 BASE_DECLARE_FEATURE(kEnableUsap);
@@ -41,6 +38,8 @@ BASE_DECLARE_FEATURE(kGmsCoreLowMemoryKillerProtection);
 BASE_DECLARE_FEATURE(kGuestZram);
 extern const base::FeatureParam<int> kGuestZramSize;
 extern const base::FeatureParam<int> kGuestZramSwappiness;
+extern const base::FeatureParam<bool> kGuestReclaimEnabled;
+extern const base::FeatureParam<bool> kGuestReclaimOnlyAnonymous;
 BASE_DECLARE_FEATURE(kInstantResponseWindowOpen);
 BASE_DECLARE_FEATURE(kLockGuestMemory);
 BASE_DECLARE_FEATURE(kLvmApplicationContainers);
@@ -55,6 +54,8 @@ BASE_DECLARE_FEATURE(kRightClickLongPress);
 BASE_DECLARE_FEATURE(kRtVcpuDualCore);
 BASE_DECLARE_FEATURE(kRtVcpuQuadCore);
 BASE_DECLARE_FEATURE(kSaveRawFilesOnTracing);
+BASE_DECLARE_FEATURE(kSwitchToKeyMintOnT);
+BASE_DECLARE_FEATURE(kSyncInstallPriority);
 BASE_DECLARE_FEATURE(kArcUpdateO4CListViaA2C2);
 BASE_DECLARE_FEATURE(kUsbStorageUIFeature);
 BASE_DECLARE_FEATURE(kUseDalvikMemoryProfile);
@@ -66,8 +67,11 @@ BASE_DECLARE_FEATURE(kVmMemorySize);
 extern const base::FeatureParam<int> kVmMemorySizeShiftMiB;
 extern const base::FeatureParam<int> kVmMemorySizeMaxMiB;
 BASE_DECLARE_FEATURE(kVmBroadcastPreNotifyANR);
-BASE_DECLARE_FEATURE(kVmGmsCoreLowMemoryKillerProtection);
 BASE_DECLARE_FEATURE(kVmmSwapKeyboardShortcut);
+BASE_DECLARE_FEATURE(kVmmSwapPolicy);
+extern const base::FeatureParam<int> kVmmSwapOutDelaySecond;
+extern const base::FeatureParam<int> kVmmSwapOutTimeIntervalSecond;
+extern const base::FeatureParam<int> kVmmSwapArcSilenceIntervalSecond;
 
 }  // namespace arc
 
