@@ -71,8 +71,6 @@ const char kArcManagementTransition[] = "arc.management_transition";
 const char kArcPolicyComplianceReported[] = "arc.policy_compliance_reported";
 // A preference that indicates that user accepted PlayStore terms.
 const char kArcTermsAccepted[] = "arc.terms.accepted";
-// A preference that indicates that ToS was shown in OOBE flow.
-const char kArcTermsShownInOobe[] = "arc.terms.shown_in_oobe";
 // A preference to keep user's consent to use location service.
 const char kArcLocationServiceEnabled[] = "arc.location_service.enabled";
 // A preference to keep list of Android packages and their infomation.
@@ -127,6 +125,16 @@ const char kArcShowResizeLockSplashScreenLimits[] =
 const char kArcPlayStoreLaunchMetricCanBeRecorded[] =
     "arc.playstore_launched_by_user";
 
+// An integer preference to count how many times ARCVM /data migration has been
+// automatically resumed.
+const char kArcVmDataMigrationAutoResumeCount[] =
+    "arc.vm_data_migration_auto_resume_count";
+
+// A time preference to indicate when the ARCVM /data migration notification is
+// shown for the first time.
+const char kArcVmDataMigrationNotificationFirstShownTime[] =
+    "arc.vm_data_migration_notification_first_shown_time";
+
 // An integer preference to indicate the status of ARCVM /data migration.
 const char kArcVmDataMigrationStatus[] = "arc.vm_data_migration_status";
 
@@ -153,6 +161,11 @@ const char kArcSnapshotHours[] = "arc.snapshot_hours";
 // A preferece to keep ARC snapshot related info in dictionary.
 const char kArcSnapshotInfo[] = "arc.snapshot";
 
+// A time pref indicating the time in microseconds when ARCVM success executed
+// vmm swap out. If it never swapped out, the pref holds the default value
+// base::Time().
+const char kArcVmmSwapOutTime[] = "arc_vmm_swap_out_time";
+
 // A preference to keep track of whether or not Android WebView was used in the
 // current ARC session.
 const char kWebViewProcessStarted[] = "arc.webview.started";
@@ -163,6 +176,7 @@ void RegisterLocalStatePrefs(PrefRegistrySimple* registry) {
   registry->RegisterStringPref(kArcSerialNumberSalt, std::string());
   registry->RegisterDictionaryPref(kArcSnapshotHours);
   registry->RegisterDictionaryPref(kArcSnapshotInfo);
+  registry->RegisterTimePref(kArcVmmSwapOutTime, base::Time());
   registry->RegisterDictionaryPref(kStabilityMetrics);
 
   registry->RegisterIntegerPref(kAnrPendingCount, 0);
@@ -209,8 +223,10 @@ void RegisterProfilePrefs(PrefRegistrySimple* registry) {
   registry->RegisterBooleanPref(kArcSignedIn, false);
   registry->RegisterBooleanPref(kArcSkippedReportingNotice, false);
   registry->RegisterBooleanPref(kArcTermsAccepted, false);
-  registry->RegisterBooleanPref(kArcTermsShownInOobe, false);
   registry->RegisterListPref(kArcVisibleExternalStorages);
+  registry->RegisterIntegerPref(kArcVmDataMigrationAutoResumeCount, 0);
+  registry->RegisterTimePref(kArcVmDataMigrationNotificationFirstShownTime,
+                             base::Time());
   registry->RegisterIntegerPref(
       kArcVmDataMigrationStatus,
       static_cast<int>(ArcVmDataMigrationStatus::kUnnotified));
