@@ -102,6 +102,9 @@ class ArcBridgeHostImpl : public mojom::ArcBridgeHost {
           keyboard_shortcut_remote) override;
   void OnKeymasterInstanceReady(
       mojo::PendingRemote<mojom::KeymasterInstance> keymaster_remote) override;
+  void OnKeyMintInstanceReady(
+      mojo::PendingRemote<mojom::keymint::KeyMintInstance> keymint_remote)
+      override;
   void OnKioskInstanceReady(
       mojo::PendingRemote<mojom::KioskInstance> kiosk_remote) override;
   void OnLockScreenInstanceReady(mojo::PendingRemote<mojom::LockScreenInstance>
@@ -156,6 +159,9 @@ class ArcBridgeHostImpl : public mojom::ArcBridgeHost {
   void OnStorageManagerInstanceReady(
       mojo::PendingRemote<mojom::StorageManagerInstance> storage_manager_remote)
       override;
+  void OnSystemStateInstanceReady(
+      mojo::PendingRemote<mojom::SystemStateInstance> system_state_remote)
+      override;
   void OnSystemUiInstanceReady(
       mojo::PendingRemote<mojom::SystemUiInstance> system_ui_remote) override;
   void OnTimerInstanceReady(
