@@ -107,6 +107,20 @@ TEST_F(ArcBridgeHostImplTest, TestOnInstanceReady) {
     EXPECT_EQ(count_before + 1, count_after);                                 \
   }
 
+#define MAKE_INSTANCE_READY_WITH_NAMESPACE(name_space, name)          \
+  ScopedPendingReceiver<mojom::name_space::name##Instance>            \
+      pending_receiver_##name(impl);                                  \
+  {                                                                   \
+    SCOPED_TRACE("mojom::" #name_space "::" #name "Instance");        \
+    mojo::PendingRemote<mojom::name_space::name##Instance> remote =   \
+        pending_receiver_##name.get().InitWithNewPipeAndPassRemote(); \
+    const size_t count_before = impl->GetNumMojoChannelsForTesting(); \
+    proxy->On##name##InstanceReady(std::move(remote));                \
+    base::RunLoop().RunUntilIdle();                                   \
+    const size_t count_after = impl->GetNumMojoChannelsForTesting();  \
+    EXPECT_EQ(count_before + 1, count_after);                         \
+  }
+
     MAKE_INSTANCE_READY(AccessibilityHelper);
     MAKE_INSTANCE_READY(AdbdMonitor);
     MAKE_INSTANCE_READY(App);
@@ -130,6 +144,7 @@ TEST_F(ArcBridgeHostImplTest, TestOnInstanceReady) {
     MAKE_INSTANCE_READY(InputMethodManager);
     MAKE_INSTANCE_READY(IntentHelper);
     MAKE_INSTANCE_READY(Keymaster);
+    MAKE_INSTANCE_READY_WITH_NAMESPACE(keymint, KeyMint);
     MAKE_INSTANCE_READY(Kiosk);
     MAKE_INSTANCE_READY(LockScreen);
     MAKE_INSTANCE_READY(MediaSession);
