@@ -2,6 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
+#include "ash/components/arc/session/arc_session_impl.h"
+
 #include <fcntl.h>
 #include <sys/stat.h>
 #include <sys/types.h>
@@ -11,7 +13,6 @@
 
 #include "ash/components/arc/arc_features.h"
 #include "ash/components/arc/session/arc_client_adapter.h"
-#include "ash/components/arc/session/arc_session_impl.h"
 #include "ash/components/arc/session/arc_start_params.h"
 #include "ash/components/arc/session/arc_upgrade_params.h"
 #include "ash/components/arc/test/arc_util_test_support.h"
@@ -120,8 +121,9 @@ class FakeArcClientAdapter : public ArcClientAdapter {
 
   void OnArcUpgraded(chromeos::VoidDBusMethodCallback callback, bool result) {
     std::move(callback).Run(result);
-    if (!result)
+    if (!result) {
       NotifyArcInstanceStopped(false /* is_system_shutdown */);
+    }
   }
 
   bool arc_available_ = true;
@@ -237,8 +239,9 @@ class TestArcSessionObserver : public ArcSession::Observer {
                         bool upgrade_requested) override {
     on_session_stopped_args_.emplace(
         OnSessionStoppedArgs{reason, was_running, upgrade_requested});
-    if (run_loop_)
+    if (run_loop_) {
       run_loop_->Quit();
+    }
   }
 
  private:
@@ -353,8 +356,9 @@ class ArcSessionImplTest : public testing::Test {
   std::unique_ptr<ArcSessionImpl, ArcSessionDeleter> CreateArcSessionInternal(
       std::unique_ptr<ArcSessionImpl::Delegate> delegate,
       float default_device_scale_factor) {
-    if (!delegate)
+    if (!delegate) {
       delegate = std::make_unique<FakeDelegate>();
+    }
     auto arc_session =
         std::unique_ptr<ArcSessionImpl, ArcSessionDeleter>(new ArcSessionImpl(
             std::move(delegate), &fake_schedule_configuration_manager_,
@@ -729,8 +733,9 @@ TEST_P(ArcSessionImplPackagesCacheModeTest, PackagesCacheModes) {
   }
 
   arc_session->StartMiniInstance();
-  if (state.full_container)
+  if (state.full_container) {
     arc_session->RequestUpgrade(DefaultUpgradeParams());
+  }
   base::RunLoop().RunUntilIdle();
   EXPECT_EQ(
       state.expected_packages_cache_mode,
@@ -926,19 +931,8 @@ TEST_F(ArcSessionImplTest, HostUreadaheadGenerationSet) {
       GetClient(arc_session.get())->last_start_params().disable_ureadahead);
 }
 
-// Test that validates TTS caching is disabled by default.
+// Test that validates TTS caching is enabled by default.
 TEST_F(ArcSessionImplTest, TTSCachingByDefault) {
-  auto arc_session = CreateArcSession();
-  arc_session->StartMiniInstance();
-  base::RunLoop().RunUntilIdle();
-  EXPECT_FALSE(
-      GetClient(arc_session.get())->last_start_params().enable_tts_caching);
-}
-
-// Test that validates TTS caching is enabled.
-TEST_F(ArcSessionImplTest, TTSCachingEnabled) {
-  base::test::ScopedFeatureList feature_list;
-  feature_list.InitWithFeatureState(arc::kEnableTTSCacheSetup, true);
   auto arc_session = CreateArcSession();
   arc_session->StartMiniInstance();
   base::RunLoop().RunUntilIdle();
