@@ -107,6 +107,12 @@ struct StartParams {
 
   // Flag that indicates whether ARCVM uses virtio-blk for /data.
   bool use_virtio_blk_data = false;
+
+  // Flag to enable Privacy Hub for chrome.
+  bool enable_privacy_hub_for_chrome = false;
+
+  // Flag to switch to KeyMint for T+.
+  bool arc_switch_to_keymint = false;
 };
 
 }  // namespace arc
