@@ -303,6 +303,11 @@ const char kCrosRegion[] = "cros-region";
 // flow.
 const char kCryptohomeRecoveryReauthUrl[] = "cryptohome-recovery-reauth-url";
 
+// Forces cryptohome recovery process to use test environment (test keys /
+// URLs).
+const char kCryptohomeRecoveryUseTestEnvironment[] =
+    "cryptohome-recovery-use-test-env";
+
 // Controls if AuthSession API should be used when interacting with cryptohomed.
 const char kCryptohomeUseAuthSession[] = "cryptohome-use-authsession";
 
@@ -486,6 +491,15 @@ const char kEnableTouchpadThreeFingerClick[] =
 // Disables ARC for managed accounts.
 const char kEnterpriseDisableArc[] = "enterprise-disable-arc";
 
+// Whether to force manual enrollment instead of trying cert based enrollment.
+// Only works on test builds.
+const char kEnterpriseForceManualEnrollmentInTestBuilds[] =
+    "enterprise-force-manual-enrollment-in-test-builds";
+
+// Whether to enable unified state determination.
+const char kEnterpriseEnableUnifiedStateDetermination[] =
+    "enterprise-enable-unified-state-determination";
+
 // Whether to enable forced enterprise re-enrollment.
 const char kEnterpriseEnableForcedReEnrollment[] =
     "enterprise-enable-forced-re-enrollment";
@@ -514,6 +528,14 @@ const char kEnterpriseEnrollmentModulusLimit[] =
 // This is only usable on test builds.
 const char kDisallowPolicyBlockDevMode[] = "disallow-policy-block-dev-mode";
 
+// Ignore the profile creation time when determining whether to show the end of
+// life notification incentive. This is meant to make manual testing easier.
+const char kEolIgnoreProfileCreationTime[] = "eol-ignore-profile-creation-time";
+
+// Reset the end of life notification prefs to their default value, at the
+// start of the user session. This is meant to make manual testing easier.
+const char kEolResetDismissedPrefs[] = "eol-reset-dismissed-prefs";
+
 // Write extension install events to chrome log for integration test.
 const char kExtensionInstallEventChromeLogForTests[] =
     "extension-install-event-chrome-log-for-tests";
@@ -658,6 +680,10 @@ const char kInstallLogFastUploadForTests[] =
 // directory. For now, only one extension can be specified.
 const char kInstallSystemExtension[] = "install-system-extension";
 
+// Minimum time the kiosk splash screen will be shown in seconds.
+const char kKioskSplashScreenMinTimeSeconds[] =
+    "kiosk-splash-screen-min-time-seconds";
+
 // When this flag is set, the lacros-availability policy is ignored.
 const char kLacrosAvailabilityIgnore[] = "lacros-availability-ignore";
 
@@ -697,6 +723,9 @@ const char kLacrosChromePath[] = "lacros-chrome-path";
 // 2. A terminal to start lacros-chrome with a debugger.
 const char kLacrosMojoSocketForTesting[] = "lacros-mojo-socket-for-testing";
 
+// When this flag is set, the lacros-selection policy is ignored.
+const char kLacrosSelectionPolicyIgnore[] = "lacros-selection-policy-ignore";
+
 // Start Chrome in RMA mode. Launches RMA app automatically.
 // kRmaNotAllowed switch takes priority over this one.
 const char kLaunchRma[] = "launch-rma";
@@ -762,6 +791,10 @@ const char kOobeForceTabletFirstRun[] = "oobe-force-tablet-first-run";
 const char kOobeLargeScreenSpecialScaling[] =
     "oobe-large-screen-special-scaling";
 
+// When present, prints the time it takes for OOBE's frontend to load.
+// See go/oobe-frontend-trace-timings for details.
+const char kOobePrintFrontendLoadTimings[] = "oobe-print-frontend-load-timings";
+
 // Specifies directory for screenshots taken with OOBE UI Debugger.
 const char kOobeScreenshotDirectory[] = "oobe-screenshot-dir";
 
@@ -786,12 +819,23 @@ const char kOobeTimezoneOverrideForTests[] = "oobe-timezone-override-for-tests";
 const char kOobeTriggerSyncTimeoutForTests[] =
     "oobe-trigger-sync-timeout-for-tests";
 
-// Removes the condition that a network has had to existed for at least two
-// weeks and allows the user to provide the frequency at which the
-// HiddenNetworkHandler class checks for and removes wrongly hidden networks.
-// The frequency should be provided in seconds, should follow the format
-// "--force-hidden-network-migration=#", and should be >= 1.
-const char kForceHiddenNetworkMigration[] = "force-hidden-network-migration";
+// Controls how often the HiddenNetworkHandler class checks for wrongly hidden
+// networks. The interval should be provided in seconds, should follow the
+// format "--hidden-network-migration-interval=#", and should be >= 1.
+const char kHiddenNetworkMigrationInterval[] =
+    "hidden-network-migration-interval";
+
+// Sets how long a wrongly hidden network must have existed in order to be
+// considered for removal. The interval should be provided in days, should
+// follow the format "--hidden-network-migration-age=#", and should be >= 0.
+const char kHiddenNetworkMigrationAge[] = "hidden-network-migration-age";
+
+// Sets the channel from which the PPD files are loaded.
+const char kPrintingPpdChannel[] = "printing-ppd-channel";
+const char kPrintingPpdChannelProduction[] = "production";
+const char kPrintingPpdChannelStaging[] = "staging";
+const char kPrintingPpdChannelDev[] = "dev";
+const char kPrintingPpdChannelLocalhost[] = "localhost";
 
 // If set to "true", the profile requires policy during restart (policy load
 // must succeed, otherwise session restart should fail).
@@ -814,6 +858,10 @@ const char kQsAddFakeCastDevices[] = "qs-add-fake-cast-devices";
 // "/usr/share/chromeos-assets/regulatory_labels/".
 const char kRegulatoryLabelDir[] = "regulatory-label-dir";
 
+// Testing timeout for reboot command. Useful for tast tests.
+const char kRemoteRebootCommandTimeoutInSecondsForTesting[] =
+    "remote-reboot-command-timeout-in-seconds-for-testing";
+
 // Indicates that reven UI strings and features should be shown.
 const char kRevenBranding[] = "reven-branding";
 
@@ -836,6 +884,11 @@ const char kSamlPasswordChangeUrl[] = "saml-password-change-url";
 // smaller shelf in clamshell mode.
 const char kShelfHotseat[] = "shelf-hotseat";
 
+// Testing grace period for DeviceScheduledReboot policy. Useful for tast tests.
+// See `ShouldSkipRebootDueToGracePeriod` in scheduled_task_util.h.
+const char kScheduledRebootGracePeriodInSecondsForTesting[] =
+    "scheduled-reboot-grace-period-in-seconds-for-testing";
+
 // App window previews when hovering over the shelf.
 const char kShelfHoverPreviews[] = "shelf-hover-previews";
 
@@ -860,6 +913,11 @@ const char kSkipForceOnlineSignInForTesting[] =
 const char kSkipReorderNudgeShowThresholdDurationForTest[] =
     "skip-reorder-nudge-show-threshold-duration";
 
+// Used to force software cursors on specific devices that do not have enough
+// planes to display a hardware cursor when connected to displays with higher
+// widths in pixels.
+const char kSwCursorOnWideDisplays[] = "sw-cursor-on-wide-displays";
+
 // If set, the device will be forced to stay in clamshell UI mode but screen
 // auto rotation will be supported. E.g, chromebase device Dooly.
 const char kSupportsClamshellAutoRotation[] =
@@ -940,6 +998,10 @@ const char kWebUiDataSourcePathForTesting[] =
 // the internal OAuth client ID.
 const char kGetAccessTokenForTest[] = "get-access-token-for-test";
 
+// Indicates whether camera effects use flag is set in ChromeOS.
+const char kCameraEffectsSupportedByHardware[] =
+    "camera-effects-supported-by-hardware";
+
 bool IsAuthSessionCryptohomeEnabled() {
   return base::CommandLine::ForCurrentProcess()->HasSwitch(
       kCryptohomeUseAuthSession);
@@ -1083,5 +1145,10 @@ bool IsStabilizeTimeDependentViewForTestsEnabled() {
       kStabilizeTimeDependentViewForTests);
 }
 
+bool IsCameraEffectsSupportedByHardware() {
+  return base::CommandLine::ForCurrentProcess()->HasSwitch(
+      kCameraEffectsSupportedByHardware);
+}
+
 }  // namespace switches
 }  // namespace ash
