@@ -1,4 +1,4 @@
-// Copyright 2018 The Chromium Authors. All rights reserved.
+// Copyright 2018 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -14,7 +14,7 @@
 #include "base/memory/weak_ptr.h"
 #include "base/observer_list.h"
 #include "base/scoped_observation.h"
-#include "chromeos/dbus/hammerd/hammerd_client.h"
+#include "chromeos/ash/components/dbus/hammerd/hammerd_client.h"
 #include "chromeos/dbus/power/power_manager_client.h"
 #include "components/account_id/account_id.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
@@ -44,7 +44,7 @@ struct UserInfo;
 // DetachableBaseHandler clients are expected to determine for which users the
 // detachable base state should be set or retrieved.
 class ASH_EXPORT DetachableBaseHandler
-    : public chromeos::HammerdClient::Observer,
+    : public HammerdClient::Observer,
       public chromeos::PowerManagerClient::Observer {
  public:
   // |local_state| - PrefService of Local state. May be null in tests.
@@ -85,7 +85,7 @@ class ASH_EXPORT DetachableBaseHandler
   // paired) - setting the last used base can be retried at that point.
   bool SetPairedBaseAsLastUsedByUser(const UserInfo& user);
 
-  // chromeos::HammerdClient::Observer:
+  // HammerdClient::Observer:
   void BaseFirmwareUpdateNeeded() override;
   void BaseFirmwareUpdateStarted() override;
   void BaseFirmwareUpdateSucceeded() override;
@@ -138,8 +138,7 @@ class ASH_EXPORT DetachableBaseHandler
   DetachableBasePairingStatus pairing_status_ =
       DetachableBasePairingStatus::kNone;
 
-  base::ScopedObservation<chromeos::HammerdClient,
-                          chromeos::HammerdClient::Observer>
+  base::ScopedObservation<HammerdClient, HammerdClient::Observer>
       hammerd_observation_;
   base::ScopedObservation<chromeos::PowerManagerClient,
                           chromeos::PowerManagerClient::Observer>
