@@ -17,8 +17,8 @@
 #include "ash/strings/grit/ash_strings.h"
 #include "ash/wallpaper/wallpaper_controller_impl.h"
 #include "base/functional/bind.h"
+#include "base/system/sys_info.h"
 #include "base/time/time.h"
-#include "chromeos/ash/components/system/devicemode.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/display/display_layout.h"
 #include "ui/display/manager/display_manager.h"
@@ -88,8 +88,9 @@ DisplayConfigurationController::DisplayConfigurationController(
     : display_manager_(display_manager),
       window_tree_host_manager_(window_tree_host_manager) {
   window_tree_host_manager_->AddObserver(this);
-  if (chromeos::IsRunningAsSystemCompositor())
+  if (base::SysInfo::IsRunningOnChromeOS()) {
     limiter_ = std::make_unique<DisplayChangeLimiter>();
+  }
   if (!g_disable_animator_for_test)
     display_animator_ = std::make_unique<DisplayAnimator>();
 }
