@@ -5,9 +5,12 @@
 #include "ash/display/window_tree_host_manager.h"
 
 #include <memory>
+#include <string>
 
 #include "ash/display/display_util.h"
 #include "ash/public/cpp/shelf_config.h"
+#include "ash/rounded_display/rounded_display_provider.h"
+#include "ash/rounded_display/rounded_display_provider_test_api.h"
 #include "ash/screen_util.h"
 #include "ash/shelf/shelf.h"
 #include "ash/shelf/shelf_widget.h"
@@ -21,6 +24,8 @@
 #include "ash/wm/wm_event.h"
 #include "base/command_line.h"
 #include "base/run_loop.h"
+#include "base/strings/string_piece_forward.h"
+#include "base/strings/stringprintf.h"
 #include "base/test/scoped_feature_list.h"
 #include "ui/aura/client/focus_change_observer.h"
 #include "ui/aura/client/focus_client.h"
@@ -45,7 +50,9 @@
 #include "ui/events/keycodes/keyboard_codes.h"
 #include "ui/events/test/event_generator.h"
 #include "ui/events/types/event_type.h"
+#include "ui/gfx/geometry/rect.h"
 #include "ui/gfx/geometry/rounded_corners_f.h"
+#include "ui/gfx/geometry/size.h"
 #include "ui/views/event_monitor.h"
 #include "ui/views/mouse_watcher.h"
 #include "ui/views/mouse_watcher_view_host.h"
@@ -59,6 +66,7 @@ namespace ash {
 namespace {
 
 const char kWallpaperView[] = "WallpaperViewWidget";
+constexpr auto kTestRoundedDisplayRadii = gfx::RoundedCornersF(10, 10, 15, 15);
 
 template <typename T>
 class Resetter {
@@ -362,6 +370,47 @@ class TestMouseWatcherListener : public views::MouseWatcherListener {
   void MouseMovedOutOfHost() override {}
 };
 
+// This test fixture adds rounded-corners to the default display on SetUp.
+class WindowTreeHostManagerRoundedDisplayTest : public AshTestBase {
+ public:
+  std::string ToDisplaySpecRadiiString(const gfx::RoundedCornersF& radii) {
+    return base::StringPrintf("%1.f|%1.f|%1.f|%1.f", radii.upper_left(),
+                              radii.upper_right(), radii.lower_right(),
+                              radii.lower_left());
+  }
+
+  WindowTreeHostManagerRoundedDisplayTest() = default;
+
+  WindowTreeHostManagerRoundedDisplayTest(
+      const WindowTreeHostManagerRoundedDisplayTest&) = delete;
+  WindowTreeHostManagerRoundedDisplayTest& operator=(
+      const WindowTreeHostManagerRoundedDisplayTest&) = delete;
+
+  // AshTestBase:
+  void SetUp() override {
+    base::CommandLine::ForCurrentProcess()->AppendSwitchASCII(
+        switches::kHostWindowBounds,
+        "1920x1080~" + ToDisplaySpecRadiiString(kTestRoundedDisplayRadii));
+    scoped_features_.InitAndEnableFeature(display::features::kRoundedDisplay);
+    AshTestBase::SetUp();
+
+    display::Display primary_display =
+        display::Screen::GetScreen()->GetPrimaryDisplay();
+    first_display_info_ =
+        display_manager()->GetDisplayInfo(primary_display.id());
+  }
+
+ protected:
+  // Currently `display::features::kRoundedDisplay` feature is used during the
+  // `ash::Shell` shutdown as we call `AshTestBase::TearDown()`, therefore
+  // `scoped_features_` needs to outlive the call.
+  base::test::ScopedFeatureList scoped_features_;
+
+  // ManagedDisplayInfo of the display initialized on the
+  // `AshTestBase::SetUp()`.
+  display::ManagedDisplayInfo first_display_info_;
+};
+
 }  // namespace
 
 class WindowTreeHostManagerTest : public AshTestBase, public TestHelper {
@@ -736,105 +785,163 @@ TEST_F(WindowTreeHostManagerTest, FindNearestDisplay) {
                 .id());
 }
 
-TEST_F(WindowTreeHostManagerTest,
-       SettingAndUpdatingRoundedCornerPropertyOnDisplay) {
-  base::test::ScopedFeatureList scoped_feature_list;
-  scoped_feature_list.InitAndEnableFeature(display::features::kRoundedDisplay);
-
+// When shell is initialized, WindowTreeHost for primary display is created
+// through WindowTreeHostManager::CreatePrimaryHost which does not call in
+// OnDisplayAdded, thus making sure RoundedDisplayProvider is created for the
+// primary host during shell initialization.
+TEST_F(WindowTreeHostManagerRoundedDisplayTest,
+       RoundedDisplayProviderCreatedForPrimaryDisplay) {
   WindowTreeHostManager* window_tree_host_manager =
       Shell::Get()->window_tree_host_manager();
 
-  // Adding rounded corners on the primary display.
-  UpdateDisplay("300x200~15");
+  display::Display primary_display =
+      display::Screen::GetScreen()->GetPrimaryDisplay();
+
+  RoundedDisplayProvider* primary_display_rounded_display_provider =
+      window_tree_host_manager->GetRoundedDisplayProvider(primary_display.id());
+
+  EXPECT_TRUE(primary_display_rounded_display_provider);
+
+  ash::RoundedDisplayProviderTestApi primary_display_provider_test(
+      primary_display_rounded_display_provider);
+  EXPECT_EQ(kTestRoundedDisplayRadii,
+            primary_display_provider_test.GetCurrentPanelRadii());
+}
+
+TEST_F(WindowTreeHostManagerRoundedDisplayTest,
+       SettingAndUpdatingRoundedCornerPropertyOnDisplay) {
+  WindowTreeHostManager* window_tree_host_manager =
+      Shell::Get()->window_tree_host_manager();
 
   display::test::DisplayManagerTestApi display_manager_test(display_manager());
 
-  aura::Window* primary_root = Shell::GetPrimaryRootWindow();
+  display::Display primary_display =
+      display::Screen::GetScreen()->GetPrimaryDisplay();
+  RoundedDisplayProvider* primary_display_rounded_display_provider =
+      window_tree_host_manager->GetRoundedDisplayProvider(primary_display.id());
 
-  EXPECT_EQ(gfx::RoundedCornersF(15.0),
-            primary_root->layer()->rounded_corner_radii());
+  ash::RoundedDisplayProviderTestApi primary_display_provider_test(
+      primary_display_rounded_display_provider);
+
+  // Primary display has rounded corners set in
+  // `WindowTreeHostManagerRoundedDisplayTest::SetUp()`.
+  EXPECT_EQ(kTestRoundedDisplayRadii,
+            primary_display_provider_test.GetCurrentPanelRadii());
 
   // Adding a secondary display should not propagate the rounded corner
   // property.
-  UpdateDisplay("300x200~15,300x200");
+  display_manager()->OnNativeDisplaysChanged(
+      {first_display_info_,
+       display::ManagedDisplayInfo::CreateFromSpec("1+1-300x200")});
 
   display::Display secondary_display =
       display_manager_test.GetSecondaryDisplay();
-  aura::Window* secondary_root =
-      window_tree_host_manager->GetRootWindowForDisplayId(
+
+  RoundedDisplayProvider* secondary_display_rounded_display_provider =
+      window_tree_host_manager->GetRoundedDisplayProvider(
           secondary_display.id());
 
-  EXPECT_EQ(gfx::RoundedCornersF(15.0),
-            primary_root->layer()->rounded_corner_radii());
-  EXPECT_EQ(primary_root->layer()->is_fast_rounded_corner(), true);
-
-  EXPECT_EQ(gfx::RoundedCornersF(0.0),
-            secondary_root->layer()->rounded_corner_radii());
+  EXPECT_EQ(kTestRoundedDisplayRadii,
+            primary_display_provider_test.GetCurrentPanelRadii());
+  EXPECT_FALSE(secondary_display_rounded_display_provider);
 
   // Removing the secondary display should not effect the rounded corner
   // property.
-  UpdateDisplay("300x200~15");
-  EXPECT_EQ(gfx::RoundedCornersF(15.0),
-            primary_root->layer()->rounded_corner_radii());
-  EXPECT_EQ(primary_root->layer()->is_fast_rounded_corner(), true);
+  display_manager()->OnNativeDisplaysChanged({first_display_info_});
+  primary_display_rounded_display_provider =
+      window_tree_host_manager->GetRoundedDisplayProvider(primary_display.id());
+
+  EXPECT_EQ(kTestRoundedDisplayRadii,
+            primary_display_provider_test.GetCurrentPanelRadii());
 
   // Changing the the metrics should not effect rounded corner property.
-  UpdateDisplay("10+20-300x200/ol~15");
-  EXPECT_EQ(gfx::RoundedCornersF(15.0),
-            primary_root->layer()->rounded_corner_radii());
-  EXPECT_EQ(primary_root->layer()->is_fast_rounded_corner(), true);
+  display::ManagedDisplayInfo update_first_display_info = first_display_info_;
+  update_first_display_info.set_device_scale_factor(2.0);
+  update_first_display_info.SetBounds(gfx::Rect(400, 200));
 
-  // Updating rounded corners property on the display.
-  UpdateDisplay("300x200~15|15|12|12");
-  EXPECT_EQ(gfx::RoundedCornersF(15.0, 15.0, 12.0, 12.0),
-            primary_root->layer()->rounded_corner_radii());
-  EXPECT_EQ(primary_root->layer()->is_fast_rounded_corner(), true);
+  display_manager()->OnNativeDisplaysChanged({update_first_display_info});
+  primary_display_rounded_display_provider =
+      window_tree_host_manager->GetRoundedDisplayProvider(primary_display.id());
+
+  EXPECT_EQ(kTestRoundedDisplayRadii,
+            primary_display_provider_test.GetCurrentPanelRadii());
 }
 
-TEST_F(WindowTreeHostManagerTest,
-       SwappingPrimaryDisplayShouldNotSwapRoundedCornersOnDisplays) {
-  base::test::ScopedFeatureList scoped_feature_list;
-  scoped_feature_list.InitAndEnableFeature(display::features::kRoundedDisplay);
-
+TEST_F(WindowTreeHostManagerRoundedDisplayTest,
+       SwappingPrimaryDisplayShouldUpdateTheHostParent) {
   WindowTreeHostManager* window_tree_host_manager =
       Shell::Get()->window_tree_host_manager();
 
-  // primary display has rounded corners.
-  UpdateDisplay("300x200~15,400x300");
-
   display::test::DisplayManagerTestApi display_manager_test(display_manager());
 
+  display::Display primary_display =
+      display::Screen::GetScreen()->GetPrimaryDisplay();
+  RoundedDisplayProvider* primary_display_rounded_display_provider =
+      window_tree_host_manager->GetRoundedDisplayProvider(primary_display.id());
+
+  ash::RoundedDisplayProviderTestApi primary_display_provider_test(
+      primary_display_rounded_display_provider);
+
+  // Primary display has rounded corners set in
+  // `WindowTreeHostManagerRoundedDisplayTest::SetUp()`.
+  EXPECT_EQ(kTestRoundedDisplayRadii,
+            primary_display_provider_test.GetCurrentPanelRadii());
+
+  // Adding a secondary display without rounded-display.
+  display_manager()->OnNativeDisplaysChanged(
+      {first_display_info_,
+       display::ManagedDisplayInfo::CreateFromSpec("1+1-300x200")});
+
   display::Display secondary_display =
       display_manager_test.GetSecondaryDisplay();
 
-  aura::Window* primary_root = Shell::GetPrimaryRootWindow();
-  aura::Window* secondary_root =
-      window_tree_host_manager->GetRootWindowForDisplayId(
+  RoundedDisplayProvider* secondary_display_rounded_display_provider =
+      window_tree_host_manager->GetRoundedDisplayProvider(
           secondary_display.id());
 
-  EXPECT_EQ(gfx::RoundedCornersF(15.0),
-            primary_root->layer()->rounded_corner_radii());
-  EXPECT_EQ(primary_root->layer()->is_fast_rounded_corner(), true);
-  EXPECT_EQ(gfx::RoundedCornersF(0.0),
-            secondary_root->layer()->rounded_corner_radii());
+  EXPECT_TRUE(primary_display_rounded_display_provider);
+  EXPECT_FALSE(secondary_display_rounded_display_provider);
+
+  RoundedDisplayProviderTestApi primary_provider_test(
+      primary_display_rounded_display_provider);
+
+  // Host Widow of RoundedDisplayProvider of primary display is attached to the
+  // root window of the display.
+  EXPECT_EQ(primary_provider_test.GetHostWindow()->parent(),
+            window_tree_host_manager->GetRootWindowForDisplayId(
+                primary_display.id()));
 
   // Switch primary and secondary by display ID.
   window_tree_host_manager->SetPrimaryDisplayId(secondary_display.id());
 
-  // Getting the new primary and secondary root windows after the swap.
+  // Getting the primary and secondary displays after the swap.
+  primary_display = display::Screen::GetScreen()->GetPrimaryDisplay();
   secondary_display = display_manager_test.GetSecondaryDisplay();
 
-  primary_root = Shell::GetPrimaryRootWindow();
-  secondary_root = window_tree_host_manager->GetRootWindowForDisplayId(
-      secondary_display.id());
+  RoundedDisplayProvider* new_primary_display_rounded_display_provider =
+      window_tree_host_manager->GetRoundedDisplayProvider(primary_display.id());
 
-  // After swapping primary display, the root windows are swapped. Secondary
-  // root now belongs to the display with rounded corners.
-  EXPECT_EQ(gfx::RoundedCornersF(15.0),
-            secondary_root->layer()->rounded_corner_radii());
-  EXPECT_EQ(secondary_root->layer()->is_fast_rounded_corner(), true);
-  EXPECT_EQ(gfx::RoundedCornersF(0.0),
-            primary_root->layer()->rounded_corner_radii());
+  // New primary display(previous secondary display) should not have rounded
+  // display provider.
+  EXPECT_FALSE(new_primary_display_rounded_display_provider);
+
+  RoundedDisplayProvider* new_secondary_display_rounded_display_provider =
+      window_tree_host_manager->GetRoundedDisplayProvider(
+          secondary_display.id());
+  EXPECT_TRUE(new_secondary_display_rounded_display_provider);
+
+  RoundedDisplayProviderTestApi secondary_provider_test(
+      new_secondary_display_rounded_display_provider);
+
+  // When a display is swapped. we should not have destroyed the rounded display
+  // provider instead just update the parent of the host window.
+  EXPECT_EQ(new_secondary_display_rounded_display_provider,
+            primary_display_rounded_display_provider);
+
+  // We should have updated the parent of the host window after the swap.
+  EXPECT_EQ(secondary_provider_test.GetHostWindow()->parent(),
+            window_tree_host_manager->GetRootWindowForDisplayId(
+                secondary_display.id()));
 }
 
 TEST_F(WindowTreeHostManagerTest, SwapPrimaryById) {
