@@ -82,7 +82,7 @@ void DropIfAllowed(const ui::OSExchangeData* drag_data,
 
   if (ui::DataTransferPolicyController::HasInstance()) {
     ui::DataTransferPolicyController::Get()->DropIfAllowed(
-        drag_data->GetSource(), &drag_info.data_endpoint, std::move(drop_cb));
+        drag_data, &drag_info.data_endpoint, std::move(drop_cb));
   } else {
     std::move(drop_cb).Run();
   }
@@ -124,6 +124,10 @@ DragDropController::~DragDropController() {
   drag_image_widget_.reset();
 }
 
+bool DragDropController::IsDragDropCompleted() {
+  return drag_drop_completed_;
+}
+
 DragOperation DragDropController::StartDragAndDrop(
     std::unique_ptr<ui::OSExchangeData> data,
     aura::Window* root_window,
@@ -181,6 +185,7 @@ DragOperation DragDropController::StartDragAndDrop(
   if (drag_source_window_)
     drag_source_window_->AddObserver(this);
 
+  drag_drop_completed_ = false;
   drag_data_ = std::move(data);
   allowed_operations_ = allowed_operations;
   current_drag_info_ = aura::client::DragUpdateInfo();
@@ -614,15 +619,20 @@ void DragDropController::Drop(aura::Window* target,
       aura::client::GetDragDropDelegate(target);
 
   aura::client::DragDropDelegate::DropCallback delegate_drop_cb =
-      base::DoNothing();
+      base::NullCallback();
 
   ui::DropTargetEvent e(*drag_data_.get(), event.location_f(),
                         event.root_location_f(), allowed_operations_);
   e.set_flags(event.flags());
   ui::Event::DispatcherApi(&e).set_target(target);
 
-  if (delegate)
+  for (aura::client::DragDropClientObserver& observer : observers_) {
+    observer.OnDragCompleted(e);
+  }
+
+  if (delegate) {
     delegate_drop_cb = delegate->GetDropCallback(e);
+  }
 
   base::ScopedClosureRunner drag_cancel(base::BindOnce(
       &DragDropController::DragCancel, weak_factory_.GetWeakPtr()));
@@ -633,7 +643,6 @@ void DragDropController::Drop(aura::Window* target,
   const bool is_tab_drag_drop = (tab_drag_drop_delegate_.get() != nullptr);
 
   DCHECK_EQ(drag_window_, target);
-  aura::WindowTracker window_tracker({drag_window_, drag_window_->parent()});
 
   DropIfAllowed(
       drag_data_.get(), current_drag_info_,
@@ -643,19 +652,6 @@ void DragDropController::Drop(aura::Window* target,
                      std::move(tab_drag_drop_delegate_),
                      std::move(drag_cancel)));
 
-  // During the drop, the event target (or its ancestors) might have
-  // been destroyed, eg by the client reaction. Adapt the DropTargetEvent
-  // accordingly.
-  //
-  // TODO(https://crbug.com/1160925): Avoid nested RunLoop in exo
-  // DataDevice::GetDropCallback() - remove the block below when it is fixed.
-  if (!window_tracker.Contains(drag_window_) ||
-      !window_tracker.Contains(drag_window_->parent())) {
-    ui::Event::DispatcherApi(&e).set_target(nullptr);
-  }
-
-  for (aura::client::DragDropClientObserver& observer : observers_)
-    observer.OnDragCompleted(e);
   Cleanup();
 
   // Tab drag-n-drop should never be async.
@@ -697,8 +693,9 @@ void DragDropController::DoDragCancel(
   if (toplevel_window_drag_delegate_)
     toplevel_window_drag_delegate_->OnToplevelWindowDragCancelled();
 
-  for (aura::client::DragDropClientObserver& observer : observers_)
+  for (aura::client::DragDropClientObserver& observer : observers_) {
     observer.OnDragCancelled();
+  }
   Cleanup();
 
   StartCanceledAnimation(drag_cancel_animation_duration);
@@ -794,7 +791,7 @@ void DragDropController::Cleanup() {
   if (drag_window_ && drag_window_ != drag_source_window_)
     drag_window_->RemoveObserver(this);
   drag_window_ = nullptr;
-
+  drag_drop_completed_ = true;
   drag_data_.reset();
   allowed_operations_ = 0;
   tab_drag_drop_delegate_.reset();
@@ -816,15 +813,19 @@ void DragDropController::PerformDrop(
     std::unique_ptr<ui::OSExchangeData> drag_data,
     aura::client::DragDropDelegate::DropCallback drop_cb,
     std::unique_ptr<TabDragDropDelegate> tab_drag_drop_delegate,
-    base::ScopedClosureRunner drag_cancel) {
+    base::ScopedClosureRunner cancel_drag_callback) {
   // Event copy constructor dooesn't copy the target. That's why we set it here.
   // DragDropController observes the `drag_window_`, so if it's destroyed, the
   // target will be set to nullptr.
   ui::Event::DispatcherApi(&event).set_target(drag_window_);
 
   ui::OSExchangeData copied_data(drag_data->provider().Clone());
-  if (drop_cb) {
-    std::move(drop_cb).Run(std::move(drag_data), operation_);
+  if (!!drop_cb) {
+    std::move(drop_cb).Run(
+        std::move(drag_data), operation_,
+        drag_image_widget_
+            ? ::wm::RecreateLayers(drag_image_widget_->GetNativeWindow())
+            : nullptr);
   }
 
   if (operation_ == DragOperation::kNone && tab_drag_drop_delegate) {
@@ -846,7 +847,14 @@ void DragDropController::PerformDrop(
   if (toplevel_window_drag_delegate_) {
     operation_ = toplevel_window_drag_delegate_->OnToplevelWindowDragDropped();
   }
-  drag_cancel.ReplaceClosure(base::DoNothing());
+
+  for (aura::client::DragDropClientObserver& observer : observers_) {
+    observer.OnDropCompleted(operation_);
+  }
+
+  // Replace `cancel_drag_callback` with an empty closure. Drop completed, so no
+  // need to cancel the drop.
+  cancel_drag_callback.ReplaceClosure(base::DoNothing());
 }
 
 void DragDropController::CancelIfInProgress() {
