@@ -71,8 +71,7 @@ class TestDelegate : public SelectToSpeakEventHandlerDelegate {
   virtual ~TestDelegate() = default;
 
   bool CapturedMouseEvent(ui::EventType event_type) {
-    return mouse_events_captured_.find(event_type) !=
-           mouse_events_captured_.end();
+    return base::Contains(mouse_events_captured_, event_type);
   }
 
   void Reset() {
