@@ -175,7 +175,7 @@ class FrameSizeButtonTest : public AshTestBase {
     minimize_button_ = test.minimize_button();
     size_button_ = test.size_button();
     static_cast<FrameSizeButton*>(size_button_)
-        ->set_delay_to_set_buttons_to_snap_mode(0);
+        ->set_long_tap_delay_for_testing(base::Milliseconds(0));
     close_button_ = test.close_button();
   }
 
@@ -569,13 +569,11 @@ namespace {
 class FrameSizeButtonNonResizableTest : public FrameSizeButtonTest {
  public:
   FrameSizeButtonNonResizableTest() : FrameSizeButtonTest(false) {}
-
   FrameSizeButtonNonResizableTest(const FrameSizeButtonNonResizableTest&) =
       delete;
   FrameSizeButtonNonResizableTest& operator=(
       const FrameSizeButtonNonResizableTest&) = delete;
-
-  ~FrameSizeButtonNonResizableTest() override {}
+  ~FrameSizeButtonNonResizableTest() override = default;
 };
 
 }  // namespace
@@ -657,16 +655,24 @@ TEST_F(FrameSizeButtonPortraitDisplayTest, SnapButtons) {
   EXPECT_TRUE(HasStateType(WindowStateType::kPrimarySnapped));
 }
 
-// Test multitask menu requires kFloatWindow feature to be enabled during setup.
+// Test multitask menu requires kWindowLayoutMenu feature to be enabled during
+// setup.
 class MultitaskMenuTest : public FrameSizeButtonTest {
  public:
-  MultitaskMenuTest() = default;
-
+  MultitaskMenuTest()
+      : scoped_feature_list_(chromeos::wm::features::kWindowLayoutMenu) {}
   MultitaskMenuTest(const MultitaskMenuTest&) = delete;
   MultitaskMenuTest& operator=(const MultitaskMenuTest&) = delete;
-
   ~MultitaskMenuTest() override = default;
 
+  MultitaskMenu* GetMultitaskMenu() {
+    views::Widget* widget = static_cast<FrameSizeButton*>(size_button())
+                                ->multitask_menu_widget_for_testing();
+    return widget ? static_cast<MultitaskMenu*>(
+                        widget->widget_delegate()->AsDialogDelegate())
+                  : nullptr;
+  }
+
   void ShowMultitaskMenu() {
     DCHECK(size_button());
 
@@ -675,32 +681,11 @@ class MultitaskMenuTest : public FrameSizeButtonTest {
         std::string(kMultitaskMenuBubbleWidgetName));
     static_cast<FrameSizeButton*>(size_button())
         ->ShowMultitaskMenu(MultitaskMenuEntryType::kFrameSizeButtonHover);
-    views::WidgetDelegate* delegate =
-        waiter.WaitIfNeededAndGet()->widget_delegate();
-    multitask_menu_ = static_cast<MultitaskMenu*>(delegate->AsDialogDelegate());
-
-    // Note that this is sync because we use `views::Widget::CloseNow()` in
-    // `MultitaskMenu.`
-    delegate->RegisterWindowClosingCallback(base::BindOnce(
-        &MultitaskMenuTest::OnMultitaskMenuClosed, base::Unretained(this)));
+    waiter.WaitIfNeededAndGet();
   }
 
-  void OnMultitaskMenuClosed() { multitask_menu_ = nullptr; }
-
-  void SetUp() override {
-    // Ensure float feature is enabled.
-    scoped_feature_list_.InitWithFeatures(
-        {chromeos::wm::features::kFloatWindow,
-         chromeos::wm::features::kPartialSplit},
-        {});
-    FrameSizeButtonTest::SetUp();
-  }
-
-  MultitaskMenu* multitask_menu() { return multitask_menu_; }
-
- protected:
+ private:
   base::test::ScopedFeatureList scoped_feature_list_;
-  MultitaskMenu* multitask_menu_ = nullptr;
 };
 
 // Test Float Button Functionality.
@@ -709,10 +694,8 @@ TEST_F(MultitaskMenuTest, TestMultitaskMenuFloatFunctionality) {
   EXPECT_TRUE(window_state()->IsNormalStateType());
   ui::test::EventGenerator* generator = GetEventGenerator();
   ShowMultitaskMenu();
-  generator->MoveMouseTo(
-      CenterPointInScreen(multitask_menu()
-                              ->multitask_menu_view_for_testing()
-                              ->float_button_for_testing()));
+  generator->MoveMouseTo(CenterPointInScreen(
+      GetMultitaskMenu()->multitask_menu_view()->float_button_for_testing()));
   generator->ClickLeftButton();
   EXPECT_TRUE(window_state()->IsFloated());
   histogram_tester.ExpectBucketCount(
@@ -726,8 +709,8 @@ TEST_F(MultitaskMenuTest, TestMultitaskMenuHalfFunctionality) {
   EXPECT_TRUE(window_state()->IsNormalStateType());
   ui::test::EventGenerator* generator = GetEventGenerator();
   ShowMultitaskMenu();
-  generator->MoveMouseTo(multitask_menu()
-                             ->multitask_menu_view_for_testing()
+  generator->MoveMouseTo(GetMultitaskMenu()
+                             ->multitask_menu_view()
                              ->half_button_for_testing()
                              ->GetBoundsInScreen()
                              .left_center());
@@ -746,8 +729,8 @@ TEST_F(MultitaskMenuTest, HalfButtonRTL) {
   base::i18n::SetRTLForTesting(true);
 
   ShowMultitaskMenu();
-  GetEventGenerator()->MoveMouseTo(multitask_menu()
-                                       ->multitask_menu_view_for_testing()
+  GetEventGenerator()->MoveMouseTo(GetMultitaskMenu()
+                                       ->multitask_menu_view()
                                        ->half_button_for_testing()
                                        ->GetBoundsInScreen()
                                        .left_center());
@@ -774,8 +757,8 @@ TEST_F(MultitaskMenuTest, HalfButtonSecondaryLayout) {
   // Click on the left side of the half button. It should be in secondary
   // snapped state, because in this orientation secondary snapped is actually
   // physically on the left side.
-  GetEventGenerator()->MoveMouseToInHost(multitask_menu()
-                                             ->multitask_menu_view_for_testing()
+  GetEventGenerator()->MoveMouseToInHost(GetMultitaskMenu()
+                                             ->multitask_menu_view()
                                              ->half_button_for_testing()
                                              ->GetBoundsInScreen()
                                              .left_center());
@@ -802,15 +785,16 @@ TEST_F(MultitaskMenuTest, TestMultitaskMenuPartialSplit) {
 
   // Snap to primary with 0.67f screen ratio.
   ShowMultitaskMenu();
-  generator->MoveMouseTo(multitask_menu()
-                             ->multitask_menu_view_for_testing()
+  generator->MoveMouseTo(GetMultitaskMenu()
+                             ->multitask_menu_view()
                              ->partial_button()
                              ->GetBoundsInScreen()
                              .left_center());
   generator->ClickLeftButton();
   EXPECT_EQ(WindowStateType::kPrimarySnapped, window_state()->GetStateType());
   EXPECT_EQ(window_state()->window()->bounds().width(),
-            work_area_bounds_in_screen.width() * 0.67);
+            std::round(work_area_bounds_in_screen.width() *
+                       chromeos::kTwoThirdSnapRatio));
   EXPECT_EQ(user_action_tester.GetActionCount(
                 chromeos::kPartialSplitTwoThirdsUserAction),
             1);
@@ -820,18 +804,17 @@ TEST_F(MultitaskMenuTest, TestMultitaskMenuPartialSplit) {
 
   // Snap to secondary with 0.33f screen ratio.
   ShowMultitaskMenu();
-  gfx::Rect partial_bounds(multitask_menu()
-                               ->multitask_menu_view_for_testing()
-                               ->partial_button()
-                               ->GetBoundsInScreen());
-  gfx::Point secondary_center(
-      gfx::Point(partial_bounds.x() + partial_bounds.width() * 0.67f,
-                 partial_bounds.y() + partial_bounds.y() / 2));
-  generator->MoveMouseTo(secondary_center);
+  generator->MoveMouseTo(GetMultitaskMenu()
+                             ->multitask_menu_view()
+                             ->partial_button()
+                             ->GetRightBottomButton()
+                             ->GetBoundsInScreen()
+                             .CenterPoint());
   generator->ClickLeftButton();
   EXPECT_EQ(WindowStateType::kSecondarySnapped, window_state()->GetStateType());
   EXPECT_EQ(window_state()->window()->bounds().width(),
-            work_area_bounds_in_screen.width() * 0.33);
+            std::round(work_area_bounds_in_screen.width() *
+                       chromeos::kOneThirdSnapRatio));
   EXPECT_EQ(user_action_tester.GetActionCount(
                 chromeos::kPartialSplitOneThirdUserAction),
             1);
@@ -846,10 +829,8 @@ TEST_F(MultitaskMenuTest, TestMultitaskMenuFullFunctionality) {
   ASSERT_TRUE(window_state()->IsNormalStateType());
   ui::test::EventGenerator* generator = GetEventGenerator();
   ShowMultitaskMenu();
-  generator->MoveMouseTo(
-      CenterPointInScreen(multitask_menu()
-                              ->multitask_menu_view_for_testing()
-                              ->full_button_for_testing()));
+  generator->MoveMouseTo(CenterPointInScreen(
+      GetMultitaskMenu()->multitask_menu_view()->full_button_for_testing()));
   generator->ClickLeftButton();
   EXPECT_TRUE(window_state()->IsFullscreen());
   histogram_tester.ExpectBucketCount(
@@ -859,11 +840,13 @@ TEST_F(MultitaskMenuTest, TestMultitaskMenuFullFunctionality) {
 
 TEST_F(MultitaskMenuTest, MultitaskMenuClosesOnTabletMode) {
   ShowMultitaskMenu();
-  ASSERT_TRUE(multitask_menu());
-  ASSERT_TRUE(multitask_menu()->GetWidget());
+  ASSERT_TRUE(GetMultitaskMenu());
 
-  ash::TabletMode::Get()->SetEnabledForTest(true);
-  EXPECT_FALSE(multitask_menu());
+  TabletMode::Get()->SetEnabledForTest(true);
+
+  // Closing the widget is done on a post task.
+  base::RunLoop().RunUntilIdle();
+  EXPECT_FALSE(GetMultitaskMenu());
 }
 
 // Verifies that long touch on the size button shows the multitask menu.
@@ -916,4 +899,46 @@ TEST_F(MultitaskMenuTest, EntryTypeHistogram) {
   histogram_tester.ExpectTotalCount(chromeos::GetEntryTypeHistogramName(), 3);
 }
 
+// Tests that we do not create a new widget when hovering on the size button
+// when the multitask menu is already opened.
+TEST_F(MultitaskMenuTest, HoverWhenMenuAlreadyShown) {
+  ShowMultitaskMenu();
+  MultitaskMenu* multitask_menu = GetMultitaskMenu();
+  ASSERT_TRUE(multitask_menu);
+
+  // Ensure the mouse is not already on the size button then move it back on.
+  // The menu should be the same one opened beforehand.
+  GetEventGenerator()->MoveMouseTo(
+      size_button()->GetBoundsInScreen().bottom_right() + gfx::Vector2d(2, 2));
+  GetEventGenerator()->MoveMouseTo(CenterPointInScreen(size_button()));
+  EXPECT_EQ(multitask_menu, GetMultitaskMenu());
+}
+
+TEST_F(MultitaskMenuTest, CloseOnClickOutside) {
+  // Snap the window to half so we can click outside the window bounds.
+  ShowMultitaskMenu();
+  GetEventGenerator()->MoveMouseTo(GetMultitaskMenu()
+                                       ->multitask_menu_view()
+                                       ->half_button_for_testing()
+                                       ->GetBoundsInScreen()
+                                       .left_center());
+  GetEventGenerator()->ClickLeftButton();
+  EXPECT_EQ(WindowStateType::kPrimarySnapped, window_state()->GetStateType());
+
+  ShowMultitaskMenu();
+  MultitaskMenu* multitask_menu = GetMultitaskMenu();
+  ASSERT_TRUE(multitask_menu);
+
+  // Click on a point outside the menu on the screen below.
+  gfx::Point offset_point(multitask_menu->multitask_menu_view()
+                              ->GetBoundsInScreen()
+                              .bottom_right());
+  offset_point.Offset(10, 10);
+  DCHECK(!GetWidget()->GetWindowBoundsInScreen().Contains(offset_point));
+  GetEventGenerator()->MoveMouseTo(offset_point);
+  GetEventGenerator()->ClickLeftButton();
+  base::RunLoop().RunUntilIdle();
+  ASSERT_FALSE(GetMultitaskMenu());
+}
+
 }  // namespace ash
