@@ -12,6 +12,7 @@
 #include "ash/public/cpp/tablet_mode_observer.h"
 #include "ash/public/cpp/window_properties.h"
 #include "ash/shell.h"
+#include "ash/shell_delegate.h"
 #include "ash/wm/overview/overview_controller.h"
 #include "ash/wm/splitview/split_view_controller.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
@@ -21,11 +22,13 @@
 #include "base/functional/bind.h"
 #include "chromeos/ui/base/window_properties.h"
 #include "chromeos/ui/frame/caption_buttons/frame_caption_button_container_view.h"
+#include "chromeos/ui/frame/caption_buttons/frame_size_button.h"
 #include "chromeos/ui/frame/default_frame_header.h"
 #include "chromeos/ui/frame/frame_utils.h"
 #include "chromeos/ui/frame/header_view.h"
 #include "chromeos/ui/frame/immersive/immersive_fullscreen_controller.h"
 #include "chromeos/ui/frame/non_client_frame_view_base.h"
+#include "chromeos/ui/wm/features.h"
 #include "ui/aura/client/aura_constants.h"
 #include "ui/aura/window.h"
 #include "ui/aura/window_observer.h"
@@ -177,6 +180,13 @@ NonClientFrameViewAsh::NonClientFrameViewAsh(views::Widget* frame)
 
   header_view_->set_context_menu_controller(
       frame_context_menu_controller_.get());
+
+  auto* size_button = header_view_->caption_button_container()->size_button();
+  if (chromeos::wm::features::IsWindowLayoutMenuEnabled() && size_button) {
+    size_button->SetFeedbackButtonCallback(
+        base::BindRepeating(&NonClientFrameViewAsh::ShowFeedbackPageForMenu,
+                            weak_factory_.GetWeakPtr()));
+  }
 }
 
 NonClientFrameViewAsh::~NonClientFrameViewAsh() = default;
@@ -205,10 +215,6 @@ void NonClientFrameViewAsh::SetCaptionButtonModel(
   header_view_->UpdateCaptionButtons();
 }
 
-chromeos::HeaderView* NonClientFrameViewAsh::GetHeaderView() {
-  return header_view_;
-}
-
 gfx::Rect NonClientFrameViewAsh::GetClientBoundsForWindowBounds(
     const gfx::Rect& window_bounds) const {
   gfx::Rect client_bounds(window_bounds);
@@ -309,11 +315,6 @@ NonClientFrameViewAsh::GetFrameCaptionButtonContainerViewForTest() {
   return header_view_->caption_button_container();
 }
 
-void NonClientFrameViewAsh::PaintAsActiveChanged() {
-  header_view_->GetFrameHeader()->SetPaintAsActive(ShouldPaintAsActive());
-  frame_->non_client_view()->Layout();
-}
-
 void NonClientFrameViewAsh::UpdateDefaultFrameColors() {
   aura::Window* frame_window = frame_->GetNativeWindow();
   if (!frame_window->GetProperty(kTrackDefaultFrameColors))
@@ -333,6 +334,12 @@ void NonClientFrameViewAsh::UpdateDefaultFrameColors() {
   frame_window->SetProperty(kFrameInactiveColorKey, dialog_title_bar_color);
 }
 
+void NonClientFrameViewAsh::ShowFeedbackPageForMenu() {
+  Shell::Get()->shell_delegate()->OpenFeedbackDialog(
+      ShellDelegate::FeedbackSource::kWindowLayoutMenu,
+      /*description_template=*/"#WindowLayoutMenu");
+}
+
 BEGIN_METADATA(NonClientFrameViewAsh, views::NonClientFrameView)
 END_METADATA
 
