@@ -16,17 +16,8 @@ class ASH_EXPORT GlanceablesDelegate {
  public:
   virtual ~GlanceablesDelegate() = default;
 
-  // Triggers session restore.
-  virtual void RestoreSession() = 0;
-
   // Called after the glanceables UI is closed.
   virtual void OnGlanceablesClosed() = 0;
-
-  // Returns true if a signout screenshot should be taken for this session. This
-  // method exists to avoid taking screenshots for account types that don't
-  // support glanceables (e.g. forced app mode) and to avoid screenshots in
-  // tests.
-  virtual bool ShouldTakeSignoutScreenshot() = 0;
 };
 
 }  // namespace ash
