@@ -15,7 +15,6 @@ class Label;
 
 namespace ash {
 
-class GlanceablesRestoreView;
 class GlanceablesUpNextView;
 class GlanceablesWeatherView;
 class GlanceablesWelcomeLabel;
@@ -23,9 +22,7 @@ class GlanceablesWelcomeLabel;
 // Container view for the "welcome back" glanceables screen shown on login.
 class ASH_EXPORT GlanceablesView : public views::View {
  public:
-  // `show_session_restore` controls whether the session restore views are
-  // created.
-  explicit GlanceablesView(bool show_session_restore);
+  GlanceablesView();
   GlanceablesView(const GlanceablesView&) = delete;
   GlanceablesView& operator=(const GlanceablesView&) = delete;
   ~GlanceablesView() override;
@@ -42,8 +39,6 @@ class ASH_EXPORT GlanceablesView : public views::View {
   GlanceablesWeatherView* weather_view_ = nullptr;
   views::Label* up_next_label_ = nullptr;
   GlanceablesUpNextView* up_next_view_ = nullptr;
-  views::Label* restore_session_label_ = nullptr;
-  GlanceablesRestoreView* restore_view_ = nullptr;
 };
 
 }  // namespace ash
