@@ -11,8 +11,8 @@
 #include "ash/hud_display/hud_properties.h"
 #include "ash/shell.h"
 #include "ash/shell_delegate.h"
-#include "base/bind.h"
 #include "base/compiler_specific.h"
+#include "base/functional/bind.h"
 #include "base/strings/stringprintf.h"
 #include "base/time/time.h"
 #include "cc/debug/layer_tree_debug_state.h"
