@@ -8,8 +8,7 @@
 #include <string>
 #include <vector>
 
-#include "base/callback.h"
-
+#include "base/functional/callback.h"
 #include "ui/views/view.h"
 
 namespace ash {
