@@ -17,9 +17,10 @@
 #include "ash/test/ash_test_base.h"
 #include "ash/test/ash_test_util.h"
 #include "ash/wallpaper/wallpaper_controller_impl.h"
-#include "base/bind.h"
+#include "base/functional/bind.h"
 #include "base/run_loop.h"
 #include "base/test/bind.h"
+#include "chromeos/ash/components/login/auth/auth_metrics_recorder.h"
 #include "components/prefs/pref_service.h"
 #include "components/session_manager/session_manager_types.h"
 #include "components/user_manager/known_user.h"
@@ -34,10 +35,23 @@ class LoginScreenControllerTest : public AshTestBase {
  public:
   LoginScreenControllerTest() {
     user_manager::KnownUser::RegisterPrefs(local_state()->registry());
+    auth_metrics_recorder_ = ash::AuthMetricsRecorder::CreateForTesting();
   }
+
+ private:
+  std::unique_ptr<ash::AuthMetricsRecorder> auth_metrics_recorder_;
 };
 
-using LoginScreenControllerNoSessionTest = NoSessionAshTestBase;
+class LoginScreenControllerNoSessionTest : public NoSessionAshTestBase {
+ public:
+  LoginScreenControllerNoSessionTest() {
+    user_manager::KnownUser::RegisterPrefs(local_state()->registry());
+    auth_metrics_recorder_ = ash::AuthMetricsRecorder::CreateForTesting();
+  }
+
+ private:
+  std::unique_ptr<ash::AuthMetricsRecorder> auth_metrics_recorder_;
+};
 
 // Enum instead of enum class, because it is used for indexing.
 enum WindowType { kPrimary = 0, kSecondary = 1 };
