@@ -65,14 +65,13 @@ class FlexCodeInput : public AccessCodeInput {
   FlexCodeInput(OnInputChange on_input_change,
                 OnEnter on_enter,
                 OnEscape on_escape,
-                bool obscure_pin,
-                SkColor text_color);
+                bool obscure_pin);
 
   FlexCodeInput(const FlexCodeInput&) = delete;
   FlexCodeInput& operator=(const FlexCodeInput&) = delete;
   ~FlexCodeInput() override;
 
-  void SetAccessibleName(const std::u16string& name);
+  void OnThemeChanged() override;
 
   // Appends |value| to the code
   void InsertDigit(int value) override;
@@ -105,6 +104,8 @@ class FlexCodeInput : public AccessCodeInput {
                       const ui::KeyEvent& key_event) override;
 
  private:
+  void OnAccessibleNameChanged(const std::u16string& new_name) override;
+
   views::Textfield* code_field_;
 
   // To be called when access input code changes (character is inserted, deleted
@@ -172,13 +173,14 @@ class FixedLengthCodeInput : public AccessCodeInput {
                        OnInputChange on_input_change,
                        OnEnter on_enter,
                        OnEscape on_escape,
-                       bool obscure_pin,
-                       SkColor text_color);
+                       bool obscure_pin);
 
   ~FixedLengthCodeInput() override;
   FixedLengthCodeInput(const FixedLengthCodeInput&) = delete;
   FixedLengthCodeInput& operator=(const FixedLengthCodeInput&) = delete;
 
+  void OnThemeChanged() override;
+
   // Inserts |value| into the |active_field_| and moves focus to the next field
   // if it exists.
   void InsertDigit(int value) override;
