@@ -30,8 +30,9 @@ FingerprintAuthFactorModel::Factory*
 // static
 std::unique_ptr<FingerprintAuthFactorModel>
 FingerprintAuthFactorModel::Factory::Create(FingerprintState state) {
-  if (factory_instance_)
+  if (factory_instance_) {
     return factory_instance_->CreateInstance(state);
+  }
   return std::make_unique<FingerprintAuthFactorModel>(state);
 }
 
@@ -47,8 +48,9 @@ FingerprintAuthFactorModel::FingerprintAuthFactorModel(FingerprintState state)
 FingerprintAuthFactorModel::~FingerprintAuthFactorModel() = default;
 
 void FingerprintAuthFactorModel::SetFingerprintState(FingerprintState state) {
-  if (state_ == state)
+  if (state_ == state) {
     return;
+  }
 
   // Clear out the timeout if the state changes. This shouldn't happen
   // ordinarily -- permanent error states are permanent after all -- but this is
@@ -71,8 +73,9 @@ void FingerprintAuthFactorModel::NotifyFingerprintAuthResult(bool result) {
 
 AuthFactorModel::AuthFactorState
 FingerprintAuthFactorModel::GetAuthFactorState() const {
-  if (!available_)
+  if (!available_) {
     return AuthFactorState::kUnavailable;
+  }
 
   if (auth_result_.has_value()) {
     if (auth_result_.value()) {
@@ -132,8 +135,9 @@ bool FingerprintAuthFactorModel::ShouldAnnounceLabel() const {
 }
 
 int FingerprintAuthFactorModel::GetAccessibleNameId() const {
-  if (state_ == FingerprintState::DISABLED_FROM_ATTEMPTS)
+  if (state_ == FingerprintState::DISABLED_FROM_ATTEMPTS) {
     return IDS_ASH_LOGIN_FINGERPRINT_UNLOCK_ACCESSIBLE_AUTH_DISABLED_FROM_ATTEMPTS;
+  }
 
   return GetLabelId();
 }
