@@ -10,10 +10,10 @@
 #include "ash/ash_export.h"
 #include "ash/ime/ime_controller_impl.h"
 #include "ash/login/ui/animated_rounded_image_view.h"
-#include "ash/login/ui/login_palette.h"
 #include "ash/public/cpp/session/user_info.h"
 #include "base/memory/weak_ptr.h"
 #include "ui/base/ime/ash/ime_keyboard.h"
+#include "ui/base/metadata/metadata_header_macros.h"
 #include "ui/compositor/layer_animation_observer.h"
 #include "ui/views/controls/button/button.h"
 #include "ui/views/controls/textfield/textfield_controller.h"
@@ -61,6 +61,7 @@ class ASH_EXPORT LoginPasswordView
       public ui::ImplicitAnimationObserver,
       public base::SupportsWeakPtr<LoginPasswordView> {
  public:
+  METADATA_HEADER(LoginPasswordView);
   // TestApi is used for tests to get internal implementation details.
   class ASH_EXPORT TestApi {
    public:
@@ -90,7 +91,7 @@ class ASH_EXPORT LoginPasswordView
   using OnEasyUnlockIconHovered = base::RepeatingClosure;
 
   // Must call |Init| after construction.
-  explicit LoginPasswordView(const LoginPalette& palette);
+  LoginPasswordView();
 
   LoginPasswordView(const LoginPasswordView&) = delete;
   LoginPasswordView& operator=(const LoginPasswordView&) = delete;
@@ -113,9 +114,6 @@ class ASH_EXPORT LoginPasswordView
   void SetEasyUnlockIcon(EasyUnlockIconState icon_state,
                          const std::u16string& accessibility_label);
 
-  // Set the textfield name used for accessibility.
-  void SetAccessibleName(const std::u16string& name);
-
   // Enable or disable focus on the child elements (i.e.: password field and
   // submit button, or display password button if it is shown).
   void SetFocusEnabledForTextfield(bool enable);
@@ -142,7 +140,6 @@ class ASH_EXPORT LoginPasswordView
   bool IsReadOnly() const;
 
   // views::View:
-  const char* GetClassName() const override;
   gfx::Size CalculatePreferredSize() const override;
   void RequestFocus() override;
   bool OnKeyPressed(const ui::KeyEvent& event) override;
@@ -175,10 +172,6 @@ class ASH_EXPORT LoginPasswordView
   // field.
   void SubmitPassword();
 
-  // When theme changes, palette should be updated and some subviews
-  // recalculated.
-  void UpdatePalette(const LoginPalette& palette);
-
  private:
   class EasyUnlockIcon;
   class DisplayPasswordButton;
@@ -198,6 +191,8 @@ class ASH_EXPORT LoginPasswordView
   // button when it is visible.
   void UpdateUiState();
 
+  void OnAccessibleNameChanged(const std::u16string& new_name) override;
+
   OnPasswordSubmit on_submit_;
   OnPasswordTextChanged on_password_text_changed_;
 
@@ -213,8 +208,6 @@ class ASH_EXPORT LoginPasswordView
   // through the password and make the characters read out loud one by one).
   base::RetainingOneShotTimer hide_password_timer_;
 
-  LoginPalette palette_;
-
   LoginPasswordRow* password_row_ = nullptr;
   LoginTextfield* textfield_ = nullptr;
   ArrowButtonView* submit_button_ = nullptr;
