@@ -4,11 +4,12 @@
 
 #include "ash/login/ui/login_remove_account_dialog.h"
 #include "ash/login/ui/non_accessible_view.h"
-#include "ash/login/ui/system_label_button.h"
 #include "ash/login/ui/views_utils.h"
 #include "ash/public/cpp/login_types.h"
 #include "ash/public/cpp/shelf_config.h"
 #include "ash/strings/grit/ash_strings.h"
+#include "ash/style/ash_color_id.h"
+#include "ash/style/pill_button.h"
 #include "base/functional/bind.h"
 #include "base/strings/strcat.h"
 #include "base/strings/utf_string_conversions.h"
@@ -70,19 +71,23 @@ class TrappedFocusSearch : public views::FocusSearch {
 }  // namespace
 
 // A system label button that dismisses its bubble dialog parent on key event.
-class RemoveUserButton : public SystemLabelButton {
+class RemoveUserButton : public PillButton {
  public:
   RemoveUserButton(PressedCallback callback, LoginRemoveAccountDialog* bubble)
-      : SystemLabelButton(std::move(callback),
-                          l10n_util::GetStringUTF16(
-                              IDS_ASH_LOGIN_POD_REMOVE_ACCOUNT_ACCESSIBLE_NAME),
-                          /*multiline=*/true),
+      : PillButton(std::move(callback),
+                   l10n_util::GetStringUTF16(
+                       IDS_ASH_LOGIN_POD_REMOVE_ACCOUNT_ACCESSIBLE_NAME)),
         bubble_(bubble) {}
 
   RemoveUserButton(const RemoveUserButton&) = delete;
   RemoveUserButton& operator=(const RemoveUserButton&) = delete;
   ~RemoveUserButton() override = default;
 
+  void SetAlert(bool alert) {
+    SetPillButtonType(alert ? PillButton::Type::kAlertWithoutIcon
+                            : PillButton::Type::kDefaultWithoutIcon);
+  }
+
  private:
   void OnKeyEvent(ui::KeyEvent* event) override {
     if (event->type() != ui::ET_KEY_PRESSED ||
@@ -153,16 +158,16 @@ LoginRemoveAccountDialog::LoginRemoveAccountDialog(
         views::BoxLayout::Orientation::kVertical, gfx::Insets(),
         kVerticalMarginUsernameMailDp));
     AddChildView(container);
-    // Colors should be updated in OnThemeChanged.
     username_label_ =
-        container->AddChildView(login_views_utils::CreateBubbleLabel(
-            display_username, nullptr, SK_ColorGREEN,
+        container->AddChildView(login_views_utils::CreateThemedBubbleLabel(
+            display_username, nullptr, kColorAshTextColorPrimary,
             gfx::FontList({login_views_utils::kGoogleSansFont},
                           gfx::Font::FontStyle::NORMAL, kFontSizeUsername,
                           gfx::Font::Weight::MEDIUM),
             kLineHeightUsername));
     email_label_ =
-        container->AddChildView(login_views_utils::CreateBubbleLabel(email));
+        container->AddChildView(login_views_utils::CreateThemedBubbleLabel(
+            email, nullptr, kColorAshTextColorSecondary));
   }
 
   // Add a warning text if the user is managed.
@@ -171,7 +176,8 @@ LoginRemoveAccountDialog::LoginRemoveAccountDialog(
         IDS_ASH_LOGIN_MANAGED_SESSION_MONITORING_USER_WARNING,
         base::UTF8ToUTF16(user.user_account_manager.value()));
     management_disclosure_label_ =
-        AddChildView(login_views_utils::CreateBubbleLabel(managed_text, this));
+        AddChildView(login_views_utils::CreateThemedBubbleLabel(
+            managed_text, this, kColorAshTextColorPrimary));
   }
 
   // If we can remove the user, the focus will be trapped by the bubble, and
@@ -200,10 +206,12 @@ LoginRemoveAccountDialog::LoginRemoveAccountDialog(
     remove_user_confirm_data_->SetVisible(false);
 
     remove_user_confirm_data_->AddChildView(
-        login_views_utils::CreateBubbleLabel(part1, this));
+        login_views_utils::CreateThemedBubbleLabel(part1, this,
+                                                   kColorAshTextColorPrimary));
 
     remove_user_confirm_data_->AddChildView(
-        login_views_utils::CreateBubbleLabel(part2, this));
+        login_views_utils::CreateThemedBubbleLabel(part2, this,
+                                                   kColorAshTextColorPrimary));
 
     remove_user_button_ = new RemoveUserButton(
         base::BindRepeating(&LoginRemoveAccountDialog::RemoveUserButtonPressed,
@@ -229,7 +237,7 @@ void LoginRemoveAccountDialog::ResetState() {
   }
   if (remove_user_confirm_data_) {
     remove_user_confirm_data_->SetVisible(false);
-    remove_user_button_->SetBackgroundAndFont(/*alert_mode=*/false);
+    remove_user_button_->SetAlert(false);
     // Reset button's description to none.
     remove_user_button_->GetViewAccessibility().OverrideDescription(
         std::u16string(),
@@ -241,29 +249,6 @@ LoginButton* LoginRemoveAccountDialog::GetBubbleOpener() const {
   return bubble_opener_;
 }
 
-void LoginRemoveAccountDialog::OnThemeChanged() {
-  LoginBaseBubbleView::OnThemeChanged();
-  username_label_->SetEnabledColor(
-      AshColorProvider::Get()->GetContentLayerColor(
-          AshColorProvider::ContentLayerType::kTextColorPrimary));
-  email_label_->SetEnabledColor(AshColorProvider::Get()->GetContentLayerColor(
-      AshColorProvider::ContentLayerType::kTextColorSecondary));
-  if (remove_user_confirm_data_) {
-    DCHECK_EQ(2u, remove_user_confirm_data_->children().size());
-    for (views::View* label : remove_user_confirm_data_->children()) {
-      static_cast<views::Label*>(label)->SetEnabledColor(
-          AshColorProvider::Get()->GetContentLayerColor(
-              AshColorProvider::ContentLayerType::kTextColorPrimary));
-    }
-  }
-
-  if (management_disclosure_label_) {
-    management_disclosure_label_->SetEnabledColor(
-        AshColorProvider::Get()->GetContentLayerColor(
-            AshColorProvider::ContentLayerType::kTextColorPrimary));
-  }
-}
-
 void LoginRemoveAccountDialog::RequestFocus() {
   // This view has no actual interesting contents to focus, so immediately
   // forward to the button.
@@ -325,7 +310,7 @@ void LoginRemoveAccountDialog::RemoveUserButtonPressed() {
     if (management_disclosure_label_) {
       management_disclosure_label_->SetVisible(false);
     }
-    remove_user_button_->SetBackgroundAndFont(/*alert_mode=*/true);
+    remove_user_button_->SetAlert(true);
 
     Layout();
 
