@@ -11,7 +11,6 @@
 #include "ash/metrics/ui_metrics_recorder.h"
 #include "ash/public/cpp/session/session_observer.h"
 #include "ash/public/cpp/shelf_types.h"
-#include "base/containers/flat_set.h"
 #include "base/memory/raw_ptr.h"
 #include "base/memory/weak_ptr.h"
 #include "base/time/time.h"
@@ -92,6 +91,12 @@ class ASH_EXPORT LoginUnlockThroughputRecorder : public SessionObserver,
   // tracing after login is done.
   void AddLoginTimeMarker(const std::string& marker_name);
 
+  // This flag signals that all expected browser windows are already scheduled.
+  void RestoreDataLoaded();
+
+  // Records that ARC has finished booting.
+  void ArcUiAvailableAfterLogin();
+
  private:
   class TimeMarker {
    public:
@@ -118,10 +123,12 @@ class ASH_EXPORT LoginUnlockThroughputRecorder : public SessionObserver,
       base::TimeTicks start,
       const cc::FrameSequenceMetrics::CustomReportData& data);
 
-  void ScheduleWaitForShelfAnimationEnd();
+  void ScheduleWaitForShelfAnimationEndIfNeeded();
 
   void OnAllExpectedShelfIconsLoaded();
 
+  void MaybeReportLoginFinished();
+
   UiMetricsRecorder ui_recorder_;
 
   // Set of window IDs ("restore_window_id") that could be restored but
@@ -144,12 +151,37 @@ class ASH_EXPORT LoginUnlockThroughputRecorder : public SessionObserver,
 
   bool shelf_initialized_ = false;
 
+  // |has_pending_icon_| is true when last shelf icons update had an item
+  // pending icon load.
+  bool has_pending_icon_ = false;
+
+  // |shelf_icons_loaded_| is true when shelf icons are considered loaded,
+  // i.e. |has_pending_icon_| is true and first resored browser window was
+  // created.
   bool shelf_icons_loaded_ = false;
 
   bool user_logged_in_ = false;
 
   bool arc_app_list_ready_reported_ = false;
 
+  bool all_restored_windows_presented_ = false;
+
+  bool shelf_animation_end_scheduled_ = false;
+
+  bool shelf_animation_finished_ = false;
+
+  bool login_animation_throughput_received_ = false;
+
+  bool login_finished_reported_ = false;
+
+  // |browser_windows_will_not_be_restored_| is true when session restore
+  // window list is empty.
+  bool browser_windows_will_not_be_restored_ = false;
+
+  // This is a signal that current list of expected windows to be restored is
+  // final.
+  bool first_restored_window_created_ = false;
+
   absl::optional<base::TimeTicks> arc_opt_in_time_;
 
   base::WeakPtr<ui::TotalAnimationThroughputReporter>
@@ -159,8 +191,6 @@ class ASH_EXPORT LoginUnlockThroughputRecorder : public SessionObserver,
       ui::TotalAnimationThroughputReporter::ScopedThroughputReporterBlocker>
       scoped_throughput_reporter_blocker_;
 
-  base::flat_set<ShelfID> expected_shelf_icons_;
-
   std::vector<TimeMarker> login_time_markers_;
 
   base::WeakPtrFactory<LoginUnlockThroughputRecorder> weak_ptr_factory_{this};
