@@ -126,6 +126,7 @@ enum AcceleratorAction {
   TOGGLE_FLOATING,
   TOGGLE_FULLSCREEN,
   TOGGLE_FULLSCREEN_MAGNIFIER,
+  TOGGLE_GAME_DASHBOARD,
   TOGGLE_HIGH_CONTRAST,
   TOGGLE_MAXIMIZED,
   TOGGLE_MESSAGE_CENTER_BUBBLE,
@@ -150,7 +151,6 @@ enum AcceleratorAction {
 
   // Debug accelerators are intentionally at the end, so that if you remove one
   // you don't need to update tests which check hashes of the ids.
-  DEBUG_DUMP_CALENDAR_MODEL,
   DEBUG_KEYBOARD_BACKLIGHT_TOGGLE,
   DEBUG_MICROPHONE_MUTE_TOGGLE,
   DEBUG_PRINT_LAYER_HIERARCHY,
@@ -231,6 +231,11 @@ ASH_PUBLIC_EXPORT extern const AcceleratorData
 ASH_PUBLIC_EXPORT extern const size_t
     kEnableWithFloatWindowAcceleratorDataLength;
 
+// Accelerators that are enabled with the game dashboard feature.
+ASH_PUBLIC_EXPORT extern const AcceleratorData
+    kToggleGameDashboardAcceleratorData[];
+ASH_PUBLIC_EXPORT extern const size_t kToggleGameDashboardAcceleratorDataLength;
+
 // The public-facing interface for accelerator handling, which is Ash's duty to
 // implement.
 class ASH_PUBLIC_EXPORT AcceleratorController {
