@@ -39,16 +39,11 @@ ASH_PUBLIC_EXPORT BASE_DECLARE_FEATURE(kQuickActionShowBubbleLauncher);
 // are interrupted by search model updates.
 ASH_PUBLIC_EXPORT BASE_DECLARE_FEATURE(kDynamicSearchUpdateAnimation);
 
-// Controls the bubble launcher (productivity launcher in clamshell) width. When
-// enabled, the bubble UI will be narrower.
-ASH_PUBLIC_EXPORT BASE_DECLARE_FEATURE(kCompactBubbleLauncher);
-
 // Enables Play Store search in the launcher.
 ASH_PUBLIC_EXPORT BASE_DECLARE_FEATURE(kLauncherPlayStoreSearch);
 
-// Enables new tablet <-> clamshell mode transition animation (scale + opacity
-// instead of slide up/down).
-ASH_PUBLIC_EXPORT BASE_DECLARE_FEATURE(kAnimateScaleOnTabletModeTransition);
+// Enables app list drag and drop refactor to use views drag and drop APIs.
+ASH_PUBLIC_EXPORT BASE_DECLARE_FEATURE(kDragAndDropRefactor);
 
 ASH_PUBLIC_EXPORT bool IsAppReinstallZeroStateEnabled();
 ASH_PUBLIC_EXPORT bool IsAppListLaunchRecordingEnabled();
@@ -60,9 +55,8 @@ ASH_PUBLIC_EXPORT bool IsSearchResultInlineIconEnabled();
 ASH_PUBLIC_EXPORT bool IsQuickActionShowBubbleLauncherEnabled();
 ASH_PUBLIC_EXPORT bool IsDynamicSearchUpdateAnimationEnabled();
 ASH_PUBLIC_EXPORT base::TimeDelta DynamicSearchUpdateAnimationDuration();
-ASH_PUBLIC_EXPORT bool IsCompactBubbleLauncherEnabled();
 ASH_PUBLIC_EXPORT bool IsLauncherPlayStoreSearchEnabled();
-ASH_PUBLIC_EXPORT bool IsAnimateScaleOnTabletModeTransitionEnabled();
+ASH_PUBLIC_EXPORT bool IsDragAndDropRefactorEnabled();
 
 }  // namespace app_list_features
 
