@@ -115,6 +115,11 @@ bool HoldingSpaceItem::IsDownload(HoldingSpaceItem::Type type) {
     case Type::kDownload:
     case Type::kLacrosDownload:
       return true;
+    case Type::kCameraAppPhoto:
+    case Type::kCameraAppScanJpg:
+    case Type::kCameraAppScanPdf:
+    case Type::kCameraAppVideoGif:
+    case Type::kCameraAppVideoMp4:
     case Type::kDiagnosticsLog:
     case Type::kDriveSuggestion:
     case Type::kLocalSuggestion:
@@ -124,11 +129,39 @@ bool HoldingSpaceItem::IsDownload(HoldingSpaceItem::Type type) {
     case Type::kPrintedPdf:
     case Type::kScan:
     case Type::kScreenRecording:
+    case Type::kScreenRecordingGif:
     case Type::kScreenshot:
       return false;
   }
 }
 
+// static
+bool HoldingSpaceItem::IsScreenCapture(HoldingSpaceItem::Type type) {
+  switch (type) {
+    case Type::kScreenRecording:
+    case Type::kScreenRecordingGif:
+    case Type::kScreenshot:
+      return true;
+    case Type::kArcDownload:
+    case Type::kCameraAppPhoto:
+    case Type::kCameraAppScanJpg:
+    case Type::kCameraAppScanPdf:
+    case Type::kCameraAppVideoGif:
+    case Type::kCameraAppVideoMp4:
+    case Type::kDiagnosticsLog:
+    case Type::kDownload:
+    case Type::kDriveSuggestion:
+    case Type::kLacrosDownload:
+    case Type::kLocalSuggestion:
+    case Type::kNearbyShare:
+    case Type::kPhoneHubCameraRoll:
+    case Type::kPinnedFile:
+    case Type::kPrintedPdf:
+    case Type::kScan:
+      return false;
+  }
+}
+
 // static
 bool HoldingSpaceItem::IsSuggestion(HoldingSpaceItem::Type type) {
   switch (type) {
@@ -136,6 +169,11 @@ bool HoldingSpaceItem::IsSuggestion(HoldingSpaceItem::Type type) {
     case Type::kLocalSuggestion:
       return true;
     case Type::kArcDownload:
+    case Type::kCameraAppPhoto:
+    case Type::kCameraAppScanJpg:
+    case Type::kCameraAppScanPdf:
+    case Type::kCameraAppVideoGif:
+    case Type::kCameraAppVideoMp4:
     case Type::kDiagnosticsLog:
     case Type::kDownload:
     case Type::kLacrosDownload:
@@ -145,6 +183,7 @@ bool HoldingSpaceItem::IsSuggestion(HoldingSpaceItem::Type type) {
     case Type::kPrintedPdf:
     case Type::kScan:
     case Type::kScreenRecording:
+    case Type::kScreenRecordingGif:
     case Type::kScreenshot:
       return false;
   }
@@ -334,26 +373,6 @@ void HoldingSpaceItem::InvalidateImage() {
     image_->Invalidate();
 }
 
-bool HoldingSpaceItem::IsScreenCapture() const {
-  switch (type_) {
-    case Type::kScreenRecording:
-    case Type::kScreenshot:
-      return true;
-    case Type::kArcDownload:
-    case Type::kDiagnosticsLog:
-    case Type::kDownload:
-    case Type::kDriveSuggestion:
-    case Type::kLacrosDownload:
-    case Type::kLocalSuggestion:
-    case Type::kNearbyShare:
-    case Type::kPhoneHubCameraRoll:
-    case Type::kPinnedFile:
-    case Type::kPrintedPdf:
-    case Type::kScan:
-      return false;
-  }
-}
-
 HoldingSpaceItem::HoldingSpaceItem(Type type,
                                    const std::string& id,
                                    const base::FilePath& file_path,
