@@ -1,4 +1,4 @@
-// Copyright 2020 The Chromium Authors. All rights reserved.
+// Copyright 2020 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,13 +7,15 @@
 #include <map>
 #include <string>
 
+#include "ash/public/cpp/holding_space/holding_space_util.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/notreached.h"
+#include "base/ranges/algorithm.h"
+#include "base/strings/strcat.h"
 #include "base/strings/string_util.h"
 #include "base/time/time.h"
 
-namespace ash {
-namespace holding_space_metrics {
+namespace ash::holding_space_metrics {
 
 namespace {
 
@@ -43,7 +45,7 @@ constexpr size_t kExtensionsSize =
 
 // Returns the string representation of the specified `action`. Note that these
 // values are persisted to histograms so should remain unchanged.
-std::string ItemActionToString(ItemAction action) {
+std::string ToString(ItemAction action) {
   switch (action) {
     case ItemAction::kCancel:
       return "Cancel";
@@ -70,37 +72,6 @@ std::string ItemActionToString(ItemAction action) {
   return std::string();
 }
 
-// Returns the string representation of the specified `type`. Note that these
-// values are persisted to histograms so should remain unchanged.
-std::string ItemTypeToString(HoldingSpaceItem::Type type) {
-  switch (type) {
-    case HoldingSpaceItem::Type::kArcDownload:
-      return "ArcDownload";
-    case HoldingSpaceItem::Type::kDiagnosticsLog:
-      return "DiagnosticsLog";
-    case HoldingSpaceItem::Type::kDownload:
-      return "Download";
-    case HoldingSpaceItem::Type::kLacrosDownload:
-      return "LacrosDownload";
-    case HoldingSpaceItem::Type::kNearbyShare:
-      return "NearbyShare";
-    case HoldingSpaceItem::Type::kPinnedFile:
-      return "PinnedFile";
-    case HoldingSpaceItem::Type::kPrintedPdf:
-      return "PrintedPdf";
-    case HoldingSpaceItem::Type::kScan:
-      return "Scan";
-    case HoldingSpaceItem::Type::kScreenRecording:
-      return "ScreenRecording";
-    case HoldingSpaceItem::Type::kScreenshot:
-      return "Screenshot";
-    case HoldingSpaceItem::Type::kPhoneHubCameraRoll:
-      return "PhoneHubCameraRoll";
-  }
-  NOTREACHED();
-  return std::string();
-}
-
 }  // namespace
 
 // Utilities -------------------------------------------------------------------
@@ -114,14 +85,35 @@ size_t FilePathToExtension(const base::FilePath& file_path) {
   if (extension.empty())
     return kEmptyExtension;
 
-  auto* const* it =
-      std::find(kKnownExtensions.begin(), kKnownExtensions.end(), extension);
+  auto* const* it = base::ranges::find(kKnownExtensions, extension);
   if (it == kKnownExtensions.end())
     return kOtherExtension;
 
   return kFirstKnownExtension + std::distance(kKnownExtensions.begin(), it);
 }
 
+// Records either the total or visible counts of `items` as appropriate..
+void RecordItemCounts(const std::vector<const HoldingSpaceItem*>& items,
+                      bool visible) {
+  constexpr char kTotalCount[] = "HoldingSpace.Item.TotalCount";
+  constexpr char kVisibleCount[] = "HoldingSpace.Item.Count";
+  const char* prefix = visible ? kVisibleCount : kTotalCount;
+
+  base::UmaHistogramCounts1000(base::StrCat({prefix, ".All"}), items.size());
+
+  std::map<HoldingSpaceItem::Type, int> counts_by_type;
+  for (const HoldingSpaceItem* item : items)
+    ++counts_by_type[item->type()];
+
+  for (int i = 0; i <= static_cast<int>(HoldingSpaceItem::Type::kMaxValue);
+       ++i) {
+    const auto type = static_cast<HoldingSpaceItem::Type>(i);
+    base::UmaHistogramCounts1000(
+        base::StrCat({prefix, ".", holding_space_util::ToString(type)}),
+        counts_by_type[type]);
+  }
+}
+
 // Metrics ---------------------------------------------------------------------
 
 void RecordPodAction(PodAction action) {
@@ -138,7 +130,7 @@ void RecordFilesAppChipAction(FilesAppChipAction action) {
 
 void RecordItemAction(const std::vector<const HoldingSpaceItem*>& items,
                       ItemAction action) {
-  const std::string action_string = ItemActionToString(action);
+  const std::string action_string = ToString(action);
 
   for (const HoldingSpaceItem* item : items) {
     base::UmaHistogramEnumeration("HoldingSpace.Item.Action.All", action);
@@ -151,19 +143,7 @@ void RecordItemAction(const std::vector<const HoldingSpaceItem*>& items,
 }
 
 void RecordItemCounts(const std::vector<const HoldingSpaceItem*>& items) {
-  base::UmaHistogramCounts1000("HoldingSpace.Item.Count.All", items.size());
-
-  std::map<HoldingSpaceItem::Type, int> counts_by_type;
-  for (const HoldingSpaceItem* item : items)
-    ++counts_by_type[item->type()];
-
-  for (int i = 0; i <= static_cast<int>(HoldingSpaceItem::Type::kMaxValue);
-       ++i) {
-    const auto type = static_cast<HoldingSpaceItem::Type>(i);
-    base::UmaHistogramCounts1000(
-        "HoldingSpace.Item.Count." + ItemTypeToString(type),
-        counts_by_type[type]);
-  }
+  RecordItemCounts(items, /*visible=*/false);
 }
 
 void RecordItemFailureToLaunch(HoldingSpaceItem::Type type,
@@ -177,6 +157,10 @@ void RecordItemFailureToLaunch(HoldingSpaceItem::Type type,
                                 reason);
 }
 
+void RecordSuggestionsAction(SuggestionsAction action) {
+  base::UmaHistogramEnumeration("HoldingSpace.Suggestions.Action.All", action);
+}
+
 void RecordTimeFromFirstAvailabilityToFirstAdd(base::TimeDelta time_delta) {
   // NOTE: 24 days appears to be the max supported number of days.
   base::UmaHistogramCustomTimes(
@@ -217,5 +201,16 @@ void RecordPodResizeAnimationSmoothness(int smoothness) {
                                smoothness);
 }
 
-}  // namespace holding_space_metrics
-}  // namespace ash
+void RecordUserPreferences(UserPreferences preferences) {
+  base::UmaHistogramBoolean("HoldingSpace.UserPreferences.PreviewsEnabled",
+                            preferences.previews_enabled);
+  base::UmaHistogramBoolean("HoldingSpace.UserPreferences.SuggestionsExpanded",
+                            preferences.suggestions_expanded);
+}
+
+void RecordVisibleItemCounts(
+    const std::vector<const HoldingSpaceItem*>& items) {
+  RecordItemCounts(items, /*visible=*/true);
+}
+
+}  // namespace ash::holding_space_metrics
