@@ -10,6 +10,7 @@
 #include "base/compiler_specific.h"
 #include "base/run_loop.h"
 #include "base/strings/string_number_conversions.h"
+#include "base/task/single_thread_task_runner.h"
 #include "base/time/time.h"
 #include "ui/views/test/widget_test.h"
 
@@ -175,7 +176,7 @@ class PaginationModelTest : public views::test::WidgetTest {
   void WaitForRevertAnimation() {
     while (pagination()->IsRevertingCurrentTransition()) {
       base::RunLoop run_loop;
-      base::ThreadTaskRunnerHandle::Get()->PostDelayedTask(
+      base::SingleThreadTaskRunner::GetCurrentDefault()->PostDelayedTask(
           FROM_HERE, run_loop.QuitClosure(), base::Milliseconds(100));
       run_loop.Run();
     }
