@@ -162,6 +162,11 @@ class ASH_PUBLIC_EXPORT SystemTrayClient {
                                  bool& opened_pwa,
                                  GURL& finalized_event_url) = 0;
 
+  // Launches video conference url's.
+  // Opens in the Google Meet PWA if installed and `video_conference_url` is a
+  // Google Meet url, otherwise opens in the browser.
+  virtual void ShowVideoConference(const GURL& video_conference_url) = 0;
+
   // Shown when the device is on a non-stable release track and the user clicks
   // the channel/version button from quick settings.
   virtual void ShowChannelInfoAdditionalDetails() = 0;
@@ -170,6 +175,16 @@ class ASH_PUBLIC_EXPORT SystemTrayClient {
   // the "send feedback" button.
   virtual void ShowChannelInfoGiveFeedback() = 0;
 
+  // Shows settings related to audio devices (input/output).
+  virtual void ShowAudioSettings() = 0;
+
+  // Shows a page with more info about auto update expiration for devices that
+  // reached end of life.
+  virtual void ShowEolInfoPage() = 0;
+
+  // Records a UMA metric that the end of life notice was shown.
+  virtual void RecordEolNoticeShown() = 0;
+
   // Returns 'true' if the user preference is set to allow users to submit
   // feedback, 'false' otherwise.
   virtual bool IsUserFeedbackEnabled() = 0;
