@@ -134,6 +134,11 @@ void TestSystemTrayClient::ShowCalendarEvent(
   show_calendar_event_count_++;
 }
 
+void TestSystemTrayClient::ShowVideoConference(
+    const GURL& video_conference_url) {
+  show_video_conference_count_++;
+}
+
 void TestSystemTrayClient::ShowChannelInfoAdditionalDetails() {
   ++show_channel_info_additional_details_count_;
 }
@@ -142,8 +147,18 @@ void TestSystemTrayClient::ShowChannelInfoGiveFeedback() {
   ++show_channel_info_give_feedback_count_;
 }
 
+void TestSystemTrayClient::ShowAudioSettings() {
+  ++show_audio_settings_count_;
+}
+
 bool TestSystemTrayClient::IsUserFeedbackEnabled() {
   return user_feedback_enabled_;
 }
 
+void TestSystemTrayClient::ShowEolInfoPage() {
+  ++show_eol_info_count_;
+}
+
+void TestSystemTrayClient::RecordEolNoticeShown() {}
+
 }  // namespace ash
