@@ -8,14 +8,16 @@
 #include "ash/public/cpp/notification_utils.h"
 #include "ash/resources/vector_icons/vector_icons.h"
 #include "ash/strings/grit/ash_strings.h"
-#include "base/bind.h"
-#include "base/callback_helpers.h"
+#include "base/functional/bind.h"
+#include "base/functional/callback_helpers.h"
 #include "base/time/time.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/message_center/message_center.h"
 #include "ui/message_center/public/cpp/notification.h"
 #include "ui/message_center/public/cpp/notification_delegate.h"
 
+#include "ash/quick_pair/common/logging.h"
+
 using message_center::MessageCenter;
 using message_center::Notification;
 
@@ -46,7 +48,10 @@ const char kFastPairDiscoverySubsequentNotificationId[] =
 // progress bar.
 const int kInfiniteLoadingProgressValue = -1;
 
-constexpr base::TimeDelta kNotificationTimeout = base::Seconds(30);
+// 12 seconds comes from aligning CrOS notification with Android. Android
+// determined it takes 12 seconds for a device to be truly lost to the adapter.
+// Within 12 seconds, a device can be perceived as lost, yet be found again.
+constexpr base::TimeDelta kNotificationTimeout = base::Seconds(12);
 
 // Creates an empty Fast Pair notification with the given id and uses the
 // Bluetooth icon and FastPair notifierID.
@@ -59,7 +64,7 @@ std::unique_ptr<message_center::Notification> CreateNotification(
   message_center->RemoveNotificationsForNotifierId(kNotifierFastPair);
 
   std::unique_ptr<message_center::Notification> notification =
-      ash::CreateSystemNotification(
+      ash::CreateSystemNotificationPtr(
           /*type=*/message_center::NOTIFICATION_TYPE_SIMPLE,
           /*id=*/id,
           /*title=*/std::u16string(),
@@ -88,7 +93,7 @@ class NotificationDelegate : public message_center::NotificationDelegate {
  public:
   explicit NotificationDelegate(
       base::RepeatingClosure on_primary_click,
-      base::OnceCallback<void(bool)> on_close,
+      base::OnceCallback<void(FastPairNotificationDismissReason)> on_close,
       base::RepeatingClosure on_secondary_click = base::DoNothing(),
       base::OneShotTimer* expire_notification_timer = nullptr) {
     on_primary_click_ = on_primary_click;
@@ -97,6 +102,8 @@ class NotificationDelegate : public message_center::NotificationDelegate {
     expire_notification_timer_ = expire_notification_timer;
   }
 
+  void DismissedByTimeout() { dismissed_by_timeout_ = true; }
+
  protected:
   ~NotificationDelegate() override = default;
 
@@ -122,17 +129,31 @@ class NotificationDelegate : public message_center::NotificationDelegate {
     // If there is an expire notification timer, stop the timer if the user
     // dismisses the notification to prevent the timer firing and removing
     // notifications that might come up later.
-    if (expire_notification_timer_)
+    if (expire_notification_timer_) {
+      QP_LOG(VERBOSE) << __func__
+                      << ": stopping expiration timer on notification close";
       expire_notification_timer_->Stop();
+    }
 
-    std::move(on_close_).Run(by_user);
+    if (dismissed_by_timeout_) {
+      std::move(on_close_).Run(
+          FastPairNotificationDismissReason::kDismissedByTimeout);
+      return;
+    } else if (by_user) {
+      std::move(on_close_).Run(
+          FastPairNotificationDismissReason::kDismissedByUser);
+      return;
+    }
+
+    std::move(on_close_).Run(FastPairNotificationDismissReason::kDismissedByOs);
   }
 
  private:
   enum class Button { kPrimaryButton, kSecondaryButton };
+  bool dismissed_by_timeout_ = false;
   base::RepeatingClosure on_primary_click_;
   base::RepeatingClosure on_secondary_click_;
-  base::OnceCallback<void(bool)> on_close_;
+  base::OnceCallback<void(FastPairNotificationDismissReason)> on_close_;
   base::OneShotTimer* expire_notification_timer_;
 };
 
@@ -148,7 +169,7 @@ void FastPairNotificationController::ShowErrorNotification(
     const std::u16string& device_name,
     gfx::Image device_image,
     base::RepeatingClosure launch_bluetooth_pairing,
-    base::OnceCallback<void(bool)> on_close) {
+    base::OnceCallback<void(FastPairNotificationDismissReason)> on_close) {
   // Because the pairing notification is pinned, we need to manually remove it
   // to explicitly say it is done not by the user. This only need to be done
   // for pinned notifications.
@@ -177,13 +198,26 @@ void FastPairNotificationController::ShowErrorNotification(
   message_center_->AddNotification(std::move(error_notification));
 }
 
+void FastPairNotificationController::ExtendNotification() {
+  // If the timer is already running, it implies that there is already a
+  // notification being shown for this device. Since the Mediator keeps track
+  // of the device for the currently shown notification, we can only get to this
+  // point if the notification is for the same device, which means we reset the
+  // timeout.
+  if (expire_notification_timer_.IsRunning()) {
+    QP_LOG(INFO) << __func__
+                 << " extending notification for re-discovered device";
+    expire_notification_timer_.Reset();
+  }
+}
+
 void FastPairNotificationController::ShowUserDiscoveryNotification(
     const std::u16string& device_name,
     const std::u16string& email_address,
     gfx::Image device_image,
     base::RepeatingClosure on_connect_clicked,
     base::RepeatingClosure on_learn_more_clicked,
-    base::OnceCallback<void(bool)> on_close) {
+    base::OnceCallback<void(FastPairNotificationDismissReason)> on_close) {
   std::unique_ptr<message_center::Notification> discovery_notification =
       CreateNotification(kFastPairDiscoveryUserNotificationId,
                          message_center::SystemNotificationWarningLevel::NORMAL,
@@ -200,12 +234,14 @@ void FastPairNotificationController::ShowUserDiscoveryNotification(
       l10n_util::GetStringUTF16(IDS_FAST_PAIR_LEARN_MORE_BUTTON));
   discovery_notification->set_buttons({connect_button, learn_more_button});
 
-  discovery_notification->set_delegate(
+  scoped_refptr<NotificationDelegate> notification_delegate =
       base::MakeRefCounted<NotificationDelegate>(
           /*on_primary_click=*/on_connect_clicked,
           /*on_close=*/std::move(on_close),
           /*on_secondary_click=*/on_learn_more_clicked,
-          /*expire_notification_timer=*/&expire_notification_timer_));
+          /*expire_notification_timer=*/&expire_notification_timer_);
+
+  discovery_notification->set_delegate(notification_delegate);
   discovery_notification->set_image(device_image);
 
   // Start timer for how long to show the notification before removing the
@@ -213,8 +249,9 @@ void FastPairNotificationController::ShowUserDiscoveryNotification(
   // from the Message Center.
   expire_notification_timer_.Start(
       FROM_HERE, kNotificationTimeout,
-      base::BindOnce(&FastPairNotificationController::RemoveNotifications,
-                     weak_ptr_factory_.GetWeakPtr()));
+      base::BindOnce(
+          &FastPairNotificationController::RemoveNotificationsByTimeout,
+          weak_ptr_factory_.GetWeakPtr(), notification_delegate));
 
   message_center_->AddNotification(std::move(discovery_notification));
 }
@@ -224,7 +261,7 @@ void FastPairNotificationController::ShowGuestDiscoveryNotification(
     const gfx::Image device_image,
     base::RepeatingClosure on_connect_clicked,
     base::RepeatingClosure on_learn_more_clicked,
-    base::OnceCallback<void(bool)> on_close) {
+    base::OnceCallback<void(FastPairNotificationDismissReason)> on_close) {
   std::unique_ptr<message_center::Notification> discovery_notification =
       CreateNotification(kFastPairDiscoveryGuestNotificationId,
                          message_center::SystemNotificationWarningLevel::NORMAL,
@@ -240,12 +277,14 @@ void FastPairNotificationController::ShowGuestDiscoveryNotification(
       l10n_util::GetStringUTF16(IDS_FAST_PAIR_LEARN_MORE_BUTTON));
   discovery_notification->set_buttons({connect_button, learn_more_button});
 
-  discovery_notification->set_delegate(
+  scoped_refptr<NotificationDelegate> notification_delegate =
       base::MakeRefCounted<NotificationDelegate>(
           /*on_primary_click=*/on_connect_clicked,
           /*on_close=*/std::move(on_close),
           /*on_secondary_click=*/on_learn_more_clicked,
-          /*expire_notification_timer=*/&expire_notification_timer_));
+          /*expire_notification_timer=*/&expire_notification_timer_);
+
+  discovery_notification->set_delegate(notification_delegate);
   discovery_notification->set_image(device_image);
 
   // Start timer for how long to show the notification before removing the
@@ -253,8 +292,9 @@ void FastPairNotificationController::ShowGuestDiscoveryNotification(
   // from the Message Center.
   expire_notification_timer_.Start(
       FROM_HERE, kNotificationTimeout,
-      base::BindOnce(&FastPairNotificationController::RemoveNotifications,
-                     weak_ptr_factory_.GetWeakPtr()));
+      base::BindOnce(
+          &FastPairNotificationController::RemoveNotificationsByTimeout,
+          weak_ptr_factory_.GetWeakPtr(), notification_delegate));
 
   message_center_->AddNotification(std::move(discovery_notification));
 }
@@ -265,7 +305,7 @@ void FastPairNotificationController::ShowSubsequentDiscoveryNotification(
     gfx::Image device_image,
     base::RepeatingClosure on_connect_clicked,
     base::RepeatingClosure on_learn_more_clicked,
-    base::OnceCallback<void(bool)> on_close) {
+    base::OnceCallback<void(FastPairNotificationDismissReason)> on_close) {
   std::unique_ptr<message_center::Notification> discovery_notification =
       CreateNotification(kFastPairDiscoverySubsequentNotificationId,
                          message_center::SystemNotificationWarningLevel::NORMAL,
@@ -282,12 +322,14 @@ void FastPairNotificationController::ShowSubsequentDiscoveryNotification(
       l10n_util::GetStringUTF16(IDS_FAST_PAIR_LEARN_MORE_BUTTON));
   discovery_notification->set_buttons({connect_button, learn_more_button});
 
-  discovery_notification->set_delegate(
+  scoped_refptr<NotificationDelegate> notification_delegate =
       base::MakeRefCounted<NotificationDelegate>(
           /*on_primary_click=*/on_connect_clicked,
           /*on_close=*/std::move(on_close),
           /*on_secondary_click=*/on_learn_more_clicked,
-          /*expire_notification_timer=*/&expire_notification_timer_));
+          /*expire_notification_timer=*/&expire_notification_timer_);
+
+  discovery_notification->set_delegate(notification_delegate);
   discovery_notification->set_image(device_image);
 
   // Start timer for how long to show the notification before removing the
@@ -295,8 +337,9 @@ void FastPairNotificationController::ShowSubsequentDiscoveryNotification(
   // from the Message Center.
   expire_notification_timer_.Start(
       FROM_HERE, kNotificationTimeout,
-      base::BindOnce(&FastPairNotificationController::RemoveNotifications,
-                     weak_ptr_factory_.GetWeakPtr()));
+      base::BindOnce(
+          &FastPairNotificationController::RemoveNotificationsByTimeout,
+          weak_ptr_factory_.GetWeakPtr(), notification_delegate));
 
   message_center_->AddNotification(std::move(discovery_notification));
 }
@@ -305,7 +348,7 @@ void FastPairNotificationController::ShowApplicationAvailableNotification(
     const std::u16string& device_name,
     gfx::Image device_image,
     base::RepeatingClosure download_app_callback,
-    base::OnceCallback<void(bool)> on_close) {
+    base::OnceCallback<void(FastPairNotificationDismissReason)> on_close) {
   std::unique_ptr<message_center::Notification>
       application_available_notification = CreateNotification(
           kFastPairApplicationAvailableNotificationId,
@@ -337,7 +380,7 @@ void FastPairNotificationController::ShowApplicationInstalledNotification(
     gfx::Image device_image,
     const std::u16string& app_name,
     base::RepeatingClosure launch_app_callback,
-    base::OnceCallback<void(bool)> on_close) {
+    base::OnceCallback<void(FastPairNotificationDismissReason)> on_close) {
   std::unique_ptr<message_center::Notification>
       application_installed_notification = CreateNotification(
           kFastPairApplicationInstalledNotificationId,
@@ -367,7 +410,7 @@ void FastPairNotificationController::ShowApplicationInstalledNotification(
 void FastPairNotificationController::ShowPairingNotification(
     const std::u16string& device_name,
     gfx::Image device_image,
-    base::OnceCallback<void(bool)> on_close) {
+    base::OnceCallback<void(FastPairNotificationDismissReason)> on_close) {
   // If we get to this point in the pairing flow where we are showing the
   // Pairing notification, then the user has elected to begin pairing and we
   // can stop the timer that was waiting for user interaction on the
@@ -400,7 +443,7 @@ void FastPairNotificationController::ShowAssociateAccount(
     gfx::Image device_image,
     base::RepeatingClosure on_save_clicked,
     base::RepeatingClosure on_learn_more_clicked,
-    base::OnceCallback<void(bool)> on_close) {
+    base::OnceCallback<void(FastPairNotificationDismissReason)> on_close) {
   std::unique_ptr<message_center::Notification> associate_account_notification =
       CreateNotification(kFastPairAssociateAccountNotificationId,
                          message_center::SystemNotificationWarningLevel::NORMAL,
@@ -417,12 +460,14 @@ void FastPairNotificationController::ShowAssociateAccount(
       l10n_util::GetStringUTF16(IDS_FAST_PAIR_LEARN_MORE_BUTTON));
   associate_account_notification->set_buttons({save_button, learn_more_button});
 
-  associate_account_notification->set_delegate(
+  scoped_refptr<NotificationDelegate> notification_delegate =
       base::MakeRefCounted<NotificationDelegate>(
           /*on_primary_click=*/on_save_clicked,
           /*on_close=*/std::move(on_close),
           /*on_secondary_click=*/on_learn_more_clicked,
-          /*expire_notification_timer=*/&expire_notification_timer_));
+          /*expire_notification_timer=*/&expire_notification_timer_);
+
+  associate_account_notification->set_delegate(notification_delegate);
   associate_account_notification->set_image(device_image);
 
   // Start timer for how long to show the notification before removing the
@@ -430,8 +475,9 @@ void FastPairNotificationController::ShowAssociateAccount(
   // from the Message Center.
   expire_notification_timer_.Start(
       FROM_HERE, kNotificationTimeout,
-      base::BindOnce(&FastPairNotificationController::RemoveNotifications,
-                     weak_ptr_factory_.GetWeakPtr()));
+      base::BindOnce(
+          &FastPairNotificationController::RemoveNotificationsByTimeout,
+          weak_ptr_factory_.GetWeakPtr(), notification_delegate));
 
   message_center_->AddNotification(std::move(associate_account_notification));
 }
@@ -440,5 +486,11 @@ void FastPairNotificationController::RemoveNotifications() {
   message_center_->RemoveNotificationsForNotifierId(kNotifierFastPair);
 }
 
+void FastPairNotificationController::RemoveNotificationsByTimeout(
+    scoped_refptr<NotificationDelegate> notification_delegate) {
+  notification_delegate->DismissedByTimeout();
+  RemoveNotifications();
+}
+
 }  // namespace quick_pair
 }  // namespace ash
