@@ -10,7 +10,7 @@
 
 #include "ash/ash_export.h"
 #include "ash/display/display_configuration_controller.h"
-#include "base/callback_forward.h"
+#include "base/functional/callback_forward.h"
 #include "base/memory/weak_ptr.h"
 #include "base/observer_list.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
