@@ -9,17 +9,18 @@
 #include <vector>
 
 #include "ash/constants/ash_features.h"
-#include "ash/public/cpp/app_list/app_list_color_provider.h"
 #include "ash/public/cpp/ash_typography.h"
+#include "ash/public/cpp/style/color_provider.h"
 #include "ash/strings/grit/ash_strings.h"
-#include "base/bind.h"
+#include "ash/style/ash_color_id.h"
+#include "base/functional/bind.h"
+#include "base/strings/strcat.h"
 #include "third_party/skia/include/core/SkPath.h"
 #include "ui/base/ime/text_input_flags.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/events/event.h"
 #include "ui/gfx/canvas.h"
 #include "ui/gfx/color_palette.h"
-#include "ui/gfx/color_utils.h"
 #include "ui/gfx/geometry/insets.h"
 #include "ui/gfx/image/image_skia.h"
 #include "ui/views/accessibility/view_accessibility.h"
@@ -51,8 +52,6 @@ constexpr base::TimeDelta kSearchIconAnimationDuration =
 
 constexpr int kInnerPadding = 16;
 
-constexpr int kFocusBorderThickness = 2;
-
 // Padding to make autocomplete ghost text line up with search box text.
 constexpr gfx::Insets kGhostTextLabelPadding = gfx::Insets::TLBR(0, 0, 1, 0);
 
@@ -83,6 +82,8 @@ void SetupLabelView(views::Label* label,
   label->SetHorizontalAlignment(gfx::ALIGN_LEFT);
   label->GetViewAccessibility().OverrideIsIgnored(true);
   label->SetBackgroundColor(SK_ColorTRANSPARENT);
+  label->SetAutoColorReadabilityEnabled(false);
+  label->SetEnabledColorId(kColorAshTextColorSuggestion);
   label->SetVisible(true);
   label->SetElideBehavior(gfx::ELIDE_TAIL);
   label->SetMultiLine(false);
@@ -128,21 +129,15 @@ class SearchBoxImageButton : public views::ImageButton {
       : ImageButton(std::move(callback)) {
     SetFocusBehavior(FocusBehavior::ALWAYS);
 
-    // Avoid drawing default dashed focus and draw customized focus in
-    // OnPaintBackground();
-    SetInstallFocusRingOnFocus(false);
-
-    // Inkdrop only on click.
     views::InkDrop::Get(this)->SetMode(views::InkDropHost::InkDropMode::ON);
     SetHasInkDropActionOnClick(true);
     views::InkDrop::UseInkDropForFloodFillRipple(views::InkDrop::Get(this),
-                                                 /*highlight_on_hover=*/false);
-
+                                                 /*highlight_on_hover=*/true);
     SetPaintToLayer();
     layer()->SetFillsBoundsOpaquely(false);
 
-    SetPreferredSize(gfx::Size(kClassicSearchBoxButtonSizeDip,
-                               kClassicSearchBoxButtonSizeDip));
+    SetPreferredSize(gfx::Size(kBubbleLauncherSearchBoxButtonSizeDip,
+                               kBubbleLauncherSearchBoxButtonSizeDip));
     SetImageHorizontalAlignment(ALIGN_CENTER);
     SetImageVerticalAlignment(ALIGN_MIDDLE);
 
@@ -176,49 +171,24 @@ class SearchBoxImageButton : public views::ImageButton {
     SchedulePaint();
   }
 
-  void OnThemeChanged() override {
-    views::View::OnThemeChanged();
-    UpdateInkDropColors();
-  }
-
   void set_is_showing(bool is_showing) { is_showing_ = is_showing; }
   bool is_showing() { return is_showing_; }
 
+  void UpdateInkDropColorAndOpacity(SkColor background_color) {
+    const std::pair<SkColor, float> base_color_and_opacity =
+        ash::ColorProvider::Get()->GetInkDropBaseColorAndOpacity(
+            background_color);
+    auto* ink_drop = views::InkDrop::Get(this);
+    ink_drop->SetBaseColor(base_color_and_opacity.first);
+    ink_drop->SetVisibleOpacity(base_color_and_opacity.second);
+  }
+
  private:
   int GetButtonRadius() const { return width() / 2; }
 
   // Whether the button is showing/shown or hiding/hidden.
   bool is_showing_ = false;
 
-  void UpdateInkDropColors() {
-    const views::Widget* app_list_widget = GetWidget();
-    SkColor search_box_card_background_color =
-        AppListColorProvider::Get()->GetSearchBoxCardBackgroundColor(
-            app_list_widget);
-
-    views::InkDrop::Get(this)->SetBaseColor(
-        AppListColorProvider::Get()->GetInkDropBaseColor(
-            app_list_widget, search_box_card_background_color));
-    views::InkDrop::Get(this)->SetVisibleOpacity(
-        AppListColorProvider::Get()->GetInkDropOpacity(
-            app_list_widget, search_box_card_background_color));
-  }
-
-  // views::View:
-  void OnPaintBackground(gfx::Canvas* canvas) override {
-    if (HasFocus()) {
-      cc::PaintFlags circle_flags;
-      circle_flags.setAntiAlias(true);
-      circle_flags.setColor(
-          AppListColorProvider::Get()->GetFocusRingColor(GetWidget()));
-      circle_flags.setStyle(cc::PaintFlags::kStroke_Style);
-      circle_flags.setStrokeWidth(kFocusBorderThickness);
-      canvas->DrawCircle(GetLocalBounds().CenterPoint(),
-                         GetButtonRadius() - kFocusBorderThickness,
-                         circle_flags);
-    }
-  }
-
   const char* GetClassName() const override { return "SearchBoxImageButton"; }
 };
 
@@ -407,7 +377,8 @@ SearchBoxViewBase::SearchBoxViewBase()
       views::BoxLayout::CrossAxisAlignment::kCenter);
   text_container_->SetMinimumCrossAxisSize(kSearchBoxPreferredHeight);
   text_container_->SetOrientation(views::BoxLayout::Orientation::kHorizontal);
-  content_container_->SetFlexForView(text_container_, 1, true);
+  content_container_->SetFlexForView(text_container_, 1,
+                                     /*use_min_size=*/false);
 
   text_container_->AddChildView(search_box_);
   ghost_text_container_ =
@@ -457,6 +428,8 @@ SearchBoxViewBase::SearchBoxViewBase()
       content_container_->AddChildView(std::make_unique<views::View>());
   search_box_button_container_->SetLayoutManager(
       std::make_unique<views::FillLayout>());
+  content_container_->SetFlexForView(search_box_button_container_, 0,
+                                     /*use_min_size=*/true);
 }
 
 SearchBoxViewBase::~SearchBoxViewBase() = default;
@@ -543,6 +516,16 @@ void SearchBoxViewBase::MaybeSetAutocompleteGhostText(
   }
 }
 
+std::string SearchBoxViewBase::GetSearchBoxGhostTextForTest() {
+  if (!autocomplete_ghost_text_->GetText().empty()) {
+    return base::UTF16ToUTF8(base::StrCat(
+        {autocomplete_ghost_text_->GetText(),
+         l10n_util::GetStringUTF16(IDS_ASH_SEARCH_RESULT_SEPARATOR),
+         category_ghost_text_->GetText()}));
+  }
+  return base::UTF16ToUTF8(category_ghost_text_->GetText());
+}
+
 void SearchBoxViewBase::SetSearchBoxActive(bool active,
                                            ui::EventType event_type) {
   if (active == is_search_box_active_)
@@ -606,25 +589,9 @@ void SearchBoxViewBase::OnMouseEvent(ui::MouseEvent* event) {
 
 void SearchBoxViewBase::OnThemeChanged() {
   views::View::OnThemeChanged();
-  const views::Widget* app_list_widget = GetWidget();
-
   if (features::IsAutocompleteExtendedSuggestionsEnabled()) {
-    auto ghost_text_color =
-        AppListColorProvider::Get()->GetSearchBoxSuggestionTextColor(
-            app_list_widget);
-    autocomplete_ghost_text_->SetEnabledColor(ghost_text_color);
-    separator_label_->SetEnabledColor(ghost_text_color);
-    category_ghost_text_->SetEnabledColor(ghost_text_color);
-    category_separator_label_->SetEnabledColor(ghost_text_color);
     search_box_->SetSelectionBackgroundColor(
-        AppListColorProvider::Get()->GetFolderNameSelectionColor(GetWidget()));
-  }
-
-  auto* background = GetBackground();
-  if (background) {
-    background->SetNativeControlColor(
-        AppListColorProvider::Get()->GetSearchBoxBackgroundColor(
-            app_list_widget));
+        GetWidget()->GetColorProvider()->GetColor(kColorAshFocusAuraColor));
   }
   UpdatePlaceholderTextStyle();
 }
@@ -768,12 +735,12 @@ void SearchBoxViewBase::HandleSearchBoxEvent(ui::LocatedEvent* located_event) {
   if (located_event->type() == ui::ET_MOUSE_PRESSED ||
       located_event->type() == ui::ET_GESTURE_TAP) {
     const bool event_is_in_searchbox_bounds =
-        GetWidget()->GetWindowBoundsInScreen().Contains(
-            located_event->root_location());
-    // Don't handle an event out of the searchbox bounds.
+        GetBoundsInScreen().Contains(located_event->root_location());
     if (!event_is_in_searchbox_bounds)
       return;
 
+    located_event->SetHandled();
+
     // If the event is in an inactive empty search box, enable the search box.
     if (!is_search_box_active_ && search_box_->GetText().empty()) {
       SetSearchBoxActive(true, located_event->type());
@@ -786,11 +753,14 @@ void SearchBoxViewBase::HandleSearchBoxEvent(ui::LocatedEvent* located_event) {
   }
 }
 
-// TODO(crbug.com/755219): Unify this with SetBackgroundColor.
 void SearchBoxViewBase::UpdateBackgroundColor(SkColor color) {
   auto* search_box_background = background();
   if (search_box_background)
     search_box_background->SetNativeControlColor(color);
+  if (close_button_)
+    close_button_->UpdateInkDropColorAndOpacity(color);
+  if (assistant_button_)
+    assistant_button_->UpdateInkDropColorAndOpacity(color);
 }
 
 }  // namespace ash
