@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -10,22 +10,17 @@
 #include "ash/animation/animation_change_type.h"
 #include "ash/public/cpp/shelf_config.h"
 #include "ash/public/cpp/shelf_types.h"
-#include "ash/public/cpp/wallpaper/wallpaper_types.h"
 #include "ash/shelf/shelf.h"
 #include "ash/shelf/shelf_background_animator_observer.h"
 #include "ash/shell.h"
-#include "ash/style/default_color_constants.h"
+#include "ash/style/ash_color_id.h"
 #include "ash/wallpaper/wallpaper_controller_impl.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
 #include "base/time/time.h"
+#include "shelf_widget.h"
+#include "ui/compositor/scoped_animation_duration_scale_mode.h"
 #include "ui/gfx/animation/slide_animation.h"
-#include "ui/gfx/color_analysis.h"
-#include "ui/gfx/color_palette.h"
-#include "ui/gfx/color_utils.h"
-
-using ColorProfile = color_utils::ColorProfile;
-using LumaRange = color_utils::LumaRange;
-using SaturationRange = color_utils::SaturationRange;
+#include "ui/gfx/animation/tween.h"
 
 namespace ash {
 
@@ -176,9 +171,7 @@ void ShelfBackgroundAnimator::CreateAnimator(
 
   switch (background_type) {
     case ShelfBackgroundType::kDefaultBg:
-    case ShelfBackgroundType::kAppList:
     case ShelfBackgroundType::kHomeLauncher:
-    case ShelfBackgroundType::kMaximizedWithAppList:
       duration = base::Milliseconds(500);
       break;
     case ShelfBackgroundType::kMaximized:
@@ -192,7 +185,8 @@ void ShelfBackgroundAnimator::CreateAnimator(
   }
 
   animator_ = std::make_unique<gfx::SlideAnimation>(this);
-  animator_->SetSlideDuration(duration);
+  animator_->SetSlideDuration(
+      ui::ScopedAnimationDurationScaleMode::duration_multiplier() * duration);
 }
 
 void ShelfBackgroundAnimator::StopAnimator() {
@@ -213,25 +207,30 @@ void ShelfBackgroundAnimator::GetTargetValues(
 
 SkColor ShelfBackgroundAnimator::GetBackgroundColor(
     ShelfBackgroundType background_type) const {
-  SkColor shelf_target_color = ShelfConfig::Get()->GetDefaultShelfColor();
+  if (!shelf_)
+    return shelf_background_values_.current_color();
+
+  const auto* shelf_widget = shelf_->shelf_widget();
+  DCHECK(shelf_widget);
+
+  SkColor shelf_target_color =
+      ShelfConfig::Get()->GetDefaultShelfColor(shelf_widget);
   switch (background_type) {
-    case ShelfBackgroundType::kAppList:
-    case ShelfBackgroundType::kMaximizedWithAppList:
-      shelf_target_color = ShelfConfig::Get()->GetShelfWithAppListColor();
-      break;
     case ShelfBackgroundType::kDefaultBg:
     case ShelfBackgroundType::kHomeLauncher:
-      shelf_target_color = ShelfConfig::Get()->GetDefaultShelfColor();
+      shelf_target_color =
+          ShelfConfig::Get()->GetDefaultShelfColor(shelf_widget);
       break;
     case ShelfBackgroundType::kMaximized:
     case ShelfBackgroundType::kInApp:
-      shelf_target_color = ShelfConfig::Get()->GetMaximizedShelfColor();
+      shelf_target_color =
+          ShelfConfig::Get()->GetMaximizedShelfColor(shelf_widget);
       break;
     case ShelfBackgroundType::kOverview:
       shelf_target_color =
           Shell::Get()->tablet_mode_controller()->InTabletMode()
-              ? ShelfConfig::Get()->GetMaximizedShelfColor()
-              : ShelfConfig::Get()->GetDefaultShelfColor();
+              ? ShelfConfig::Get()->GetMaximizedShelfColor(shelf_widget)
+              : ShelfConfig::Get()->GetDefaultShelfColor(shelf_widget);
       break;
     case ShelfBackgroundType::kOobe:
       shelf_target_color = SK_ColorTRANSPARENT;
@@ -240,8 +239,8 @@ SkColor ShelfBackgroundAnimator::GetBackgroundColor(
       shelf_target_color = SK_ColorTRANSPARENT;
       break;
     case ShelfBackgroundType::kLoginNonBlurredWallpaper:
-      shelf_target_color = AshColorProvider::Get()->GetShieldLayerColor(
-          AshColorProvider::ShieldLayerType::kShield80);
+      shelf_target_color = shelf_->shelf_widget()->GetColorProvider()->GetColor(
+          kColorAshShieldAndBase80);
       break;
   }
   return shelf_target_color;
