@@ -18,6 +18,8 @@
 #include "base/functional/bind.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/scoped_observation.h"
+#include "chromeos/constants/chromeos_features.h"
+#include "ui/chromeos/styles/cros_tokens_color_mappings.h"
 
 namespace ash {
 
@@ -42,6 +44,7 @@ constexpr float kDragHideRatioThreshold = 0.4f;
 
 constexpr int kSystemShelfSizeTabletModeDense = 48;
 constexpr int kSystemShelfSizeTabletModeNormal = 56;
+constexpr int kElevatedSystemShelfSizeTabletMode = 136;
 
 // Records the histogram value tracking the reason shelf control buttons are
 // shown in tablet mode.
@@ -140,16 +143,7 @@ class ShelfConfig::ShelfSplitViewObserver : public SplitViewObserver {
 };
 
 ShelfConfig::ShelfConfig()
-    : use_in_app_shelf_in_overview_(false),
-      overview_mode_(false),
-      in_tablet_mode_(false),
-      is_dense_(false),
-      is_in_app_(true),
-      in_split_view_with_overview_(false),
-      shelf_controls_shown_(true),
-      is_virtual_keyboard_shown_(false),
-      is_app_list_visible_(false),
-      shelf_button_icon_size_(44),
+    : shelf_button_icon_size_(44),
       shelf_button_icon_size_median_(40),
       shelf_button_icon_size_dense_(36),
       shelf_button_size_(56),
@@ -337,6 +331,10 @@ int ShelfConfig::GetHotseatSize(HotseatDensity density) const {
   return GetShelfButtonSize(density);
 }
 
+int ShelfConfig::GetHomecherElevatedAppBarOffset() const {
+  return 8;
+}
+
 int ShelfConfig::shelf_size() const {
   return GetShelfSize(false /*ignore_in_app_state*/);
 }
@@ -484,19 +482,33 @@ SkColor ShelfConfig::GetShelfControlButtonColor(
 }
 
 SkColor ShelfConfig::GetMaximizedShelfColor(const views::Widget* widget) const {
-  return SkColorSetA(GetDefaultShelfColor(widget), 0xFF);  // 100% opacity
+  if (!chromeos::features::IsJellyEnabled()) {
+    return SkColorSetA(GetDefaultShelfColor(widget), 0xFF);  // 100% opacity
+  }
+  return widget->GetColorProvider()->GetColor(cros_tokens::kCrosSysSystemBase);
 }
 
 ui::ColorId ShelfConfig::GetShelfBaseLayerColorId() const {
-  if (!in_tablet_mode_)
-    return kColorAshShieldAndBase80;
+  if (!chromeos::features::IsJellyEnabled()) {
+    if (!in_tablet_mode_) {
+      return kColorAshShieldAndBase80;
+    }
 
-  if (!is_in_app_)
-    return kColorAshShieldAndBase60;
+    if (!is_in_app_) {
+      return kColorAshShieldAndBase60;
+    }
 
-  return DarkLightModeControllerImpl::Get()->IsDarkModeEnabled()
-             ? kColorAshShieldAndBase90
-             : kColorAshShieldAndBaseOpaque;
+    return DarkLightModeControllerImpl::Get()->IsDarkModeEnabled()
+               ? kColorAshShieldAndBase90
+               : kColorAshShieldAndBaseOpaque;
+  }
+
+  if (in_tablet_mode_ && is_in_app_) {
+    // In tablet mode with an app, we use the same opaque color as maximized.
+    return cros_tokens::kCrosSysSystemBase;
+  }
+
+  return cros_tokens::kCrosSysSystemBaseElevated;
 }
 
 SkColor ShelfConfig::GetDefaultShelfColor(const views::Widget* widget) const {
@@ -548,6 +560,27 @@ int ShelfConfig::GetSystemShelfSizeInTabletMode() const {
                                    : kSystemShelfSizeTabletModeNormal;
 }
 
+int ShelfConfig::GetSystemShelfInsetsInTabletMode() const {
+  if (elevate_tablet_mode_app_bar_) {
+    return kElevatedSystemShelfSizeTabletMode;
+  } else {
+    return GetSystemShelfSizeInTabletMode();
+  }
+}
+
+int ShelfConfig::GetMinimumInlineAppBarSize() const {
+  return 6 * kSystemShelfSizeTabletModeDense + 5 * shelf_button_spacing_ +
+         2 * app_icon_end_padding_;
+}
+
+void ShelfConfig::UpdateShowElevatedAppBar(
+    const gfx::Size& inline_app_bar_size) {
+  if (features::IsShelfStackedHotseatEnabled()) {
+    elevate_tablet_mode_app_bar_ =
+        inline_app_bar_size.width() < GetMinimumInlineAppBarSize();
+  }
+}
+
 void ShelfConfig::UpdateConfigForAccessibilityState() {
   UpdateConfig(is_app_list_visible_, /*tablet_mode_changed=*/false);
 }
