@@ -71,8 +71,10 @@
 #include "ash/frame/non_client_frame_view_ash.h"
 #include "ash/frame/snap_controller_impl.h"
 #include "ash/frame_throttler/frame_throttling_controller.h"
+#include "ash/game_dashboard/game_dashboard_controller.h"
 #include "ash/glanceables/glanceables_controller.h"
 #include "ash/glanceables/glanceables_delegate.h"
+#include "ash/glanceables/glanceables_v2_controller.h"
 #include "ash/host/ash_window_tree_host_init_params.h"
 #include "ash/hud_display/hud_display.h"
 #include "ash/ime/ime_controller_impl.h"
@@ -90,6 +92,7 @@
 #include "ash/multi_device_setup/multi_device_notification_presenter.h"
 #include "ash/policy/policy_recommendation_restorer.h"
 #include "ash/projector/projector_controller_impl.h"
+#include "ash/public/cpp/accelerator_keycode_lookup_cache.h"
 #include "ash/public/cpp/ash_prefs.h"
 #include "ash/public/cpp/holding_space/holding_space_controller.h"
 #include "ash/public/cpp/nearby_share_delegate.h"
@@ -114,6 +117,7 @@
 #include "ash/style/ash_color_mixer.h"
 #include "ash/style/ash_color_provider.h"
 #include "ash/style/dark_light_mode_controller_impl.h"
+#include "ash/style/style_util.h"
 #include "ash/system/audio/audio_effects_controller.h"
 #include "ash/system/audio/display_speaker_controller.h"
 #include "ash/system/bluetooth/bluetooth_device_status_ui_handler.h"
@@ -130,6 +134,7 @@
 #include "ash/system/human_presence/human_presence_orientation_controller.h"
 #include "ash/system/human_presence/snooping_protection_controller.h"
 #include "ash/system/input_device_settings/input_device_settings_controller_impl.h"
+#include "ash/system/input_device_settings/input_device_settings_dispatcher.h"
 #include "ash/system/input_device_settings/input_device_tracker.h"
 #include "ash/system/input_device_settings/keyboard_modifier_metrics_recorder.h"
 #include "ash/system/keyboard_brightness/keyboard_backlight_color_controller.h"
@@ -168,6 +173,8 @@
 #include "ash/touch/touch_devices_controller.h"
 #include "ash/touch/touch_selection_magnifier_runner_ash.h"
 #include "ash/tray_action/tray_action.h"
+#include "ash/user_education/user_education_controller.h"
+#include "ash/user_education/user_education_delegate.h"
 #include "ash/utility/occlusion_tracker_pauser.h"
 #include "ash/wallpaper/wallpaper_controller_impl.h"
 #include "ash/wm/ash_focus_rules.h"
@@ -175,6 +182,7 @@
 #include "ash/wm/cursor_manager_chromeos.h"
 #include "ash/wm/desks/desks_controller.h"
 #include "ash/wm/desks/persistent_desks_bar/persistent_desks_bar_controller.h"
+#include "ash/wm/desks/templates/saved_desk_controller.h"
 #include "ash/wm/event_client_impl.h"
 #include "ash/wm/float/float_controller.h"
 #include "ash/wm/gestures/back_gesture/back_gesture_event_handler.h"
@@ -183,10 +191,10 @@
 #include "ash/wm/mru_window_tracker.h"
 #include "ash/wm/multi_display/multi_display_metrics_controller.h"
 #include "ash/wm/multi_display/persistent_window_controller.h"
-#include "ash/wm/multitask_menu_nudge_controller.h"
+#include "ash/wm/multitask_menu_nudge_delegate_ash.h"
 #include "ash/wm/native_cursor_manager_ash.h"
-#include "ash/wm/overlay_event_filter.h"
 #include "ash/wm/overview/overview_controller.h"
+#include "ash/wm/raster_scale_controller.h"
 #include "ash/wm/resize_shadow_controller.h"
 #include "ash/wm/screen_pinning_controller.h"
 #include "ash/wm/snap_group/snap_group_controller.h"
@@ -199,7 +207,6 @@
 #include "ash/wm/video_detector.h"
 #include "ash/wm/window_animations.h"
 #include "ash/wm/window_cycle/window_cycle_controller.h"
-#include "ash/wm/window_positioner.h"
 #include "ash/wm/window_properties.h"
 #include "ash/wm/window_restore/window_restore_controller.h"
 #include "ash/wm/window_util.h"
@@ -218,7 +225,6 @@
 #include "chromeos/ash/components/dbus/usb/usbguard_client.h"
 #include "chromeos/ash/components/fwupd/firmware_update_manager.h"
 #include "chromeos/ash/components/peripheral_notification/peripheral_notification_manager.h"
-#include "chromeos/ash/components/system/devicemode.h"
 #include "chromeos/ash/services/assistant/public/cpp/features.h"
 #include "chromeos/dbus/init/initialize_dbus_client.h"
 #include "chromeos/dbus/power/power_policy_controller.h"
@@ -687,6 +693,7 @@ Shell::~Shell() {
 
   ash_dbus_services_.reset();
 
+  saved_desk_controller_.reset();
   saved_desk_delegate_.reset();
   desks_controller_->Shutdown();
 
@@ -717,9 +724,6 @@ Shell::~Shell() {
   RemovePreTargetHandler(speech_feedback_handler_.get());
   speech_feedback_handler_.reset();
 
-  RemovePreTargetHandler(overlay_filter_.get());
-  overlay_filter_.reset();
-
   RemovePreTargetHandler(control_v_histogram_recorder_.get());
   RemovePreTargetHandler(accelerator_tracker_.get());
   RemovePreTargetHandler(accelerator_filter_.get());
@@ -740,6 +744,7 @@ Shell::~Shell() {
 
   event_rewriter_controller_.reset();
   keyboard_modifier_metrics_recorder_.reset();
+  input_device_settings_dispatcher_.reset();
   input_device_tracker_.reset();
   input_device_settings_controller_.reset();
 
@@ -836,25 +841,34 @@ Shell::~Shell() {
 
   shadow_controller_.reset();
   resize_shadow_controller_.reset();
+  raster_scale_controller_.reset();
 
   // Has to happen before ~MruWindowTracker.
   window_cycle_controller_.reset();
   overview_controller_.reset();
 
+  game_dashboard_controller_.reset();
+
   // This must be destroyed before deleting all the windows below in
   // `CloseAllRootWindowChildWindows()`, since shutting down the session will
   // need to access those windows and it will be a UAF.
   // https://crbug.com/1350711.
   capture_mode_controller_.reset();
 
+  // This must be called before deleting all the windows below in
+  // `CloseAllRootWindowChildWindows()` since host_windows(which gets destroyed)
+  // are needed for proper deletion of RoundedDisplayProviders.
+  window_tree_host_manager_->ShutdownRoundedDisplays();
+
   // Close all widgets (including the shelf) and destroy all window containers.
   CloseAllRootWindowChildWindows();
 
   // Glanceables has a dependency on `tablet_mode_controller_`. Should be
   // destroyed first to remove the tablet mode observer.
   glanceables_controller_.reset();
+  glanceables_v2_controller_.reset();
 
-  multitask_menu_nudge_controller_.reset();
+  multitask_menu_nudge_delegate_.reset();
   tablet_mode_controller_.reset();
   login_screen_controller_.reset();
   system_notification_controller_.reset();
@@ -1160,12 +1174,14 @@ void Shell::Init(
       peripheral_battery_listener_.get());
   power_event_observer_ = std::make_unique<PowerEventObserver>();
   window_cycle_controller_ = std::make_unique<WindowCycleController>();
-  multitask_menu_nudge_controller_ =
-      std::make_unique<MultitaskMenuNudgeController>();
 
   capture_mode_controller_ = std::make_unique<CaptureModeController>(
       shell_delegate_->CreateCaptureModeDelegate());
 
+  if (features::IsGameDashboardEnabled()) {
+    game_dashboard_controller_ = std::make_unique<GameDashboardController>();
+  }
+
   // Accelerometer file reader starts listening to tablet mode controller.
   AccelerometerReader::GetInstance()->StartListenToTabletModeController();
 
@@ -1183,8 +1199,6 @@ void Shell::Init(
         std::make_unique<KeyboardBacklightColorController>(local_state_);
   }
 
-  window_positioner_ = std::make_unique<WindowPositioner>();
-
   native_cursor_manager_ = new NativeCursorManagerAsh;
   cursor_manager_ =
       std::make_unique<CursorManager>(base::WrapUnique(native_cursor_manager_));
@@ -1241,12 +1255,18 @@ void Shell::Init(
   window_modality_controller_ =
       std::make_unique<::wm::WindowModalityController>(this, env);
 
-  // The `InputDeviceSettingsController` is a dependency of the
-  // `EventRewriterController`, `InputDeviceTracker` and
-  // `KeyboardModifierMetricsRecorder` so it must be initialized first.
+  // The `InputDeviceSettingsController` is a dependency of the following so it
+  // must be initialized first:
+  //  - `EventRewriterController`
+  //  - `InputDeviceTracker`
+  //  - `KeyboardModifierMetricsRecorder`
+  //  - `InputDeviceSettingsDispatcher`
   input_device_settings_controller_ =
       std::make_unique<InputDeviceSettingsControllerImpl>();
   input_device_tracker_ = std::make_unique<InputDeviceTracker>();
+  input_device_settings_dispatcher_ =
+      std::make_unique<InputDeviceSettingsDispatcher>(
+          ui::OzonePlatform::GetInstance()->GetInputController());
   keyboard_modifier_metrics_recorder_ =
       std::make_unique<KeyboardModifierMetricsRecorder>();
   event_rewriter_controller_ = std::make_unique<EventRewriterControllerImpl>();
@@ -1286,6 +1306,10 @@ void Shell::Init(
   // controller.
   desks_controller_ = std::make_unique<DesksController>();
   saved_desk_delegate_ = shell_delegate_->CreateSavedDeskDelegate();
+  // Initialized here since it depends on desks.
+  if (base::FeatureList::IsEnabled(features::kAppLaunchAutomation)) {
+    saved_desk_controller_ = std::make_unique<SavedDeskController>();
+  }
 
   Shell::SetRootWindowForNewWindows(GetPrimaryRootWindow());
 
@@ -1295,6 +1319,9 @@ void Shell::Init(
   cursor_manager_->SetDisplay(
       display::Screen::GetScreen()->GetPrimaryDisplay());
 
+  // Must be initialized after InputMethodManager.
+  accelerator_keycode_lookup_cache_ =
+      std::make_unique<AcceleratorKeycodeLookupCache>();
   ash_accelerator_configuration_ =
       std::make_unique<AshAcceleratorConfiguration>();
   ash_accelerator_configuration_->Initialize();
@@ -1309,11 +1336,8 @@ void Shell::Init(
 
   calendar_controller_ = std::make_unique<CalendarController>();
 
-  if (CameraEffectsController::IsCameraEffectsSupported()) {
-    camera_effects_controller_ = std::make_unique<CameraEffectsController>();
-  }
-
   if (features::IsVideoConferenceEnabled()) {
+    camera_effects_controller_ = std::make_unique<CameraEffectsController>();
     audio_effects_controller_ = std::make_unique<AudioEffectsController>();
   }
 
@@ -1333,9 +1357,6 @@ void Shell::Init(
   // rewritten first.
   user_activity_detector_ = std::make_unique<ui::UserActivityDetector>();
 
-  overlay_filter_ = std::make_unique<OverlayEventFilter>();
-  AddPreTargetHandler(overlay_filter_.get());
-
   control_v_histogram_recorder_ = std::make_unique<ControlVHistogramRecorder>();
   AddPreTargetHandler(control_v_histogram_recorder_.get());
 
@@ -1416,15 +1437,11 @@ void Shell::Init(
   multi_display_metrics_controller_ =
       std::make_unique<MultiDisplayMetricsController>();
 
-  // |assistant_controller_| is put before |ambient_controller_| as it will be
-  // used by the latter.
-  if (features::IsAmbientModeEnabled()) {
-    mojo::PendingRemote<device::mojom::Fingerprint> fingerprint;
-    shell_delegate_->BindFingerprint(
-        fingerprint.InitWithNewPipeAndPassReceiver());
-    ambient_controller_ =
-        std::make_unique<AmbientController>(std::move(fingerprint));
-  }
+  mojo::PendingRemote<device::mojom::Fingerprint> ambient_fingerprint;
+  shell_delegate_->BindFingerprint(
+      ambient_fingerprint.InitWithNewPipeAndPassReceiver());
+  ambient_controller_ =
+      std::make_unique<AmbientController>(std::move(ambient_fingerprint));
 
   mojo::PendingRemote<video_capture::mojom::MultiCaptureService>
       multi_capture_service;
@@ -1459,7 +1476,9 @@ void Shell::Init(
   video_detector_ = std::make_unique<VideoDetector>();
 
   tooltip_controller_ = std::make_unique<views::corewm::TooltipController>(
-      std::make_unique<views::corewm::TooltipAura>(), activation_client());
+      std::make_unique<views::corewm::TooltipAura>(
+          base::BindRepeating(&StyleUtil::CreateAshStyleTooltipView)),
+      activation_client());
   AddPreTargetHandler(tooltip_controller_.get());
 
   modality_filter_ = std::make_unique<SystemModalContainerEventFilter>(this);
@@ -1468,6 +1487,7 @@ void Shell::Init(
   event_client_ = std::make_unique<EventClientImpl>();
 
   resize_shadow_controller_ = std::make_unique<ResizeShadowController>();
+  raster_scale_controller_ = std::make_unique<RasterScaleController>();
   shadow_controller_ = std::make_unique<::wm::ShadowController>(
       focus_controller_.get(), std::make_unique<WmShadowControllerDelegate>(),
       env);
@@ -1536,7 +1556,7 @@ void Shell::Init(
   // WindowTreeHostManager to host the keyboard window.
   keyboard_controller_->CreateVirtualKeyboard(std::move(keyboard_ui_factory));
 
-  // Create window restore controller after WindowTreeHostManager::InitHosts()
+  // Create window restore controller after `WindowTreeHostManager::InitHosts()`
   // since it may need to add observers to root windows.
   window_restore_controller_ = std::make_unique<WindowRestoreController>();
 
@@ -1590,12 +1610,18 @@ void Shell::Init(
         glanceables_controller_.get()));
   }
 
+  if (features::AreGlanceablesV2Enabled()) {
+    glanceables_v2_controller_ = std::make_unique<GlanceablesV2Controller>();
+  }
+
   if (features::IsProjectorEnabled()) {
     projector_controller_ = std::make_unique<ProjectorControllerImpl>();
   }
 
-  if (chromeos::wm::features::IsFloatWindowEnabled()) {
+  if (chromeos::wm::features::IsWindowLayoutMenuEnabled()) {
     float_controller_ = std::make_unique<FloatController>();
+    multitask_menu_nudge_delegate_ =
+        std::make_unique<MultitaskMenuNudgeDelegateAsh>();
   }
 
   if (features::IsFederatedServiceEnabled()) {
@@ -1603,6 +1629,11 @@ void Shell::Init(
         std::make_unique<federated::FederatedServiceControllerImpl>();
   }
 
+  if (features::IsUserEducationEnabled()) {
+    user_education_controller_ = std::make_unique<UserEducationController>(
+        shell_delegate_->CreateUserEducationDelegate());
+  }
+
   // Injects the factory which fulfills the implementation of the text context
   // menu exclusive to CrOS.
   views::ViewsTextServicesContextMenuChromeos::SetImplFactory(
@@ -1652,7 +1683,7 @@ void Shell::InitializeDisplayManager() {
   bool display_initialized = display_manager_->InitFromCommandLine();
 
   if (!display_initialized) {
-    if (chromeos::IsRunningAsSystemCompositor()) {
+    if (base::SysInfo::IsRunningOnChromeOS()) {
       display_change_observer_ =
           std::make_unique<display::DisplayChangeObserver>(
               display_manager_.get());
