@@ -42,10 +42,16 @@ class NearbyShareController;
 class NearbyShareDelegate;
 class SavedDeskDelegate;
 class SystemSoundsDelegate;
+class UserEducationDelegate;
 
 // Delegate of the Shell.
 class ASH_EXPORT ShellDelegate {
  public:
+  enum class FeedbackSource {
+    kBentoBar,
+    kWindowLayoutMenu,
+  };
+
   // The Shell owns the delegate.
   virtual ~ShellDelegate() = default;
 
@@ -82,6 +88,10 @@ class ASH_EXPORT ShellDelegate {
   virtual std::unique_ptr<SystemSoundsDelegate> CreateSystemSoundsDelegate()
       const = 0;
 
+  // Creates and returns the delegate for user education features.
+  virtual std::unique_ptr<UserEducationDelegate> CreateUserEducationDelegate()
+      const = 0;
+
   // Returns the geolocation loader factory used to initialize geolocation
   // provider.
   virtual scoped_refptr<network::SharedURLLoaderFactory>
@@ -150,10 +160,11 @@ class ASH_EXPORT ShellDelegate {
   // primary user Downloads folder if user has already logged in.
   virtual base::FilePath GetPrimaryUserDownloadsFolder() const = 0;
 
-  // Opens the feedback page with pre-populated description #BentoBar for
-  // persistent desks bar. Note, this will be removed once the feature is fully
-  // launched or removed.
-  virtual void OpenFeedbackPageForPersistentDesksBar() = 0;
+  // Opens the feedback page with pre-populated `source` and
+  // `description_template` fields. Note, this will only be used by features
+  // before they are fully launched or removed.
+  virtual void OpenFeedbackDialog(FeedbackSource source,
+                                  const std::string& description_template) = 0;
 
   // Returns the last committed URL from the web contents if the given |window|
   // contains a browser frame, otherwise returns GURL::EmptyURL().
