@@ -21,14 +21,7 @@ namespace ash {
   E_CPONLY(kColorAshShieldAndBase90) \
   E_CPONLY(kColorAshShieldAndBase95) \
   E_CPONLY(kColorAshShieldAndBaseOpaque) \
-  E_CPONLY(kColorAshShieldAndBase20Light) \
-  E_CPONLY(kColorAshShieldAndBase40Light) \
-  E_CPONLY(kColorAshShieldAndBase60Light) \
   E_CPONLY(kColorAshShieldAndBase80Light) \
-  E_CPONLY(kColorAshInvertedShieldAndBase80Light) \
-  E_CPONLY(kColorAshShieldAndBase90Light) \
-  E_CPONLY(kColorAshShieldAndBase95Light) \
-  E_CPONLY(kColorAshShieldAndBaseOpaqueLight) \
   /* Controls Layer colors. */ \
   E_CPONLY(kColorAshHairlineBorderColor) \
   E_CPONLY(kColorAshControlBackgroundColorActive) \
@@ -129,7 +122,11 @@ namespace ash {
   /* Color for checkmark icon in holding space */ \
   E_CPONLY(kColorAshCheckmarkIconColor) \
   /* Color for drag image overflow badge text in holding space */ \
-  E_CPONLY(kColorAshDragImageOverflowBadgeTextColor)
+  E_CPONLY(kColorAshDragImageOverflowBadgeTextColor) \
+  /* Color for feature tile small circle */ \
+  E_CPONLY(kColorAshTileSmallCircle) \
+  /* Color for the background of the app count indicator on a folder */ \
+  E_CPONLY(kColorAshFolderItemCountBackgroundColor)
 
 #include "ui/color/color_id_macros.inc"
 
