@@ -8,6 +8,7 @@
 #include "ash/ash_export.h"
 #include "base/functional/callback_forward.h"
 #include "ui/base/metadata/metadata_header_macros.h"
+#include "ui/gfx/paint_vector_icon.h"
 #include "ui/views/view.h"
 
 namespace views {
@@ -21,12 +22,10 @@ namespace ash {
 class ScopedA11yOverrideWindowSetter;
 class SystemShadow;
 
-// A view that has rounded corner with label and button inside. The label shows
-// the information. The button inside is optional and has certain functionality
-// e.g. dismiss the view or retry. A managed icon will be put ahead of the label
-// inside if `is_managed` is true.
-// TODO(crbug/1289478): Migrate the `managed_icon_` to `Quick settings toast`,
-// which includes an icon on the left.
+// A view used to present Toasts. It has rounded corners and may have a
+// dismiss button if a `dismiss_text` is provided, and a `leading_icon` if one
+// is provided. The spacing surrounding the elements may change if the text has
+// one or two lines.
 class ASH_EXPORT SystemToastStyle : public views::View {
  public:
   METADATA_HEADER(SystemToastStyle);
@@ -34,7 +33,7 @@ class ASH_EXPORT SystemToastStyle : public views::View {
   SystemToastStyle(base::RepeatingClosure dismiss_callback,
                    const std::u16string& text,
                    const std::u16string& dismiss_text,
-                   const bool is_managed);
+                   const gfx::VectorIcon& leading_icon = gfx::kNoneIcon);
   SystemToastStyle(const SystemToastStyle&) = delete;
   SystemToastStyle& operator=(const SystemToastStyle&) = delete;
   ~SystemToastStyle() override;
@@ -53,13 +52,18 @@ class ASH_EXPORT SystemToastStyle : public views::View {
   views::LabelButton* button() const { return button_; }
 
  private:
+  friend class ToastManagerImplTest;
+
   // views::View:
   void AddedToWidget() override;
   void OnThemeChanged() override;
 
+  const gfx::VectorIcon* const leading_icon_ = nullptr;
+
+  // Owned by views hierarchy.
   views::Label* label_ = nullptr;
   views::LabelButton* button_ = nullptr;
-  views::ImageView* managed_icon_ = nullptr;
+  views::ImageView* leading_icon_view_ = nullptr;
 
   // Tells the toast if the dismiss button is already highlighted if one exists.
   bool is_dismiss_button_highlighted_ = false;
