@@ -73,7 +73,8 @@ class TabSlider::SelectorView : public views::View {
     auto* view_layer = layer();
 
     gfx::Transform reverse_transform = gfx::TransformBetweenRects(
-        gfx::RectF(button_->bounds()), gfx::RectF(previous_button->bounds()));
+        gfx::RectF(button_->GetMirroredBounds()),
+        gfx::RectF(previous_button->GetMirroredBounds()));
     view_layer->SetTransform(reverse_transform);
     ui::ScopedLayerAnimationSettings settings(view_layer->GetAnimator());
     settings.SetTransitionDuration(kSelectorAnimationDuration);
@@ -110,6 +111,10 @@ TabSlider::TabSlider(bool has_background,
 
 TabSlider::~TabSlider() = default;
 
+views::View* TabSlider::GetSelectorView() {
+  return selector_view_;
+}
+
 void TabSlider::SetCustomLayout(const LayoutParams& layout_params) {
   use_button_recommended_layout_ = false;
 
@@ -217,17 +222,16 @@ void TabSlider::UpdateLayout() {
 
   // Add the row buttons will live in.
   table_layout->AddRows(1, views::TableLayout::kFixedSize);
-  if (distribute_space_evenly_) {
-    // Ensure extra space is spread evenly between the button containing
-    // columns.
-    table_layout->LinkColumnSizes(columns_containing_buttons);
-  }
-
   table_layout
       ->AddPaddingRow(views::TableLayout::kFixedSize,
                       custom_layout_params_.internal_border_padding)
       .AddPaddingColumn(views::TableLayout::kFixedSize,
                         custom_layout_params_.internal_border_padding);
+  if (distribute_space_evenly_) {
+    // Ensure extra space is spread evenly between the button containing
+    // columns.
+    table_layout->LinkColumnSizes(columns_containing_buttons);
+  }
 }
 
 void TabSlider::OnEnabledStateChanged() {
