@@ -8,8 +8,10 @@
 #include "ash/constants/ash_features.h"
 #include "ash/session/session_controller_impl.h"
 #include "ash/shell.h"
+#include "ash/style/switch.h"
 #include "ash/system/audio/audio_detailed_view.h"
 #include "ash/system/audio/mic_gain_slider_controller.h"
+#include "ash/system/audio/mic_gain_slider_view.h"
 #include "ash/system/audio/unified_volume_slider_controller.h"
 #include "ash/system/tray/hover_highlight_view.h"
 #include "ash/system/unified/unified_system_tray_controller.h"
@@ -43,6 +45,9 @@ constexpr uint64_t kFrontMicId = 10012;
 constexpr uint64_t kRearMicId = 10013;
 const uint64_t kInternalSpeakerId = 10001;
 const uint64_t kHeadphoneId = 10002;
+constexpr uint64_t kDualInternalMicId = 0;
+const int kFrontMicGainPercent = 50;
+const int kRearMicGainPercent = 100;
 
 const std::u16string kInitialLiveCaptionViewSubtitleText = u"This is a test";
 const std::u16string kSodaDownloaded = u"Speech files downloaded";
@@ -196,7 +201,13 @@ class UnifiedAudioDetailedViewControllerTest
   }
 
   void ToggleLiveCaption() {
-    audio_detailed_view()->HandleViewClicked(live_caption_view());
+    GetAudioDetailedView()->HandleViewClicked(live_caption_view());
+  }
+
+  // Toggles the noise cancellation button for QsRevamp.
+  void ToggleNoiseCancellation() {
+    GetAudioDetailedView()->HandleViewClicked(
+        GetAudioDetailedView()->noise_cancellation_view_);
   }
 
  protected:
@@ -204,7 +215,7 @@ class UnifiedAudioDetailedViewControllerTest
     return FakeCrasAudioClient::Get();
   }
 
-  AudioDetailedView* audio_detailed_view() {
+  AudioDetailedView* GetAudioDetailedView() {
     if (!audio_detailed_view_) {
       audio_detailed_view_ = base::WrapUnique(static_cast<AudioDetailedView*>(
           audio_detailed_view_controller_->CreateView().release()));
@@ -213,7 +224,17 @@ class UnifiedAudioDetailedViewControllerTest
   }
 
   HoverHighlightView* live_caption_view() {
-    return audio_detailed_view()->live_caption_view_;
+    return GetAudioDetailedView()->live_caption_view_;
+  }
+
+  views::ToggleButton* noise_cancellation_button() {
+    if (!IsQsRevampEnabled()) {
+      DCHECK(toggles_map_[kInternalMicId]);
+      DCHECK(toggles_map_[kInternalMicId]->children().size() >= 2);
+      return (views::ToggleButton*)toggles_map_[kInternalMicId]->children()[1];
+    }
+
+    return GetAudioDetailedView()->noise_cancellation_button_;
   }
 
   bool live_caption_enabled() {
@@ -323,6 +344,73 @@ TEST_P(UnifiedAudioDetailedViewControllerTest, DualInternalMicSlider) {
   EXPECT_TRUE(input_sliders_map_.begin()->second->GetVisible());
 }
 
+TEST_P(UnifiedAudioDetailedViewControllerTest,
+       DualInternalMicSliderActiveState) {
+  fake_cras_audio_client()->SetAudioNodesAndNotifyObserversForTesting(
+      GenerateAudioNodeList({kFrontMic, kRearMic}));
+
+  // Verify the device has dual internal mics.
+  EXPECT_TRUE(cras_audio_handler_->HasDualInternalMic());
+
+  std::unique_ptr<views::View> view =
+      audio_detailed_view_controller_->CreateView();
+
+  // Verify there is only 1 slider in the view.
+  EXPECT_EQ(input_sliders_map_.size(), 1u);
+
+  auto* mic_gain_slider_view =
+      static_cast<MicGainSliderView*>(input_sliders_map_.begin()->second);
+
+  // Verify the slider is visible.
+  EXPECT_TRUE(mic_gain_slider_view->GetVisible());
+
+  // For QsRevamp: Verify the slider is active since it's the only slider.
+  if (IsQsRevampEnabled()) {
+    EXPECT_EQ(static_cast<QuickSettingsSlider*>(mic_gain_slider_view->slider())
+                  ->slider_style(),
+              QuickSettingsSlider::Style::kRadioActive);
+  }
+}
+
+TEST_P(UnifiedAudioDetailedViewControllerTest,
+       DualInternalMicSliderInactiveState) {
+  fake_cras_audio_client()->SetAudioNodesAndNotifyObserversForTesting(
+      GenerateAudioNodeList({kFrontMic, kRearMic, kMicJack}));
+
+  // Verify the device has dual internal mics.
+  EXPECT_TRUE(cras_audio_handler_->HasDualInternalMic());
+
+  std::unique_ptr<views::View> view =
+      audio_detailed_view_controller_->CreateView();
+
+  // Verify there are 2 sliders in the view and one of them is the new dual
+  // internal mic.
+  EXPECT_EQ(input_sliders_map_.size(), 2u);
+  EXPECT_TRUE(input_sliders_map_.contains(kDualInternalMicId));
+
+  // Sets different volume gain levels for front and rear mics.
+  cras_audio_handler_->SetVolumeGainPercentForDevice(kFrontMicId,
+                                                     kFrontMicGainPercent);
+  cras_audio_handler_->SetVolumeGainPercentForDevice(kRearMicId,
+                                                     kRearMicGainPercent);
+
+  // Switches to `kMicJack` to make the internal mic inactive.
+  cras_audio_handler_->SwitchToDevice(AudioDevice(GenerateAudioNode(kMicJack)),
+                                      true, CrasAudioHandler::ACTIVATE_BY_USER);
+
+  // For QsRevamp: Verify the dual internal mic slider is inactive and its
+  // volume level equals to the front mic's level.
+  if (IsQsRevampEnabled()) {
+    auto* mic_gain_slider_view = static_cast<MicGainSliderView*>(
+        input_sliders_map_.find(kDualInternalMicId)->second);
+    EXPECT_EQ(static_cast<QuickSettingsSlider*>(mic_gain_slider_view->slider())
+                  ->slider_style(),
+              QuickSettingsSlider::Style::kRadioInactive);
+    EXPECT_EQ(mic_gain_slider_view->slider()->GetValue(),
+              kFrontMicGainPercent / 100.0);
+  }
+}
+
 TEST_P(UnifiedAudioDetailedViewControllerTest,
        NoiseCancellationToggleNotDisplayedIfNotSupported) {
   fake_cras_audio_client()->SetAudioNodesAndNotifyObserversForTesting(
@@ -349,13 +437,11 @@ TEST_P(UnifiedAudioDetailedViewControllerTest,
   cras_audio_handler_->SwitchToDevice(internal_mic, true,
                                       CrasAudioHandler::ACTIVATE_BY_USER);
 
-  std::unique_ptr<views::View> view =
-      audio_detailed_view_controller_->CreateView();
+  // If `audio_detailed_view_` doesn't exist, this getter method will create the
+  // view first.
+  GetAudioDetailedView();
   EXPECT_EQ(1u, toggles_map_.size());
-
-  views::ToggleButton* toggle =
-      (views::ToggleButton*)toggles_map_[internal_mic.id]->children()[1];
-  EXPECT_TRUE(toggle->GetIsOn());
+  noise_cancellation_button()->GetIsOn();
 }
 
 TEST_P(UnifiedAudioDetailedViewControllerTest,
@@ -371,12 +457,12 @@ TEST_P(UnifiedAudioDetailedViewControllerTest,
   cras_audio_handler_->SwitchToDevice(internal_mic, true,
                                       CrasAudioHandler::ACTIVATE_BY_USER);
 
-  std::unique_ptr<views::View> view =
-      audio_detailed_view_controller_->CreateView();
+  // If `audio_detailed_view_` doesn't exist, this getter method will create the
+  // view first.
+  GetAudioDetailedView();
   EXPECT_EQ(1u, toggles_map_.size());
 
-  views::ToggleButton* toggle =
-      (views::ToggleButton*)toggles_map_[internal_mic.id]->children()[1];
+  views::ToggleButton* toggle = noise_cancellation_button();
   auto widget = CreateFramelessTestWidget();
   widget->SetContentsView(toggle);
 
@@ -384,18 +470,27 @@ TEST_P(UnifiedAudioDetailedViewControllerTest,
   EXPECT_FALSE(toggle->GetIsOn());
   EXPECT_FALSE(audio_pref_handler_->GetNoiseCancellationState());
 
-  ui::MouseEvent press(ui::ET_MOUSE_PRESSED, gfx::PointF(), gfx::PointF(),
-                       ui::EventTimeForNow(), ui::EF_LEFT_MOUSE_BUTTON,
-                       ui::EF_NONE);
+  if (!IsQsRevampEnabled()) {
+    ui::MouseEvent press(ui::ET_MOUSE_PRESSED, gfx::PointF(), gfx::PointF(),
+                         ui::EventTimeForNow(), ui::EF_LEFT_MOUSE_BUTTON,
+                         ui::EF_NONE);
 
-  // Flipping the toggle.
-  views::test::ButtonTestApi(toggle).NotifyClick(press);
-  // The new state of the toggle must be saved to the prefs.
-  EXPECT_TRUE(audio_pref_handler_->GetNoiseCancellationState());
+    // Flipping the toggle.
+    views::test::ButtonTestApi(toggle).NotifyClick(press);
+    // The new state of the toggle must be saved to the prefs.
+    EXPECT_TRUE(audio_pref_handler_->GetNoiseCancellationState());
 
-  // Flipping back and checking the prefs again.
-  views::test::ButtonTestApi(toggle).NotifyClick(press);
-  EXPECT_FALSE(audio_pref_handler_->GetNoiseCancellationState());
+    // Flipping back and checking the prefs again.
+    views::test::ButtonTestApi(toggle).NotifyClick(press);
+    EXPECT_FALSE(audio_pref_handler_->GetNoiseCancellationState());
+  } else {
+    // For QsRevamp, the entire row of `noise_cancellation_view_` is clickable.
+    ToggleNoiseCancellation();
+    EXPECT_TRUE(audio_pref_handler_->GetNoiseCancellationState());
+
+    ToggleNoiseCancellation();
+    EXPECT_FALSE(audio_pref_handler_->GetNoiseCancellationState());
+  }
 }
 
 TEST_P(UnifiedAudioDetailedViewControllerTest,
@@ -419,6 +514,51 @@ TEST_P(UnifiedAudioDetailedViewControllerTest,
   EXPECT_EQ(1u, toggles_map_.size());
 }
 
+TEST_P(UnifiedAudioDetailedViewControllerTest,
+       NoiseCancellationUpdatedWhenOnNoiseCancellationChanges) {
+  fake_cras_audio_client()->SetAudioNodesAndNotifyObserversForTesting(
+      GenerateAudioNodeList({kInternalMic, kMicJack, kFrontMic, kRearMic}));
+  fake_cras_audio_client()->SetNoiseCancellationSupported(true);
+  cras_audio_handler_->RequestNoiseCancellationSupported(base::DoNothing());
+
+  cras_audio_handler_->SwitchToDevice(
+      AudioDevice(GenerateAudioNode(kInternalMic)), true,
+      CrasAudioHandler::ACTIVATE_BY_USER);
+
+  // If `audio_detailed_view_` doesn't exist, this getter method will create the
+  // view first.
+  GetAudioDetailedView();
+
+  if (!IsQsRevampEnabled()) {
+    EXPECT_EQ(1u, toggles_map_.size());
+    // The toggle loaded the pref correctly.
+    EXPECT_TRUE(noise_cancellation_button()->GetIsOn());
+    EXPECT_TRUE(audio_pref_handler_->GetNoiseCancellationState());
+
+    cras_audio_handler_->SetNoiseCancellationState(
+        /*noise_cancellation_on=*/false);
+
+    EXPECT_EQ(1u, toggles_map_.size());
+    // The toggle updates the pref correctly.
+    EXPECT_FALSE(noise_cancellation_button()->GetIsOn());
+    EXPECT_FALSE(audio_pref_handler_->GetNoiseCancellationState());
+  } else {
+    auto widget = CreateFramelessTestWidget();
+    widget->SetContentsView(noise_cancellation_button());
+
+    // The noise cancellation button loaded the pref correctly.
+    EXPECT_TRUE(noise_cancellation_button()->GetIsOn());
+    EXPECT_TRUE(audio_pref_handler_->GetNoiseCancellationState());
+
+    cras_audio_handler_->SetNoiseCancellationState(
+        /*noise_cancellation_on=*/false);
+
+    // The noise cancellation button updates the pref correctly.
+    EXPECT_FALSE(noise_cancellation_button()->GetIsOn());
+    EXPECT_FALSE(audio_pref_handler_->GetNoiseCancellationState());
+  }
+}
+
 TEST_P(UnifiedAudioDetailedViewControllerTest, ToggleLiveCaption) {
   scoped_feature_list_.Reset();
   if (!IsQsRevampEnabled()) {
