@@ -6,6 +6,7 @@
 
 #include "ash/constants/ash_switches.h"
 #include "ash/public/cpp/bluetooth_config_service.h"
+#include "ash/public/cpp/hats_bluetooth_revamp_trigger.h"
 #include "ash/public/cpp/system_tray_client.h"
 #include "ash/shell.h"
 #include "ash/strings/grit/ash_strings.h"
@@ -13,6 +14,7 @@
 #include "ash/system/unified/unified_system_tray_controller.h"
 #include "base/check.h"
 #include "base/command_line.h"
+#include "base/memory/ptr_util.h"
 #include "build/chromeos_buildflags.h"
 #include "chromeos/ash/services/bluetooth_config/public/cpp/cros_bluetooth_config_util.h"
 #include "mojo/public/cpp/bindings/clone_traits.h"
@@ -48,7 +50,7 @@ BluetoothDetailedViewController::BluetoothDetailedViewController(
 
 BluetoothDetailedViewController::~BluetoothDetailedViewController() = default;
 
-views::View* BluetoothDetailedViewController::CreateView() {
+std::unique_ptr<views::View> BluetoothDetailedViewController::CreateView() {
   DCHECK(!view_);
   std::unique_ptr<BluetoothDetailedView> bluetooth_detailed_view =
       BluetoothDetailedView::Factory::Create(detailed_view_delegate_.get(),
@@ -63,9 +65,8 @@ views::View* BluetoothDetailedViewController::CreateView() {
                                               previously_connected_devices_);
   }
 
-  // We are expected to return an unowned pointer that the caller is responsible
-  // for deleting.
-  return bluetooth_detailed_view.release()->GetAsView();
+  // `bluetooth_detailed_view` is not a views::View, so we must GetAsView().
+  return base::WrapUnique(bluetooth_detailed_view.release()->GetAsView());
 }
 
 std::u16string BluetoothDetailedViewController::GetAccessibleName() const {
@@ -112,12 +113,20 @@ void BluetoothDetailedViewController::OnPropertiesUpdated(
 
 void BluetoothDetailedViewController::OnToggleClicked(bool new_state) {
   remote_cros_bluetooth_config_->SetBluetoothEnabledState(new_state);
+
+  if (auto* hats_bluetooth_revamp_trigger = HatsBluetoothRevampTrigger::Get()) {
+    hats_bluetooth_revamp_trigger->TryToShowSurvey();
+  }
 }
 
 void BluetoothDetailedViewController::OnPairNewDeviceRequested() {
   tray_controller_->CloseBubble();  // Deletes |this|.
   Shell::Get()->system_tray_model()->client()->ShowBluetoothPairingDialog(
       /*device_address=*/absl::nullopt);
+
+  if (auto* hats_bluetooth_revamp_trigger = HatsBluetoothRevampTrigger::Get()) {
+    hats_bluetooth_revamp_trigger->TryToShowSurvey();
+  }
 }
 
 void BluetoothDetailedViewController::OnDeviceListItemSelected(
@@ -288,7 +297,8 @@ void BluetoothDetailedViewController::AddFakeBluetoothDevices() {
     paired_device_properties->device_properties =
         BluetoothDeviceProperties::New();
     paired_device_properties->device_properties->id = "Video Camera";
-    paired_device_properties->device_properties->public_name = u"Video Camera";
+    paired_device_properties->device_properties->public_name =
+        u"Video Camera with a very very very very very very very long name";
     paired_device_properties->device_properties->device_type =
         DeviceType::kVideoCamera;
     paired_device_properties->device_properties->connection_state =
