@@ -372,6 +372,28 @@ TEST_F(DiagnosticsLogControllerTest,
   EXPECT_EQ(expected_path_not_regular_user, log_base_path());
 }
 
+TEST_F(DiagnosticsLogControllerTest, LogsDeletedOnUserSignin) {
+  base::ScopedTempDir scoped_dir;
+  EXPECT_TRUE(scoped_dir.CreateUniqueTempDir());
+  const base::FilePath expected_path_regular_user =
+      base::FilePath(scoped_dir.GetPath().Append(kFakeUserDir));
+  const base::FilePath expected_diagnostics_log_path =
+      expected_path_regular_user.Append(kDiangosticsDirName);
+  DiagnosticsLogController::Initialize(
+      std::make_unique<FakeDiagnosticsBrowserDelegate>(
+          expected_path_regular_user));
+
+  // Create directory after initialize to simulate user sign in when a user ran
+  // diagnostics previously.
+  EXPECT_TRUE(base::CreateDirectory(expected_diagnostics_log_path));
+  EXPECT_TRUE(base::PathExists(expected_diagnostics_log_path));
+
+  // Sign in and verify the log directory is deleted.
+  SimulateUserLogin(kTestUserEmail);
+  task_environment()->RunUntilIdle();
+  EXPECT_FALSE(base::PathExists(expected_diagnostics_log_path));
+}
+
 TEST_F(DiagnosticsLogControllerTest, SetLogWritersUsingLogBasePath) {
   base::ScopedTempDir scoped_dir;
 
