@@ -16,6 +16,8 @@
 #include "ash/system/eche/eche_icon_loading_indicator_view.h"
 #include "ash/system/screen_layout_observer.h"
 #include "ash/system/tray/tray_background_view.h"
+#include "ash/webui/eche_app_ui/eche_connection_status_handler.h"
+#include "ash/webui/eche_app_ui/mojom/eche_app.mojom-shared.h"
 #include "ash/webui/eche_app_ui/mojom/eche_app.mojom.h"
 #include "base/gtest_prod_util.h"
 #include "base/timer/timer.h"
@@ -59,13 +61,15 @@ class Shell;
 
 // This class represents the Eche tray button in the status area and
 // controls the bubble that is shown when the tray button is clicked.
-class ASH_EXPORT EcheTray : public TrayBackgroundView,
-                            public SessionObserver,
-                            public ScreenLayoutObserver,
-                            public ShelfObserver,
-                            public TabletModeObserver,
-                            public KeyboardControllerObserver,
-                            public ShellObserver {
+class ASH_EXPORT EcheTray
+    : public TrayBackgroundView,
+      public SessionObserver,
+      public ScreenLayoutObserver,
+      public ShelfObserver,
+      public TabletModeObserver,
+      public KeyboardControllerObserver,
+      public ShellObserver,
+      public eche_app::EcheConnectionStatusHandler::Observer {
  public:
   METADATA_HEADER(EcheTray);
 
@@ -148,6 +152,11 @@ class ASH_EXPORT EcheTray : public TrayBackgroundView,
   void OnKeyboardUIDestroyed() override;
   void OnKeyboardHidden(bool is_temporary_hide) override;
 
+  // eche_app::EcheConnectionStatusHandler::Observer:
+  void OnConnectionStatusChanged(
+      eche_app::mojom::ConnectionStatus connection_status) override;
+  void OnRequestBackgroundConnectionAttempt() override;
+
   // Sets the url that will be passed to the webview.
   // Setting a new value will cause the current bubble be destroyed.
   void SetUrl(const GURL& url);
@@ -192,7 +201,9 @@ class ASH_EXPORT EcheTray : public TrayBackgroundView,
   bool LoadBubble(const GURL& url,
                   const gfx::Image& icon,
                   const std::u16string& visible_name,
-                  const std::u16string& phone_name);
+                  const std::u16string& phone_name,
+                  eche_app::mojom::ConnectionStatus last_connection_status,
+                  eche_app::mojom::AppStreamLaunchEntryPoint entry_point);
 
   // Destroys the view inclusing the web view.
   // Note: `CloseBubble` only hides the view.
@@ -206,18 +217,33 @@ class ASH_EXPORT EcheTray : public TrayBackgroundView,
   // started. 2. Purges and closes the bubble when the streaming is stopped.
   void OnStreamStatusChanged(eche_app::mojom::StreamStatus status);
 
+  // Receives the `orientation` change when the stream switches between
+  // landscape and portrait.
+  void OnStreamOrientationChanged(bool is_landscape);
+
   // Set up the params and init the bubble.
   // Note: This function makes the bubble active and makes the
   // TrayBackgroundView's background inkdrop activate.
-  void InitBubble(const std::u16string& phone_name);
+  void InitBubble(const std::u16string& phone_name,
+                  eche_app::mojom::ConnectionStatus last_connection_status,
+                  eche_app::mojom::AppStreamLaunchEntryPoint entry_point);
 
   // Starts graceful close to ensure the connection resource is released before
   // the window is closed.
   void StartGracefulClose();
 
+  void SetEcheConnectionStatusHandler(
+      eche_app::EcheConnectionStatusHandler* eche_connection_status_handler);
+
+  bool IsBackgroundConnectionAttemptInProgress();
+
   // Test helpers
+  bool get_is_landscape_for_test() { return is_landscape_; }
   TrayBubbleWrapper* get_bubble_wrapper_for_test() { return bubble_.get(); }
   AshWebView* get_web_view_for_test() { return web_view_; }
+  AshWebView* get_initializer_webview_for_test() {
+    return initializer_webview_.get();
+  }
   views::ImageButton* GetIcon();
 
  private:
@@ -225,6 +251,7 @@ class ASH_EXPORT EcheTray : public TrayBackgroundView,
   FRIEND_TEST_ALL_PREFIXES(EcheTrayTest, EcheTrayOnDisplayConfigurationChanged);
   FRIEND_TEST_ALL_PREFIXES(EcheTrayTest,
                            EcheTrayKeyboardShowHideUpdateBubbleBounds);
+  FRIEND_TEST_ALL_PREFIXES(EcheTrayTest, EcheTrayOnStreamOrientationChanged);
 
   // Intercepts all the events targeted to the internal webview in order to
   // process the accelerator keys.
@@ -293,6 +320,12 @@ class ASH_EXPORT EcheTray : public TrayBackgroundView,
   // Returns true only if the bubble is initialized and visible.
   bool IsBubbleVisible();
 
+  // Starts graceful shutdown for the initializer.
+  void StartGracefulCloseInitializer();
+
+  // Kills the renderer.
+  void CloseInitializer();
+
   // The url that is transferred to the web view.
   // In the current implementation, this is supposed to be
   // Eche window URL. However, the bubble does not interpret,
@@ -309,6 +342,15 @@ class ASH_EXPORT EcheTray : public TrayBackgroundView,
   // owned by `bubble_`
   AshWebView* web_view_ = nullptr;
 
+  // Webview used to create a prewarming channel, before we have a video to
+  // attach to.
+  std::unique_ptr<AshWebView> initializer_webview_{};
+  std::unique_ptr<base::DelayTimer> initializer_timeout_{};
+  bool has_reported_initializer_result_ = false;
+
+  eche_app::EcheConnectionStatusHandler* eche_connection_status_handler_ =
+      nullptr;
+
   GracefulCloseCallback graceful_close_callback_;
   GracefulGoBackCallback graceful_go_back_callback_;
 
@@ -325,6 +367,10 @@ class ASH_EXPORT EcheTray : public TrayBackgroundView,
   // when the stream is initializing to when the stream is closed by user.
   absl::optional<base::TimeTicks> init_stream_timestamp_;
 
+  // The orientation of the stream (portrait vs landscape). The default
+  // orientation is portrait.
+  bool is_landscape_ = false;
+
   bool is_stream_started_ = false;
   std::u16string phone_name_;
 
