@@ -64,6 +64,38 @@ gfx::Image CreateTestImage() {
 
 }  // namespace
 
+using ConnectionStatus = eche_app::mojom::ConnectionStatus;
+
+class FakeConnectionStatusObserver
+    : public eche_app::EcheConnectionStatusHandler::Observer {
+ public:
+  FakeConnectionStatusObserver() = default;
+  ~FakeConnectionStatusObserver() override = default;
+
+  size_t num_connection_status_for_ui_changed_calls() const {
+    return num_connection_status_for_ui_changed_calls_;
+  }
+
+  ConnectionStatus last_connection_changed_for_ui_status() const {
+    return last_connection_changed_for_ui_status_;
+  }
+
+  // eche_app::EcheConnectionStatusObserver::Observer:
+  void OnConnectionStatusForUiChanged(
+      ConnectionStatus connection_status) override {
+    if (last_connection_changed_for_ui_status_ == connection_status) {
+      return;
+    }
+    ++num_connection_status_for_ui_changed_calls_;
+    last_connection_changed_for_ui_status_ = connection_status;
+  }
+
+ private:
+  size_t num_connection_status_for_ui_changed_calls_ = 0;
+  ConnectionStatus last_connection_changed_for_ui_status_ =
+      ConnectionStatus::kConnectionStatusDisconnected;
+};
+
 class EcheTrayTest : public AshTestBase {
  public:
   EcheTrayTest() = default;
@@ -76,7 +108,8 @@ class EcheTrayTest : public AshTestBase {
   // AshTestBase:
   void SetUp() override {
     feature_list_.InitWithFeatures(
-        /*enabled_features=*/{features::kEcheSWA},
+        /*enabled_features=*/{features::kEcheSWA,
+                              features::kEcheNetworkConnectionState},
         /*disabled_features=*/{});
 
     DCHECK(test_web_view_factory_.get());
@@ -86,7 +119,13 @@ class EcheTrayTest : public AshTestBase {
 
     AshTestBase::SetUp();
 
+    eche_connection_status_handler_ =
+        std::make_unique<eche_app::EcheConnectionStatusHandler>();
+    eche_connection_status_handler_->AddObserver(
+        &fake_connection_status_observer_);
     eche_tray_ = StatusAreaWidgetTestHelper::GetStatusAreaWidget()->eche_tray();
+    eche_tray_->SetEcheConnectionStatusHandler(
+        eche_connection_status_handler_.get());
     phone_hub_tray_ =
         StatusAreaWidgetTestHelper::GetStatusAreaWidget()->phone_hub_tray();
 
@@ -107,19 +146,33 @@ class EcheTrayTest : public AshTestBase {
         button->GetBoundsInScreen().CenterPoint());
   }
 
+  size_t GetNumConnectionStatusForUiChangedCalls() {
+    return fake_connection_status_observer_
+        .num_connection_status_for_ui_changed_calls();
+  }
+
+  ConnectionStatus GetLastConnectionChangedForUiStatus() {
+    return fake_connection_status_observer_
+        .last_connection_changed_for_ui_status();
+  }
+
   EcheTray* eche_tray() { return eche_tray_; }
   PhoneHubTray* phone_hub_tray() { return phone_hub_tray_; }
   ToastManagerImpl* toast_manager() { return toast_manager_; }
 
+  base::test::ScopedFeatureList feature_list_;
+
  private:
+  FakeConnectionStatusObserver fake_connection_status_observer_;
   EcheTray* eche_tray_ = nullptr;  // Not owned
   PhoneHubTray* phone_hub_tray_ = nullptr;  // Not owned
-  base::test::ScopedFeatureList feature_list_;
   ToastManagerImpl* toast_manager_ = nullptr;
 
   // Calling the factory constructor is enough to set it up.
   std::unique_ptr<TestAshWebViewFactory> test_web_view_factory_ =
       std::make_unique<TestAshWebViewFactory>();
+  std::unique_ptr<eche_app::EcheConnectionStatusHandler>
+      eche_connection_status_handler_;
 };
 
 // Verify the Eche tray button exists and but is not visible initially.
@@ -138,8 +191,10 @@ TEST_F(EcheTrayTest, EcheTrayShowBubbleAndTapTwice) {
   EXPECT_FALSE(eche_tray()->GetVisible());
 
   eche_tray()->SetVisiblePreferred(true);
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(eche_tray()->is_active());
@@ -175,8 +230,10 @@ TEST_F(EcheTrayTest, EcheTrayShowBubbleAndTapTwice) {
 
 TEST_F(EcheTrayTest, EcheTrayIconResize) {
   eche_tray()->SetVisiblePreferred(true);
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   int image_width = phone_hub_tray()
@@ -195,8 +252,10 @@ TEST_F(EcheTrayTest, EcheTrayIconResize) {
 }
 
 TEST_F(EcheTrayTest, OnAnyBubbleVisibilityChanged) {
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -214,8 +273,10 @@ TEST_F(EcheTrayTest, OnAnyBubbleVisibilityChanged) {
 // OnAnyBubbleVisibilityChanged() is called on the current bubble and hence
 // should be ignored.
 TEST_F(EcheTrayTest, OnAnyBubbleVisibilityChanged_SameWidget) {
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -231,8 +292,10 @@ TEST_F(EcheTrayTest, OnAnyBubbleVisibilityChanged_SameWidget) {
 // OnAnyBubbleVisibilityChanged() is called on some other bubble but the
 // visible parameter is false, hence we should not do anything.
 TEST_F(EcheTrayTest, OnAnyBubbleVisibilityChanged_NonVisible) {
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -253,8 +316,10 @@ TEST_F(EcheTrayTest, EcheTrayCreatesBubbleButHideFirst) {
 
   // Allow us to create the bubble but it is not visible until we need this
   // bubble to show up.
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
 
   EXPECT_FALSE(eche_tray()->is_active());
   EXPECT_TRUE(eche_tray()->get_bubble_wrapper_for_test());
@@ -281,8 +346,10 @@ TEST_F(EcheTrayTest, EcheTrayCreatesBubbleButStreamStatusChanged) {
 
   // Allow us to create the bubble but it is not visible until we need this
   // bubble to show up.
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
 
   EXPECT_FALSE(eche_tray()->is_active());
   EXPECT_TRUE(eche_tray()->get_bubble_wrapper_for_test());
@@ -309,8 +376,10 @@ TEST_F(EcheTrayTest, EcheTrayCreatesBubbleButStreamStatusChanged) {
 }
 
 TEST_F(EcheTrayTest, EcheTrayMinimizeButtonClicked) {
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -326,8 +395,10 @@ TEST_F(EcheTrayTest, EcheTrayMinimizeButtonClicked) {
 TEST_F(EcheTrayTest, EcheTrayCloseButtonClicked) {
   ResetUnloadWebContent();
   eche_tray()->SetGracefulCloseCallback(base::BindOnce(&UnloadWebContent));
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   ClickButton(eche_tray()->GetCloseButtonForTesting());
@@ -339,8 +410,10 @@ TEST_F(EcheTrayTest, EcheTrayBackButtonClicked) {
   ResetWebContentGoBack();
   eche_tray()->SetGracefulGoBackCallback(
       base::BindRepeating(&WebContentGoBack));
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   ClickButton(eche_tray()->GetArrowBackButtonForTesting());
@@ -353,8 +426,10 @@ TEST_F(EcheTrayTest, EcheTrayBackButtonClicked) {
 }
 
 TEST_F(EcheTrayTest, AcceleratorKeyHandled_Minimize) {
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -380,8 +455,10 @@ TEST_F(EcheTrayTest, AcceleratorKeyHandled_Minimize) {
 TEST_F(EcheTrayTest, AcceleratorKeyHandled_Ctrl_W) {
   ResetUnloadWebContent();
   eche_tray()->SetGracefulCloseCallback(base::BindOnce(&UnloadWebContent));
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -395,8 +472,10 @@ TEST_F(EcheTrayTest, AcceleratorKeyHandled_Ctrl_W) {
 }
 
 TEST_F(EcheTrayTest, AcceleratorKeyHandled_Ctrl_C) {
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -413,8 +492,10 @@ TEST_F(EcheTrayTest, AcceleratorKeyHandled_Ctrl_C) {
 }
 
 TEST_F(EcheTrayTest, AcceleratorKeyHandled_Ctrl_V) {
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -431,8 +512,10 @@ TEST_F(EcheTrayTest, AcceleratorKeyHandled_Ctrl_V) {
 }
 
 TEST_F(EcheTrayTest, AcceleratorKeyHandled_Ctrl_X) {
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -452,8 +535,10 @@ TEST_F(EcheTrayTest, AcceleratorKeyHandled_BROWSER_BACK_KEY) {
   ResetWebContentGoBack();
   eche_tray()->SetGracefulGoBackCallback(
       base::BindRepeating(&WebContentGoBack));
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   GetEventGenerator()->PressKey(ui::KeyboardCode::VKEY_BROWSER_BACK, 0);
@@ -464,8 +549,10 @@ TEST_F(EcheTrayTest, AcceleratorKeyHandled_BROWSER_BACK_KEY) {
 TEST_F(EcheTrayTest, AcceleratorKeyHandled_Esc) {
   ResetUnloadWebContent();
   eche_tray()->SetGracefulCloseCallback(base::BindOnce(&UnloadWebContent));
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(
@@ -481,8 +568,10 @@ TEST_F(EcheTrayTest, AcceleratorKeyHandled_Esc) {
 TEST_F(EcheTrayTest, EcheTrayOnDisplayConfigurationChanged) {
   UpdateDisplay("800x600");
   gfx::Size expected_eche_size = eche_tray()->CalculateSizeForEche();
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_EQ(expected_eche_size.width(),
@@ -505,8 +594,10 @@ TEST_F(EcheTrayTest, EcheTrayOnDisplayConfigurationChanged) {
 
 TEST_F(EcheTrayTest, EcheTrayKeyboardShowHideUpdateBubbleBounds) {
   gfx::Size expected_eche_size = eche_tray()->CalculateSizeForEche();
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_EQ(expected_eche_size.width(),
@@ -533,10 +624,100 @@ TEST_F(EcheTrayTest, EcheTrayKeyboardShowHideUpdateBubbleBounds) {
       eche_tray()->get_web_view_for_test()->height() + kBubbleMenuPadding * 2);
 }
 
+TEST_F(EcheTrayTest, EcheTrayOnStreamOrientationChanged) {
+  gfx::Size expected_eche_size = eche_tray()->CalculateSizeForEche();
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
+  eche_tray()->ShowBubble();
+
+  EXPECT_EQ(eche_tray()->get_is_landscape_for_test(), false);
+  EXPECT_EQ(expected_eche_size.width(),
+            eche_tray()->get_bubble_wrapper_for_test()->bubble_view()->width());
+  EXPECT_EQ(
+      expected_eche_size.height(),
+      eche_tray()->get_web_view_for_test()->height() + kBubbleMenuPadding * 2);
+
+  // Orientation should stay the same
+  eche_tray()->OnStreamOrientationChanged(false);
+  EXPECT_EQ(eche_tray()->get_is_landscape_for_test(), false);
+
+  expected_eche_size = eche_tray()->CalculateSizeForEche();
+
+  EXPECT_EQ(expected_eche_size.width(),
+            eche_tray()->get_bubble_wrapper_for_test()->bubble_view()->width());
+  EXPECT_EQ(
+      expected_eche_size.height(),
+      eche_tray()->get_web_view_for_test()->height() + kBubbleMenuPadding * 2);
+
+  // Change orientation
+  eche_tray()->OnStreamOrientationChanged(true);
+  EXPECT_EQ(eche_tray()->get_is_landscape_for_test(), true);
+
+  expected_eche_size = eche_tray()->CalculateSizeForEche();
+  EXPECT_EQ(
+      expected_eche_size.width(),
+      eche_tray()->get_web_view_for_test()->width() + kBubbleMenuPadding * 2);
+  EXPECT_EQ(
+      expected_eche_size.height(),
+      eche_tray()->get_web_view_for_test()->height() + kBubbleMenuPadding * 2);
+}
+
+TEST_F(EcheTrayTest, OnRequestBackgroundConnectionAttempt) {
+  ResetUnloadWebContent();
+
+  EXPECT_FALSE(eche_tray()->is_active());
+  EXPECT_FALSE(eche_tray()->get_initializer_webview_for_test());
+
+  eche_tray()->OnRequestBackgroundConnectionAttempt();
+
+  EXPECT_TRUE(eche_tray()->get_initializer_webview_for_test());
+  EXPECT_FALSE(eche_tray()->is_active());
+}
+
+TEST_F(EcheTrayTest, OnRequestBackgroundConnectionAttemptFlagDisabled) {
+  feature_list_.Reset();
+  feature_list_.InitWithFeatures(
+      /*enabled_features=*/{features::kEcheSWA},
+      /*disabled_features=*/{features::kEcheNetworkConnectionState});
+
+  ResetUnloadWebContent();
+
+  EXPECT_FALSE(eche_tray()->is_active());
+  EXPECT_FALSE(eche_tray()->get_initializer_webview_for_test());
+
+  eche_tray()->OnRequestBackgroundConnectionAttempt();
+
+  EXPECT_FALSE(eche_tray()->get_initializer_webview_for_test());
+  EXPECT_FALSE(eche_tray()->is_active());
+}
+
+TEST_F(EcheTrayTest, OnConnectionStatusChanged) {
+  EXPECT_EQ(GetLastConnectionChangedForUiStatus(),
+            ConnectionStatus::kConnectionStatusDisconnected);
+  EXPECT_EQ(GetNumConnectionStatusForUiChangedCalls(), 0u);
+
+  eche_tray()->OnRequestBackgroundConnectionAttempt();
+
+  eche_tray()->OnConnectionStatusChanged(
+      ConnectionStatus::kConnectionStatusConnecting);
+
+  EXPECT_EQ(GetNumConnectionStatusForUiChangedCalls(), 0u);
+  EXPECT_TRUE(eche_tray()->get_initializer_webview_for_test());
+
+  eche_tray()->OnConnectionStatusChanged(
+      ConnectionStatus::kConnectionStatusConnected);
+  EXPECT_EQ(GetNumConnectionStatusForUiChangedCalls(), 1u);
+  EXPECT_TRUE(eche_tray()->get_initializer_webview_for_test());
+}
+
 TEST_F(EcheTrayTest, DISABLED_OnThemeChanged) {
   ResetUnloadWebContent();
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
   eche_tray()->ShowBubble();
 
   EXPECT_TRUE(eche_tray()->is_active());
@@ -563,8 +744,10 @@ TEST_F(EcheTrayTest, DISABLED_OnThemeChanged) {
 
 TEST_F(EcheTrayTest, OnThemeChangedNoBubble) {
   ResetUnloadWebContent();
-  eche_tray()->LoadBubble(GURL("http://google.com"), CreateTestImage(),
-                          u"app 1", u"your phone");
+  eche_tray()->LoadBubble(
+      GURL("http://google.com"), CreateTestImage(), u"app 1", u"your phone",
+      eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+      eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST);
 
   eche_tray()->ShowBubble();
   EXPECT_TRUE(eche_tray()->is_active());
