@@ -15,8 +15,11 @@ namespace ash {
 // Handles reading and updating prefs that store keyboard settings.
 class ASH_EXPORT KeyboardPrefHandler {
  public:
+  virtual ~KeyboardPrefHandler() = default;
+
   // Initializes device settings in prefs and update the `settings` member of
   // the `mojom::Keyboard` object.
+  // If `pref_service` is null, sets the `settings` member to default settings.
   virtual void InitializeKeyboardSettings(PrefService* pref_service,
                                           mojom::Keyboard* keyboard) = 0;
 
@@ -24,9 +27,6 @@ class ASH_EXPORT KeyboardPrefHandler {
   // `keyboard.settings`.
   virtual void UpdateKeyboardSettings(PrefService* pref_service,
                                       const mojom::Keyboard& keyboard) = 0;
-
- protected:
-  virtual ~KeyboardPrefHandler() = default;
 };
 
 }  // namespace ash
