@@ -32,6 +32,13 @@ class ASH_EXPORT KeyboardBacklightColorController
       public SessionObserver,
       public WallpaperControllerObserver {
  public:
+  // Used to indicate which display type is being set on the keyboard.
+  // TODO(b/266588717): Add a new value for rainbow color option.
+  enum class DisplayType {
+    kStatic = 0,
+    kMultiZone = 1,
+  };
+
   // Default brightness to be set by the `KeyboardBacklightColorController` when
   // the backlight is off and the user configures a new color.
   static constexpr double kDefaultBacklightBrightness = 40.0;
@@ -48,7 +55,10 @@ class ASH_EXPORT KeyboardBacklightColorController
   // Register the pref to store keyboard color in the given registry.
   static void RegisterPrefs(PrefRegistrySimple* registry);
 
-  // Sets the keyboard backlight color for the user with |account_id|.
+  // Sets the keyboard backlight color for the user with |account_id|. This call
+  // also invokes |UpdateAllBacklightZoneColors| to populate the color for all
+  // the zones so that when a zone is customized, we still have the info of what
+  // the correct colors for other zones should be.
   void SetBacklightColor(
       personalization_app::mojom::BacklightColor backlight_color,
       const AccountId& account_id);
@@ -57,6 +67,22 @@ class ASH_EXPORT KeyboardBacklightColorController
   personalization_app::mojom::BacklightColor GetBacklightColor(
       const AccountId& account_id);
 
+  // Sets the color of the |zone| for the user with |account_id|.
+  void SetBacklightZoneColor(
+      int zone,
+      personalization_app::mojom::BacklightColor backlight_color,
+      const AccountId& account_id);
+
+  // Returns all the zone colors. The order of the colors corresponds to the
+  // order of the zones. The size of the vector is guaranteed to be the same as
+  // |RgbKeyboardManager::GetZoneCount()|.
+  std::vector<personalization_app::mojom::BacklightColor>
+  GetBacklightZoneColors(const AccountId& account_id);
+
+  // Returns the current keyboard backlight color display type for user with
+  // |account_id|.
+  DisplayType GetDisplayType(const AccountId& account_id);
+
   // RgbKeyboardManagerObserver:
   void OnRgbKeyboardSupportedChanged(bool supported) override;
 
@@ -84,11 +110,33 @@ class ASH_EXPORT KeyboardBacklightColorController
   void DisplayBacklightColor(
       personalization_app::mojom::BacklightColor backlight_color);
 
+  // Displays the |backlight_color| at the specific |zone| on the keyboard.
+  void DisplayBacklightZoneColor(
+      int zone,
+      personalization_app::mojom::BacklightColor backlight_color);
+
   // Sets the keyboard backlight color pref for user with |account_id|.
   void SetBacklightColorPref(
       personalization_app::mojom::BacklightColor backlight_color,
       const AccountId& account_id);
 
+  // Updates all the zone colors to be |backlight_color| in pref for the user
+  // with |account_id|.
+  void UpdateAllBacklightZoneColors(
+      personalization_app::mojom::BacklightColor backlight_color,
+      const AccountId& account_id);
+
+  // Updates the keyboard backlight color zone pref at given |zone| for the user
+  // with |account_id|.
+  void UpdateBacklightZoneColorPref(
+      int zone,
+      personalization_app::mojom::BacklightColor backlight_color,
+      const AccountId& account_id);
+
+  // Used inside |SetBacklightColor()| and |SetBacklightZoneColors()| to set
+  // the keyboard backlight color display type for user with |account_id|.
+  void SetDisplayType(DisplayType type, const AccountId& account_id);
+
   // Toggles on the keyboard brightness at 40% if the backlight is off.
   void MaybeToggleOnKeyboardBrightness();
 
