@@ -67,12 +67,12 @@ class ASH_EXPORT MediaTray : public MediaNotificationProviderObserver,
   void UpdateAfterLoginStatusChange() override;
   void HandleLocaleChange() override;
   views::Widget* GetBubbleWidget() const override;
+  TrayBubbleView* GetBubbleView() override;
   void ShowBubble() override;
   void CloseBubble() override;
   void HideBubbleWithView(const TrayBubbleView* bubble_view) override;
   void ClickedOutsideBubble() override;
   void AnchorUpdated() override;
-  void OnThemeChanged() override;
 
   // SessionObserver implementation.
   void OnLockStateChanged(bool locked) override;
