@@ -31,11 +31,14 @@
 #include "ash/system/message_center/metrics_utils.h"
 #include "ash/system/message_center/notification_grouping_controller.h"
 #include "ash/wm/work_area_insets.h"
+#include "base/base64.h"
 #include "base/check.h"
 #include "base/functional/bind.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/ranges/algorithm.h"
+#include "base/strings/strcat.h"
 #include "base/time/time.h"
+#include "ui/base/dragdrop/os_exchange_data.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/metadata/metadata_impl_macros.h"
 #include "ui/color/color_id.h"
@@ -47,6 +50,7 @@
 #include "ui/compositor/layer_animator.h"
 #include "ui/compositor/scoped_animation_duration_scale_mode.h"
 #include "ui/gfx/animation/tween.h"
+#include "ui/gfx/codec/png_codec.h"
 #include "ui/gfx/color_utils.h"
 #include "ui/gfx/font.h"
 #include "ui/gfx/geometry/insets.h"
@@ -65,6 +69,7 @@
 #include "ui/message_center/public/cpp/message_center_constants.h"
 #include "ui/message_center/public/cpp/notification.h"
 #include "ui/message_center/vector_icons.h"
+#include "ui/message_center/views/large_image_view.h"
 #include "ui/message_center/views/notification_background_painter.h"
 #include "ui/message_center/views/notification_control_buttons_view.h"
 #include "ui/message_center/views/notification_header_view.h"
@@ -76,6 +81,7 @@
 #include "ui/views/background.h"
 #include "ui/views/controls/focus_ring.h"
 #include "ui/views/controls/label.h"
+#include "ui/views/controls/progress_bar.h"
 #include "ui/views/controls/scroll_view.h"
 #include "ui/views/controls/textfield/textfield.h"
 #include "ui/views/drag_utils.h"
@@ -93,7 +99,14 @@
 
 namespace {
 
-constexpr auto kNotificationViewPadding = gfx::Insets(4);
+// Used when encoding a notification drop image into binary data. The drop image
+// should be resized if its binary size exceeds this limit.
+// Use 1 MB as the size limit. On a 256 color image, each pixel takes four bytes
+// (RGB + Alpha). The size limit of 1 MB means the maximum pixel count being
+// 250K, which should be enough for most notification images without file
+// backing.
+constexpr size_t kMaxImageSizeInByte = 1000000;
+
 constexpr int kMainRightViewVerticalSpacing = 4;
 
 // This padding is applied to all the children of `main_right_view_` except the
@@ -108,7 +121,8 @@ constexpr int kActionsRowHorizontalSpacing = 8;
 constexpr auto kContentRowPadding = gfx::Insets::TLBR(16, 0, 0, 0);
 
 constexpr int kLeftContentVerticalSpacing = 4;
-constexpr int kTitleRowMinimumWidth = 186;
+constexpr int kTitleRowMinimumWidthWithIcon = 186;
+constexpr int kTitleRowMinimumWidth = 266;
 constexpr int kTitleRowSpacing = 6;
 
 constexpr auto kHeaderRowExpandedPadding = gfx::Insets::TLBR(4, 0, 8, 0);
@@ -250,6 +264,26 @@ void ScaleAndTranslateView(views::View* view,
       .SetTransform(view, gfx::Transform(), gfx::Tween::ACCEL_0_100_DECEL_80);
 }
 
+// Returns the HTML snippet that contains the binary data of `bitmap`. Returns
+// `absl::nullopt` if having any error.
+absl::optional<std::u16string> GetHtmlForBitmap(const SkBitmap& bitmap) {
+  std::vector<unsigned char> image_data;
+  if (gfx::PNGCodec::EncodeBGRASkBitmap(bitmap, /*discard_transparency=*/false,
+                                        &image_data)) {
+    std::string encoded_data;
+    base::Base64Encode(
+        /*input=*/std::string(image_data.cbegin(), image_data.cend()),
+        &encoded_data);
+    const std::string html = base::StrCat(
+        {"<img src=\"data:image/png;base64,", encoded_data, "\"/>"});
+    std::u16string html_in_u16;
+    if (base::UTF8ToUTF16(html.c_str(), html.size(), &html_in_u16)) {
+      return html_in_u16;
+    }
+  }
+  return absl::nullopt;
+}
+
 }  // namespace
 
 namespace ash {
@@ -262,6 +296,8 @@ BEGIN_METADATA(AshNotificationView, NotificationTitleRow, views::View)
 END_METADATA
 
 void AshNotificationView::AddedToWidget() {
+  MessageView::AddedToWidget();
+
   // crbug/1337661: We need to abort animations in a grouped parent view when
   // it's widget is being destroyed. By default when a widget is destroyed, all
   // current animations are forced to finish. The grouped notification removal
@@ -386,6 +422,11 @@ void AshNotificationView::NotificationTitleRow::
   }
 }
 
+void AshNotificationView::NotificationTitleRow::SetMaxAvailableWidth(
+    int max_available_width) {
+  max_available_width_ = max_available_width;
+}
+
 gfx::Size AshNotificationView::NotificationTitleRow::CalculatePreferredSize()
     const {
   // TODO(crbug.com/1349528): The size constraint is not passed down from the
@@ -393,8 +434,8 @@ gfx::Size AshNotificationView::NotificationTitleRow::CalculatePreferredSize()
   // the view. The layout manager can size the view beyond this width if there
   // is available space. This works similar to applying a max width on the
   // internal labels.
-  return gfx::Size(kTitleRowMinimumWidth,
-                   GetHeightForWidth(kTitleRowMinimumWidth));
+  return gfx::Size(max_available_width_,
+                   GetHeightForWidth(max_available_width_));
 }
 
 void AshNotificationView::NotificationTitleRow::OnThemeChanged() {
@@ -823,23 +864,27 @@ absl::optional<gfx::ImageSkia> AshNotificationView::GetDragImage() {
     return absl::nullopt;
   }
 
-  // Assume that an Ash notification has at most one large image view.
-  views::View* large_image_view =
-      GetViewByID(message_center::NotificationViewBase::kLargeImageView);
+  // Assume that an Ash notification has at most one large image view. Fetch the
+  // image shown in the large image view.
+  return static_cast<message_center::LargeImageView*>(
+             GetViewByID(message_center::NotificationViewBase::kLargeImageView))
+      ->drawn_image();
+}
 
-  // Paint `large_image_view` on a bitmap.
-  const gfx::Size& image_view_size = large_image_view->size();
-  const views::Widget* widget = GetWidget();
-  const float scale = views::ScaleFactorForDragFromWidget(widget);
-  SkBitmap bitmap;
-  large_image_view->Paint(views::PaintInfo::CreateRootPaintInfo(
-      ui::CanvasPainter(&bitmap, image_view_size, scale,
-                        /*clear_color=*/SK_ColorTRANSPARENT,
-                        widget->GetCompositor()->is_pixel_canvas())
-          .context(),
-      image_view_size));
+void AshNotificationView::AttachDropData(ui::OSExchangeData* data) {
+  DCHECK(IsDraggable());
 
-  return gfx::ImageSkia::CreateFromBitmap(bitmap, scale);
+  // If the notification large image is file-backed, attach the image file path
+  // to `data`; otherwise, attach the large image's binary data.
+  if (const absl::optional<base::FilePath>& image_path =
+          message_center::MessageCenter::Get()
+              ->FindNotificationById(notification_id())
+              ->rich_notification_data()
+              .image_path) {
+    data->SetFilename(*image_path);
+  } else {
+    AttachBinaryImageAsDropData(data);
+  }
 }
 
 bool AshNotificationView::IsDraggable() const {
@@ -1044,6 +1089,20 @@ void AshNotificationView::UpdateViewForExpandedState(bool expanded) {
                                                  !is_grouped_parent_view_);
   }
 
+  if (progress_bar_view()) {
+    int progress_bar_bottom_padding;
+    if (!action_buttons().empty()) {
+      progress_bar_bottom_padding = kProgressBarWithActionButtonsBottomPadding;
+    } else if (use_expanded_padding) {
+      progress_bar_bottom_padding = kProgressBarExpandedBottomPadding;
+    } else {
+      progress_bar_bottom_padding = kProgressBarCollapsedBottomPadding;
+    }
+    progress_bar_view()->SetBorder(views::CreateEmptyBorder(
+        gfx::Insets::TLBR(message_center::kProgressBarTopPadding, 0,
+                          progress_bar_bottom_padding, 0)));
+  }
+
   // Custom padding for app icon and expand button. These 2 views should always
   // use the same padding value so that they are vertical aligned.
   app_icon_view_->SetProperty(views::kMarginsKey,
@@ -1176,6 +1235,15 @@ void AshNotificationView::CreateOrUpdateTitleView(
     ReorderViewInLeftContent(title_row_);
   }
 
+  int max_available_width = notification.icon().IsEmpty()
+                                ? kTitleRowMinimumWidth
+                                : kTitleRowMinimumWidthWithIcon;
+  if (shown_in_popup_) {
+    max_available_width -=
+        message_center::kNotificationWidth - kNotificationInMessageCenterWidth;
+  }
+  title_row_->SetMaxAvailableWidth(max_available_width);
+
   title_row_->UpdateTimestamp(notification.timestamp());
 }
 
@@ -1238,6 +1306,11 @@ void AshNotificationView::CreateOrUpdateProgressViews(
   // bar. This is the opposite of what is required of the chrome notification.
   CreateOrUpdateProgressStatusView(notification);
   CreateOrUpdateProgressBarView(notification);
+
+  if (status_view()) {
+    status_view()->SetMultiLine(true);
+    status_view()->SetMaxLines(message_center::kMaxLinesForStatusView);
+  }
 }
 
 void AshNotificationView::UpdateControlButtonsVisibility() {
@@ -2015,4 +2088,27 @@ bool AshNotificationView::IsMessageLabelTruncated() {
   return text_width > left_content()->width();
 }
 
+void AshNotificationView::AttachBinaryImageAsDropData(
+    ui::OSExchangeData* data) {
+  DCHECK(IsDraggable());
+
+  // Fetch the original image from the large image view.
+  const gfx::ImageSkia& image =
+      static_cast<message_center::LargeImageView*>(
+          GetViewByID(message_center::NotificationViewBase::kLargeImageView))
+          ->original_image();
+  DCHECK(!image.size().IsEmpty());
+
+  // Resize `image` if necessary.
+  absl::optional<gfx::ImageSkia> resized_image =
+      message_center_utils::ResizeImageIfExceedSizeLimit(image,
+                                                         kMaxImageSizeInByte);
+
+  // Add the drop data in the format of HTML.
+  if (const absl::optional<std::u16string> html_snippet = GetHtmlForBitmap(
+          resized_image ? *resized_image->bitmap() : *image.bitmap())) {
+    data->SetHtml(*html_snippet, /*base_url=*/GURL());
+  }
+}
+
 }  // namespace ash
