@@ -18,10 +18,9 @@
 #include "ui/color/color_id.h"
 #include "ui/compositor/scoped_animation_duration_scale_mode.h"
 #include "ui/compositor/test/layer_animation_stopped_waiter.h"
-#include "ui/events/test/event_generator.h"
-#include "ui/gfx/geometry/vector2d.h"
 #include "ui/gfx/vector_icon_types.h"
 #include "ui/message_center/public/cpp/message_center_constants.h"
+#include "ui/message_center/public/cpp/notification_types.h"
 #include "ui/message_center/public/cpp/notifier_id.h"
 #include "ui/message_center/views/message_popup_view.h"
 #include "ui/views/animation/slide_out_controller.h"
@@ -306,6 +305,34 @@ TEST_P(NotificationGroupingControllerTest, ParentNotificationMetadata) {
   EXPECT_EQ(&icon, &parent_notification->vector_small_image());
 }
 
+// Parent notification's priority should always match the priority of the last
+// added notification to the group.
+TEST_P(NotificationGroupingControllerTest, ParentNotificationPriority) {
+  auto* message_center = MessageCenter::Get();
+  std::string id1, id2, id3;
+  const GURL url(u"http://test-url.com/");
+
+  auto notification = MakeNotification(id1, url);
+  notification->set_priority(message_center::LOW_PRIORITY);
+  message_center->AddNotification(std::move(notification));
+
+  auto notification2 = MakeNotification(id2, url);
+  notification2->set_priority(message_center::LOW_PRIORITY);
+  message_center->AddNotification(std::move(notification2));
+
+  auto* parent_notification = message_center->FindNotificationById(
+      id1 + kIdSuffixForGroupContainerNotification);
+  EXPECT_TRUE(parent_notification->group_parent());
+
+  EXPECT_EQ(message_center::LOW_PRIORITY, parent_notification->priority());
+
+  auto notification3 = MakeNotification(id3, url);
+  notification3->set_priority(message_center::HIGH_PRIORITY);
+  message_center->AddNotification(std::move(notification3));
+
+  EXPECT_EQ(message_center::HIGH_PRIORITY, parent_notification->priority());
+}
+
 TEST_P(NotificationGroupingControllerTest,
        NotificationsGroupingOnMultipleScreens) {
   UpdateDisplay("800x600,800x600");
@@ -515,7 +542,8 @@ TEST_P(NotificationGroupingControllerTest, ChildNotificationUpdate) {
 // When the last child of the group notification is removed, its parent
 // notification should be removed as well. We are testing in the case where
 // there is no popup or notification center is not showing.
-TEST_P(NotificationGroupingControllerTest, ChildNotificationRemove) {
+// TODO(crbug.com/1417929): Re-enable this test
+TEST_P(NotificationGroupingControllerTest, DISABLED_ChildNotificationRemove) {
   auto* message_center = MessageCenter::Get();
   std::string id0, id1;
   const GURL url(u"http://test-url.com/");
@@ -543,4 +571,50 @@ TEST_P(NotificationGroupingControllerTest, ChildNotificationRemove) {
   EXPECT_FALSE(message_center->FindNotificationById(id0));
 }
 
+TEST_P(NotificationGroupingControllerTest,
+       ChildNotificationsWithDifferentPriorities) {
+  auto* message_center = MessageCenter::Get();
+  std::string id0, id1, id2;
+  const GURL url(u"http://test-url.com/");
+
+  // Create 2 notifications with low priority, the parent notification should be
+  // low priority as well.
+  auto notification = MakeNotification(id0, url);
+  notification->set_priority(message_center::LOW_PRIORITY);
+  message_center->AddNotification(std::move(notification));
+
+  notification = MakeNotification(id1, url);
+  notification->set_priority(message_center::LOW_PRIORITY);
+  message_center->AddNotification(std::move(notification));
+
+  std::string id_parent = id0 + kIdSuffixForGroupContainerNotification;
+  auto* parent_notification = message_center->FindNotificationById(id_parent);
+  ASSERT_TRUE(parent_notification->group_parent());
+  ASSERT_EQ(message_center::LOW_PRIORITY, parent_notification->priority());
+
+  // Now create another notification in the group with normal priority. Parent
+  // should still have the same id and have normal priority now.
+  id2 = AddNotificationWithOriginUrl(url);
+  parent_notification = message_center->FindNotificationById(id_parent);
+  ASSERT_TRUE(parent_notification);
+  ASSERT_EQ(message_center::DEFAULT_PRIORITY, parent_notification->priority());
+
+  // There should be 4 notifications now (no duplicates created).
+  EXPECT_EQ(4u, message_center->GetVisibleNotifications().size());
+
+  // Remove one child then add back. Parent notification is still retained with
+  // same id.
+  message_center->RemoveNotification(id0,
+                                     /*by_user=*/false);
+  notification = MakeNotification(id0, url);
+  notification->set_priority(message_center::LOW_PRIORITY);
+  message_center->AddNotification(std::move(notification));
+
+  parent_notification = message_center->FindNotificationById(id_parent);
+  ASSERT_TRUE(parent_notification->group_parent());
+
+  // Should have no duplicates.
+  EXPECT_EQ(4u, message_center->GetVisibleNotifications().size());
+}
+
 }  // namespace ash
