@@ -4,6 +4,8 @@
 //
 #include "ash/system/network/unified_vpn_detailed_view_controller.h"
 
+#include <memory>
+
 #include "ash/session/session_controller_impl.h"
 #include "ash/shell.h"
 #include "ash/strings/grit/ash_strings.h"
@@ -21,12 +23,14 @@ UnifiedVPNDetailedViewController::UnifiedVPNDetailedViewController(
 
 UnifiedVPNDetailedViewController::~UnifiedVPNDetailedViewController() = default;
 
-views::View* UnifiedVPNDetailedViewController::CreateView() {
+std::unique_ptr<views::View> UnifiedVPNDetailedViewController::CreateView() {
   DCHECK(!view_);
-  view_ = new VPNListView(detailed_view_delegate_.get(),
-                          Shell::Get()->session_controller()->login_status());
+  auto view = std::make_unique<VPNListView>(
+      detailed_view_delegate_.get(),
+      Shell::Get()->session_controller()->login_status());
+  view_ = view.get();
   view_->Init();
-  return view_;
+  return view;
 }
 
 std::u16string UnifiedVPNDetailedViewController::GetAccessibleName() const {
