@@ -4,21 +4,22 @@
 
 #include "ash/system/network/vpn_feature_pod_controller.h"
 
+#include <string>
+
+#include "ash/constants/ash_features.h"
 #include "ash/constants/quick_settings_catalogs.h"
 #include "ash/resources/vector_icons/vector_icons.h"
-#include "ash/session/session_controller_impl.h"
 #include "ash/shell.h"
 #include "ash/strings/grit/ash_strings.h"
 #include "ash/system/model/system_tray_model.h"
-#include "ash/system/network/network_icon.h"
 #include "ash/system/network/tray_network_state_model.h"
 #include "ash/system/network/vpn_list.h"
-#include "ash/system/tray/tray_constants.h"
 #include "ash/system/unified/feature_pod_button.h"
+#include "ash/system/unified/feature_tile.h"
+#include "ash/system/unified/quick_settings_metrics_util.h"
 #include "ash/system/unified/unified_system_tray_controller.h"
 #include "chromeos/services/network_config/public/mojom/cros_network_config.mojom.h"
 #include "ui/base/l10n/l10n_util.h"
-#include "ui/gfx/paint_vector_icon.h"
 
 using chromeos::network_config::mojom::ConnectionStateType;
 using chromeos::network_config::mojom::NetworkStateProperties;
@@ -62,10 +63,35 @@ FeaturePodButton* VPNFeaturePodController::CreateButton() {
       l10n_util::GetStringUTF16(IDS_ASH_STATUS_TRAY_VPN_TOOLTIP));
   button_->ShowDetailedViewArrow();
   button_->DisableLabelButtonFocus();
+  // Init the button with invisible state. The `Update` method will update the
+  // visibility based on the current condition.
+  button_->SetVisible(false);
   Update();
   return button_;
 }
 
+std::unique_ptr<FeatureTile> VPNFeaturePodController::CreateTile(bool compact) {
+  DCHECK(features::IsQsRevampEnabled());
+  DCHECK(!tile_);
+  auto tile = std::make_unique<FeatureTile>(
+      base::BindRepeating(&FeaturePodControllerBase::OnIconPressed,
+                          weak_ptr_factory_.GetWeakPtr()));
+  tile_ = tile.get();
+  tile_->SetVectorIcon(kUnifiedMenuVpnIcon);
+  tile_->SetLabel(l10n_util::GetStringUTF16(IDS_ASH_STATUS_TRAY_VPN_SHORT));
+  const std::u16string tooltip =
+      l10n_util::GetStringUTF16(IDS_ASH_STATUS_TRAY_VPN_TOOLTIP);
+  tile_->SetTooltipText(tooltip);
+  tile_->CreateDrillInButton(
+      base::BindRepeating(&FeaturePodControllerBase::OnLabelPressed,
+                          weak_ptr_factory_.GetWeakPtr()),
+      tooltip);
+  // Init the tile with invisible state. `Update()` will update visibility.
+  tile_->SetVisible(false);
+  Update();
+  return tile;
+}
+
 QsFeatureCatalogName VPNFeaturePodController::GetCatalogName() {
   return QsFeatureCatalogName::kVPN;
 }
@@ -80,18 +106,37 @@ void VPNFeaturePodController::ActiveNetworkStateChanged() {
 }
 
 void VPNFeaturePodController::Update() {
-  button_->SetVisible(IsVPNVisibleInSystemTray());
-  if (!button_->GetVisible())
+  const bool is_vpn_visible = IsVPNVisibleInSystemTray();
+
+  // Log UMA metrics if the tile/button changes from invisible to visible.
+  if (features::IsQsRevampEnabled()) {
+    if (!tile_->GetVisible() && is_vpn_visible)
+      TrackVisibilityUMA();
+    tile_->SetVisible(is_vpn_visible);
+  } else {
+    if (!button_->GetVisible() && is_vpn_visible)
+      TrackVisibilityUMA();
+    button_->SetVisible(is_vpn_visible);
+  }
+
+  // No need to update label/toggle state if the button/tile isn't visible.
+  if (!is_vpn_visible)
     return;
 
   const NetworkStateProperties* vpn =
       Shell::Get()->system_tray_model()->network_state_model()->active_vpn();
-  bool is_active =
+  const bool is_active =
       vpn && vpn->connection_state != ConnectionStateType::kNotConnected;
-  button_->SetSubLabel(l10n_util::GetStringUTF16(
+  const std::u16string sub_label = l10n_util::GetStringUTF16(
       is_active ? IDS_ASH_STATUS_TRAY_VPN_CONNECTED_SHORT
-                : IDS_ASH_STATUS_TRAY_VPN_DISCONNECTED_SHORT));
-  button_->SetToggled(is_active);
+                : IDS_ASH_STATUS_TRAY_VPN_DISCONNECTED_SHORT);
+  if (features::IsQsRevampEnabled()) {
+    tile_->SetSubLabel(sub_label);
+    tile_->SetToggled(is_active);
+  } else {
+    button_->SetSubLabel(sub_label);
+    button_->SetToggled(is_active);
+  }
 }
 
 }  // namespace ash
