@@ -19,9 +19,9 @@
 #include "ash/system/tray/tray_constants.h"
 #include "ash/system/unified/unified_system_tray_model.h"
 #include "base/auto_reset.h"
-#include "base/callback_forward.h"
-#include "base/callback_helpers.h"
 #include "base/containers/adapters.h"
+#include "base/functional/callback_forward.h"
+#include "base/functional/callback_helpers.h"
 #include "base/memory/scoped_refptr.h"
 #include "base/metrics/histogram_functions.h"
 #include "base/metrics/histogram_macros.h"
@@ -31,6 +31,8 @@
 #include "ui/compositor/compositor.h"
 #include "ui/gfx/animation/linear_animation.h"
 #include "ui/gfx/canvas.h"
+#include "ui/message_center/message_center.h"
+#include "ui/message_center/notification_list.h"
 #include "ui/message_center/notification_view_controller.h"
 #include "ui/message_center/public/cpp/notification_types.h"
 #include "ui/message_center/views/message_view.h"
@@ -76,8 +78,9 @@ void SetupThroughputTrackerForAnimationSmoothness(
     absl::optional<ui::ThroughputTracker>& tracker,
     const char* histogram_name) {
   // `widget` may not exist in tests.
-  if (!widget)
+  if (!widget) {
     return;
+  }
 
   tracker.emplace(widget->GetCompositor()->RequestNewThroughputTracker());
   tracker->Start(ash::metrics_util::ForSmoothness(
@@ -97,9 +100,16 @@ class NotificationListView::MessageViewContainer : public MessageView::Observer,
         list_view_(list_view),
         control_view_(new NotificationSwipeControlView(message_view)) {
     message_view_->AddObserver(this);
-    if (!features::IsNotificationsRefreshEnabled()) {
-      message_view_->SetBackground(
-          views::CreateSolidBackground(SK_ColorTRANSPARENT));
+
+    if (features::IsQsRevampEnabled()) {
+      message_center::ExpandState expand_state =
+          MessageCenter::Get()->GetNotificationExpandState(
+              message_view_->notification_id());
+
+      if (expand_state != message_center::ExpandState::DEFAULT) {
+        message_view_->SetExpanded(expand_state ==
+                                   message_center::ExpandState::USER_EXPANDED);
+      }
     }
 
     SetLayoutManager(std::make_unique<views::FillLayout>());
@@ -115,8 +125,9 @@ class NotificationListView::MessageViewContainer : public MessageView::Observer,
   base::TimeDelta GetBoundsAnimationDuration() const {
     auto* notification = MessageCenter::Get()->FindNotificationById(
         message_view()->notification_id());
-    if (!notification)
+    if (!notification) {
       return base::Milliseconds(0);
+    }
     return message_view()->GetBoundsAnimationDuration(*notification);
   }
 
@@ -124,8 +135,9 @@ class NotificationListView::MessageViewContainer : public MessageView::Observer,
   // at the top or the bottom. If `force_update` is true, ignore previous states
   // and always update the border.
   void UpdateBorder(bool is_top, bool is_bottom, bool force_update) {
-    if (is_top_ == is_top && is_bottom_ == is_bottom && !force_update)
+    if (is_top_ == is_top && is_bottom_ == is_bottom && !force_update) {
       return;
+    }
     is_top_ = is_top;
     is_bottom_ = is_bottom;
 
@@ -166,8 +178,9 @@ class NotificationListView::MessageViewContainer : public MessageView::Observer,
 
   // Collapses the notification if its state haven't changed manually by a user.
   void Collapse() {
-    if (!message_view_->IsManuallyExpandedOrCollapsed())
+    if (!message_view_->IsManuallyExpandedOrCollapsed()) {
       message_view_->SetExpanded(false);
+    }
   }
 
   // Check if the notification is manually expanded / collapsed before and
@@ -179,11 +192,15 @@ class NotificationListView::MessageViewContainer : public MessageView::Observer,
         model->GetNotificationExpanded(GetNotificationId());
     if (manually_expanded.has_value()) {
       message_view_->SetExpanded(manually_expanded.value());
-      message_view_->SetManuallyExpandedOrCollapsed(true);
+      message_view_->SetManuallyExpandedOrCollapsed(
+          manually_expanded.value()
+              ? message_center::ExpandState::USER_EXPANDED
+              : message_center::ExpandState::USER_COLLAPSED);
     } else {
       // Expand the latest notification, and collapse all other notifications.
-      message_view_->SetExpanded(is_latest &&
-                                 message_view_->IsAutoExpandingAllowed());
+      message_view_->SetExpanded(
+          is_latest && message_view_->IsAutoExpandingAllowed() &&
+          !message_view_->IsManuallyExpandedOrCollapsed());
     }
   }
 
@@ -233,25 +250,29 @@ class NotificationListView::MessageViewContainer : public MessageView::Observer,
   // views::View:
   void ChildPreferredSizeChanged(views::View* child) override {
     // If we've already been removed, ignore new child size changes.
-    if (is_removed_)
+    if (is_removed_) {
       return;
+    }
 
     // PreferredSizeChanged will trigger
     // NotificationListView::ChildPreferredSizeChanged.
     base::ScopedClosureRunner defer_preferred_size_changed(base::BindOnce(
         &MessageViewContainer::PreferredSizeChanged, base::Unretained(this)));
 
-    if (!features::IsNotificationsRefreshEnabled())
+    if (!features::IsNotificationsRefreshEnabled()) {
       return;
+    }
 
     // Ignore non user triggered expand/collapses.
-    if (loading_expanded_state_)
+    if (loading_expanded_state_) {
       return;
+    }
 
     auto* notification = MessageCenter::Get()->FindNotificationById(
         message_view()->notification_id());
-    if (!notification)
+    if (!notification) {
       return;
+    }
 
     needs_bounds_animation_ = true;
   }
@@ -293,28 +314,32 @@ class NotificationListView::MessageViewContainer : public MessageView::Observer,
     auto list_child_views = list_view_->children();
 
     above_view_ = (index == 0) ? nullptr : AsMVC(list_child_views[index - 1]);
-    if (above_view_)
+    if (above_view_) {
       above_view_->message_view()->UpdateCornerRadius(
           kMessageCenterNotificationInnerCornerRadius,
           kMessageCenterNotificationTopBottomCornerRadius);
+    }
 
     below_view_ = (index == list_child_views.size() - 1)
                       ? nullptr
                       : AsMVC(list_child_views[index + 1]);
-    if (below_view_)
+    if (below_view_) {
       below_view_->message_view()->UpdateCornerRadius(
           kMessageCenterNotificationTopBottomCornerRadius,
           kMessageCenterNotificationInnerCornerRadius);
+    }
   }
 
   void OnSlideEnded(const std::string& notification_id) override {
     if (!features::IsNotificationsRefreshEnabled() ||
-        notification_id != GetNotificationId())
+        notification_id != GetNotificationId()) {
       return;
+    }
 
     absl::optional<size_t> index = list_view_->GetIndexOf(this);
-    if (!index.has_value())
+    if (!index.has_value()) {
       return;
+    }
     auto list_child_views = list_view_->children();
     above_view_ = (index == size_t{0})
                       ? nullptr
@@ -325,10 +350,12 @@ class NotificationListView::MessageViewContainer : public MessageView::Observer,
 
     // Reset the corner radius of views to their normal state.
     ResetCornerRadius();
-    if (above_view_ && !above_view_->is_slid_out())
+    if (above_view_ && !above_view_->is_slid_out()) {
       above_view_->ResetCornerRadius();
-    if (below_view_ && !below_view_->is_slid_out())
+    }
+    if (below_view_ && !below_view_->is_slid_out()) {
       below_view_->ResetCornerRadius();
+    }
   }
 
   void OnPreSlideOut(const std::string& notification_id) override {
@@ -435,8 +462,15 @@ NotificationListView::NotificationListView(
 NotificationListView::~NotificationListView() {
   if (!features::IsQsRevampEnabled()) {
     model_->ClearNotificationChanges();
-    for (auto* view : children())
-      AsMVC(view)->StoreExpandedState(model_.get());
+    for (auto* view : children()) {
+      auto* mvc = AsMVC(view);
+      // Make sure we only store expanded state for notifications that still
+      // exist.
+      if (message_center::MessageCenter::Get()->FindVisibleNotificationById(
+              mvc->message_view()->notification_id())) {
+        mvc->StoreExpandedState(model_.get());
+      }
+    }
   }
 }
 
@@ -447,13 +481,15 @@ void NotificationListView::Init() {
     auto* view =
         new MessageViewContainer(CreateMessageView(*notification), this);
 
-    // TODO(b/252876795): We cannot use the `UnifiedSystemTrayModel` to store
-    // the expanded state for notifications with QsRevamp since it is owned by
-    // `UnifiedSystemTray` and  notifications are being completely separated
-    // from it. Implement a way to remember collase/expand state for
-    // notifications across popups and notification center.
-    if (!features::IsQsRevampEnabled())
+    if (!features::IsQsRevampEnabled()) {
       view->LoadExpandedState(model_.get(), is_latest);
+    }
+
+    if (features::IsQsRevampEnabled() && is_latest &&
+        !view->message_view()->IsManuallyExpandedOrCollapsed()) {
+      view->message_view()->SetExpanded(
+          view->message_view()->IsAutoExpandingAllowed());
+    }
 
     // The insertion order for notifications will be reversed when
     // is_notifications_refresh_enabled_.
@@ -468,8 +504,10 @@ void NotificationListView::Init() {
 }
 
 void NotificationListView::ClearAllWithAnimation() {
-  if (state_ == State::CLEAR_ALL_STACKED || state_ == State::CLEAR_ALL_VISIBLE)
+  if (state_ == State::CLEAR_ALL_STACKED ||
+      state_ == State::CLEAR_ALL_VISIBLE) {
     return;
+  }
   ResetBounds();
 
   UMA_HISTOGRAM_COUNTS_100("ChromeOS.SystemTray.NotificationsRemovedByClearAll",
@@ -490,8 +528,9 @@ void NotificationListView::ClearAllWithAnimation() {
 
   state_ = State::CLEAR_ALL_STACKED;
   UpdateClearAllAnimation();
-  if (state_ != State::IDLE)
+  if (state_ != State::IDLE) {
     StartAnimation();
+  }
 }
 
 std::vector<message_center::Notification*>
@@ -502,8 +541,9 @@ NotificationListView::GetAllNotifications() const {
     // center.
     auto* notification = MessageCenter::Get()->FindVisibleNotificationById(
         AsMVC(view)->GetNotificationId());
-    if (notification)
+    if (notification) {
       notifications.insert(notifications.begin(), notification);
+    }
   }
   return notifications;
 }
@@ -526,8 +566,9 @@ NotificationListView::GetNotificationsAboveY(int y_offset) const {
     if (bottom_limit <= y_offset) {
       auto* notification = MessageCenter::Get()->FindVisibleNotificationById(
           AsMVC(view)->GetNotificationId());
-      if (notification)
+      if (notification) {
         notifications.insert(notifications.begin(), notification);
+      }
     }
   }
   return notifications;
@@ -542,8 +583,9 @@ NotificationListView::GetNotificationsBelowY(int y_offset) const {
     if (bottom_limit >= y_offset) {
       auto* notification = MessageCenter::Get()->FindVisibleNotificationById(
           AsMVC(view)->GetNotificationId());
-      if (notification)
+      if (notification) {
         notifications.push_back(notification);
+      }
     }
   }
   return notifications;
@@ -555,8 +597,9 @@ std::vector<std::string> NotificationListView::GetNotificationIdsAboveY(
   for (views::View* view : children()) {
     const int bottom_limit =
         view->bounds().y() + kNotificationIconStackThreshold;
-    if (bottom_limit > y_offset)
+    if (bottom_limit > y_offset) {
       continue;
+    }
     notifications.insert(notifications.begin(),
                          AsMVC(view)->GetNotificationId());
   }
@@ -568,8 +611,9 @@ std::vector<std::string> NotificationListView::GetNotificationIdsBelowY(
   std::vector<std::string> notifications;
   for (views::View* view : children()) {
     const int top_of_notification = view->bounds().y();
-    if (top_of_notification < y_offset)
+    if (top_of_notification < y_offset) {
       continue;
+    }
     notifications.insert(notifications.begin(),
                          AsMVC(view)->GetNotificationId());
   }
@@ -583,8 +627,9 @@ int NotificationListView::GetTotalNotificationCount() const {
 int NotificationListView::GetTotalPinnedNotificationCount() const {
   int count = 0;
   for (auto* child : children()) {
-    if (AsMVC(child)->IsPinned())
+    if (AsMVC(child)->IsPinned()) {
       count++;
+    }
   }
   return count;
 }
@@ -595,8 +640,9 @@ bool NotificationListView::IsAnimating() const {
 
 bool NotificationListView::IsAnimatingExpandOrCollapseContainer(
     const views::View* view) const {
-  if (!view || !expand_or_collapsing_container_)
+  if (!view || !expand_or_collapsing_container_) {
     return false;
+  }
 
   DCHECK_EQ(kMessageViewContainerClassName, view->GetClassName())
       << view->GetClassName() << " is not a " << kMessageViewContainerClassName;
@@ -605,8 +651,9 @@ bool NotificationListView::IsAnimatingExpandOrCollapseContainer(
 }
 
 void NotificationListView::ChildPreferredSizeChanged(views::View* child) {
-  if (ignore_size_change_)
+  if (ignore_size_change_) {
     return;
+  }
 
   // No State::EXPAND_OR_COLLAPSE animation in the old UI.
   if (!features::IsNotificationsRefreshEnabled()) {
@@ -632,16 +679,18 @@ void NotificationListView::ChildPreferredSizeChanged(views::View* child) {
     return;
   }
 
-  if (state_ == State::EXPAND_OR_COLLAPSE)
+  if (state_ == State::EXPAND_OR_COLLAPSE) {
     return;
+  }
 
   ResetBounds();
 }
 
 void NotificationListView::PreferredSizeChanged() {
   views::View::PreferredSizeChanged();
-  if (message_center_view_)
+  if (message_center_view_) {
     message_center_view_->ListPreferredSizeChanged();
+  }
 }
 
 void NotificationListView::Layout() {
@@ -659,8 +708,9 @@ void NotificationListView::Layout() {
 gfx::Rect NotificationListView::GetNotificationBounds(
     const std::string& notification_id) const {
   const MessageViewContainer* child = nullptr;
-  if (!notification_id.empty())
+  if (!notification_id.empty()) {
     child = GetNotificationById(notification_id);
+  }
   return child ? child->bounds() : GetLastNotificationBounds();
 }
 
@@ -677,8 +727,9 @@ gfx::Rect NotificationListView::GetNotificationBoundsBelowY(
 }
 
 gfx::Size NotificationListView::CalculatePreferredSize() const {
-  if (state_ == State::IDLE)
+  if (state_ == State::IDLE) {
     return gfx::Size(message_view_width_, target_height_);
+  }
 
   return gfx::Size(message_view_width_,
                    gfx::Tween::IntValueBetween(GetCurrentValue(), start_height_,
@@ -694,14 +745,13 @@ message_center::MessageView*
 NotificationListView::GetMessageViewForNotificationId(const std::string& id) {
   auto it = base::ranges::find(children(), id, [](auto* child) {
     DCHECK(child->GetClassName() == kMessageViewContainerClassName);
-    return static_cast<MessageViewContainer*>(child)
-        ->message_view()
-        ->notification_id();
+    return AsMVC(child)->message_view()->notification_id();
   });
 
-  if (it == children().end())
+  if (it == children().end()) {
     return nullptr;
-  return static_cast<MessageViewContainer*>(*it)->message_view();
+  }
+  return AsMVC(*it)->message_view();
 }
 
 void NotificationListView::ConvertNotificationViewToGroupedNotificationView(
@@ -709,8 +759,9 @@ void NotificationListView::ConvertNotificationViewToGroupedNotificationView(
     const std::string& new_grouped_notification_id) {
   auto* message_view =
       GetMessageViewForNotificationId(ungrouped_notification_id);
-  if (message_view)
+  if (message_view) {
     message_view->set_notification_id(new_grouped_notification_id);
+  }
 }
 
 void NotificationListView::ConvertGroupedNotificationViewToNotificationView(
@@ -722,12 +773,14 @@ void NotificationListView::ConvertGroupedNotificationViewToNotificationView(
 
 void NotificationListView::OnNotificationAdded(const std::string& id) {
   auto* notification = MessageCenter::Get()->FindVisibleNotificationById(id);
-  if (!notification)
+  if (!notification) {
     return;
+  }
 
   // A group child notification should be added to its parent's message view.
-  if (is_notifications_refresh_enabled_ && notification->group_child())
+  if (is_notifications_refresh_enabled_ && notification->group_child()) {
     return;
+  }
 
   InterruptClearAll();
 
@@ -753,8 +806,9 @@ void NotificationListView::OnNotificationAdded(const std::string& id) {
     auto* child_notification =
         MessageCenter::Get()->FindVisibleNotificationById(
             message_view->GetNotificationId());
-    if (!child_notification)
+    if (!child_notification) {
       break;
+    }
 
     // The insertion order for notifications will be reversed when
     // is_notifications_refresh_enabled_.
@@ -778,14 +832,16 @@ void NotificationListView::OnNotificationAdded(const std::string& id) {
 
 void NotificationListView::OnNotificationRemoved(const std::string& id,
                                                  bool by_user) {
-  if (ignore_notification_remove_)
+  if (ignore_notification_remove_) {
     return;
+  }
 
   // The corresponding MessageView may have already been deleted after being
   // manually slid out.
   auto* child = GetNotificationById(id);
-  if (!child)
+  if (!child) {
     return;
+  }
 
   InterruptClearAll();
   ResetBounds();
@@ -794,16 +850,18 @@ void NotificationListView::OnNotificationRemoved(const std::string& id,
 
   // If the MessageView is slid out, then do nothing here. The MOVE_DOWN
   // animation will be started in OnNotificationSlidOut().
-  if (!child->is_slid_out())
+  if (!child->is_slid_out()) {
     child->SlideOutAndClose();
+  }
 }
 
 void NotificationListView::OnNotificationSlidOut() {
   DeleteRemovedNotifications();
 
   // |message_center_view_| can be null in tests.
-  if (message_center_view_)
+  if (message_center_view_) {
     message_center_view_->OnNotificationSlidOut();
+  }
 
   state_ = State::MOVE_DOWN;
   UpdateBounds();
@@ -812,16 +870,18 @@ void NotificationListView::OnNotificationSlidOut() {
 
 void NotificationListView::OnNotificationUpdated(const std::string& id) {
   auto* notification = MessageCenter::Get()->FindVisibleNotificationById(id);
-  if (!notification)
+  if (!notification) {
     return;
+  }
 
   InterruptClearAll();
 
   // The corresponding MessageView may have been slid out and deleted, so just
   // ignore this update as the notification will soon be deleted.
   auto* child = GetNotificationById(id);
-  if (!child)
+  if (!child) {
     return;
+  }
 
   child->UpdateWithNotification(*notification);
   ResetBounds();
@@ -832,8 +892,9 @@ void NotificationListView::OnSlideStarted(const std::string& notification_id) {
   // controls.
   for (auto* child : children()) {
     auto* view = AsMVC(child);
-    if (view->GetNotificationId() != notification_id)
+    if (view->GetNotificationId() != notification_id) {
       view->CloseSwipeControl();
+    }
   }
 }
 
@@ -885,14 +946,16 @@ void NotificationListView::AnimationEnded(const gfx::Animation* animation) {
 
   UpdateBorders(/*force_update=*/false);
 
-  if (state_ != State::IDLE)
+  if (state_ != State::IDLE) {
     StartAnimation();
+  }
 }
 
 void NotificationListView::AnimationProgressed(
     const gfx::Animation* animation) {
-  if (state_ == State::EXPAND_OR_COLLAPSE)
+  if (state_ == State::EXPAND_OR_COLLAPSE) {
     expand_or_collapsing_container_->TriggerPreferredSizeChangedForAnimation();
+  }
 
   PreferredSizeChanged();
 }
@@ -917,12 +980,14 @@ void NotificationListView::ConfigureMessageView(
   auto* notification = MessageCenter::Get()->FindNotificationById(
       message_view->notification_id());
   // `notification` may not exist in tests.
-  if (notification && !notification->group_child())
+  if (notification && !notification->group_child()) {
     message_view->SetIsNested();
+  }
   message_view_multi_source_observation_.AddObservation(message_view);
   // `message_center_view_` may not exist in tests.
-  if (message_center_view_)
+  if (message_center_view_) {
     message_center_view_->ConfigureMessageView(message_view);
+  }
 }
 
 std::vector<message_center::Notification*>
@@ -971,16 +1036,18 @@ NotificationListView::GetNextRemovableNotification() {
 
 void NotificationListView::CollapseAllNotifications() {
   base::AutoReset<bool> auto_reset(&ignore_size_change_, true);
-  for (auto* child : children())
+  for (auto* child : children()) {
     AsMVC(child)->Collapse();
+  }
 }
 
 void NotificationListView::UpdateBorders(bool force_update) {
   // The top notification is drawn with rounded corners when the stacking bar
   // is not shown.
   bool is_top = state_ != State::MOVE_DOWN;
-  if (!is_notifications_refresh_enabled_)
+  if (!is_notifications_refresh_enabled_) {
     is_top = is_top && children().size() == 1;
+  }
 
   for (auto* child : children()) {
     AsMVC(child)->UpdateBorder(is_top, child == children().back(),
@@ -999,8 +1066,9 @@ void NotificationListView::UpdateBounds() {
     const int height = view->GetHeightForWidth(message_view_width_);
     const int direction = view->GetSlideDirection();
 
-    if (y > 0 && is_notifications_refresh_enabled_)
+    if (y > 0 && is_notifications_refresh_enabled_) {
       y += kMessageListNotificationSpacing;
+    }
 
     view->set_start_bounds(view->target_bounds());
     view->set_target_bounds(view->is_removed()
@@ -1019,28 +1087,33 @@ void NotificationListView::ResetBounds() {
   UpdateBounds();
 
   state_ = State::IDLE;
-  if (animation_->is_animating())
+  if (animation_->is_animating()) {
     animation_->End();
-  else
+  } else {
     PreferredSizeChanged();
+  }
 }
 
 void NotificationListView::InterruptClearAll() {
-  if (state_ != State::CLEAR_ALL_STACKED && state_ != State::CLEAR_ALL_VISIBLE)
+  if (state_ != State::CLEAR_ALL_STACKED &&
+      state_ != State::CLEAR_ALL_VISIBLE) {
     return;
+  }
 
   for (auto* child : children()) {
     auto* view = AsMVC(child);
-    if (!view->IsPinned())
+    if (!view->IsPinned()) {
       view->set_is_removed();
+    }
   }
 
   DeleteRemovedNotifications();
 }
 
 void NotificationListView::DeleteRemovedNotifications() {
-  if (!features::IsQsRevampEnabled())
+  if (!features::IsQsRevampEnabled()) {
     DCHECK(model_);
+  }
 
   views::View::Views removed_views;
   base::ranges::copy_if(children(), std::back_inserter(removed_views),
@@ -1049,8 +1122,9 @@ void NotificationListView::DeleteRemovedNotifications() {
   {
     base::AutoReset<bool> auto_reset(&is_deleting_removed_notifications_, true);
     for (auto* view : removed_views) {
-      if (!features::IsQsRevampEnabled())
+      if (!features::IsQsRevampEnabled()) {
         model_->RemoveNotificationExpanded(AsMVC(view)->GetNotificationId());
+      }
       message_view_multi_source_observation_.RemoveObservation(
           AsMVC(view)->message_view());
       delete view;
@@ -1108,8 +1182,9 @@ void NotificationListView::UpdateClearAllAnimation() {
          state_ == State::CLEAR_ALL_VISIBLE);
 
   auto* view = GetNextRemovableNotification();
-  if (view)
+  if (view) {
     view->set_is_removed();
+  }
 
   if (state_ == State::CLEAR_ALL_STACKED) {
     const auto non_visible_notification_ids =
@@ -1119,8 +1194,9 @@ void NotificationListView::UpdateClearAllAnimation() {
       // window.
       for (const auto& id : non_visible_notification_ids) {
         auto* message_view_container = GetNotificationById(id);
-        if (message_view_container)
+        if (message_view_container) {
           message_view_container->set_is_removed();
+        }
       }
 
       DeleteRemovedNotifications();
@@ -1139,10 +1215,11 @@ void NotificationListView::UpdateClearAllAnimation() {
   if (state_ == State::CLEAR_ALL_VISIBLE) {
     UpdateBounds();
 
-    if (view || start_height_ != target_height_)
+    if (view || start_height_ != target_height_) {
       state_ = State::CLEAR_ALL_VISIBLE;
-    else
+    } else {
       state_ = State::IDLE;
+    }
   }
 }
 
