@@ -8,6 +8,7 @@
 
 #include "ash/constants/ash_features.h"
 #include "ash/style/ash_color_provider.h"
+#include "ash/system/phonehub/app_stream_connection_error_dialog.h"
 #include "ash/system/phonehub/camera_roll_view.h"
 #include "ash/system/phonehub/multidevice_feature_opt_in_view.h"
 #include "ash/system/phonehub/phone_hub_recent_apps_view.h"
@@ -17,6 +18,7 @@
 #include "ash/system/phonehub/task_continuation_view.h"
 #include "ash/system/phonehub/ui_constants.h"
 #include "ash/system/tray/tray_constants.h"
+#include "chromeos/ash/components/multidevice/logging/logging.h"
 #include "chromeos/ash/components/phonehub/multidevice_feature_access_manager.h"
 #include "chromeos/ash/components/phonehub/phone_hub_manager.h"
 #include "chromeos/ash/components/phonehub/ping_manager.h"
@@ -29,6 +31,7 @@
 #include "ui/views/controls/label.h"
 #include "ui/views/controls/separator.h"
 #include "ui/views/layout/box_layout.h"
+#include "ui/views/view.h"
 
 namespace ash {
 
@@ -46,7 +49,8 @@ constexpr auto kDarkLightModeDisabledPadding =
 }  // namespace
 
 PhoneConnectedView::PhoneConnectedView(
-    phonehub::PhoneHubManager* phone_hub_manager) {
+    phonehub::PhoneHubManager* phone_hub_manager)
+    : phone_hub_manager_(phone_hub_manager) {
   SetID(PhoneHubViewID::kPhoneConnectedView);
 
   auto setup_layered_view = [](views::View* view) {
@@ -87,7 +91,7 @@ PhoneConnectedView::PhoneConnectedView(
       phone_hub_manager->GetRecentAppsInteractionHandler();
   if (features::IsEcheSWAEnabled() && recent_apps_handler) {
     setup_layered_view(AddChildView(std::make_unique<PhoneHubRecentAppsView>(
-        recent_apps_handler, phone_hub_manager)));
+        recent_apps_handler, phone_hub_manager, this)));
   }
 
   auto* ping_manager = phone_hub_manager->GetPingManager();
@@ -96,6 +100,11 @@ PhoneConnectedView::PhoneConnectedView(
   }
 
   phone_hub_manager->GetUserActionRecorder()->RecordUiOpened();
+
+  if (phone_hub_manager->GetAppStreamLauncherDataModel()) {
+    phone_hub_manager->GetAppStreamLauncherDataModel()->SetLauncherSize(
+        GetPreferredSize().height(), GetPreferredSize().width());
+  }
 }
 
 PhoneConnectedView::~PhoneConnectedView() = default;
@@ -103,11 +112,21 @@ PhoneConnectedView::~PhoneConnectedView() = default;
 void PhoneConnectedView::ChildPreferredSizeChanged(View* child) {
   // Resize the bubble when the child change its size.
   PreferredSizeChanged();
+  if (phone_hub_manager_ &&
+      phone_hub_manager_->GetAppStreamLauncherDataModel()) {
+    phone_hub_manager_->GetAppStreamLauncherDataModel()->SetLauncherSize(
+        GetPreferredSize().height(), GetPreferredSize().width());
+  }
 }
 
 void PhoneConnectedView::ChildVisibilityChanged(View* child) {
   // Resize the bubble when the child change its visibility.
   PreferredSizeChanged();
+  if (phone_hub_manager_ &&
+      phone_hub_manager_->GetAppStreamLauncherDataModel()) {
+    phone_hub_manager_->GetAppStreamLauncherDataModel()->SetLauncherSize(
+        GetPreferredSize().height(), GetPreferredSize().width());
+  }
 }
 
 const char* PhoneConnectedView::GetClassName() const {
@@ -118,4 +137,26 @@ phone_hub_metrics::Screen PhoneConnectedView::GetScreenForMetrics() const {
   return phone_hub_metrics::Screen::kPhoneConnected;
 }
 
+void PhoneConnectedView::ShowAppStreamErrorDialog() {
+  if (!features::IsEcheNetworkConnectionStateEnabled()) {
+    return;
+  }
+  app_stream_error_dialog_ = std::make_unique<AppStreamConnectionErrorDialog>(
+      this,
+      base::BindOnce(&PhoneConnectedView::OnAppStreamErrorDialogClosed,
+                     base::Unretained(this)),
+      base::BindOnce(&PhoneConnectedView::OnAppStreamErrorDialogButtonClicked,
+                     base::Unretained(this)));
+  app_stream_error_dialog_->UpdateBounds();
+  app_stream_error_dialog_->widget()->Show();
+}
+
+void PhoneConnectedView::OnAppStreamErrorDialogClosed() {
+  app_stream_error_dialog_.reset();
+}
+
+void PhoneConnectedView::OnAppStreamErrorDialogButtonClicked() {
+  // TODO(b/273823627): Add method to enable hotspot.
+}
+
 }  // namespace ash
