@@ -4,10 +4,6 @@
 
 #include "ash/system/phonehub/phone_hub_notification_controller.h"
 
-#include "ash/components/phonehub/notification.h"
-#include "ash/components/phonehub/notification_interaction_handler.h"
-#include "ash/components/phonehub/phone_hub_manager.h"
-#include "ash/components/phonehub/phone_model.h"
 #include "ash/constants/ash_features.h"
 #include "ash/constants/notifier_catalogs.h"
 #include "ash/public/cpp/notification_utils.h"
@@ -20,8 +16,8 @@
 #include "ash/system/model/system_tray_model.h"
 #include "ash/system/phonehub/phone_hub_metrics.h"
 #include "ash/system/tray/tray_popup_utils.h"
-#include "base/bind.h"
 #include "base/containers/contains.h"
+#include "base/functional/bind.h"
 #include "base/logging.h"
 #include "base/memory/weak_ptr.h"
 #include "base/strings/strcat.h"
@@ -29,6 +25,10 @@
 #include "base/strings/utf_string_conversions.h"
 #include "base/timer/timer.h"
 #include "chromeos/ash/components/multidevice/logging/logging.h"
+#include "chromeos/ash/components/phonehub/notification.h"
+#include "chromeos/ash/components/phonehub/notification_interaction_handler.h"
+#include "chromeos/ash/components/phonehub/phone_hub_manager.h"
+#include "chromeos/ash/components/phonehub/phone_model.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/resource/resource_bundle.h"
 #include "ui/display/types/display_constants.h"
@@ -98,7 +98,9 @@ class PhoneHubNotificationView : public message_center::NotificationView {
     custom_view_type_ = notification.custom_view_type();
     if (custom_view_type_ == kNotificationCustomCallViewType) {
       // Expand the action buttons row by default for Call Style notification.
-      SetManuallyExpandedOrCollapsed(true);
+      SetManuallyExpandedOrCollapsed(
+          !IsExpanded() ? message_center::ExpandState::USER_EXPANDED
+                        : message_center::ExpandState::USER_COLLAPSED);
       SetExpanded(true);
       return;
     }
@@ -192,7 +194,9 @@ class PhoneHubAshNotificationView : public AshNotificationView {
     custom_view_type_ = notification.custom_view_type();
     if (custom_view_type_ == kNotificationCustomCallViewType) {
       // Expand the action buttons row by default for Call Style notification.
-      SetManuallyExpandedOrCollapsed(true);
+      SetManuallyExpandedOrCollapsed(
+          !IsExpanded() ? message_center::ExpandState::USER_EXPANDED
+                        : message_center::ExpandState::USER_COLLAPSED);
       SetExpanded(true);
       return;
     }
@@ -224,6 +228,8 @@ class PhoneHubAshNotificationView : public AshNotificationView {
   // message_center::NotificationView:
   void OnNotificationInputSubmit(size_t index,
                                  const std::u16string& text) override {
+    if (text.empty())
+      return;
     AshNotificationView::OnNotificationInputSubmit(index, text);
 
     DCHECK(reply_button_);
@@ -504,7 +510,7 @@ void PhoneHubNotificationController::OnAttemptConnectionScanFailed() {
             }
           }));
   std::unique_ptr<message_center::Notification> notification =
-      CreateSystemNotification(
+      CreateSystemNotificationPtr(
           message_center::NOTIFICATION_TYPE_SIMPLE,
           kPhoneHubInstantTetherNotificationId,
           l10n_util::GetStringUTF16(
@@ -568,7 +574,7 @@ PhoneHubNotificationController::CreateCameraRollGenericNotification(
   button.title = l10n_util::GetStringUTF16(
       IDS_ASH_PHONE_HUB_CAMERA_ROLL_ERROR_GENERIC_ACTION);
   optional_fields.buttons.push_back(button);
-  return CreateSystemNotification(
+  return CreateSystemNotificationPtr(
       message_center::NOTIFICATION_TYPE_SIMPLE,
       kPhoneHubCameraRollNotificationId,
       l10n_util::GetStringUTF16(IDS_ASH_PHONE_HUB_CAMERA_ROLL_ERROR_TITLE),
@@ -612,7 +618,7 @@ PhoneHubNotificationController::CreateCameraRollStorageNotification(
   button.title = l10n_util::GetStringUTF16(
       IDS_ASH_PHONE_HUB_CAMERA_ROLL_ERROR_STORAGE_ACTION);
   optional_fields.buttons.push_back(button);
-  return CreateSystemNotification(
+  return CreateSystemNotificationPtr(
       message_center::NOTIFICATION_TYPE_SIMPLE,
       kPhoneHubCameraRollNotificationId,
       l10n_util::GetStringUTF16(IDS_ASH_PHONE_HUB_CAMERA_ROLL_ERROR_TITLE),
@@ -654,7 +660,7 @@ PhoneHubNotificationController::CreateCameraRollNetworkNotification(
   button.title = l10n_util::GetStringUTF16(
       IDS_ASH_PHONE_HUB_CAMERA_ROLL_ERROR_NETWORK_ACTION);
   optional_fields.buttons.push_back(button);
-  return CreateSystemNotification(
+  return CreateSystemNotificationPtr(
       message_center::NOTIFICATION_TYPE_SIMPLE,
       kPhoneHubCameraRollNotificationId,
       l10n_util::GetStringUTF16(IDS_ASH_PHONE_HUB_CAMERA_ROLL_ERROR_TITLE),
