@@ -6,33 +6,40 @@
 #include <utility>
 
 #include "ash/accessibility/accessibility_controller_impl.h"
-#include "ash/components/phonehub/phone_hub_manager.h"
-#include "ash/components/phonehub/phone_model.h"
 #include "ash/constants/ash_features.h"
 #include "ash/constants/tray_background_view_catalog.h"
 #include "ash/focus_cycler.h"
 #include "ash/public/cpp/system_tray_client.h"
 #include "ash/resources/vector_icons/vector_icons.h"
+#include "ash/root_window_controller.h"
 #include "ash/shelf/shelf.h"
 #include "ash/shell.h"
 #include "ash/strings/grit/ash_strings.h"
+#include "ash/style/ash_color_id.h"
 #include "ash/style/ash_color_provider.h"
 #include "ash/system/eche/eche_icon_loading_indicator_view.h"
+#include "ash/system/eche/eche_tray.h"
 #include "ash/system/model/system_tray_model.h"
 #include "ash/system/phonehub/phone_hub_content_view.h"
 #include "ash/system/phonehub/phone_hub_metrics.h"
 #include "ash/system/phonehub/quick_actions_view.h"
 #include "ash/system/phonehub/task_continuation_view.h"
 #include "ash/system/phonehub/ui_constants.h"
+#include "ash/system/status_area_widget.h"
 #include "ash/system/tray/system_menu_button.h"
 #include "ash/system/tray/tray_bubble_wrapper.h"
 #include "ash/system/tray/tray_constants.h"
 #include "ash/system/tray/tray_container.h"
 #include "ash/system/tray/tray_popup_utils.h"
 #include "ash/system/tray/tray_utils.h"
-#include "base/bind.h"
-#include "base/callback_helpers.h"
+#include "base/functional/bind.h"
+#include "base/functional/callback_helpers.h"
+#include "base/task/sequenced_task_runner.h"
+#include "chromeos/ash/components/phonehub/icon_decoder.h"
+#include "chromeos/ash/components/phonehub/phone_hub_manager.h"
+#include "chromeos/ash/components/phonehub/phone_model.h"
 #include "ui/base/l10n/l10n_util.h"
+#include "ui/base/models/image_model.h"
 #include "ui/base/resource/resource_bundle.h"
 #include "ui/events/event.h"
 #include "ui/gfx/geometry/insets.h"
@@ -58,6 +65,10 @@ constexpr auto kBubblePadding =
 PhoneHubTray::PhoneHubTray(Shelf* shelf)
     : TrayBackgroundView(shelf, TrayBackgroundViewCatalogName::kPhoneHub),
       ui_controller_(new PhoneHubUiController()) {
+  // By default, if the individual buttons did not handle the event consider it
+  // as a phone hub icon event.
+  SetPressedCallback(base::BindRepeating(&PhoneHubTray::PhoneHubIconActivated,
+                                         base::Unretained(this)));
   observed_phone_hub_ui_controller_.Observe(ui_controller_.get());
   observed_session_.Observe(Shell::Get()->session_controller());
 
@@ -89,17 +100,32 @@ PhoneHubTray::PhoneHubTray(Shelf* shelf)
       views::ImageButton::VerticalAlignment::ALIGN_MIDDLE);
   icon->SetImageHorizontalAlignment(
       views::ImageButton::HorizontalAlignment::ALIGN_CENTER);
+  icon->SetImageModel(views::ImageButton::STATE_NORMAL,
+                      ui::ImageModel::FromVectorIcon(
+                          kPhoneHubPhoneIcon, kColorAshIconColorPrimary));
   icon_ = tray_container()->AddChildView(std::move(icon));
+  Shell::Get()->window_tree_host_manager()->AddObserver(this);
 }
 
 PhoneHubTray::~PhoneHubTray() {
   if (bubble_)
     bubble_->bubble_view()->ResetDelegate();
+  if (phone_hub_manager_) {
+    phone_hub_manager_->GetAppStreamManager()->RemoveObserver(this);
+  }
+  Shell::Get()->window_tree_host_manager()->RemoveObserver(this);
 }
 
 void PhoneHubTray::SetPhoneHubManager(
     phonehub::PhoneHubManager* phone_hub_manager) {
   ui_controller_->SetPhoneHubManager(phone_hub_manager);
+  if (phone_hub_manager_) {
+    phone_hub_manager_->GetAppStreamManager()->RemoveObserver(this);
+  }
+  if (phone_hub_manager) {
+    phone_hub_manager->GetAppStreamManager()->AddObserver(this);
+  }
+  phone_hub_manager_ = phone_hub_manager;
 }
 
 void PhoneHubTray::ClickedOutsideBubble() {
@@ -134,6 +160,7 @@ void PhoneHubTray::HideBubble(const TrayBubbleView* bubble_view) {
 
 void PhoneHubTray::OnPhoneHubUiStateChanged() {
   UpdateVisibility();
+  UpdateHeaderVisibility();
 
   if (!bubble_)
     return;
@@ -165,9 +192,6 @@ void PhoneHubTray::OnPhoneHubUiStateChanged() {
 }
 
 void PhoneHubTray::OnSessionStateChanged(session_manager::SessionState state) {
-  icon_->SetImage(views::ImageButton::STATE_NORMAL,
-                  CreateVectorIcon(kPhoneHubPhoneIcon, TrayIconColor(state)));
-
   TemporarilyDisableAnimation();
 }
 
@@ -189,6 +213,13 @@ void PhoneHubTray::OnDisplayConfigurationChanged() {
 
 void PhoneHubTray::Initialize() {
   TrayBackgroundView::Initialize();
+  // For secondary displays to have Phone Hub visible, manager must
+  // be set.
+  phonehub::PhoneHubManager* phone_hub_tray_manager =
+      Shell::Get()->system_tray_model()->phone_hub_manager();
+  if (phone_hub_tray_manager) {
+    SetPhoneHubManager(phone_hub_tray_manager);
+  }
   UpdateVisibility();
 }
 
@@ -211,13 +242,13 @@ void PhoneHubTray::ShowBubble() {
   init_params.reroute_event_handler = true;
   init_params.corner_radius = kTrayItemCornerRadius;
 
-  TrayBubbleView* bubble_view = new TrayBubbleView(init_params);
+  auto bubble_view = std::make_unique<TrayBubbleView>(init_params);
   bubble_view->SetBorder(views::CreateEmptyBorder(kBubblePadding));
 
   // Creates header view on top for displaying phone status and settings icon.
   auto phone_status = ui_controller_->CreateStatusHeaderView(this);
-  phone_status_view_ = phone_status.get();
-  DCHECK(phone_status_view_);
+  phone_status_view_dont_use_ = phone_status.get();
+  DCHECK(phone_status_view_dont_use_);
   bubble_view->AddChildView(std::move(phone_status));
 
   // Other contents, i.e. the connected view and the interstitial views,
@@ -233,7 +264,9 @@ void PhoneHubTray::ShowBubble() {
 
   bubble_view->AddChildView(std::move(content_view));
 
-  bubble_ = std::make_unique<TrayBubbleWrapper>(this, bubble_view);
+  bubble_ = std::make_unique<TrayBubbleWrapper>(this);
+  bubble_->ShowBubble(std::move(bubble_view));
+  UpdateHeaderVisibility();
 
   SetIsActive(true);
 
@@ -241,13 +274,6 @@ void PhoneHubTray::ShowBubble() {
       content_view_->GetScreenForMetrics());
 }
 
-bool PhoneHubTray::PerformAction(const ui::Event& event) {
-  // By default, if the individual buttons did not handle the event consider it
-  // as a phone hub icon event.
-  PhoneHubIconActivated(event);
-  return true;
-}
-
 TrayBubbleView* PhoneHubTray::GetBubbleView() {
   return bubble_ ? bubble_->bubble_view() : nullptr;
 }
@@ -260,16 +286,6 @@ const char* PhoneHubTray::GetClassName() const {
   return "PhoneHubTray";
 }
 
-void PhoneHubTray::OnThemeChanged() {
-  TrayBackgroundView::OnThemeChanged();
-  icon_->SetImage(
-      views::ImageButton::STATE_NORMAL,
-      CreateVectorIcon(
-          kPhoneHubPhoneIcon,
-          TrayIconColor(
-              Shell::Get()->session_controller()->GetSessionState())));
-}
-
 bool PhoneHubTray::CanOpenConnectedDeviceSettings() {
   return TrayPopupUtils::CanOpenWebUISettings();
 }
@@ -284,13 +300,52 @@ void PhoneHubTray::OpenConnectedDevicesSettings() {
 }
 
 void PhoneHubTray::HideStatusHeaderView() {
-  if (!phone_status_view_)
+  if (!GetPhoneStatusView())
     return;
 
-  phone_status_view_->SetVisible(false);
+  GetPhoneStatusView()->SetVisible(false);
   bubble_->bubble_view()->UpdateBubble();
 }
 
+void PhoneHubTray::OnAppStreamUpdate(
+    const phonehub::proto::AppStreamUpdate app_stream_update) {
+  auto* app = &app_stream_update.foreground_app();
+  // TODO(nayebi): Try to extract this decoding process into a shared code
+  // inside the icon decoder.
+  // Decode the icon
+  std::unique_ptr<std::vector<phonehub::IconDecoder::DecodingData>>
+      decoding_data_list =
+          std::make_unique<std::vector<phonehub::IconDecoder::DecodingData>>();
+  std::hash<std::string> str_hash;
+  std::string key = app->package_name() + base::NumberToString(app->user_id());
+  phonehub::IconDecoder::DecodingData decoding_data =
+      phonehub::IconDecoder::DecodingData(str_hash(key), app->icon());
+  // load with default image
+  decoding_data.result =
+      gfx::Image(CreateVectorIcon(kPhoneHubPhoneIcon, gfx::kGoogleGrey700));
+  decoding_data_list->push_back(decoding_data);
+  phone_hub_manager_->GetIconDecoder()->BatchDecode(
+      std::move(decoding_data_list),
+      base::BindOnce(&PhoneHubTray::OnIconsDecoded, weak_factory_.GetWeakPtr(),
+                     app->visible_name()));
+}
+
+void PhoneHubTray::OnIconsDecoded(
+    std::string visible_name,
+    std::unique_ptr<std::vector<phonehub::IconDecoder::DecodingData>>
+        decoding_data_list) {
+  if (decoding_data_list->empty())
+    return;
+  EcheTray* eche_tray = Shell::GetPrimaryRootWindowController()
+                            ->GetStatusAreaWidget()
+                            ->eche_tray();
+  if (!eche_tray)
+    return;
+
+  eche_tray->SetIcon(decoding_data_list->front().result,
+                     base::UTF8ToUTF16(visible_name));
+}
+
 void PhoneHubTray::SetEcheIconActivationCallback(
     base::RepeatingCallback<bool(const ui::Event&)> callback) {
   eche_icon_callback_ = std::move(callback);
@@ -312,6 +367,16 @@ void PhoneHubTray::CloseBubble() {
     content_view_ = nullptr;
   }
 
+  if (phone_status_view_dont_use_) {
+    phone_status_view_dont_use_ = nullptr;
+  }
+
+  if (features::IsEcheSWAEnabled() && features::IsEcheLauncherEnabled() &&
+      phone_hub_manager_->GetAppStreamLauncherDataModel()) {
+    phone_hub_manager_->GetAppStreamLauncherDataModel()
+        ->SetShouldShowMiniLauncher(false);
+  }
+
   bubble_.reset();
   SetIsActive(false);
   shelf()->UpdateAutoHideState();
@@ -323,8 +388,20 @@ void PhoneHubTray::UpdateVisibility() {
   SetVisiblePreferred(ui_state != PhoneHubUiController::UiState::kHidden);
 }
 
+void PhoneHubTray::UpdateHeaderVisibility() {
+  if (!features::IsEcheLauncherEnabled())
+    return;
+  if (!GetPhoneStatusView())
+    return;
+
+  DCHECK(ui_controller_.get());
+  auto ui_state = ui_controller_->ui_state();
+  GetPhoneStatusView()->SetVisible(
+      ui_state != PhoneHubUiController::UiState::kMiniLauncher);
+}
+
 void PhoneHubTray::TemporarilyDisableAnimation() {
-  base::SequencedTaskRunnerHandle::Get()->PostDelayedTask(
+  base::SequencedTaskRunner::GetCurrentDefault()->PostDelayedTask(
       FROM_HERE, DisableShowAnimation().Release(), base::Seconds(5));
 }
 
@@ -341,4 +418,11 @@ void PhoneHubTray::PhoneHubIconActivated(const ui::Event& event) {
   }
 }
 
+views::View* PhoneHubTray::GetPhoneStatusView() {
+  if (!bubble_ || !bubble_->GetBubbleView()) {
+    phone_status_view_dont_use_ = nullptr;
+  }
+  return phone_status_view_dont_use_;
+}
+
 }  // namespace ash
