@@ -6,24 +6,26 @@
 
 #include <utility>
 
+#include "ash/curtain/security_curtain_controller.h"
 #include "ash/shell.h"
 #include "ash/style/ash_color_provider.h"
 #include "ash/style/default_color_constants.h"
 #include "ash/style/default_colors.h"
+#include "ash/system/power/power_button_menu_curtain_view.h"
 #include "ash/system/power/power_button_menu_metrics_type.h"
 #include "ash/system/power/power_button_menu_view.h"
+#include "ash/system/power/power_button_menu_view_util.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
 #include "ui/compositor/layer.h"
 #include "ui/compositor/layer_animation_observer.h"
 #include "ui/compositor/scoped_layer_animation_settings.h"
 #include "ui/display/display.h"
 #include "ui/display/screen.h"
+#include "ui/views/view.h"
 #include "ui/views/widget/widget.h"
 
 namespace ash {
 
-constexpr int PowerButtonMenuView::kMenuViewTransformDistanceDp;
-
 namespace {
 
 // Opacity of the power button menu fullscreen background shield.
@@ -46,11 +48,13 @@ gfx::Size GetPrimaryDisplayLandscapeSize() {
 int AdjustMenuEdgeForDisplaySize(int actual_position,
                                  int display_edge,
                                  int menu_size) {
-  return std::min(display_edge -
-                      PowerButtonMenuView::kMenuViewTransformDistanceDp -
-                      menu_size,
-                  std::max(PowerButtonMenuView::kMenuViewTransformDistanceDp,
-                           actual_position));
+  return std::min(
+      display_edge - kPowerButtonMenuTransformDistanceDp - menu_size,
+      std::max(kPowerButtonMenuTransformDistanceDp, actual_position));
+}
+
+bool IsCurtainModeEnabled() {
+  return ash::Shell::Get()->security_curtain_controller().IsEnabled();
 }
 
 }  // namespace
@@ -93,8 +97,7 @@ class PowerButtonMenuScreenView::PowerButtonMenuBackgroundView
     animation.AddObserver(this);
     animation.SetTweenType(show ? gfx::Tween::EASE_IN_2
                                 : gfx::Tween::FAST_OUT_LINEAR_IN);
-    animation.SetTransitionDuration(
-        PowerButtonMenuView::kMenuAnimationDuration);
+    animation.SetTransitionDuration(kPowerButtonMenuAnimationDuration);
     animation.SetPreemptionStrategy(
         ui::LayerAnimator::IMMEDIATELY_ANIMATE_TO_NEW_TARGET);
     layer()->SetOpacity(show ? kPowerButtonMenuOpacity : 0.f);
@@ -139,14 +142,26 @@ PowerButtonMenuScreenView::~PowerButtonMenuScreenView() = default;
 
 void PowerButtonMenuScreenView::ScheduleShowHideAnimation(bool show) {
   power_button_screen_background_shield_->ScheduleShowHideAnimation(show);
-  power_button_menu_view_->ScheduleShowHideAnimation(show);
+  if (IsCurtainModeEnabled()) {
+    GetOrCreateCurtainView()->ScheduleShowHideAnimation(show);
+  } else {
+    power_button_menu_view_->ScheduleShowHideAnimation(show);
+  }
 }
 
 void PowerButtonMenuScreenView::ResetOpacity() {
-  for (ui::Layer* layer : {power_button_screen_background_shield_->layer(),
-                           power_button_menu_view_->layer()}) {
-    DCHECK(layer);
-    layer->SetOpacity(0.f);
+  if (IsCurtainModeEnabled()) {
+    for (ui::Layer* layer : {power_button_screen_background_shield_->layer(),
+                             GetOrCreateCurtainView()->layer()}) {
+      DCHECK(layer);
+      layer->SetOpacity(0.f);
+    }
+  } else {
+    for (ui::Layer* layer : {power_button_screen_background_shield_->layer(),
+                             power_button_menu_view_->layer()}) {
+      DCHECK(layer);
+      layer->SetOpacity(0.f);
+    }
   }
 }
 
@@ -159,20 +174,38 @@ void PowerButtonMenuScreenView::OnWidgetShown(
   // UpdateMenuBoundsOrigins(), since the latter relies on the
   // power_button_menu_view_'s preferred size, which depends on the items added
   // to the view.
-  power_button_menu_view_->RecreateItems();
+  if (!IsCurtainModeEnabled()) {
+    power_button_menu_view_->RecreateItems();
+  }
   if (power_button_position_ != PowerButtonPosition::NONE) {
     UpdateMenuBoundsOrigins();
   }
   Layout();
 }
 
+PowerButtonMenuCurtainView*
+PowerButtonMenuScreenView::GetOrCreateCurtainView() {
+  if (!power_button_menu_curtain_view_) {
+    power_button_menu_curtain_view_ =
+        AddChildView(std::make_unique<PowerButtonMenuCurtainView>());
+  }
+  return power_button_menu_curtain_view_;
+}
+
 const char* PowerButtonMenuScreenView::GetClassName() const {
   return "PowerButtonMenuScreenView";
 }
 
 void PowerButtonMenuScreenView::Layout() {
   power_button_screen_background_shield_->SetBoundsRect(GetContentsBounds());
+  if (IsCurtainModeEnabled()) {
+    LayoutMenuCurtainView();
+  } else {
+    LayoutMenuView();
+  }
+}
 
+void PowerButtonMenuScreenView::LayoutMenuView() {
   gfx::Rect menu_bounds = GetMenuBounds();
   PowerButtonMenuView::TransformDisplacement transform_displacement =
       power_button_menu_view_->GetTransformDisplacement();
@@ -185,6 +218,12 @@ void PowerButtonMenuScreenView::Layout() {
   power_button_menu_view_->SetBoundsRect(menu_bounds);
 }
 
+void PowerButtonMenuScreenView::LayoutMenuCurtainView() {
+  gfx::Rect menu_bounds = GetMenuBounds();
+  menu_bounds.set_y(menu_bounds.y() - kPowerButtonMenuTransformDistanceDp);
+  GetOrCreateCurtainView()->SetBoundsRect(menu_bounds);
+}
+
 bool PowerButtonMenuScreenView::OnMousePressed(const ui::MouseEvent& event) {
   return true;
 }
@@ -223,8 +262,12 @@ void PowerButtonMenuScreenView::OnDisplayMetricsChanged(
 
 void PowerButtonMenuScreenView::LayoutWithoutTransform() {
   power_button_screen_background_shield_->SetBoundsRect(GetContentsBounds());
-  power_button_menu_view_->layer()->SetTransform(gfx::Transform());
-  power_button_menu_view_->SetBoundsRect(GetMenuBounds());
+  if (IsCurtainModeEnabled()) {
+    GetOrCreateCurtainView()->SetBoundsRect(GetMenuBounds());
+  } else {
+    power_button_menu_view_->layer()->SetTransform(gfx::Transform());
+    power_button_menu_view_->SetBoundsRect(GetMenuBounds());
+  }
 }
 
 void PowerButtonMenuScreenView::UpdateMenuBoundsOrigins() {
@@ -302,20 +345,19 @@ void PowerButtonMenuScreenView::UpdateMenuBoundsOrigins() {
   }
 
   menu_bounds_origins_.clear();
-  const gfx::Size menu_size = power_button_menu_view_->GetPreferredSize();
+  const gfx::Size menu_size = GetMenuViewPreferredSize();
   // Power button position offset from the left when the button is at the left
   // is always zero.
   menu_bounds_origins_.insert(std::make_pair(
       left_screen_orientation,
-      gfx::Point(PowerButtonMenuView::kMenuViewTransformDistanceDp,
+      gfx::Point(kPowerButtonMenuTransformDistanceDp,
                  AdjustMenuEdgeForDisplaySize(
                      left_power_button_y - menu_size.height() / 2,
                      display_edge_for_adjust, menu_size.height()))));
 
   menu_bounds_origins_.insert(std::make_pair(
       right_screen_orientation,
-      gfx::Point(display_width -
-                     PowerButtonMenuView::kMenuViewTransformDistanceDp -
+      gfx::Point(display_width - kPowerButtonMenuTransformDistanceDp -
                      menu_size.width(),
                  AdjustMenuEdgeForDisplaySize(
                      right_power_button_y - menu_size.height() / 2,
@@ -323,20 +365,19 @@ void PowerButtonMenuScreenView::UpdateMenuBoundsOrigins() {
 
   // Power button position offset from the top when the button is at the top
   // is always zero.
-  menu_bounds_origins_.insert(std::make_pair(
-      top_screen_orientation,
-      gfx::Point(AdjustMenuEdgeForDisplaySize(
-                     top_power_button_x - menu_size.width() / 2,
-                     display_edge_for_adjust, menu_size.width()),
-                 PowerButtonMenuView::kMenuViewTransformDistanceDp)));
+  menu_bounds_origins_.insert(
+      std::make_pair(top_screen_orientation,
+                     gfx::Point(AdjustMenuEdgeForDisplaySize(
+                                    top_power_button_x - menu_size.width() / 2,
+                                    display_edge_for_adjust, menu_size.width()),
+                                kPowerButtonMenuTransformDistanceDp)));
 
   menu_bounds_origins_.insert(std::make_pair(
       bottom_screen_orientation,
       gfx::Point(AdjustMenuEdgeForDisplaySize(
                      bottom_power_button_x - menu_size.width() / 2,
                      display_edge_for_adjust, menu_size.width()),
-                 display_width -
-                     PowerButtonMenuView::kMenuViewTransformDistanceDp -
+                 display_width - kPowerButtonMenuTransformDistanceDp -
                      menu_size.height())));
 }
 
@@ -346,16 +387,23 @@ gfx::Rect PowerButtonMenuScreenView::GetMenuBounds() {
   if (power_button_position_ == PowerButtonPosition::NONE ||
       !Shell::Get()->tablet_mode_controller()->InTabletMode()) {
     menu_bounds = GetContentsBounds();
-    menu_bounds.ClampToCenteredSize(
-        power_button_menu_view_->GetPreferredSize());
+    menu_bounds.ClampToCenteredSize(GetMenuViewPreferredSize());
   } else {
     menu_bounds.set_origin(
         menu_bounds_origins_[Shell::Get()
                                  ->screen_orientation_controller()
                                  ->GetCurrentOrientation()]);
-    menu_bounds.set_size(power_button_menu_view_->GetPreferredSize());
+    menu_bounds.set_size(GetMenuViewPreferredSize());
   }
   return menu_bounds;
 }
 
+gfx::Size PowerButtonMenuScreenView::GetMenuViewPreferredSize() {
+  if (IsCurtainModeEnabled()) {
+    return GetOrCreateCurtainView()->GetPreferredSize();
+  } else {
+    return power_button_menu_view_->GetPreferredSize();
+  }
+}
+
 }  // namespace ash
