@@ -15,6 +15,7 @@
 #include "ash/strings/grit/ash_strings.h"
 #include "ash/system/geolocation/geolocation_controller.h"
 #include "ash/system/model/system_tray_model.h"
+#include "ash/system/scheduled_feature/schedule_utils.h"
 #include "base/cxx17_backports.h"
 #include "base/functional/bind.h"
 #include "base/i18n/time_formatting.h"
@@ -38,6 +39,34 @@ constexpr int kDefaultStartTimeOffsetMinutes = 18 * 60;
 // Default end time at 6:00 AM as an offset from 00:00.
 constexpr int kDefaultEndTimeOffsetMinutes = 6 * 60;
 
+bool IsEnabledAtCheckpoint(ScheduleCheckpoint checkpoint) {
+  switch (checkpoint) {
+    case ScheduleCheckpoint::kDisabled:
+    case ScheduleCheckpoint::kSunrise:
+    case ScheduleCheckpoint::kMorning:
+    case ScheduleCheckpoint::kLateAfternoon:
+      return false;
+    case ScheduleCheckpoint::kEnabled:
+    case ScheduleCheckpoint::kSunset:
+      return true;
+  }
+}
+
+// Converts a boolean feature `is_enabled` state to the appropriate
+// `ScheduleCheckpoint` for the given `schedule_type`.
+ScheduleCheckpoint GetCheckpointForEnabledState(bool is_enabled,
+                                                ScheduleType schedule_type) {
+  switch (schedule_type) {
+    case ScheduleType::kNone:
+    case ScheduleType::kCustom:
+      return is_enabled ? ScheduleCheckpoint::kEnabled
+                        : ScheduleCheckpoint::kDisabled;
+    case ScheduleType::kSunsetToSunrise:
+      return is_enabled ? ScheduleCheckpoint::kSunset
+                        : ScheduleCheckpoint::kSunrise;
+  }
+}
+
 }  // namespace
 
 base::Time ScheduledFeature::Clock::Now() const {
@@ -149,6 +178,14 @@ void ScheduledFeature::SetCustomEndTime(TimeOfDay end_time) {
   }
 }
 
+void ScheduledFeature::AddCheckpointObserver(CheckpointObserver* obs) {
+  checkpoint_observers_.AddObserver(obs);
+}
+
+void ScheduledFeature::RemoveCheckpointObserver(CheckpointObserver* obs) {
+  checkpoint_observers_.RemoveObserver(obs);
+}
+
 void ScheduledFeature::OnActiveUserPrefServiceChanged(
     PrefService* pref_service) {
   if (pref_service == active_user_pref_service_)
@@ -189,20 +226,22 @@ bool ScheduledFeature::MaybeRestoreSchedule() {
   DCHECK(active_user_pref_service_);
   DCHECK_NE(GetScheduleType(), ScheduleType::kNone);
 
-  auto iter = per_user_schedule_target_state_.find(active_user_pref_service_);
-  if (iter == per_user_schedule_target_state_.end())
+  auto iter = per_user_schedule_snapshot_.find(active_user_pref_service_);
+  if (iter == per_user_schedule_snapshot_.end()) {
     return false;
+  }
 
-  ScheduleTargetState& target_state = iter->second;
+  const ScheduleSnapshot& snapshot_to_restore = iter->second;
   const base::Time now = clock_->Now();
   // It may be that the device was suspended for a very long time that the
   // target time is no longer valid.
-  if (target_state.target_time <= now)
+  if (snapshot_to_restore.target_time <= now) {
     return false;
+  }
 
   VLOG(1) << "Restoring a previous schedule.";
-  DCHECK_NE(GetEnabled(), target_state.target_status);
-  ScheduleNextToggle(target_state.target_time - now);
+  current_checkpoint_ = snapshot_to_restore.current_checkpoint;
+  ScheduleNextRefresh(snapshot_to_restore, now);
   return true;
 }
 
@@ -277,6 +316,8 @@ void ScheduledFeature::Refresh(bool did_schedule_change,
     case ScheduleType::kNone:
       timer_->Stop();
       RefreshFeatureState();
+      SetCurrentCheckpoint(
+          GetCheckpointForEnabledState(GetEnabled(), ScheduleType::kNone));
       return;
     case ScheduleType::kSunsetToSunrise:
       RefreshScheduleTimer(geolocation_controller_->GetSunsetTime(),
@@ -292,141 +333,118 @@ void ScheduledFeature::Refresh(bool did_schedule_change,
   }
 }
 
+// The `ScheduleCheckpoint` usage in this method does not directly apply
+// to `ScheduleType::kCustom`, but the business logic still works for that
+// `ScheduleType` with no caller-facing impact. The internal `timer_` may just
+// fire a couple more times a day and be no-ops.
 void ScheduledFeature::RefreshScheduleTimer(
     base::Time start_time,
     base::Time end_time,
     bool did_schedule_change,
     bool keep_manual_toggles_during_schedules) {
-  DCHECK(GetScheduleType() != ScheduleType::kNone);
+  const ScheduleType schedule_type = GetScheduleType();
+  DCHECK(schedule_type != ScheduleType::kNone);
 
   if (keep_manual_toggles_during_schedules && MaybeRestoreSchedule()) {
     RefreshFeatureState();
     return;
   }
 
-  // NOTE: Users can set any weird combinations.
   const base::Time now = clock_->Now();
-  if (end_time <= start_time) {
-    // Example:
-    // Start: 9:00 PM, End: 6:00 AM.
-    //
-    //       6:00                21:00
-    // <----- + ------------------ + ----->
-    //        |                    |
-    //       end                 start
-    //
-    // Note that the above times are times of day (today). It is important to
-    // know where "now" is with respect to these times to decide how to adjust
-    // them.
-    if (end_time >= now) {
-      // If the end time (today) is greater than the time now, this means "now"
-      // is within the feature schedule, and the start time is actually
-      // yesterday. The above timeline is interpreted as:
-      //
-      //   21:00 (-1day)              6:00
-      // <----- + ----------- + ------ + ----->
-      //        |             |        |
-      //      start          now      end
-      //
-      start_time -= base::Days(1);
-    } else {
-      // Two possibilities here:
-      // - Either "now" is greater than the end time, but less than start time.
-      //   This means the feature is outside the schedule, waiting for the next
-      //   start time. The end time is actually a day later.
-      // - Or "now" is greater than both the start and end times. This means
-      //   the feature is within the schedule, waiting to turn off at the next
-      //   end time, which is also a day later.
-      end_time += base::Days(1);
-    }
-  }
+  const schedule_utils::Position schedule_position =
+      schedule_utils::GetCurrentPosition(now, start_time, end_time,
+                                         schedule_type);
+  const bool enable_now =
+      IsEnabledAtCheckpoint(schedule_position.current_checkpoint);
+  const bool current_enabled = GetEnabled();
 
-  DCHECK_GE(end_time, start_time);
-
-  // The target status that we need to set the feature to now if a change of
-  // status is needed immediately.
-  bool enable_now = false;
-
-  // Where are we now with respect to the start and end times?
-  if (now < start_time) {
-    // Example:
-    // Start: 6:00 PM today, End: 6:00 AM tomorrow, Now: 4:00 PM.
-    //
-    // <----- + ----------- + ----------- + ----->
-    //        |             |             |
-    //       now          start          end
-    //
-    // In this case, we need to disable the feature immediately if it's enabled.
-    enable_now = false;
-  } else if (now >= start_time && now < end_time) {
-    // Example:
-    // Start: 6:00 PM today, End: 6:00 AM tomorrow, Now: 11:00 PM.
-    //
-    // <----- + ----------- + ----------- + ----->
-    //        |             |             |
-    //      start          now           end
-    //
-    // Turn the feature on right away. Our future start time is a day later than
-    // its current value.
-    enable_now = true;
-    start_time += base::Days(1);
-  } else {  // now >= end_time.
-    // Example:
-    // Start: 6:00 PM today, End: 10:00 PM today, Now: 11:00 PM.
-    //
-    // <----- + ----------- + ----------- + ----->
-    //        |             |             |
-    //      start          end           now
-    //
-    // In this case, our future start and end times are a day later from their
-    // current values. The feature needs to be off immediately if it's already
-    // enabled.
-    enable_now = false;
-    start_time += base::Days(1);
-    end_time += base::Days(1);
-  }
-
-  // After the above processing, the start and end time are all in the future.
-  DCHECK_GE(start_time, now);
-  DCHECK_GE(end_time, now);
-
-  if (did_schedule_change && enable_now != GetEnabled()) {
+  base::TimeDelta time_until_next_refresh;
+  bool next_feature_status = false;
+  ScheduleCheckpoint new_checkpoint = current_checkpoint_;
+  if (enable_now == current_enabled) {
+    // The most standard case:
+    next_feature_status =
+        IsEnabledAtCheckpoint(schedule_position.next_checkpoint);
+    time_until_next_refresh = schedule_position.time_until_next_checkpoint;
+    new_checkpoint = schedule_position.current_checkpoint;
+  } else if (did_schedule_change) {  // && enable_now != current_enabled
     // If the change in the schedule introduces a change in the status, then
     // calling SetEnabled() is all we need, since it will trigger a change in
     // the user prefs to which we will respond by calling Refresh(). This will
-    // end up in this function again, adjusting all the needed schedules.
+    // end up in this function again and enter the case above, adjusting all
+    // the needed schedules.
     SetEnabled(enable_now);
     return;
+  } else {  // enable_now != current_enabled && !did_schedule_change
+    // The user manually toggled the feature status to the opposite of what the
+    // schedule says. In this case, ignore the current `schedule_position` since
+    // it doesn't apply anymore. Just find the next time that the feature will
+    // flip back to a status that matches the schedule, and then normal
+    // scheduling logic (the 2 cases above) will resume.
+    next_feature_status = !current_enabled;
+    const base::Time next_toggle_time = schedule_utils::ShiftWithinOneDayFrom(
+        now, current_enabled ? end_time : start_time);
+    time_until_next_refresh = next_toggle_time - now;
+    new_checkpoint =
+        GetCheckpointForEnabledState(current_enabled, schedule_type);
   }
 
   // We reach here in one of the following conditions:
   // 1) If schedule changes don't result in changes in the status, we need to
-  // explicitly update the timer to re-schedule the next toggle to account for
+  // explicitly update the timer to re-schedule the next refresh to account for
   // any changes.
   // 2) The user has just manually toggled the status of the feature either from
   // the System Menu or System Settings. In this case, we respect the user
   // wish and maintain the current status that they desire, but we schedule the
   // status to be toggled according to the time that corresponds with the
   // opposite status of the current one.
-  ScheduleNextToggle(GetEnabled() ? end_time - now : start_time - now);
+  ScheduleNextRefresh(
+      {now + time_until_next_refresh, next_feature_status, new_checkpoint},
+      now);
   RefreshFeatureState();
+  // Should be called after `ScheduleNextRefresh` and `RefreshFeatureState()`
+  // so that all of the feature's internal bookkeeping has been updated before
+  // broadcasting to users that a new feature state has been reached. This
+  // ensures that the feature is in a stable internal state in case a
+  // `CheckpointObserver` tries to use the feature immediately within its
+  // observer method.
+  SetCurrentCheckpoint(new_checkpoint);
 }
 
-void ScheduledFeature::ScheduleNextToggle(base::TimeDelta delay) {
+void ScheduledFeature::ScheduleNextRefresh(
+    const ScheduleSnapshot& current_snapshot,
+    base::Time now) {
   DCHECK(active_user_pref_service_);
+  const base::TimeDelta delay = current_snapshot.target_time - now;
+  DCHECK_GE(delay, base::TimeDelta());
 
-  const bool new_status = !GetEnabled();
-  const base::Time target_time = clock_->Now() + delay;
+  per_user_schedule_snapshot_[active_user_pref_service_] = current_snapshot;
+  base::OnceClosure timer_cb;
+  if (current_snapshot.target_status == GetEnabled()) {
+    timer_cb =
+        base::BindOnce(&ScheduledFeature::Refresh, base::Unretained(this),
+                       /*did_schedule_change=*/false,
+                       /*keep_manual_toggles_during_schedules=*/false);
+  } else {
+    timer_cb =
+        base::BindOnce(&ScheduledFeature::SetEnabled, base::Unretained(this),
+                       current_snapshot.target_status);
+  }
+  VLOG(1) << "Setting " << GetFeatureName() << " to refresh to "
+          << (current_snapshot.target_status ? "enabled" : "disabled") << " at "
+          << base::TimeFormatTimeOfDay(current_snapshot.target_time);
+  timer_->Start(FROM_HERE, delay, std::move(timer_cb));
+}
 
-  per_user_schedule_target_state_[active_user_pref_service_] =
-      ScheduleTargetState{target_time, new_status};
+void ScheduledFeature::SetCurrentCheckpoint(ScheduleCheckpoint new_checkpoint) {
+  if (new_checkpoint == current_checkpoint_) {
+    return;
+  }
 
-  VLOG(1) << "Setting " << GetFeatureName() << " to toggle to "
-          << (new_status ? "enabled" : "disabled") << " at "
-          << base::TimeFormatTimeOfDay(target_time);
-  timer_->Start(FROM_HERE, delay,
-                base::BindOnce(&ScheduledFeature::SetEnabled,
-                               base::Unretained(this), new_status));
+  current_checkpoint_ = new_checkpoint;
+  for (CheckpointObserver& obs : checkpoint_observers_) {
+    obs.OnCheckpointChanged(this, current_checkpoint_);
+  }
 }
 
 }  // namespace ash
