@@ -12,6 +12,9 @@
 #include "ash/public/cpp/system_tray_client.h"
 #include "ash/shell.h"
 #include "ash/strings/grit/ash_strings.h"
+#include "ash/style/pill_button.h"
+#include "ash/style/style_util.h"
+#include "ash/style/typography.h"
 #include "ash/system/model/system_tray_model.h"
 #include "ash/system/time/calendar_metrics.h"
 #include "ash/system/time/calendar_utils.h"
@@ -28,6 +31,7 @@
 #include "ui/gfx/geometry/insets.h"
 #include "ui/views/accessibility/view_accessibility.h"
 #include "ui/views/background.h"
+#include "ui/views/controls/highlight_path_generator.h"
 #include "ui/views/controls/label.h"
 #include "ui/views/layout/box_layout.h"
 #include "ui/views/layout/fill_layout.h"
@@ -36,10 +40,12 @@ namespace ash {
 namespace {
 
 // The paddings for `CalendarEventListViewItemJelly`.
-constexpr auto kEventListItemDotOffset = 12;
 constexpr auto kEventListItemInsets =
-    gfx::Insets::TLBR(6, kEventListItemDotOffset, 6, 12);
+    gfx::Insets::VH(6, calendar_utils::kEventListItemViewStartEndMargin);
 constexpr auto kEventListItemHorizontalChildSpacing = 8;
+constexpr int kEventListItemCornerRadius = 16;
+constexpr int kEventListItemCornerDefaultRadius = 4;
+constexpr float kEventListItemFocusCornerRadius = 3.0f;
 
 // Radius of the event color dot.
 constexpr int kColorDotRadius = 4;
@@ -64,8 +70,9 @@ class CalendarEventListItemDot : public views::View {
     std::string hex_code =
         kEventHexColorCodes[color_id.empty() ? kDefaultColorId : color_id];
     base::HexStringToInt(hex_code, &color_);
-    SetPreferredSize(gfx::Size(kColorDotViewSize,
-                               kColorDotViewSize + kEventListItemDotOffset));
+    SetPreferredSize(gfx::Size(
+        kColorDotViewSize,
+        kColorDotViewSize + calendar_utils::kEventListItemViewStartEndMargin));
   }
   CalendarEventListItemDot(const CalendarEventListItemDot& other) = delete;
   CalendarEventListItemDot& operator=(const CalendarEventListItemDot& other) =
@@ -91,10 +98,10 @@ class CalendarEventListItemDot : public views::View {
 views::Builder<views::Label> CreateSummaryLabel(
     const std::string& event_summary,
     const std::u16string& tooltip_text,
-    const int& max_width) {
+    const int& fixed_width) {
   return views::Builder<views::Label>(
              bubble_utils::CreateLabel(
-                 bubble_utils::TypographyStyle::kButton1,
+                 TypographyToken::kCrosAnnotation1,
                  event_summary.empty()
                      ? l10n_util::GetStringUTF16(IDS_ASH_CALENDAR_NO_TITLE)
                      : base::UTF8ToUTF16(event_summary)))
@@ -103,7 +110,7 @@ views::Builder<views::Label> CreateSummaryLabel(
       .SetAutoColorReadabilityEnabled(false)
       .SetMultiLine(true)
       .SetMaxLines(1)
-      .SetMaximumWidth(max_width)
+      .SizeToFit(fixed_width)
       .SetElideBehavior(gfx::ElideBehavior::ELIDE_TAIL)
       .SetSubpixelRenderingEnabled(false)
       .SetTextContext(CONTEXT_CALENDAR_DATE)
@@ -115,8 +122,8 @@ views::Builder<views::Label> CreateTimeLabel(
     const std::u16string& title,
     const std::u16string& tooltip_text) {
   return views::Builder<views::Label>(
-             bubble_utils::CreateLabel(bubble_utils::TypographyStyle::kBody1,
-                                       title))
+             bubble_utils::CreateLabel(TypographyToken::kCrosAnnotation2, title,
+                                       cros_tokens::kColorSecondary))
       .SetID(kTimeLabelID)
       .SetHorizontalAlignment(gfx::HorizontalAlignment::ALIGN_LEFT)
       .SetAutoColorReadabilityEnabled(false)
@@ -126,19 +133,42 @@ views::Builder<views::Label> CreateTimeLabel(
       .SetTooltipText(tooltip_text);
 }
 
+// A `HighlightPathGenerator` that uses caller-supplied rounded rect corners.
+class VIEWS_EXPORT RoundedCornerHighlightPathGenerator
+    : public views::HighlightPathGenerator {
+ public:
+  explicit RoundedCornerHighlightPathGenerator(
+      const gfx::RoundedCornersF& corners)
+      : corners_(corners) {}
+
+  RoundedCornerHighlightPathGenerator(
+      const RoundedCornerHighlightPathGenerator&) = delete;
+  RoundedCornerHighlightPathGenerator& operator=(
+      const RoundedCornerHighlightPathGenerator&) = delete;
+
+  // views::HighlightPathGenerator:
+  absl::optional<gfx::RRectF> GetRoundRect(const gfx::RectF& rect) override {
+    return gfx::RRectF(rect, corners_);
+  }
+
+ private:
+  // The user-supplied rounded rect corners.
+  const gfx::RoundedCornersF corners_;
+};
+
 }  // namespace
 
 CalendarEventListItemViewJelly::CalendarEventListItemViewJelly(
     CalendarViewController* calendar_view_controller,
     SelectedDateParams selected_date_params,
     google_apis::calendar::CalendarEvent event,
-    const bool round_top_corners,
-    const bool round_bottom_corners,
-    const int max_width)
+    UIParams ui_params,
+    EventListItemIndex event_list_item_index)
     : ActionableView(TrayPopupInkDropStyle::FILL_BOUNDS),
       calendar_view_controller_(calendar_view_controller),
       selected_date_params_(selected_date_params),
-      event_url_(event.html_link()) {
+      event_url_(event.html_link()),
+      video_conference_url_(event.conference_data_uri()) {
   SetLayoutManager(std::make_unique<views::FillLayout>());
 
   const auto [start_time, end_time] = calendar_utils::GetStartAndEndTime(
@@ -149,28 +179,32 @@ CalendarEventListItemViewJelly::CalendarEventListItemViewJelly(
       event_date_formatter_util::GetStartAndEndTimeAccessibleNames(start_time,
                                                                    end_time);
   GetViewAccessibility().OverrideRole(ax::mojom::Role::kButton);
+  const std::u16string event_item_index_in_list_string =
+      l10n_util::GetStringFUTF16(
+          IDS_ASH_CALENDAR_EVENT_POSITION_ACCESSIBLE_DESCRIPTION,
+          base::NumberToString16(event_list_item_index.item_index),
+          base::NumberToString16(event_list_item_index.total_count_of_events));
   SetAccessibleName(l10n_util::GetStringFUTF16(
-      IDS_ASH_CALENDAR_EVENT_ENTRY_ACCESSIBLE_DESCRIPTION,
+      IDS_ASH_CALENDAR_EVENT_ENTRY_ACCESSIBLE_DESCRIPTION_JELLY,
+      event_item_index_in_list_string, base::UTF8ToUTF16(event.summary()),
       start_time_accessible_name, end_time_accessible_name,
-      calendar_utils::GetTimeZone(start_time),
-      base::UTF8ToUTF16(event.summary())));
+      calendar_utils::GetTimeZone(start_time)));
   SetFocusBehavior(FocusBehavior::ALWAYS);
 
   // Conditionally round the items corners depending upon where it sits in the
   // list.
-  const int top_radius = round_top_corners ? 12 : 0;
-  const int bottom_radius = round_bottom_corners ? 12 : 0;
+  const int top_radius = ui_params.round_top_corners
+                             ? kEventListItemCornerRadius
+                             : kEventListItemCornerDefaultRadius;
+  const int bottom_radius = ui_params.round_bottom_corners
+                                ? kEventListItemCornerRadius
+                                : kEventListItemCornerDefaultRadius;
   const gfx::RoundedCornersF item_corner_radius = gfx::RoundedCornersF(
       top_radius, top_radius, bottom_radius, bottom_radius);
   SetPaintToLayer();
   layer()->SetFillsBoundsOpaquely(false);
   layer()->SetRoundedCornerRadius(item_corner_radius);
-
-  auto horizontal_layout_manager = std::make_unique<views::BoxLayout>(
-      views::BoxLayout::Orientation::kHorizontal, kEventListItemInsets,
-      kEventListItemHorizontalChildSpacing);
-  horizontal_layout_manager->set_cross_axis_alignment(
-      views::BoxLayout::CrossAxisAlignment::kStart);
+  SetUpFocusHighlight(item_corner_radius);
 
   std::u16string formatted_time_text;
   if (calendar_utils::IsMultiDayEvent(&event) || event.all_day_event()) {
@@ -185,19 +219,63 @@ CalendarEventListItemViewJelly::CalendarEventListItemViewJelly(
       IDS_ASH_CALENDAR_EVENT_ENTRY_TOOL_TIP, base::UTF8ToUTF16(event.summary()),
       formatted_time_text);
 
-  AddChildView(
-      views::Builder<views::View>()
-          .SetLayoutManager(std::move(horizontal_layout_manager))
-          .AddChild(views::Builder<views::View>(
-              std::make_unique<CalendarEventListItemDot>(event.color_id())))
-          .AddChild(
-              views::Builder<views::View>()
-                  .SetLayoutManager(std::make_unique<views::BoxLayout>(
-                      views::BoxLayout::Orientation::kVertical))
-                  .AddChild(CreateSummaryLabel(event.summary(), tooltip_text,
-                                               max_width))
-                  .AddChild(CreateTimeLabel(formatted_time_text, tooltip_text)))
+  auto horizontal_layout_manager = std::make_unique<views::BoxLayout>(
+      views::BoxLayout::Orientation::kHorizontal, kEventListItemInsets,
+      kEventListItemHorizontalChildSpacing);
+  views::View* horizontal_container =
+      AddChildView(std::make_unique<views::View>());
+  auto* horizontal_container_layout_manager =
+      horizontal_container->SetLayoutManager(
+          std::move(horizontal_layout_manager));
+
+  // Event list dot.
+  if (ui_params.show_event_list_dot) {
+    views::View* event_list_dot_container =
+        horizontal_container->AddChildView(std::make_unique<views::View>());
+    auto* layout_vertical_start = event_list_dot_container->SetLayoutManager(
+        std::make_unique<views::BoxLayout>(
+            views::BoxLayout::Orientation::kVertical));
+    layout_vertical_start->set_main_axis_alignment(
+        views::BoxLayout::MainAxisAlignment::kStart);
+    event_list_dot_container
+        ->AddChildView(
+            std::make_unique<CalendarEventListItemDot>(event.color_id()))
+        ->SetID(kEventListItemDotID);
+  }
+
+  // Labels.
+  views::View* vertical_container =
+      horizontal_container->AddChildView(std::make_unique<views::View>());
+  vertical_container->SetLayoutManager(std::make_unique<views::BoxLayout>(
+      views::BoxLayout::Orientation::kVertical));
+  vertical_container->AddChildView(
+      CreateSummaryLabel(event.summary(), tooltip_text, ui_params.fixed_width)
           .Build());
+  vertical_container->AddChildView(
+      CreateTimeLabel(formatted_time_text, tooltip_text).Build());
+  horizontal_container_layout_manager->SetFlexForView(vertical_container, 1);
+
+  // Join button.
+  if (!video_conference_url_.is_empty()) {
+    views::View* join_button_container =
+        horizontal_container->AddChildView(std::make_unique<views::View>());
+    auto* layout_vertical_center = join_button_container->SetLayoutManager(
+        std::make_unique<views::BoxLayout>(
+            views::BoxLayout::Orientation::kVertical));
+    layout_vertical_center->set_main_axis_alignment(
+        views::BoxLayout::MainAxisAlignment::kCenter);
+    auto join_button = std::make_unique<PillButton>(
+        base::BindRepeating(
+            &CalendarEventListItemViewJelly::OnJoinMeetingButtonPressed,
+            weak_ptr_factory_.GetWeakPtr()),
+        l10n_util::GetStringUTF16(IDS_ASH_CALENDAR_JOIN_BUTTON),
+        PillButton::Type::kPrimaryWithoutIcon);
+    join_button->SetAccessibleName(
+        l10n_util::GetStringFUTF16(IDS_ASH_CALENDAR_JOIN_BUTTON_ACCESSIBLE_NAME,
+                                   base::UTF8ToUTF16(event.summary())));
+    join_button->SetID(kJoinButtonID);
+    join_button_container->AddChildView(std::move(join_button));
+  }
 }
 
 CalendarEventListItemViewJelly::~CalendarEventListItemViewJelly() = default;
@@ -222,6 +300,34 @@ bool CalendarEventListItemViewJelly::PerformAction(const ui::Event& event) {
   return true;
 }
 
+void CalendarEventListItemViewJelly::SetUpFocusHighlight(
+    const gfx::RoundedCornersF& item_corner_radius) {
+  StyleUtil::SetUpInkDropForButton(this, gfx::Insets(),
+                                   /*highlight_on_hover=*/false,
+                                   /*highlight_on_focus=*/false,
+                                   /*background_color=*/
+                                   gfx::kPlaceholderColor);
+  views::FocusRing::Get(this)->SetColorId(ui::kColorAshFocusRing);
+  views::FocusRing::Get(this)->SetHaloThickness(
+      kEventListItemFocusCornerRadius);
+  views::HighlightPathGenerator::Install(
+      this, std::make_unique<RoundedCornerHighlightPathGenerator>(
+                item_corner_radius));
+  // Unset the focus painter set by `ActionableView`.
+  SetFocusPainter(nullptr);
+}
+
+void CalendarEventListItemViewJelly::OnJoinMeetingButtonPressed(
+    const ui::Event& event) {
+  calendar_view_controller_->RecordJoinMeetingButtonPressed(event);
+
+  // The join button won't be shown if `video_conference_url_` doesn't have a
+  // value.
+  DCHECK(!video_conference_url_.is_empty());
+  Shell::Get()->system_tray_model()->client()->ShowVideoConference(
+      video_conference_url_);
+}
+
 BEGIN_METADATA(CalendarEventListItemViewJelly, views::View);
 END_METADATA
 
