@@ -46,7 +46,8 @@ std::unique_ptr<google_apis::calendar::CalendarEvent> CreateEvent(
     const google_apis::calendar::CalendarEvent::EventStatus event_status,
     const google_apis::calendar::CalendarEvent::ResponseStatus
         self_response_status,
-    const bool all_day_event) {
+    bool all_day_event,
+    GURL video_conference_url) {
   auto event = std::make_unique<google_apis::calendar::CalendarEvent>();
   base::Time start_time_base, end_time_base;
   google_apis::calendar::DateTime start_time_date, end_time_date;
@@ -70,6 +71,7 @@ std::unique_ptr<google_apis::calendar::CalendarEvent> CreateEvent(
   event->set_status(event_status);
   event->set_self_response_status(self_response_status);
   event->set_all_day_event(all_day_event);
+  event->set_conference_data_uri(video_conference_url);
   return event;
 }
 
@@ -81,7 +83,8 @@ std::unique_ptr<google_apis::calendar::CalendarEvent> CreateEvent(
     const google_apis::calendar::CalendarEvent::EventStatus event_status,
     const google_apis::calendar::CalendarEvent::ResponseStatus
         self_response_status,
-    const bool all_day_event) {
+    bool all_day_event,
+    GURL video_conference_url) {
   auto event = std::make_unique<google_apis::calendar::CalendarEvent>();
   google_apis::calendar::DateTime start_time_date, end_time_date;
   event->set_id(id);
@@ -93,6 +96,7 @@ std::unique_ptr<google_apis::calendar::CalendarEvent> CreateEvent(
   event->set_status(event_status);
   event->set_self_response_status(self_response_status);
   event->set_all_day_event(all_day_event);
+  event->set_conference_data_uri(video_conference_url);
   return event;
 }
 
