@@ -4,8 +4,10 @@
 
 #include "ash/system/time/calendar_up_next_view.h"
 
+#include "ash/public/cpp/test/test_system_tray_client.h"
 #include "ash/shell.h"
 #include "ash/system/model/system_tray_model.h"
+#include "ash/system/time/calendar_event_list_item_view_jelly.h"
 #include "ash/system/time/calendar_unittest_utils.h"
 #include "ash/system/time/calendar_view_controller.h"
 #include "ash/system/tray/tray_constants.h"
@@ -23,12 +25,32 @@ namespace {
 std::unique_ptr<google_apis::calendar::CalendarEvent> CreateEvent(
     const base::Time start_time,
     const base::Time end_time,
-    bool all_day_event = false) {
+    bool all_day_event = false,
+    const GURL video_conference_url = GURL()) {
   return calendar_test_utils::CreateEvent(
       "id_0", "summary_0", start_time, end_time,
       google_apis::calendar::CalendarEvent::EventStatus::kConfirmed,
       google_apis::calendar::CalendarEvent::ResponseStatus::kAccepted,
-      all_day_event);
+      all_day_event, video_conference_url);
+}
+
+std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>>
+CreateUpcomingEvents(int event_count = 1,
+                     bool all_day_event = false,
+                     const GURL video_conference_url = GURL()) {
+  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
+  auto event_in_ten_mins_start_time =
+      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
+      base::Minutes(10);
+  auto event_in_ten_mins_end_time =
+      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
+  for (int i = 0; i < event_count; ++i) {
+    events.push_back(CreateEvent(event_in_ten_mins_start_time,
+                                 event_in_ten_mins_end_time, all_day_event,
+                                 video_conference_url));
+  }
+
+  return events;
 }
 
 }  // namespace
@@ -54,8 +76,9 @@ class CalendarUpNextViewTest : public AshTestBase {
       std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events,
       views::Button::PressedCallback callback =
           views::Button::PressedCallback()) {
-    if (!widget_)
+    if (!widget_) {
       widget_ = CreateFramelessTestWidget();
+    }
 
     // Mock events being fetched.
     Shell::Get()->system_tray_model()->calendar_model()->OnEventsFetched(
@@ -105,6 +128,16 @@ class CalendarUpNextViewTest : public AshTestBase {
     PressScrollButton(GetScrollRightButton());
   }
 
+  void PressTab() {
+    ui::test::EventGenerator generator(Shell::GetPrimaryRootWindow());
+    generator.PressKey(ui::KeyboardCode::VKEY_TAB, ui::EF_NONE);
+  }
+
+  void PressShiftTab() {
+    ui::test::EventGenerator generator(Shell::GetPrimaryRootWindow());
+    generator.PressKey(ui::KeyboardCode::VKEY_TAB, ui::EF_SHIFT_DOWN);
+  }
+
   int ScrollPosition() { return GetScrollView()->GetVisibleRect().x(); }
 
   void ScrollHorizontalPositionTo(int position_in_px) {
@@ -173,17 +206,8 @@ TEST_F(CalendarUpNextViewTest,
       []() { return base::subtle::TimeNowIgnoringOverride().LocalMidnight(); },
       nullptr, nullptr);
 
-  // Add single event starting in 10 mins.
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
-      base::Minutes(10);
-  auto event_in_ten_mins_end_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
-  events.push_back(
-      CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-
-  CreateUpNextView(std::move(events));
+  // Create UpNextView with a single upcoming event.
+  CreateUpNextView(CreateUpcomingEvents());
 
   EXPECT_EQ(GetContentsView()->children().size(), size_t(1));
   EXPECT_EQ(GetContentsView()->children()[0]->width(),
@@ -197,21 +221,11 @@ TEST_F(CalendarUpNextViewTest,
       []() { return base::subtle::TimeNowIgnoringOverride().LocalMidnight(); },
       nullptr, nullptr);
 
-  // Add multiple events starting in 10 mins.
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
-      base::Minutes(10);
-  auto event_in_ten_mins_end_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
-  for (int i = 0; i < 5; ++i) {
-    events.push_back(
-        CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-  }
+  // Add multiple upcoming events.
+  const int event_count = 5;
+  CreateUpNextView(CreateUpcomingEvents(event_count));
 
-  CreateUpNextView(std::move(events));
-
-  EXPECT_EQ(GetContentsView()->children().size(), size_t(5));
+  EXPECT_EQ(GetContentsView()->children().size(), size_t(event_count));
   EXPECT_EQ(ScrollPosition(), 0);
 
   // Press scroll right. We should scroll past the first event + margin.
@@ -246,17 +260,8 @@ TEST_F(CalendarUpNextViewTest, ShouldHideScrollButtons_WhenOnlyOneEvent) {
       []() { return base::subtle::TimeNowIgnoringOverride().LocalMidnight(); },
       nullptr, nullptr);
 
-  // Add single event starting in 10 mins.
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
-      base::Minutes(10);
-  auto event_in_ten_mins_end_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
-  events.push_back(
-      CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-
-  CreateUpNextView(std::move(events));
+  // Create UpNextView with a single upcoming event.
+  CreateUpNextView(CreateUpcomingEvents());
 
   EXPECT_EQ(GetContentsView()->children().size(), size_t(1));
   EXPECT_EQ(ScrollPosition(), 0);
@@ -273,21 +278,10 @@ TEST_F(CalendarUpNextViewTest, ShouldShowScrollButtons_WhenMultipleEvents) {
       []() { return base::subtle::TimeNowIgnoringOverride().LocalMidnight(); },
       nullptr, nullptr);
 
-  // Add multiple events starting in 10 mins.
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
-      base::Minutes(10);
-  auto event_in_ten_mins_end_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
-  for (int i = 0; i < 5; ++i) {
-    events.push_back(
-        CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-  }
-
-  CreateUpNextView(std::move(events));
-
-  EXPECT_EQ(GetContentsView()->children().size(), size_t(5));
+  // Add multiple upcoming events.
+  const int event_count = 5;
+  CreateUpNextView(CreateUpcomingEvents(event_count));
+  EXPECT_EQ(GetContentsView()->children().size(), size_t(event_count));
 
   // At the start the scroll left button should be disabled and visible.
   EXPECT_EQ(ScrollPosition(), 0);
@@ -333,40 +327,33 @@ TEST_F(
   calendar_test_utils::ScopedLibcTimeZone scoped_libc_timezone("GMT");
   ASSERT_TRUE(scoped_libc_timezone.is_success());
 
-  // Add multiple events starting in 10 mins.
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
-      base::Minutes(10);
-  auto event_in_ten_mins_end_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
-  for (int i = 0; i < 5; ++i) {
-    events.push_back(
-        CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-  }
-
-  CreateUpNextView(std::move(events));
-
-  EXPECT_EQ(GetContentsView()->children().size(), size_t(5));
+  // Add multiple upcoming events.
+  const int event_count = 5;
+  CreateUpNextView(CreateUpcomingEvents(event_count));
+  EXPECT_EQ(GetContentsView()->children().size(), size_t(event_count));
   EXPECT_EQ(ScrollPosition(), 0);
 
-  // Scroll right so the second event is partially visible on the left of the
-  // scrollview.
-  ScrollHorizontalPositionTo(200);
-  ASSERT_EQ(ScrollPosition(), 200);
+  // Scroll right past the first event and so that the second event is partially
+  // visible on the left of the scrollview.
+  const int first_event_width =
+      GetContentsView()->children()[0]->GetContentsBounds().width() +
+      calendar_utils::kUpNextBetweenChildSpacing;
+  const int scroll_position_partially_over_second_event =
+      first_event_width + 50;
+  ScrollHorizontalPositionTo(scroll_position_partially_over_second_event);
+  ASSERT_EQ(scroll_position_partially_over_second_event, ScrollPosition());
+  const views::View* first_event = GetContentsView()->children()[0];
   const views::View* second_event = GetContentsView()->children()[1];
-  // Assert second view is partially visible.
-  EXPECT_TRUE(second_event->GetVisibleBounds().width() <
-              second_event->GetContentsBounds().width());
+  // Assert first view is not visible and second view is partially visible.
+  ASSERT_EQ(0, first_event->GetVisibleBounds().width());
+  EXPECT_LT(second_event->GetVisibleBounds().width(),
+            second_event->GetContentsBounds().width());
 
   // Press scroll left. We should scroll so that the second event is aligned to
   // the start of the scroll view and fully visible. This is the equivalent
   // position of being scrolled to the right of the width of the first event.
-  const int first_event_width =
-      GetContentsView()->children()[0]->GetContentsBounds().width() +
-      calendar_utils::kUpNextBetweenChildSpacing;
   PressScrollLeftButton();
-  EXPECT_EQ(ScrollPosition(), first_event_width);
+  EXPECT_EQ(first_event_width, ScrollPosition());
 }
 
 // If we have a partially visible event and the scroll right button is pressed,
@@ -386,21 +373,10 @@ TEST_F(
       []() { return base::subtle::TimeNowIgnoringOverride().LocalMidnight(); },
       nullptr, nullptr);
 
-  // Add multiple events starting in 10 mins.
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
-      base::Minutes(10);
-  auto event_in_ten_mins_end_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
-  for (int i = 0; i < 5; ++i) {
-    events.push_back(
-        CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-  }
-
-  CreateUpNextView(std::move(events));
-
-  EXPECT_EQ(GetContentsView()->children().size(), size_t(5));
+  // Add multiple upcoming events.
+  const int event_count = 5;
+  CreateUpNextView(CreateUpcomingEvents(event_count));
+  EXPECT_EQ(GetContentsView()->children().size(), size_t(event_count));
   EXPECT_EQ(ScrollPosition(), 0);
 
   ScrollHorizontalPositionTo(100);
@@ -425,21 +401,12 @@ TEST_F(CalendarUpNextViewTest,
       []() { return base::subtle::TimeNowIgnoringOverride().LocalMidnight(); },
       nullptr, nullptr);
 
-  // Add event starting in 10 mins.
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
-      base::Minutes(10);
-  auto event_in_ten_mins_end_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
-  events.push_back(
-      CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-
   bool called = false;
   auto callback = base::BindLambdaForTesting(
       [&called](const ui::Event& event) { called = true; });
 
-  CreateUpNextView(std::move(events), callback);
+  // Create UpNextView with a single upcoming event.
+  CreateUpNextView(CreateUpcomingEvents(), callback);
   EXPECT_FALSE(called);
 
   LeftClickOn(GetTodaysEventsButton());
@@ -453,19 +420,9 @@ TEST_F(CalendarUpNextViewTest, ShouldTrackLaunchingFromEventListItem) {
       []() { return base::subtle::TimeNowIgnoringOverride().LocalMidnight(); },
       nullptr, nullptr);
 
-  // Add an upcoming event.
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
-      base::Minutes(10);
-  auto event_in_ten_mins_end_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
-  events.push_back(
-      CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-
+  // Create UpNextView with a single upcoming event.
   auto histogram_tester = std::make_unique<base::HistogramTester>();
-  CreateUpNextView(std::move(events));
-
+  CreateUpNextView(CreateUpcomingEvents());
   EXPECT_EQ(GetContentsView()->children().size(), size_t(1));
 
   // Click event inside the scrollview contents.
@@ -482,27 +439,96 @@ TEST_F(CalendarUpNextViewTest, ShouldTrackEventDisplayedCount) {
       nullptr, nullptr);
 
   // Add 5 upcoming events.
-  const int event_count = 5;
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() +
-      base::Minutes(10);
-  auto event_in_ten_mins_end_time =
-      base::subtle::TimeNowIgnoringOverride().LocalMidnight() + base::Hours(1);
-  for (int i = 0; i < event_count; ++i) {
-    events.push_back(
-        CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-  }
-
   auto histogram_tester = std::make_unique<base::HistogramTester>();
-  CreateUpNextView(std::move(events));
-
+  const int event_count = 5;
+  CreateUpNextView(CreateUpcomingEvents(event_count));
   EXPECT_EQ(GetContentsView()->children().size(), size_t(event_count));
 
   histogram_tester->ExpectBucketCount(
       "Ash.Calendar.UpNextView.EventDisplayedCount", event_count, 1);
 }
 
+TEST_F(CalendarUpNextViewTest,
+       ShouldLaunchAndTrackGoogleMeet_WhenJoinMeetingButtonPressed) {
+  // Set time override.
+  base::subtle::ScopedTimeClockOverrides time_override(
+      []() { return base::subtle::TimeNowIgnoringOverride().LocalMidnight(); },
+      nullptr, nullptr);
+
+  auto histogram_tester = std::make_unique<base::HistogramTester>();
+  // Create up next view with upcoming google meet event.
+  CreateUpNextView(
+      CreateUpcomingEvents(1, false, GURL("https://meet.google.com/abc-123")));
+  EXPECT_EQ(GetContentsView()->children().size(), size_t(1));
+  EXPECT_EQ(GetSystemTrayClient()->show_video_conference_count(), 0);
+
+  // Click the "Join" meeting button.
+  const auto* join_meeting_button =
+      GetContentsView()->children()[0]->GetViewByID(kJoinButtonID);
+  ASSERT_TRUE(join_meeting_button);
+  LeftClickOn(join_meeting_button);
+
+  EXPECT_EQ(GetSystemTrayClient()->show_video_conference_count(), 1);
+  histogram_tester->ExpectTotalCount(
+      "Ash.Calendar.UpNextView.JoinMeetingButton.Pressed", 1);
+}
+
+// Greenlines can be found in b/258648030.
+TEST_F(CalendarUpNextViewTest, ShouldFocusViewsInCorrectOrder_WhenPressingTab) {
+  // Set time override.
+  base::subtle::ScopedTimeClockOverrides time_override(
+      []() { return base::subtle::TimeNowIgnoringOverride().LocalMidnight(); },
+      nullptr, nullptr);
+
+  // Create up next view with 2 upcoming google meet events.
+  CreateUpNextView(
+      CreateUpcomingEvents(2, false, GURL("https://meet.google.com/abc-123")));
+  EXPECT_EQ(GetContentsView()->children().size(), size_t(2));
+  auto* focus_manager = up_next_view()->GetFocusManager();
+
+  // First the event list item view should be focused.
+  PressTab();
+  auto* first_item = GetContentsView()->children()[0];
+  ASSERT_TRUE(first_item);
+  EXPECT_EQ(first_item, focus_manager->GetFocusedView());
+  EXPECT_STREQ("CalendarEventListItemViewJelly",
+               focus_manager->GetFocusedView()->GetClassName());
+
+  // Next, the "Join" button should be focused.
+  PressTab();
+  EXPECT_EQ(first_item->GetViewByID(kJoinButtonID),
+            focus_manager->GetFocusedView());
+
+  // Next, the second event list item view should be focused.
+  PressTab();
+  auto* second_item = GetContentsView()->children()[1];
+  ASSERT_TRUE(second_item);
+  EXPECT_EQ(second_item, focus_manager->GetFocusedView());
+  EXPECT_STREQ("CalendarEventListItemViewJelly",
+               focus_manager->GetFocusedView()->GetClassName());
+
+  // Next, the second event list item view "Join" button should be focused.
+  PressTab();
+  EXPECT_EQ(second_item->GetViewByID(kJoinButtonID),
+            focus_manager->GetFocusedView());
+
+  // Finally, the show upcoming events button should be focused.
+  PressTab();
+  EXPECT_EQ(GetTodaysEventsButton(), focus_manager->GetFocusedView());
+
+  // Going back, the second event list item view "Join" button should be
+  // focused.
+  PressShiftTab();
+  EXPECT_EQ(second_item->GetViewByID(kJoinButtonID),
+            focus_manager->GetFocusedView());
+
+  // Going back again, the second event list item view should be focused.
+  PressShiftTab();
+  EXPECT_EQ(second_item, focus_manager->GetFocusedView());
+  EXPECT_STREQ("CalendarEventListItemViewJelly",
+               focus_manager->GetFocusedView()->GetClassName());
+}
+
 class CalendarUpNextViewAnimationTest : public CalendarUpNextViewTest {
  public:
   CalendarUpNextViewAnimationTest()
@@ -527,16 +553,9 @@ class CalendarUpNextViewAnimationTest : public CalendarUpNextViewTest {
 // Flaky: https://crbug.com/1401505
 TEST_F(CalendarUpNextViewAnimationTest,
        DISABLED_ShouldAnimateScrollView_WhenScrollButtonsArePressed) {
-  // Add multiple events starting in 10 mins.
-  std::list<std::unique_ptr<google_apis::calendar::CalendarEvent>> events;
-  auto event_in_ten_mins_start_time = base::Time::Now() + base::Minutes(10);
-  auto event_in_ten_mins_end_time = base::Time::Now() + base::Hours(1);
-  for (int i = 0; i < 5; ++i) {
-    events.push_back(
-        CreateEvent(event_in_ten_mins_start_time, event_in_ten_mins_end_time));
-  }
-
-  CreateUpNextView(std::move(events));
+  // Add multiple upcoming events.
+  const int event_count = 5;
+  CreateUpNextView(CreateUpcomingEvents(event_count));
   EXPECT_FALSE(IsAnimating());
 
   PressScrollRightButton();
