@@ -325,21 +325,19 @@ class ASH_EXPORT CalendarView : public CalendarModel::Observer,
   // shown in `scroll_view_`'s visible window.
   int CalculateFirstFullyVisibleRow();
 
-  // Set the bounds of the EventListView to be flush with the bottom of the
-  // scroll view. Only the position will be animated, so give the view its final
-  // bounds.
-  void SetEventListViewBounds();
+  // Sets the bounds of the container of the `up_next_view_` and
+  // `event_list_view_` to be flush with the bottom of the scroll view. Only the
+  // position will be animated, so give the view its final bounds.
+  void SetCalendarSlidingSurfaceBounds(bool event_list_view_open);
 
-  // Conditionally displays the "Up next" view.
+  // Conditionally displays the `up_next_view_`.
   void MaybeShowUpNextView();
 
-  // Removes the "Up next" view.
+  // Removes the `up_next_view_`.
   void RemoveUpNextView();
 
-  // Sets the bounds of the up next view to be flush with the bottom of the
-  // scrollview. We need to do this manually so it sits over the top of the
-  // scrollview, rather than as an adjacent sibling.
-  void SetUpNextViewBounds();
+  // Animation callback.
+  void OnShowUpNextComplete();
 
   // Used by the `CalendarUpNextView` to open the event list for today's date.
   void OpenEventListForTodaysDate();
@@ -365,6 +363,7 @@ class ASH_EXPORT CalendarView : public CalendarModel::Observer,
   UnifiedSystemTrayController* controller_;
 
   std::unique_ptr<CalendarViewController> calendar_view_controller_;
+
   // Reset `scrolling_settled_timer_`.
   void reset_scrolling_settled_timer() { scrolling_settled_timer_.Reset(); }
 
@@ -390,6 +389,7 @@ class ASH_EXPORT CalendarView : public CalendarModel::Observer,
   IconButton* managed_button_ = nullptr;
   IconButton* up_button_ = nullptr;
   IconButton* down_button_ = nullptr;
+  views::View* calendar_sliding_surface_ = nullptr;
   CalendarEventListView* event_list_view_ = nullptr;
   CalendarUpNextView* up_next_view_ = nullptr;
   std::map<base::Time, CalendarModel::FetchingStatus> on_screen_month_;
