@@ -6,15 +6,13 @@
 #define ASH_SYSTEM_TIME_TIME_TRAY_ITEM_VIEW_H_
 
 #include "ash/ash_export.h"
-#include "ash/public/cpp/session/session_observer.h"
 #include "ash/system/tray/tray_item_view.h"
 #include "time_view.h"
 
 namespace ash {
 class Shelf;
 
-class ASH_EXPORT TimeTrayItemView : public TrayItemView,
-                                    public SessionObserver {
+class ASH_EXPORT TimeTrayItemView : public TrayItemView {
  public:
   TimeTrayItemView(Shelf* shelf, TimeView::Type type);
 
@@ -29,18 +27,13 @@ class ASH_EXPORT TimeTrayItemView : public TrayItemView,
   // TrayItemView:
   void HandleLocaleChange() override;
 
-  // SessionObserver:
-  void OnSessionStateChanged(session_manager::SessionState state) override;
-
   // views::View:
   const char* GetClassName() const override;
-  void OnThemeChanged() override;
 
  private:
   friend class TimeTrayItemViewTest;
 
   TimeView* time_view_ = nullptr;
-  ScopedSessionObserver session_observer_;
 };
 
 }  // namespace ash
