@@ -228,6 +228,11 @@ void ToastManagerImpl::OnSessionStateChanged(
   }
 }
 
+const ToastData& ToastManagerImpl::GetCurrentToastDataForTesting() const {
+  DCHECK(current_toast_data_);
+  return current_toast_data_.value();
+}
+
 void ToastManagerImpl::ShowLatest() {
   DCHECK(!HasActiveToasts());
   DCHECK(!current_toast_data_);
@@ -272,10 +277,10 @@ void ToastManagerImpl::CreateToastOverlayForRoot(aura::Window* root_window) {
   DCHECK(current_toast_data_);
   new_overlay = std::make_unique<ToastOverlay>(
       this, current_toast_data_->text, current_toast_data_->dismiss_text,
-      current_toast_data_->duration,
+      *current_toast_data_->leading_icon, current_toast_data_->duration,
       current_toast_data_->visible_on_lock_screen && locked_,
-      current_toast_data_->is_managed, current_toast_data_->persist_on_hover,
-      root_window, current_toast_data_->dismiss_callback);
+      current_toast_data_->persist_on_hover, root_window,
+      current_toast_data_->dismiss_callback);
   new_overlay->Show(true);
 
   // We only want to record this value when the first instance of the toast is
