@@ -143,9 +143,9 @@ class ToastOverlay::ToastHoverObserver : public ui::EventObserver {
 ToastOverlay::ToastOverlay(Delegate* delegate,
                            const std::u16string& text,
                            const std::u16string& dismiss_text,
+                           const gfx::VectorIcon& leading_icon,
                            base::TimeDelta duration,
                            bool show_on_lock_screen,
-                           bool is_managed,
                            bool persist_on_hover,
                            aura::Window* root_window,
                            base::RepeatingClosure dismiss_callback)
@@ -158,7 +158,7 @@ ToastOverlay::ToastOverlay(Delegate* delegate,
                               base::Unretained(this)),
           text,
           dismiss_text,
-          is_managed)),
+          leading_icon)),
       display_observer_(std::make_unique<ToastDisplayObserver>(this)),
       root_window_(root_window),
       dismiss_callback_(std::move(dismiss_callback)),
