@@ -1,4 +1,4 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -63,7 +63,7 @@ class TrayEventFilterTest : public AshTestBase {
   std::string AddNotification() {
     std::string notification_id = base::NumberToString(notification_id_++);
     MessageCenter::Get()->AddNotification(std::make_unique<Notification>(
-        message_center::NOTIFICATION_TYPE_BASE_FORMAT, notification_id,
+        message_center::NOTIFICATION_TYPE_SIMPLE, notification_id,
         u"test title", u"test message", ui::ImageModel(),
         std::u16string() /* display_source */, GURL(),
         message_center::NotifierId(), message_center::RichNotificationData(),
@@ -124,6 +124,26 @@ TEST_F(TrayEventFilterTest, ClickingInsideDoesNotCloseBubble) {
   EXPECT_TRUE(IsBubbleShown());
 }
 
+TEST_F(TrayEventFilterTest, DraggingInsideDoesNotCloseBubble) {
+  ShowSystemTrayMainView();
+  EXPECT_TRUE(IsBubbleShown());
+
+  // Dragging within the bubble should not close the bubble.
+  const gfx::Rect tray_bounds = GetSystemTrayBoundsInScreen();
+  const gfx::Point start = tray_bounds.origin();
+  const gfx::Point end_inside = start + gfx::Vector2d(5, 5);
+  GetEventGenerator()->GestureScrollSequence(start, end_inside,
+                                             base::Milliseconds(100), 4);
+  EXPECT_TRUE(IsBubbleShown());
+
+  // Dragging from inside to outside of the bubble should not close the bubble.
+  const gfx::Point start_inside = end_inside;
+  const gfx::Point end_outside = start + gfx::Vector2d(-5, -5);
+  GetEventGenerator()->GestureScrollSequence(start_inside, end_outside,
+                                             base::Milliseconds(100), 4);
+  EXPECT_TRUE(IsBubbleShown());
+}
+
 TEST_F(TrayEventFilterTest, ClickingOnMenuContainerDoesNotCloseBubble) {
   // Create a menu window and place it in the menu container window.
   std::unique_ptr<aura::Window> menu_window = CreateTestWindow();
@@ -190,6 +210,20 @@ TEST_F(TrayEventFilterTest, ClickingOnKeyboardContainerDoesNotCloseBubble) {
   EXPECT_TRUE(IsBubbleShown());
 }
 
+TEST_F(TrayEventFilterTest, DraggingOnTrayClosesBubble) {
+  ShowSystemTrayMainView();
+  EXPECT_TRUE(IsBubbleShown());
+
+  // Dragging on the tray background view should close the bubble.
+  const gfx::Rect tray_bounds =
+      GetPrimaryUnifiedSystemTray()->GetBoundsInScreen();
+  const gfx::Point start = tray_bounds.CenterPoint();
+  const gfx::Point end_inside = start + gfx::Vector2d(0, 10);
+  GetEventGenerator()->GestureScrollSequence(start, end_inside,
+                                             base::Milliseconds(100), 4);
+  EXPECT_FALSE(IsBubbleShown());
+}
+
 TEST_F(TrayEventFilterTest, MessageCenterAndSystemTrayStayOpenTogether) {
   AddNotification();
 
