@@ -1,11 +1,14 @@
-// Copyright 2019 The Chromium Authors. All rights reserved.
+// Copyright 2019 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 #include "ash/system/unified/custom_shape_button.h"
 
 #include "ash/style/ash_color_provider.h"
-#include "ash/system/tray/tray_popup_utils.h"
+#include "ash/style/color_util.h"
+#include "ash/style/style_util.h"
+#include "ui/base/metadata/metadata_impl_macros.h"
+#include "ui/color/color_id.h"
 #include "ui/compositor/paint_recorder.h"
 #include "ui/gfx/image/image_skia_operations.h"
 #include "ui/gfx/skbitmap_operations.h"
@@ -35,9 +38,10 @@ namespace ash {
 
 CustomShapeButton::CustomShapeButton(PressedCallback callback)
     : ImageButton(std::move(callback)) {
-  TrayPopupUtils::ConfigureTrayPopupButton(this);
+  StyleUtil::SetUpInkDropForButton(this);
   views::HighlightPathGenerator::Install(
       this, std::make_unique<CustomShapeButtonHighlightPathGenerator>());
+  views::FocusRing::Get(this)->SetColorId(ui::kColorAshFocusRing);
 }
 
 CustomShapeButton::~CustomShapeButton() = default;
@@ -47,29 +51,19 @@ void CustomShapeButton::PaintButtonContents(gfx::Canvas* canvas) {
   views::ImageButton::PaintButtonContents(canvas);
 }
 
-const char* CustomShapeButton::GetClassName() const {
-  return "CustomShapeButton";
-}
-
-void CustomShapeButton::OnThemeChanged() {
-  ImageButton::OnThemeChanged();
-  views::FocusRing::Get(this)->SetColor(
-      AshColorProvider::Get()->GetControlsLayerColor(
-          AshColorProvider::ControlsLayerType::kFocusRingColor));
-  SchedulePaint();
-}
-
 void CustomShapeButton::PaintCustomShapePath(gfx::Canvas* canvas) {
   cc::PaintFlags flags;
   flags.setAntiAlias(true);
   const SkColor button_color = AshColorProvider::Get()->GetControlsLayerColor(
       AshColorProvider::ControlsLayerType::kControlBackgroundColorInactive);
-  flags.setColor(GetEnabled()
-                     ? button_color
-                     : AshColorProvider::GetDisabledColor(button_color));
+  flags.setColor(GetEnabled() ? button_color
+                              : ColorUtil::GetDisabledColor(button_color));
   flags.setStyle(cc::PaintFlags::kFill_Style);
 
   canvas->DrawPath(CreateCustomShapePath(GetLocalBounds()), flags);
 }
 
+BEGIN_METADATA(CustomShapeButton, views::ImageButton)
+END_METADATA
+
 }  // namespace ash
