@@ -5,6 +5,7 @@
 #include "ash/system/unified/date_tray.h"
 
 #include "ash/constants/tray_background_view_catalog.h"
+#include "ash/public/cpp/ash_view_ids.h"
 #include "ash/shell.h"
 #include "ash/strings/grit/ash_strings.h"
 #include "ash/system/model/clock_model.h"
@@ -28,6 +29,10 @@ DateTray::DateTray(Shelf* shelf, UnifiedSystemTray* tray)
       time_view_(tray_container()->AddChildView(
           std::make_unique<TimeTrayItemView>(shelf, TimeView::Type::kDate))),
       unified_system_tray_(tray) {
+  SetID(VIEW_ID_SA_DATE_TRAY);
+  SetPressedCallback(
+      base::BindRepeating(&DateTray::OnButtonPressed, base::Unretained(this)));
+
   tray_container()->SetMargin(
       /*main_axis_margin=*/kUnifiedTrayContentPadding -
           ShelfConfig::Get()->status_area_hit_region_padding(),
@@ -37,22 +42,6 @@ DateTray::DateTray(Shelf* shelf, UnifiedSystemTray* tray)
 
 DateTray::~DateTray() = default;
 
-bool DateTray::PerformAction(const ui::Event& event) {
-  // Lets the `unified_system_tray_` decide whether to show the bubble or not,
-  // since it's the owner of the bubble view.
-  if (is_active()) {
-    unified_system_tray_->CloseBubble();
-  } else {
-    // Need to set the date tray as active before notifying the system tray of
-    // an action because we need the system tray to know that the date tray is
-    // already active when it is creating the `UnifiedSystemTrayBubble`.
-    SetIsActive(true);
-    unified_system_tray_->OnDateTrayActionPerformed(event);
-  }
-
-  return true;
-}
-
 std::u16string DateTray::GetAccessibleNameForBubble() {
   if (unified_system_tray_->IsBubbleShown())
     return unified_system_tray_->GetAccessibleNameForQuickSettingsBubble();
@@ -83,6 +72,15 @@ void DateTray::UpdateAfterLoginStatusChange() {
   SetVisiblePreferred(true);
 }
 
+void DateTray::CloseBubble() {
+  if (!is_active()) {
+    return;
+  }
+  // Lets the `unified_system_tray_` close the bubble since it's the owner of
+  // the bubble view.
+  unified_system_tray_->CloseBubble();
+}
+
 void DateTray::OnOpeningCalendarView() {
   SetIsActive(true);
 }
@@ -91,6 +89,21 @@ void DateTray::OnLeavingCalendarView() {
   SetIsActive(false);
 }
 
+void DateTray::OnButtonPressed(const ui::Event& event) {
+  // Lets the `unified_system_tray_` decide whether to show the bubble or not,
+  // since it's the owner of the bubble view.
+  if (is_active()) {
+    unified_system_tray_->CloseBubble();
+    return;
+  }
+
+  // Need to set the date tray as active before notifying the system tray of
+  // an action because we need the system tray to know that the date tray is
+  // already active when it is creating the `UnifiedSystemTrayBubble`.
+  SetIsActive(true);
+  unified_system_tray_->OnDateTrayActionPerformed(event);
+}
+
 BEGIN_METADATA(DateTray, ActionableView)
 END_METADATA
 
