@@ -6,6 +6,7 @@
 #define ASH_SYSTEM_UNIFIED_FEATURE_TILE_H_
 
 #include "ash/ash_export.h"
+#include "ash/style/icon_button.h"
 #include "base/memory/weak_ptr.h"
 #include "ui/base/metadata/metadata_header_macros.h"
 #include "ui/views/controls/button/button.h"
@@ -43,11 +44,6 @@ class ASH_EXPORT FeatureTile : public views::Button {
     kMaxValue = kCompact,
   };
 
-  // Constructor for prototype tiles without a callback. Applies placeholder
-  // icons and titles.
-  // TODO(b/252871301): Remove when having implemented each feature tile.
-  explicit FeatureTile(TileType type = TileType::kPrimary);
-
   // Constructor for FeatureTiles. `callback` will be called when interacting
   // with the main part of the button, which accounts for the whole tile.
   // For primary tiles with drill-in, `callback` is called when interacting with
@@ -98,6 +94,9 @@ class ASH_EXPORT FeatureTile : public views::Button {
   // Sets the tooltip text of `drill_in_button_`.
   void SetDrillInButtonTooltipText(const std::u16string& text);
 
+  // views::View:
+  void OnThemeChanged() override;
+
   views::ImageView* icon() { return icon_; }
   views::Label* label() { return label_; }
   views::Label* sub_label() { return sub_label_; }
@@ -107,6 +106,10 @@ class ASH_EXPORT FeatureTile : public views::Button {
   friend class BluetoothFeaturePodControllerTest;
   friend class NotificationCounterViewTest;
 
+  // Updates `drill_in_arrow_` since it uses a different focus ring color when
+  // the tile is toggled to provide contrast with the background color.
+  void UpdateDrillInButtonFocusRingColor();
+
   // The vector icon for the tile, if one is set.
   const gfx::VectorIcon* vector_icon_ = nullptr;
 
@@ -115,6 +118,7 @@ class ASH_EXPORT FeatureTile : public views::Button {
   views::Label* label_ = nullptr;
   views::Label* sub_label_ = nullptr;
   views::LabelButton* drill_in_button_ = nullptr;
+  IconButton* drill_in_arrow_ = nullptr;
 
   // Whether this button is togglable.
   bool is_togglable_ = false;
@@ -125,8 +129,8 @@ class ASH_EXPORT FeatureTile : public views::Button {
   // The type of the feature tile that determines how it lays out its view.
   TileType type_;
 
-  // Used to set the drill-in button enabled state when the button state
-  // changes.
+  // Used to update tile colors and to set the drill-in button enabled state
+  // when the button state changes.
   base::CallbackListSubscription enabled_changed_subscription_;
 
   base::WeakPtrFactory<FeatureTile> weak_ptr_factory_{this};
