@@ -121,7 +121,7 @@ SkColor QuickSettingsSlider::GetThumbColor() const {
           cros_tokens::kCrosSysSystemPrimaryContainer));
     case Style::kRadioInactive:
       return GetColorProvider()->GetColor(
-          static_cast<ui::ColorId>(cros_tokens::kCrosSysDisabled));
+          static_cast<ui::ColorId>(cros_tokens::kCrosSysSystemOnBase));
     default:
       NOTREACHED();
   }
@@ -142,7 +142,7 @@ SkColor QuickSettingsSlider::GetTroughColor() const {
           static_cast<ui::ColorId>(cros_tokens::kCrosSysHighlightShape));
     case Style::kRadioInactive:
       return GetColorProvider()->GetColor(
-          static_cast<ui::ColorId>(cros_tokens::kCrosSysDisabled));
+          static_cast<ui::ColorId>(cros_tokens::kCrosSysSystemOnBase));
     default:
       NOTREACHED();
   }
@@ -203,7 +203,7 @@ void QuickSettingsSlider::OnPaint(gfx::Canvas* canvas) {
   if (HasFocus()) {
     cc::PaintFlags highlight_border;
     highlight_border.setColor(GetColorProvider()->GetColor(
-        static_cast<ui::ColorId>(cros_tokens::kCrosSysPrimary)));
+        static_cast<ui::ColorId>(cros_tokens::kCrosSysFocusRing)));
     highlight_border.setAntiAlias(true);
     highlight_border.setStyle(cc::PaintFlags::kStroke_Style);
     highlight_border.setStrokeWidth(kLineThickness);
@@ -214,6 +214,14 @@ void QuickSettingsSlider::OnPaint(gfx::Canvas* canvas) {
   }
 }
 
+void QuickSettingsSlider::OnThemeChanged() {
+  views::View::OnThemeChanged();
+
+  // Signals that this view needs to be repainted since `GetColorProvider()` is
+  // called in `OnPaint()` and the views system won't know about it.
+  SchedulePaint();
+}
+
 ReadOnlySlider::ReadOnlySlider(Style slider_style)
     : QuickSettingsSlider(/*listener=*/nullptr, slider_style) {}
 
