@@ -22,6 +22,7 @@
 #include "ash/system/audio/unified_volume_slider_controller.h"
 #include "ash/system/bluetooth/bluetooth_detailed_view_controller.h"
 #include "ash/system/bluetooth/bluetooth_feature_pod_controller.h"
+#include "ash/system/brightness/quick_settings_display_detailed_view_controller.h"
 #include "ash/system/brightness/unified_brightness_slider_controller.h"
 #include "ash/system/camera/autozoom_feature_pod_controller.h"
 #include "ash/system/cast/cast_feature_pod_controller.h"
@@ -55,6 +56,7 @@
 #include "ash/system/unified/feature_pod_controller_base.h"
 #include "ash/system/unified/feature_pods_container_view.h"
 #include "ash/system/unified/feature_tile.h"
+#include "ash/system/unified/feature_tiles_container_view.h"
 #include "ash/system/unified/quick_settings_metrics_util.h"
 #include "ash/system/unified/quick_settings_view.h"
 #include "ash/system/unified/quiet_mode_feature_pod_controller.h"
@@ -179,7 +181,10 @@ UnifiedSystemTrayController::CreateUnifiedQuickSettingsView() {
   unified_view->AddSliderView(volume_slider_controller_->CreateView());
 
   brightness_slider_controller_ =
-      std::make_unique<UnifiedBrightnessSliderController>(model_);
+      std::make_unique<UnifiedBrightnessSliderController>(
+          model_, views::Button::PressedCallback(base::BindRepeating(
+                      &UnifiedSystemTrayController::ShowDisplayDetailedView,
+                      base::Unretained(this))));
   unified_view->AddSliderView(brightness_slider_controller_->CreateView());
 
   return unified_view;
@@ -205,7 +210,10 @@ UnifiedSystemTrayController::CreateQuickSettingsView(int max_height) {
   qs_view->AddSliderView(unified_volume_view_);
 
   brightness_slider_controller_ =
-      std::make_unique<UnifiedBrightnessSliderController>(model_);
+      std::make_unique<UnifiedBrightnessSliderController>(
+          model_, views::Button::PressedCallback(base::BindRepeating(
+                      &UnifiedSystemTrayController::ShowDisplayDetailedView,
+                      base::Unretained(this))));
   unified_brightness_view_ = brightness_slider_controller_->CreateView();
   qs_view->AddSliderView(unified_brightness_view_);
 
@@ -295,8 +303,6 @@ void UnifiedSystemTrayController::HandleOpenPowerSettingsAction() {
 }
 
 void UnifiedSystemTrayController::HandleEnterpriseInfoAction() {
-  UMA_HISTOGRAM_ENUMERATION("ChromeOS.SystemTray.OpenHelpPageForManaged",
-                            MANAGED_TYPE_ENTERPRISE, MANAGED_TYPE_COUNT);
   Shell::Get()->system_tray_model()->client()->ShowEnterpriseInfo();
 }
 
@@ -484,6 +490,12 @@ void UnifiedSystemTrayController::ShowAudioDetailedView() {
   showing_audio_detailed_view_ = true;
 }
 
+void UnifiedSystemTrayController::ShowDisplayDetailedView() {
+  ShowDetailedView(
+      std::make_unique<QuickSettingsDisplayDetailedViewController>(this));
+  showing_display_detailed_view_ = true;
+}
+
 void UnifiedSystemTrayController::ShowNotifierSettingsView() {
   if (features::IsOsSettingsAppBadgingToggleEnabled()) {
     return;
@@ -497,15 +509,12 @@ void UnifiedSystemTrayController::ShowNotifierSettingsView() {
 void UnifiedSystemTrayController::ShowCalendarView(
     calendar_metrics::CalendarViewShowSource show_source,
     calendar_metrics::CalendarEventSource event_source) {
-  if (!features::IsCalendarViewEnabled()) {
-    return;
-  }
-
   calendar_metrics::RecordCalendarShowMetrics(show_source, event_source);
   ShowDetailedView(std::make_unique<UnifiedCalendarViewController>(this));
 
   showing_calendar_view_ = true;
   showing_audio_detailed_view_ = false;
+  showing_display_detailed_view_ = false;
 
   for (auto& observer : observers_) {
     observer.OnOpeningCalendarView();
@@ -526,6 +535,7 @@ void UnifiedSystemTrayController::TransitionToMainView(bool restore_focus) {
   }
 
   showing_audio_detailed_view_ = false;
+  showing_display_detailed_view_ = false;
 
   // Transfer `detailed_view_controller_` to a scoped object, which will be
   // destroyed once it's out of this method's scope (after resetting
@@ -572,17 +582,8 @@ void UnifiedSystemTrayController::EnsureCollapsed() {
 
 void UnifiedSystemTrayController::EnsureExpanded() {
   if (detailed_view_controller_) {
-    showing_audio_detailed_view_ = false;
-    if (features::IsQsRevampEnabled()) {
-      quick_settings_view_->ResetDetailedView();
-    } else {
-      unified_view_->ResetDetailedView();
-    }
-
-    // Destroy `detailed_view_controller_` after resetting
-    // `quick_settings_view_`'s `detailed_view_` because the detailed view has a
-    // reference to its `detailed_view_controller_` which is used in shutdown.
-    detailed_view_controller_.reset();
+    // If a detailed view is showing, first transit to the main view.
+    TransitionToMainView(false);
   }
   StartAnimation(true /*expand*/);
 
@@ -694,7 +695,6 @@ void UnifiedSystemTrayController::InitFeatureTiles() {
   create_tile(std::make_unique<QuietModeFeaturePodController>(this),
               feature_pod_controllers_, tiles,
               capture_and_quiet_tiles_are_compact);
-
   create_tile(std::make_unique<BluetoothFeaturePodController>(this),
               feature_pod_controllers_, tiles);
 
@@ -708,29 +708,34 @@ void UnifiedSystemTrayController::InitFeatureTiles() {
   create_tile(std::make_unique<RotationLockFeaturePodController>(),
               feature_pod_controllers_, tiles,
               cast_and_rotation_tiles_are_compact);
-
-  create_tile(std::make_unique<NearbyShareFeaturePodController>(this),
-              feature_pod_controllers_, tiles);
   create_tile(std::make_unique<AccessibilityFeaturePodController>(this),
               feature_pod_controllers_, tiles);
-  create_tile(std::make_unique<PrivacyScreenFeaturePodController>(),
-              feature_pod_controllers_, tiles);
-  create_tile(std::make_unique<IMEFeaturePodController>(this),
-              feature_pod_controllers_, tiles);
-  create_tile(std::make_unique<VPNFeaturePodController>(this),
+  create_tile(std::make_unique<NearbyShareFeaturePodController>(this),
               feature_pod_controllers_, tiles);
   create_tile(std::make_unique<LocaleFeaturePodController>(this),
               feature_pod_controllers_, tiles);
-  if (base::FeatureList::IsEnabled(features::kShelfParty)) {
-    create_tile(std::make_unique<ShelfPartyFeaturePodController>(),
-                feature_pod_controllers_, tiles);
-  }
+  create_tile(std::make_unique<IMEFeaturePodController>(this),
+              feature_pod_controllers_, tiles);
   if (media::ShouldEnableAutoFraming()) {
     create_tile(std::make_unique<AutozoomFeaturePodController>(),
                 feature_pod_controllers_, tiles);
   }
+  create_tile(std::make_unique<VPNFeaturePodController>(this),
+              feature_pod_controllers_, tiles);
+
+  if (base::FeatureList::IsEnabled(features::kShelfParty)) {
+    create_tile(std::make_unique<ShelfPartyFeaturePodController>(),
+                feature_pod_controllers_, tiles);
+  }
+  create_tile(std::make_unique<PrivacyScreenFeaturePodController>(),
+              feature_pod_controllers_, tiles);
 
   quick_settings_view_->AddTiles(std::move(tiles));
+
+  quick_settings_metrics_util::RecordQsFeaturePodCount(
+      quick_settings_view_->feature_tiles_container()
+          ->GetVisibleFeatureTileCount(),
+      Shell::Get()->tablet_mode_controller()->InTabletMode());
 }
 
 void UnifiedSystemTrayController::AddFeaturePodItem(
@@ -761,6 +766,7 @@ void UnifiedSystemTrayController::ShowDetailedView(
   }
 
   showing_audio_detailed_view_ = false;
+  showing_display_detailed_view_ = false;
   if (features::IsQsRevampEnabled()) {
     bubble_->UpdateBubbleHeight(/*is_showing_detiled_view=*/true);
     quick_settings_view_->SetDetailedView(controller->CreateView());
@@ -845,6 +851,9 @@ bool UnifiedSystemTrayController::IsExpanded() const {
 }
 
 void UnifiedSystemTrayController::UpdateBubble() {
+  if (!bubble_) {
+    return;
+  }
   bubble_->UpdateBubble();
 }
 
