@@ -8,10 +8,14 @@
 
 #include "ash/public/cpp/shelf_types.h"
 #include "ash/resources/vector_icons/vector_icons.h"
+#include "ash/session/session_controller_impl.h"
 #include "ash/shelf/shelf.h"
+#include "ash/shell.h"
 #include "ash/strings/grit/ash_strings.h"
 #include "ash/style/ash_color_id.h"
 #include "ash/style/icon_button.h"
+#include "ash/system/privacy/screen_security_controller.h"
+#include "ash/system/system_notification_controller.h"
 #include "ash/system/tray/tray_background_view.h"
 #include "ash/system/tray/tray_bubble_wrapper.h"
 #include "ash/system/tray/tray_constants.h"
@@ -20,6 +24,8 @@
 #include "ash/system/video_conference/bubble/bubble_view.h"
 #include "ash/system/video_conference/video_conference_tray_controller.h"
 #include "base/functional/bind.h"
+#include "base/metrics/histogram_functions.h"
+#include "components/session_manager/session_manager_types.h"
 #include "ui/base/metadata/metadata_header_macros.h"
 #include "ui/base/metadata/metadata_impl_macros.h"
 #include "ui/chromeos/styles/cros_tokens_color_mappings.h"
@@ -36,6 +42,16 @@ constexpr float kTrayButtonsSpacing = 4;
 constexpr float kPrivacyIndicatorRadius = 4;
 constexpr float kIndicatorBorderWidth = 1;
 
+// Histogram names
+constexpr char kToggleButtonHistogramName[] =
+    "Ash.VideoConferenceTray.ToggleBubbleButton.Click";
+constexpr char kCameraMuteHistogramName[] =
+    "Ash.VideoConferenceTray.CameraMuteButton.Click";
+constexpr char kMicrophoneMuteHistogramName[] =
+    "Ash.VideoConferenceTray.MicrophoneMuteButton.Click";
+constexpr char kStopScreenShareHistogramName[] =
+    "Ash.VideoConferenceTray.StopScreenShareButton.Click";
+
 // A customized toggle button for the VC tray's toggle bubble button.
 class ToggleBubbleButton : public IconButton {
  public:
@@ -90,11 +106,24 @@ VideoConferenceTrayButton::VideoConferenceTrayButton(
 
 VideoConferenceTrayButton::~VideoConferenceTrayButton() = default;
 
-void VideoConferenceTrayButton::SetShowPrivacyIndicator(bool show) {
-  if (show_privacy_indicator_ == show)
+void VideoConferenceTrayButton::SetIsCapturing(bool is_capturing) {
+  if (is_capturing_ == is_capturing) {
     return;
+  }
 
-  show_privacy_indicator_ = show;
+  is_capturing_ = is_capturing;
+  UpdateCapturingState();
+}
+
+void VideoConferenceTrayButton::UpdateCapturingState() {
+  // We should only show the privacy indicator when the button is not
+  // muted/untoggled.
+  const bool show_privacy_indicator = is_capturing_ && !toggled();
+  if (show_privacy_indicator_ == show_privacy_indicator) {
+    return;
+  }
+
+  show_privacy_indicator_ = show_privacy_indicator;
   SchedulePaint();
 }
 
@@ -132,8 +161,6 @@ void VideoConferenceTrayButton::PaintButtonContents(gfx::Canvas* canvas) {
 VideoConferenceTray::VideoConferenceTray(Shelf* shelf)
     : TrayBackgroundView(shelf,
                          TrayBackgroundViewCatalogName::kVideoConferenceTray) {
-  SetVisiblePreferred(false);
-
   tray_container()->SetSpacingBetweenChildren(kTrayButtonsSpacing);
 
   audio_icon_ = tray_container()->AddChildView(
@@ -168,14 +195,24 @@ VideoConferenceTray::VideoConferenceTray(Shelf* shelf)
                                     weak_ptr_factory_.GetWeakPtr())));
 
   VideoConferenceTrayController::Get()->AddObserver(this);
+  Shell::Get()->session_controller()->AddObserver(this);
+
+  // Update visibility of the tray and all child icons and indicators. If this
+  // lives on a secondary display, it's possible a media session already exists
+  // so force update all state.
+  UpdateTrayAndIconsState();
+
+  DCHECK_EQ(4u, tray_container()->children().size())
+      << "Icons must be updated here in case a media session begins prior to "
+         "connecting a secondary display.";
 }
 
 VideoConferenceTray::~VideoConferenceTray() {
+  Shell::Get()->session_controller()->RemoveObserver(this);
   VideoConferenceTrayController::Get()->RemoveObserver(this);
 }
 
 void VideoConferenceTray::CloseBubble() {
-  SetIsActive(false);
   toggle_bubble_button_->SetToggled(false);
 
   bubble_.reset();
@@ -211,46 +248,79 @@ void VideoConferenceTray::HandleLocaleChange() {
   // TODO(b/253646076): Finish this function.
 }
 
-void VideoConferenceTray::OnHasMediaAppStateChange(bool has_media_app) {
-  SetVisiblePreferred(has_media_app);
+void VideoConferenceTray::AnchorUpdated() {
+  if (bubble_) {
+    bubble_->bubble_view()->UpdateBubble();
+  }
 }
 
-void VideoConferenceTray::OnCameraPermissionStateChange(bool has_permission) {
-  camera_icon_->SetVisible(has_permission);
+void VideoConferenceTray::OnHasMediaAppStateChange() {
+  SetVisiblePreferred(VideoConferenceTrayController::Get()->ShouldShowTray());
 }
 
-void VideoConferenceTray::OnMicrophonePermissionStateChange(
-    bool has_permission) {
-  audio_icon_->SetVisible(has_permission);
+void VideoConferenceTray::OnCameraPermissionStateChange() {
+  camera_icon_->SetVisible(
+      VideoConferenceTrayController::Get()->GetHasCameraPermissions());
+}
+
+void VideoConferenceTray::OnMicrophonePermissionStateChange() {
+  audio_icon_->SetVisible(
+      VideoConferenceTrayController::Get()->GetHasMicrophonePermissions());
 }
 
 void VideoConferenceTray::OnScreenSharingStateChange(bool is_capturing_screen) {
   screen_share_icon_->SetVisible(is_capturing_screen);
-  screen_share_icon_->SetShowPrivacyIndicator(/*show=*/is_capturing_screen);
+  screen_share_icon_->SetIsCapturing(
+      /*is_capturing=*/is_capturing_screen);
 }
 
 void VideoConferenceTray::OnCameraCapturingStateChange(bool is_capturing) {
-  camera_icon_->SetShowPrivacyIndicator(/*show=*/is_capturing);
+  camera_icon_->SetIsCapturing(is_capturing);
 }
 
 void VideoConferenceTray::OnMicrophoneCapturingStateChange(bool is_capturing) {
-  audio_icon_->SetShowPrivacyIndicator(/*show=*/is_capturing);
+  audio_icon_->SetIsCapturing(is_capturing);
 }
 
 SkScalar VideoConferenceTray::GetRotationValueForToggleBubbleButton() {
+  // If `bubble_` is not null, it means that the bubble is opened.
   switch (shelf()->alignment()) {
     case ShelfAlignment::kBottom:
     case ShelfAlignment::kBottomLocked:
-      return is_active() ? 180 : 0;
+      return bubble_ ? 180 : 0;
     case ShelfAlignment::kLeft:
-      return is_active() ? 270 : 90;
+      return bubble_ ? 270 : 90;
     case ShelfAlignment::kRight:
-      return is_active() ? 90 : 270;
+      return bubble_ ? 90 : 270;
   }
 }
 
+void VideoConferenceTray::UpdateTrayAndIconsState() {
+  auto* controller = VideoConferenceTrayController::Get();
+
+  SetVisiblePreferred(controller->ShouldShowTray());
+
+  camera_icon_->SetVisible(controller->GetHasCameraPermissions());
+  camera_icon_->SetIsCapturing(controller->IsCapturingCamera());
+
+  audio_icon_->SetVisible(controller->GetHasMicrophonePermissions());
+  audio_icon_->SetIsCapturing(controller->IsCapturingMicrophone());
+
+  bool is_capturing_screen = controller->IsCapturingScreen();
+  screen_share_icon_->SetVisible(is_capturing_screen);
+  screen_share_icon_->SetIsCapturing(is_capturing_screen);
+}
+
+void VideoConferenceTray::OnSessionStateChanged(
+    session_manager::SessionState state) {
+  SetVisiblePreferred(VideoConferenceTrayController::Get()->ShouldShowTray());
+}
+
 void VideoConferenceTray::ToggleBubble(const ui::Event& event) {
-  if (GetBubbleWidget()) {
+  const bool bubble_open = GetBubbleWidget();
+  base::UmaHistogramBoolean(kToggleButtonHistogramName, !bubble_open);
+
+  if (bubble_open) {
     CloseBubble();
     return;
   }
@@ -259,7 +329,7 @@ void VideoConferenceTray::ToggleBubble(const ui::Event& event) {
   init_params.delegate = GetWeakPtr();
   init_params.parent_window = GetBubbleWindowContainer();
   init_params.anchor_mode = TrayBubbleView::AnchorMode::kRect;
-  init_params.anchor_rect = shelf()->GetSystemTrayAnchorRect();
+  init_params.anchor_rect = GetAnchorBoundsInScreen();
   init_params.insets = GetTrayBubbleInsets();
   init_params.shelf_alignment = shelf()->alignment();
   init_params.preferred_width = kTrayMenuWidth;
@@ -272,23 +342,30 @@ void VideoConferenceTray::ToggleBubble(const ui::Event& event) {
   bubble_ = std::make_unique<TrayBubbleWrapper>(this);
   bubble_->ShowBubble(std::move(bubble_view));
 
-  SetIsActive(true);
   toggle_bubble_button_->SetToggled(true);
 }
 
 void VideoConferenceTray::OnCameraButtonClicked(const ui::Event& event) {
-  VideoConferenceTrayController::Get()->SetCameraMuted(
-      /*muted=*/!camera_icon_->toggled());
+  const bool muted = !camera_icon_->toggled();
+  VideoConferenceTrayController::Get()->SetCameraMuted(muted);
+
+  base::UmaHistogramBoolean(kCameraMuteHistogramName, !muted);
 }
 
 void VideoConferenceTray::OnAudioButtonClicked(const ui::Event& event) {
-  // TODO(b/253275993): Implement the callback for `audio_icon_`.
-  VideoConferenceTrayController::Get()->SetMicrophoneMuted(
-      /*muted=*/!audio_icon_->toggled());
+  const bool muted = !audio_icon_->toggled();
+  VideoConferenceTrayController::Get()->SetMicrophoneMuted(muted);
+
+  base::UmaHistogramBoolean(kMicrophoneMuteHistogramName, !muted);
 }
 
 void VideoConferenceTray::OnScreenShareButtonClicked(const ui::Event& event) {
-  // TODO(b/253277644): Implement the callback for `screen_share_icon_`.
+  Shell::Get()
+      ->system_notification_controller()
+      ->screen_security_controller()
+      ->StopAllSessions(/*is_screen_access=*/true);
+
+  base::UmaHistogramBoolean(kStopScreenShareHistogramName, true);
 }
 
 BEGIN_METADATA(VideoConferenceTray, TrayBackgroundView)
