@@ -8,6 +8,7 @@
 #include <string>
 
 #include "ash/ash_export.h"
+#include "ash/public/cpp/session/session_observer.h"
 #include "ash/style/icon_button.h"
 #include "ash/system/tray/tray_background_view.h"
 #include "ash/system/video_conference/video_conference_tray_controller.h"
@@ -19,6 +20,10 @@ class Canvas;
 struct VectorIcon;
 }  // namespace gfx
 
+namespace session_manager {
+enum class SessionState;
+}  // namespace session_manager
+
 namespace ui {
 class Event;
 }  // namespace ui
@@ -32,6 +37,8 @@ namespace ash {
 namespace video_conference {
 class BubbleViewTest;
 class ReturnToAppPanelTest;
+class ResourceDependencyTest;
+class ToggleEffectsViewTest;
 }  // namespace video_conference
 
 class Shelf;
@@ -54,21 +61,31 @@ class VideoConferenceTrayButton : public IconButton {
   ~VideoConferenceTrayButton() override;
 
   bool show_privacy_indicator() const { return show_privacy_indicator_; }
+  bool is_capturing() const { return is_capturing_; }
 
-  // Sets the state of showing the privacy indicator in the button.
-  void SetShowPrivacyIndicator(bool show);
+  // Set the state of `is_capturing_`.
+  void SetIsCapturing(bool is_capturing);
+
+  // Updates the capturing state and show/hide the privacy indicator
+  // accordingly.
+  void UpdateCapturingState();
 
   // IconButton:
   void PaintButtonContents(gfx::Canvas* canvas) override;
 
  private:
+  // Cache of the capturing state received from `VideoConferenceManagerAsh`.
+  bool is_capturing_ = false;
+
+  // Indicates whether we are showing the privacy indicator in the button.
   bool show_privacy_indicator_ = false;
 };
 
 // This class represents the VC Controls tray button in the status area and
 // controls the bubble that is shown when the tray button is clicked.
 class ASH_EXPORT VideoConferenceTray
-    : public TrayBackgroundView,
+    : public SessionObserver,
+      public TrayBackgroundView,
       public VideoConferenceTrayController::Observer {
  public:
   METADATA_HEADER(VideoConferenceTray);
@@ -81,6 +98,7 @@ class ASH_EXPORT VideoConferenceTray
   VideoConferenceTrayButton* audio_icon() { return audio_icon_; }
   VideoConferenceTrayButton* camera_icon() { return camera_icon_; }
   VideoConferenceTrayButton* screen_share_icon() { return screen_share_icon_; }
+  IconButton* toggle_bubble_button() { return toggle_bubble_button_; }
 
   // TrayBackgroundView:
   void CloseBubble() override;
@@ -90,11 +108,12 @@ class ASH_EXPORT VideoConferenceTray
   void HideBubbleWithView(const TrayBubbleView* bubble_view) override;
   void ClickedOutsideBubble() override;
   void HandleLocaleChange() override;
+  void AnchorUpdated() override;
 
   // VideoConferenceTrayController::Observer:
-  void OnHasMediaAppStateChange(bool has_media_app) override;
-  void OnCameraPermissionStateChange(bool has_permission) override;
-  void OnMicrophonePermissionStateChange(bool has_permission) override;
+  void OnHasMediaAppStateChange() override;
+  void OnCameraPermissionStateChange() override;
+  void OnMicrophonePermissionStateChange() override;
   void OnCameraCapturingStateChange(bool is_capturing) override;
   void OnMicrophoneCapturingStateChange(bool is_capturing) override;
   void OnScreenSharingStateChange(bool is_capturing_screen) override;
@@ -104,11 +123,20 @@ class ASH_EXPORT VideoConferenceTray
   // calculate that rotation value.
   SkScalar GetRotationValueForToggleBubbleButton();
 
+  // Update the visibility and capturing state of the tray and icons according
+  // to the state in `VideoConferenceTrayController`.
+  void UpdateTrayAndIconsState();
+
  private:
   friend class video_conference::BubbleViewTest;
   friend class video_conference::ReturnToAppPanelTest;
+  friend class video_conference::ResourceDependencyTest;
+  friend class video_conference::ToggleEffectsViewTest;
   friend class VideoConferenceTrayTest;
 
+  // SessionObserver:
+  void OnSessionStateChanged(session_manager::SessionState state) override;
+
   // Callback function for `toggle_bubble_button_`.
   void ToggleBubble(const ui::Event& event);
 
