@@ -7,7 +7,7 @@
 
 #include "ash/ash_export.h"
 #include "ash/system/video_conference/effects/video_conference_tray_effects_manager.h"
-#include "ash/system/video_conference/video_conference_media_state.h"
+#include "ash/system/video_conference/video_conference_common.h"
 #include "base/observer_list_types.h"
 #include "base/time/time.h"
 #include "chromeos/ash/components/audio/cras_audio_handler.h"
@@ -37,13 +37,13 @@ class ASH_EXPORT VideoConferenceTrayController
 
     // Called when the state of `has_media_app` within
     // `VideoConferenceMediaState` is changed.
-    virtual void OnHasMediaAppStateChange(bool has_media_app) = 0;
+    virtual void OnHasMediaAppStateChange() = 0;
 
     // Called when the state of camera permission is changed.
-    virtual void OnCameraPermissionStateChange(bool has_permission) = 0;
+    virtual void OnCameraPermissionStateChange() = 0;
 
     // Called when the state of microphone permission is changed.
-    virtual void OnMicrophonePermissionStateChange(bool has_permission) = 0;
+    virtual void OnMicrophonePermissionStateChange() = 0;
 
     // Called when the state of camera capturing is changed.
     virtual void OnCameraCapturingStateChange(bool is_capturing) = 0;
@@ -66,33 +66,70 @@ class ASH_EXPORT VideoConferenceTrayController
   // Returns the singleton instance.
   static VideoConferenceTrayController* Get();
 
+  // Adds this class as an observer for CrasAudioHandler and
+  // CameraHalDispatcherImpl.
+  // (1) We should not call this in /ash/system/* tests, because we are not
+  // using FakeCrasAudioClient or MockCameraHalServer. Currently, we directly
+  // mock the VideoConferenceTrayButtons inside
+  // FakeVideoConferenceTrayController; which is a simpler approach.
+  // (2) We need this initialization in
+  // ChromeBrowserMainExtraPartsAsh::PreProfileInit for production code.
+  void Initialize(VideoConferenceManagerBase* video_conference_manager);
+
   // Observer functions.
   void AddObserver(Observer* observer);
   void RemoveObserver(Observer* observer);
 
+  // Whether the tray should be shown.
+  bool ShouldShowTray() const;
+
+  // Returns whether `state_` indicates permissions are granted for different
+  // mediums.
+  bool GetHasCameraPermissions() const;
+  bool GetHasMicrophonePermissions() const;
+
+  // Returns whether `state_` indicates a capture session is in progress for
+  // different mediums.
+  bool IsCapturingScreen() const;
+  bool IsCapturingCamera() const;
+  bool IsCapturingMicrophone() const;
+
   // Sets the state for camera mute. Virtual for testing/mocking.
-  virtual void SetCameraMuted(bool muted) = 0;
+  virtual void SetCameraMuted(bool muted);
+
+  // Gets the state for camera mute. Virtual for testing/mocking.
+  virtual bool GetCameraMuted();
 
   // Sets the state for microphone mute. Virtual for testing/mocking.
-  virtual void SetMicrophoneMuted(bool muted) = 0;
+  virtual void SetMicrophoneMuted(bool muted);
+
+  // Gets the state for microphone mute. Virtual for testing/mocking.
+  virtual bool GetMicrophoneMuted();
 
   // Returns asynchronously a vector of media apps that will be displayed in the
   // "Return to app" panel of the bubble. Virtual for testing/mocking.
-  virtual void GetMediaApps(
-      base::OnceCallback<void(MediaApps)> ui_callback) = 0;
+  virtual void GetMediaApps(base::OnceCallback<void(MediaApps)> ui_callback);
 
   // Brings the app with the given `id` to the foreground.
-  virtual void ReturnToApp(const base::UnguessableToken& id) = 0;
+  virtual void ReturnToApp(const base::UnguessableToken& id);
 
   // Updates the tray UI with the given `VideoConferenceMediaState`.
   void UpdateWithMediaState(VideoConferenceMediaState state);
 
+  // Returns true if any running media apps have been granted permission for
+  // camera/microphone.
+  bool HasCameraPermission() const;
+  bool HasMicrophonePermission() const;
+
   // Handles device usage from a VC app while the device is system disabled.
   virtual void HandleDeviceUsedWhileDisabled(
       crosapi::mojom::VideoConferenceMediaDevice device,
       const std::u16string& app_name);
 
   // media::CameraPrivacySwitchObserver:
+  void OnCameraHWPrivacySwitchStateChanged(
+      const std::string& device_id,
+      cros::mojom::CameraPrivacySwitchState state) override;
   void OnCameraSWPrivacySwitchStateChanged(
       cros::mojom::CameraPrivacySwitchState state) override;
 
@@ -109,11 +146,35 @@ class ASH_EXPORT VideoConferenceTrayController
     return effects_manager_;
   }
 
+  bool camera_muted_by_hardware_switch() const {
+    return camera_muted_by_hardware_switch_;
+  }
+  bool camera_muted_by_software_switch() const {
+    return camera_muted_by_software_switch_;
+  }
+
+  bool initialized() const { return initialized_; }
+
  private:
+  // Update the state of the camera icons across all `VideoConferenceTray`.
+  void UpdateCameraIcons();
+
   // This keeps track the current VC media state. The state is being updated by
   // `UpdateWithMediaState()`, calling from `VideoConferenceManagerAsh`.
   VideoConferenceMediaState state_;
 
+  // This keeps track of the current Camera Privacy Switch state.
+  // Updated via `OnCameraHWPrivacySwitchStateChanged()` and
+  // `OnCameraSWPrivacySwitchStateChanged()` Fetching this would otherwise take
+  // an asynchronous call to `media::CameraHalDispatcherImpl`.
+  bool camera_muted_by_hardware_switch_ = false;
+  bool camera_muted_by_software_switch_ = false;
+
+  // True if microphone is muted by the hardware switch, false if the microphone
+  // is muted through software. If the microphone is not muted, disregards this
+  // value.
+  bool microphone_muted_by_hardware_switch_ = false;
+
   // Used by the views to construct and lay out effects in the bubble.
   VideoConferenceTrayEffectsManager effects_manager_;
 
@@ -122,6 +183,16 @@ class ASH_EXPORT VideoConferenceTrayController
 
   // The last time speak-on-mute notification showed.
   absl::optional<base::TimeTicks> last_speak_on_mute_notification_time_;
+
+  // video_conference_manager_ should be valid after initialized_.
+  // Currently, VideoConferenceTrayController is destroyed inside
+  // ChromeBrowserMainParts::PostMainMessageLoopRun() as a chrome_extra_part;
+  // VideoConferenceManagerAsh is destroyed inside crosapi_manager_.reset()
+  // which is after VideoConferenceTrayController.
+  base::raw_ptr<VideoConferenceManagerBase> video_conference_manager_ = nullptr;
+  bool initialized_ = false;
+
+  base::WeakPtrFactory<VideoConferenceTrayController> weak_ptr_factory_{this};
 };
 
 }  // namespace ash
