@@ -27,6 +27,7 @@
 #include "third_party/skia/include/core/SkColor.h"
 #include "ui/aura/client/window_types.h"
 #include "ui/aura/env.h"
+#include "ui/compositor/test/test_context_factories.h"
 #include "ui/display/display.h"
 #include "ui/events/event_constants.h"
 #include "ui/events/test/event_generator.h"
@@ -122,6 +123,8 @@ class AshTestBase : public testing::Test {
 
   // Update the display configuration as given in |display_specs|.
   // See ash::DisplayManagerTestApi::UpdateDisplay for more details.
+  // Note: To add rounded-corners properly upon startup, set it via
+  // specifying the command line switch `ash-host-window-bounds`.
   void UpdateDisplay(const std::string& display_specs);
 
   // Returns a root Window. Usually this is the active root Window, but that
@@ -266,6 +269,13 @@ class AshTestBase : public testing::Test {
   TestingPrefServiceSimple* local_state() { return &local_state_; }
   AshTestHelper* ash_test_helper() { return ash_test_helper_.get(); }
 
+  // Returns nullptr before SetUp() is called.
+  ui::InProcessContextFactory* GetContextFactory() {
+    return test_context_factories_
+               ? test_context_factories_->GetContextFactory()
+               : nullptr;
+  }
+
   void SetUserPref(const std::string& user_email,
                    const std::string& path,
                    const base::Value& value);
@@ -381,6 +391,8 @@ class AshTestBase : public testing::Test {
   // `PrepareForPixelDiffTest()`.
   std::unique_ptr<AshPixelDiffer> pixel_differ_;
 
+  std::unique_ptr<ui::TestContextFactories> test_context_factories_;
+
   // Must be constructed after |task_environment_|.
   std::unique_ptr<AshTestHelper> ash_test_helper_;
 
