@@ -34,7 +34,6 @@
 #include "ash/wallpaper/test_wallpaper_controller_client.h"
 #include "ash/wallpaper/wallpaper_controller_impl.h"
 #include "ash/wm/desks/templates/saved_desk_test_helper.h"
-#include "ash/wm/multitask_menu_nudge_controller.h"
 #include "ash/wm/overview/overview_controller.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
 #include "base/run_loop.h"
@@ -45,8 +44,11 @@
 #include "chromeos/ash/components/dbus/rgbkbd/rgbkbd_client.h"
 #include "chromeos/ash/components/login/login_state/login_state.h"
 #include "chromeos/dbus/power/power_policy_controller.h"
+#include "chromeos/ui/frame/multitask_menu/multitask_menu_nudge_controller.h"
 #include "device/bluetooth/bluetooth_adapter_factory.h"
 #include "device/bluetooth/dbus/bluez_dbus_manager.h"
+#include "device/bluetooth/floss/floss_dbus_manager.h"
+#include "device/bluetooth/floss/floss_features.h"
 #include "ui/aura/test/test_windows.h"
 #include "ui/aura/window.h"
 #include "ui/aura/window_tree_host.h"
@@ -85,6 +87,15 @@ class AshTestHelper::BluezDBusManagerInitializer {
   }
 };
 
+class AshTestHelper::FlossDBusManagerInitializer {
+ public:
+  FlossDBusManagerInitializer() { floss::FlossDBusManager::InitializeFake(); }
+  ~FlossDBusManagerInitializer() {
+    device::BluetoothAdapterFactory::Shutdown();
+    floss::FlossDBusManager::Shutdown();
+  }
+};
+
 class AshTestHelper::PowerPolicyControllerInitializer {
  public:
   PowerPolicyControllerInitializer() {
@@ -185,6 +196,7 @@ void AshTestHelper::TearDown() {
   test_views_delegate_.reset();
   new_window_delegate_provider_.reset();
   bluez_dbus_manager_initializer_.reset();
+  floss_dbus_manager_initializer_.reset();
   system_tray_client_.reset();
   assistant_service_.reset();
   notifier_settings_controller_.reset();
@@ -264,11 +276,18 @@ void AshTestHelper::SetUp(InitParams init_params) {
     input_method_manager_ = new input_method::MockInputMethodManager();
     input_method::InputMethodManager::Initialize(input_method_manager_);
   }
-
-  if (!bluez::BluezDBusManager::IsInitialized()) {
-    bluez_dbus_manager_initializer_ =
-        std::make_unique<BluezDBusManagerInitializer>();
+  if (floss::features::IsFlossEnabled()) {
+    if (!floss::FlossDBusManager::IsInitialized()) {
+      floss_dbus_manager_initializer_ =
+          std::make_unique<FlossDBusManagerInitializer>();
+    }
+  } else {
+    if (!bluez::BluezDBusManager::IsInitialized()) {
+      bluez_dbus_manager_initializer_ =
+          std::make_unique<BluezDBusManagerInitializer>();
+    }
   }
+
   if (!RgbkbdClient::Get())
     RgbkbdClient::InitializeFake();
   if (!chromeos::PowerManagerClient::Get())
@@ -309,7 +328,7 @@ void AshTestHelper::SetUp(InitParams init_params) {
   // the nudge first before dismissing the launcher.
   shell->dark_light_mode_controller()->SetShowNudgeForTesting(false);
 
-  MultitaskMenuNudgeController::SetSuppressNudgeForTesting(true);
+  chromeos::MultitaskMenuNudgeController::SetSuppressNudgeForTesting(true);
 
   // Set up a test wallpaper controller client before signing in any users. At
   // the time a user logs in, Wallpaper controller relies on
