@@ -50,6 +50,11 @@ gfx::ImageSkia CreateSolidColorTestImage(const gfx::Size& image_size,
 // Returns true if `win1` is stacked (not directly) below `win2`.
 bool IsStackedBelow(aura::Window* win1, aura::Window* win2);
 
+// Configures `window` with the specified title and color.
+void DecorateWindow(aura::Window* window,
+                    const std::u16string& title,
+                    SkColor color);
+
 }  // namespace ash
 
 #endif
