@@ -12,9 +12,9 @@
 
 #include "ash/ash_export.h"
 #include "ash/display/window_tree_host_manager.h"
+#include "ash/public/cpp/image_downloader.h"
 #include "ash/public/cpp/image_util.h"
 #include "ash/public/cpp/session/session_observer.h"
-#include "ash/public/cpp/style/color_mode_observer.h"
 #include "ash/public/cpp/tablet_mode_observer.h"
 #include "ash/public/cpp/wallpaper/google_photos_wallpaper_params.h"
 #include "ash/public/cpp/wallpaper/online_wallpaper_params.h"
@@ -22,6 +22,7 @@
 #include "ash/public/cpp/wallpaper/wallpaper_info.h"
 #include "ash/public/cpp/wallpaper/wallpaper_types.h"
 #include "ash/shell_observer.h"
+#include "ash/system/scheduled_feature/scheduled_feature.h"
 #include "ash/wallpaper/online_wallpaper_variant_info_fetcher.h"
 #include "ash/wallpaper/wallpaper_utils/wallpaper_calculated_colors.h"
 #include "ash/wallpaper/wallpaper_utils/wallpaper_resizer_observer.h"
@@ -55,6 +56,7 @@ namespace ash {
 
 class WallpaperColorCalculator;
 class WallpaperDriveFsDelegate;
+class WallpaperImageDownloader;
 class WallpaperMetricsManager;
 class WallpaperPrefManager;
 class WallpaperResizer;
@@ -83,7 +85,7 @@ class ASH_EXPORT WallpaperControllerImpl
       public OverviewObserver,
       public ui::CompositorLockClient,
       public ui::NativeThemeObserver,
-      public ColorModeObserver {
+      public ScheduledFeature::CheckpointObserver {
  public:
   // Directory names of custom wallpapers.
   static const char kSmallWallpaperSubDir[];
@@ -96,11 +98,15 @@ class ASH_EXPORT WallpaperControllerImpl
   static void SetWallpaperPrefManagerForTesting(
       std::unique_ptr<WallpaperPrefManager> pref_manager);
 
-  // Prefer to use to obtain an new instance unless injecting non-production
-  // members i.e. in tests.
+  static void SetWallpaperImageDownloaderForTesting(
+      std::unique_ptr<WallpaperImageDownloader> image_downloader);
+
+  // Prefer to use `Create` to obtain an new instance unless injecting
+  // non-production members i.e. in tests.
   explicit WallpaperControllerImpl(
       std::unique_ptr<WallpaperPrefManager> pref_manager,
-      std::unique_ptr<OnlineWallpaperVariantInfoFetcher> fetcher);
+      std::unique_ptr<OnlineWallpaperVariantInfoFetcher> fetcher,
+      std::unique_ptr<WallpaperImageDownloader> image_downloader);
 
   WallpaperControllerImpl(const WallpaperControllerImpl&) = delete;
   WallpaperControllerImpl& operator=(const WallpaperControllerImpl&) = delete;
@@ -225,6 +231,10 @@ class ASH_EXPORT WallpaperControllerImpl
                            bool show_wallpaper,
                            const base::FilePath& wallpaper_path);
 
+  // Returns false when the color extraction algorithm shouldn't be run based on
+  // system state (e.g. wallpaper image, SessionState, etc.).
+  bool ShouldCalculateColors() const;
+
   // WallpaperController:
   void SetClient(WallpaperControllerClient* client) override;
   void SetDriveFsDelegate(
@@ -233,6 +243,7 @@ class ASH_EXPORT WallpaperControllerImpl
             const base::FilePath& wallpapers,
             const base::FilePath& custom_wallpapers,
             const base::FilePath& device_policy_wallpaper) override;
+  bool CanSetUserWallpaper(const AccountId& account_id) const override;
   void SetCustomWallpaper(const AccountId& account_id,
                           const base::FilePath& file_path,
                           WallpaperLayout layout,
@@ -288,7 +299,8 @@ class ASH_EXPORT WallpaperControllerImpl
   void ShowOneShotWallpaper(const gfx::ImageSkia& image) override;
   void ShowAlwaysOnTopWallpaper(const base::FilePath& image_path) override;
   void RemoveAlwaysOnTopWallpaper() override;
-  void RemoveUserWallpaper(const AccountId& account_id) override;
+  void RemoveUserWallpaper(const AccountId& account_id,
+                           base::OnceClosure on_removed) override;
   void RemovePolicyWallpaper(const AccountId& account_id) override;
   void SetAnimationDuration(base::TimeDelta animation_duration) override;
   void OpenWallpaperPickerIfAllowed() override;
@@ -331,8 +343,9 @@ class ASH_EXPORT WallpaperControllerImpl
   void OnTabletModeStarted() override;
   void OnTabletModeEnded() override;
 
-  // ColorModeObserver:
-  void OnColorModeChanged(bool dark_mode_enabled) override;
+  // ScheduledFeature::CheckpointObserver:
+  void OnCheckpointChanged(const ScheduledFeature* src,
+                           const ScheduleCheckpoint new_checkpoint) override;
 
   // ui::NativeThemeObserver:
   void OnNativeThemeUpdated(ui::NativeTheme* observed_theme) override;
@@ -419,10 +432,12 @@ class ASH_EXPORT WallpaperControllerImpl
 
   // Implementation of |RemoveUserWallpaper|, which deletes |account_id|'s
   // custom wallpapers and directories.
-  void RemoveUserWallpaperImpl(const AccountId& account_id);
+  void RemoveUserWallpaperImpl(const AccountId& account_id,
+                               base::OnceClosure on_removed);
 
   void RemoveUserWallpaperImplWithFilesId(
       const AccountId& account_id,
+      base::OnceClosure on_removed,
       const std::string& wallpaper_files_id);
 
   // Implementation of |SetDefaultWallpaper|. Sets wallpaper to default if
@@ -432,10 +447,6 @@ class ASH_EXPORT WallpaperControllerImpl
                                bool show_wallpaper,
                                SetWallpaperCallback callback);
 
-  // When kiosk app is running or policy is enforced, setting a user wallpaper
-  // is not allowed.
-  bool CanSetUserWallpaper(const AccountId& account_id) const;
-
   // Returns true if the specified wallpaper is already stored in
   // |current_wallpaper_|. If |compare_layouts| is false, layout is ignored.
   bool WallpaperIsAlreadyLoaded(const gfx::ImageSkia& image,
@@ -517,6 +528,12 @@ class ASH_EXPORT WallpaperControllerImpl
                                       SetWallpaperCallback callback,
                                       const gfx::ImageSkia& image);
 
+  void OnGooglePhotosAuthenticationTokenFetched(
+      ash::personalization_app::mojom::GooglePhotosPhotoPtr photo,
+      const AccountId& account_id,
+      ImageDownloader::DownloadCallback callback,
+      const absl::optional<std::string>& access_token);
+
   // Used as the callback of downloading wallpapers of type
   // `WallpaperType::kOnceGooglePhotos`. Shows the wallpaper immediately if
   // `params.account_id` is the active user.
@@ -634,10 +651,6 @@ class ASH_EXPORT WallpaperControllerImpl
   void OnColorCalculationComplete(const WallpaperInfo& info,
                                   const WallpaperCalculatedColors& colors);
 
-  // Returns false when the color extraction algorithm shouldn't be run based on
-  // system state (e.g. wallpaper image, SessionState, etc.).
-  bool ShouldCalculateColors() const;
-
   // The callback when decoding of the always-on-top wallpaper completes.
   void OnAlwaysOnTopWallpaperDecoded(const WallpaperInfo& info,
                                      const gfx::ImageSkia& image);
@@ -831,6 +844,8 @@ class ASH_EXPORT WallpaperControllerImpl
   // If true, the current wallpaper should always stay on top.
   bool is_always_on_top_wallpaper_ = false;
 
+  const std::unique_ptr<WallpaperImageDownloader> wallpaper_image_downloader_;
+
   scoped_refptr<base::SequencedTaskRunner> sequenced_task_runner_;
 
   ScopedSessionObserver scoped_session_observer_{this};
