@@ -7,7 +7,6 @@
 #include <string>
 #include <utility>
 
-#include "ash/constants/ash_features.h"
 #include "ash/constants/ash_pref_names.h"
 #include "ash/public/cpp/wallpaper/wallpaper_info.h"
 #include "ash/session/session_controller_impl.h"
@@ -18,6 +17,7 @@
 #include "base/run_loop.h"
 #include "base/test/scoped_feature_list.h"
 #include "base/test/task_environment.h"
+#include "chromeos/constants/chromeos_features.h"
 #include "components/prefs/scoped_user_pref_update.h"
 #include "components/prefs/testing_pref_service.h"
 #include "components/user_manager/user_type.h"
@@ -456,6 +456,8 @@ TEST_F(WallpaperPrefManagerTest, SetCalculatedColors) {
 }
 
 TEST_F(WallpaperPrefManagerTest, CalculatedColorsEmptyIfKMeanMissing) {
+  base::test::ScopedFeatureList scoped_feature_list;
+  scoped_feature_list.InitAndDisableFeature({chromeos::features::kJelly});
   const char location[] = "location";
 
   const std::vector<SkColor> prominent_colors = {
@@ -466,5 +468,33 @@ TEST_F(WallpaperPrefManagerTest, CalculatedColorsEmptyIfKMeanMissing) {
   EXPECT_FALSE(pref_manager_->GetCachedWallpaperColors(location));
 }
 
+TEST_F(WallpaperPrefManagerTest, CalculatedColorsWhenJellyEnabled) {
+  base::test::ScopedFeatureList scoped_feature_list(chromeos::features::kJelly);
+  const char location[] = "location";
+
+  const SkColor k_mean_color = SkColorSetRGB(0xAB, 0xBC, 0xEF);
+  pref_manager_->CacheKMeanColor(location, k_mean_color);
+
+  const SkColor celebi_color = SkColorSetRGB(0xFF, 0xCC, 0x22);
+  pref_manager_->CacheCelebiColor(location, celebi_color);
+
+  absl::optional<WallpaperCalculatedColors> actual_colors =
+      pref_manager_->GetCachedWallpaperColors(location);
+  ASSERT_TRUE(actual_colors);
+  EXPECT_EQ(k_mean_color, actual_colors->k_mean_color);
+  EXPECT_EQ(celebi_color, actual_colors->celebi_color);
+}
+
+TEST_F(WallpaperPrefManagerTest,
+       CalculatedColorsEmptyIfCelebiMissingWhenJellyEnabled) {
+  base::test::ScopedFeatureList scoped_feature_list(chromeos::features::kJelly);
+  const char location[] = "location";
+
+  const SkColor k_mean_color = SkColorSetRGB(0xAB, 0xBC, 0xEF);
+  pref_manager_->CacheKMeanColor(location, k_mean_color);
+
+  EXPECT_FALSE(pref_manager_->GetCachedWallpaperColors(location));
+}
+
 }  // namespace
 }  // namespace ash
