@@ -10,8 +10,11 @@ WallpaperCalculatedColors::WallpaperCalculatedColors() = default;
 
 WallpaperCalculatedColors::WallpaperCalculatedColors(
     const std::vector<SkColor>& in_prominent_colors,
-    SkColor in_k_mean_color)
-    : prominent_colors(in_prominent_colors), k_mean_color(in_k_mean_color) {}
+    SkColor in_k_mean_color,
+    SkColor in_celebi_color)
+    : prominent_colors(in_prominent_colors),
+      k_mean_color(in_k_mean_color),
+      celebi_color(in_celebi_color) {}
 
 WallpaperCalculatedColors::WallpaperCalculatedColors(
     const WallpaperCalculatedColors& other) = default;
@@ -26,7 +29,8 @@ WallpaperCalculatedColors& WallpaperCalculatedColors::operator=(
 bool WallpaperCalculatedColors::operator==(
     const WallpaperCalculatedColors& other) const {
   return prominent_colors == other.prominent_colors &&
-         k_mean_color == other.k_mean_color;
+         k_mean_color == other.k_mean_color &&
+         celebi_color == other.celebi_color;
 }
 
 bool WallpaperCalculatedColors::operator!=(
