@@ -177,7 +177,7 @@ void WallpaperView::DrawWallpaper(const gfx::ImageSkia& wallpaper,
   gfx::Canvas filtered_canvas(small_image_->size(),
                               /*image_scale=*/1.f,
                               /*is_opaque=*/false);
-  filtered_canvas.sk_canvas()->saveLayer(nullptr, &filter_flags);
+  filtered_canvas.sk_canvas()->saveLayer(filter_flags);
   filtered_canvas.DrawImageInt(
       *small_image_, 0, 0, small_image_->width(), small_image_->height(), 0, 0,
       small_image_->width(), small_image_->height(), true);
