@@ -7,9 +7,9 @@ import {assertExists, assertNotReached} from './assert.js';
 import * as dom from './dom.js';
 import {I18nString} from './i18n_string.js';
 import * as loadTimeData from './models/load_time_data.js';
-import {ChromeHelper} from './mojo/chrome_helper.js';
 import {speakMessage} from './spoken_msg.js';
 import * as state from './state.js';
+import {PerfEvent} from './type';
 import * as util from './util.js';
 
 /**
@@ -50,7 +50,7 @@ class RippleEffect {
     this.addRipple();
   }
 
-  private async addRipple(): Promise<void> {
+  private addRipple(): void {
     const rect = this.anchor.getBoundingClientRect();
     if (rect.width === 0) {
       return;
@@ -63,8 +63,11 @@ class RippleEffect {
     style.set('width', CSS.px(this.width));
     style.set('height', CSS.px(this.height));
     this.parent.appendChild(template);
-    await animation.play(ripple);
-    ripple.remove();
+    // We don't care about waiting for the single ripple animation to end
+    // before returning.
+    void animation.play(ripple).then(() => {
+      ripple.remove();
+    });
   }
 
   /**
@@ -101,9 +104,7 @@ type PositionInfos = Array<{
 }>;
 
 export enum IndicatorType {
-  DOC_SCAN_AVAILABLE = 'doc_scan_available',
-  DOC_MODE_MULTI_PAGE_AVAILABLE = 'doc_mode_multi_scan_available',
-  DOWNLOAD_DOCUMENT_SCANNER = 'download_document_scanner',
+  // NEW_FEATURE = 'new_feature',
 }
 
 /**
@@ -111,12 +112,12 @@ export enum IndicatorType {
  * modes/cameras.
  */
 export function setup(): void {
-  state.addObserver(state.State.CAMERA_SWITCHING, (val) => {
+  state.addObserver(PerfEvent.CAMERA_SWITCHING, (val) => {
     if (val) {
       hide();
     }
   });
-  state.addObserver(state.State.MODE_SWITCHING, (val) => {
+  state.addObserver(PerfEvent.MODE_SWITCHING, (val) => {
     if (val) {
       hide();
     }
@@ -130,12 +131,6 @@ export function setup(): void {
 
 function getIndicatorI18nStringId(indicatorType: IndicatorType): I18nString {
   switch (indicatorType) {
-    case IndicatorType.DOWNLOAD_DOCUMENT_SCANNER:
-      return I18nString.DOWNLOADING_DOCUMENT_SCANNING_FEATURE;
-    case IndicatorType.DOC_SCAN_AVAILABLE:
-      return I18nString.NEW_DOCUMENT_SCAN_TOAST;
-    case IndicatorType.DOC_MODE_MULTI_PAGE_AVAILABLE:
-      return I18nString.DOCUMENT_MODE_MULTI_PAGE_TOAST;
     default:
       assertNotReached();
   }
@@ -143,13 +138,8 @@ function getIndicatorI18nStringId(indicatorType: IndicatorType): I18nString {
 
 function getIndicatorIcon(indicatorType: IndicatorType): string|null {
   switch (indicatorType) {
-    case IndicatorType.DOWNLOAD_DOCUMENT_SCANNER:
-      return '/images/download_dlc_toast_icon.svg';
-    case IndicatorType.DOC_SCAN_AVAILABLE:
-    case IndicatorType.DOC_MODE_MULTI_PAGE_AVAILABLE:
-      return '/images/new_feature_toast_icon.svg';
     default:
-      return null;
+      return '/images/new_feature_toast_icon.svg';
   }
 }
 
@@ -256,8 +246,9 @@ class NewFeatureToast extends Toast {
         dom.getFrom(template, '.custom-toast-text', HTMLSpanElement);
     const text = loadTimeData.getI18nMessage(i18nId);
     textElement.textContent = text;
-    const ariaLabel =
-        loadTimeData.getI18nMessage(I18nString.NEW_CONTROL_NAVIGATION, text);
+    const ariaLabelI18nId = util.assertEnumVariant(
+        I18nString, anchor.getAttribute('i18n-new-feature-label'));
+    const ariaLabel = loadTimeData.getI18nMessage(ariaLabelI18nId, text);
     toast.setAttribute('aria-label', ariaLabel);
 
     super(
@@ -412,34 +403,3 @@ export function focus(): void {
   }
   globalEffectPayload.toast.focus();
 }
-
-/**
- * Shows feature visual effect for PTZ options entry.
- */
-export function showPtzToast(parent: HTMLElement): void {
-  const ptzPanelEntry = dom.get('#open-ptz-panel', HTMLButtonElement);
-  const {hide, focusToast} = showNewFeature(ptzPanelEntry, parent);
-  focusToast();
-  ptzPanelEntry.addEventListener('click', hide, {once: true});
-}
-
-/**
- * Shows document scan feature is available indicator on the scan mode button.
- */
-export function showDocScanAvailableIndicator(parent: HTMLElement): void {
-  const scanModeButton = dom.get('input[data-mode="scan"]', HTMLInputElement);
-  showIndicator(scanModeButton, IndicatorType.DOC_SCAN_AVAILABLE, parent);
-}
-
-/**
- * Shows loading indicator toast for document mode when it's supported but not
- * yet ready.
- */
-export async function showDownloadingDocScanIndicator(parent: HTMLElement):
-    Promise<void> {
-  const docModeButton = dom.get('#scan-document-option', HTMLDivElement);
-  const {hide} = showIndicator(
-      docModeButton, IndicatorType.DOWNLOAD_DOCUMENT_SCANNER, parent);
-  await ChromeHelper.getInstance().checkDocumentModeReadiness();
-  hide();
-}
