@@ -13,7 +13,7 @@ import {
   Resolution,
 } from '../../type.js';
 import * as util from '../../util.js';
-import {WaitableEvent} from '../../waitable_event.js';
+import {CancelableEvent, WaitableEvent} from '../../waitable_event.js';
 import {StreamConstraints} from '../stream_constraints.js';
 
 import {ModeBase, ModeFactory} from './mode_base.js';
@@ -105,7 +105,7 @@ export class Photo extends ModeBase {
         onReady.signal(true);
       });
       (async () => {
-        await this.video.onExpired;
+        await this.video.onExpired.wait();
         videoEl.cancelVideoFrameCallback(callbackId);
         onReady.signal(false);
       })();
@@ -119,37 +119,51 @@ export class Photo extends ModeBase {
     } while (track.muted);
   }
 
-  private async takePhoto(): Promise<{blob: Blob, metadata: Metadata|null}> {
-    if (state.get(state.State.ENABLE_PTZ)) {
-      // Workaround for b/184089334 on PTZ camera to use preview frame as
-      // photo result.
-      const blob = await this.getImageCapture().grabJpegFrame();
+  private takePhoto(): Promise<{blob: Blob, metadata: Metadata|null}> {
+    const photoResult =
+        new CancelableEvent<{blob: Blob, metadata: Metadata | null}>();
+    const track = this.video.getVideoTrack();
+
+    function stopTakingPhoto() {
+      photoResult.signalError(new Error('Camera is disconnected.'));
+    }
+    track.addEventListener('ended', stopTakingPhoto, {once: true});
+
+    (async () => {
+      if (state.get(state.State.ENABLE_PTZ)) {
+        // Workaround for b/184089334 on PTZ camera to use preview frame as
+        // photo result.
+        const blob = await this.getImageCapture().grabJpegFrame();
+        this.handler.playShutterEffect();
+        photoResult.signal({
+          blob,
+          metadata: null,
+        });
+        return;
+      }
+      let photoSettings: PhotoSettings;
+      if (this.captureResolution) {
+        photoSettings = {
+          imageWidth: this.captureResolution.width,
+          imageHeight: this.captureResolution.height,
+        };
+      } else {
+        const caps = await this.getImageCapture().getPhotoCapabilities();
+        photoSettings = {
+          imageWidth: caps.imageWidth.max,
+          imageHeight: caps.imageHeight.max,
+        };
+      }
+      await this.waitPreviewReady();
+      const results = await this.getImageCapture().takePhoto(photoSettings);
       this.handler.playShutterEffect();
-      return {
-        blob,
-        metadata: null,
-      };
-    }
-    let photoSettings: PhotoSettings;
-    if (this.captureResolution) {
-      photoSettings = {
-        imageWidth: this.captureResolution.width,
-        imageHeight: this.captureResolution.height,
-      };
-    } else {
-      const caps = await this.getImageCapture().getPhotoCapabilities();
-      photoSettings = {
-        imageWidth: caps.imageWidth.max,
-        imageHeight: caps.imageHeight.max,
-      };
-    }
-    await this.waitPreviewReady();
-    const results = await this.getImageCapture().takePhoto(photoSettings);
-    this.handler.playShutterEffect();
-    return {
-      blob: await results[0].pendingBlob,
-      metadata: await results[0].pendingMetadata,
-    };
+      photoResult.signal({
+        blob: await results[0].pendingBlob,
+        metadata: await results[0].pendingMetadata,
+      });
+    })().catch((e) => photoResult.signalError(e));
+
+    return photoResult.wait();
   }
 }
 
