@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-import {assert, assertInstanceof} from '../assert.js';
+import {assert, assertExists, assertInstanceof} from '../assert.js';
 import * as dom from '../dom.js';
 import {reportError} from '../error.js';
 import * as expert from '../expert.js';
@@ -106,10 +106,7 @@ export class Preview {
   }
 
   getVideo(): PreviewVideo {
-    return new PreviewVideo(
-        this.video,
-        assertInstanceof(this.onPreviewExpired, WaitableEvent).wait(),
-    );
+    return new PreviewVideo(this.video, assertExists(this.onPreviewExpired));
   }
 
   /**
@@ -424,9 +421,11 @@ export class Preview {
       element.textContent = val;
     }
 
-    function buildInverseLookupFunction(
-        obj: Record<string, number>, prefix: string): (key: number) => string {
+    function buildInverseLookupFunction<T extends number>(
+        enumType: Record<string, T|string>, prefix: string): (key: number) =>
+        string {
       const map = new Map<number, string>();
+      const obj = util.getNumberEnumMapping(enumType);
       for (const [key, val] of Object.entries(obj)) {
         if (!key.startsWith(prefix)) {
           continue;
