@@ -5,6 +5,7 @@
 import {assert, assertInstanceof} from './assert.js';
 import * as dom from './dom.js';
 import {reportError} from './error.js';
+import {AsyncIntervalRunner} from './models/async_interval.js';
 import {Filenamer} from './models/file_namer.js';
 import * as filesystem from './models/file_system.js';
 import {
@@ -12,7 +13,7 @@ import {
   FileAccessEntry,
 } from './models/file_system_access_entry.js';
 import {ResultSaver} from './models/result_saver.js';
-import {VideoSaver} from './models/video_saver.js';
+import {TimeLapseSaver, VideoSaver} from './models/video_saver.js';
 import {ChromeHelper} from './mojo/chrome_helper.js';
 import {extractImageFromBlob} from './thumbnailer.js';
 import {
@@ -141,13 +142,15 @@ export class GalleryButton implements ResultSaver {
     this.coverPhoto.src = cover?.url ?? '';
 
     if (file !== null) {
-      ChromeHelper.getInstance().monitorFileDeletion(file.name, async () => {
-        try {
-          await this.checkCover();
-        } catch (e) {
-          reportError(ErrorType.CHECK_COVER_FAILURE, ErrorLevel.ERROR, e);
-        }
-      });
+      // The promise is only resolved after the file is deleted.
+      void ChromeHelper.getInstance().monitorFileDeletion(
+          file.name, async () => {
+            try {
+              await this.checkCover();
+            } catch (e) {
+              reportError(ErrorType.CHECK_COVER_FAILURE, ErrorLevel.ERROR, e);
+            }
+          });
     }
   }
 
@@ -162,7 +165,7 @@ export class GalleryButton implements ResultSaver {
 
     // Checks existence of cached cover photo.
     if (this.cover !== null) {
-      if (await dir.isExist(this.cover.name)) {
+      if (await dir.exists(this.cover.name)) {
         return;
       }
     }
@@ -210,14 +213,14 @@ export class GalleryButton implements ResultSaver {
     async function checkFileCount() {
       const newFileCount = (await filesystem.getEntries()).length;
       if (prevFileCount === newFileCount) {
-        clearInterval(intervalId);
+        runner.stop();
         cameraFolderStable.signal();
       } else {
         prevFileCount = newFileCount;
       }
     }
 
-    const intervalId = setInterval(checkFileCount, 500);
+    const runner = new AsyncIntervalRunner(checkFileCount, 500);
     return cameraFolderStable.wait();
   }
 
@@ -241,14 +244,16 @@ export class GalleryButton implements ResultSaver {
   }
 
   async startSaveVideo(videoRotation: number): Promise<VideoSaver> {
-    const file = await filesystem.createVideoFile(VideoType.MP4);
-    return VideoSaver.createForFile(file, videoRotation);
+    return VideoSaver.create(videoRotation);
   }
 
-  async finishSaveVideo(video: VideoSaver): Promise<void> {
+  async finishSaveVideo(video: TimeLapseSaver|VideoSaver): Promise<void> {
     const file = await video.endWrite();
     assert(file !== null);
 
+    const videoName = (new Filenamer()).newVideoName(VideoType.MP4);
+    assert(this.directory !== null);
+    await file.moveTo(this.directory, videoName);
     ChromeHelper.getInstance().sendNewCaptureBroadcast(
         {isVideo: true, name: file.name});
     await this.updateCover(file);
