@@ -5,9 +5,12 @@
 // This file contains many long export lines that exceed the max-len limit */
 /* eslint-disable max-len */
 
+export {
+  PointF,
+} from 'chrome://resources/mojo/ui/gfx/geometry/mojom/geometry.mojom-webui.js';
 export {
   CameraIntentAction,
-} from '/mojom-webui/ash/components/arc/mojom/camera_intent.mojom-webui.js';
+} from '../../mojom/ash/components/arc/mojom/camera_intent.mojom-webui.js';
 export {
   CameraAppHelper,
   CameraAppHelperRemote,
@@ -24,19 +27,20 @@ export {
   WindowStateControllerRemote,
   WindowStateMonitorCallbackRouter,
   WindowStateType,
-} from '/mojom-webui/ash/webui/camera_app_ui/camera_app_helper.mojom-webui.js';
+} from '../../mojom/ash/webui/camera_app_ui/camera_app_helper.mojom-webui.js';
 export {
   Rotation,
 } from
-    '/mojom-webui/chromeos/services/machine_learning/public/mojom/document_scanner_param_types.mojom-webui.js';
+    '../../mojom/chromeos/services/machine_learning/public/mojom/document_scanner_param_types.mojom-webui.js';
 export {
   Blob as MojoBlob,
-} from '/mojom-webui/media/capture/mojom/image_capture.mojom-webui.js';
+} from '../../mojom/media/capture/mojom/image_capture.mojom-webui.js';
 export {
   CameraAppDeviceProvider,
   CameraAppDeviceProviderRemote,
   CameraAppDeviceRemote,
   CameraEventObserverCallbackRouter,
+  CameraInfoObserverCallbackRouter,
   CaptureIntent,
   DocumentCornersObserverCallbackRouter,
   Effect,
@@ -45,18 +49,18 @@ export {
   ResultMetadataObserverCallbackRouter,
   StreamType,
 } from
-    '/mojom-webui/media/capture/video/chromeos/mojom/camera_app.mojom-webui.js';
+    '../../mojom/media/capture/video/chromeos/mojom/camera_app.mojom-webui.js';
 export {
   CameraFacing,
   CameraInfo,
 } from
-    '/mojom-webui/media/capture/video/chromeos/mojom/camera_common.mojom-webui.js';
+    '../../mojom/media/capture/video/chromeos/mojom/camera_common.mojom-webui.js';
 export {
   CameraMetadata,
   CameraMetadataEntry,
   EntryType,
 } from
-    '/mojom-webui/media/capture/video/chromeos/mojom/camera_metadata.mojom-webui.js';
+    '../../mojom/media/capture/video/chromeos/mojom/camera_metadata.mojom-webui.js';
 export {
   AndroidControlAeAntibandingMode,
   AndroidControlAeMode,
@@ -69,7 +73,4 @@ export {
   AndroidStatisticsFaceDetectMode,
   CameraMetadataTag,
 } from
-    '/mojom-webui/media/capture/video/chromeos/mojom/camera_metadata_tags.mojom-webui.js';
-export {
-  PointF,
-} from 'chrome://resources/mojo/ui/gfx/geometry/mojom/geometry.mojom-webui.js';
+    '../../mojom/media/capture/video/chromeos/mojom/camera_metadata_tags.mojom-webui.js';
