@@ -102,13 +102,10 @@ const KEYBOARD_KEYS = [
 const KEYBOARD_KEY_SET = new Set(KEYBOARD_KEYS);
 type KeyboardKey = typeof KEYBOARD_KEYS[number];
 
-// TODO(b/248398229): After upgrading TS to 4.7 or later, we can use "extends
-// constraints on infer" to simplify the syntax of `WithModifiers`.
 type WithModifiers<Modifiers extends string[], Key extends string> =
-    Modifiers extends [...infer Rest, infer Last] ?
-    Rest extends string[] ?
-    Last extends string ? WithModifiers<Rest, Key|`${Last}-${Key}`>: never :
-    never :
+    Modifiers extends [...infer Rest extends string[], infer Last extends
+                           string] ?
+    WithModifiers<Rest, Key|`${Last}-${Key}`>:
     Key;
 export type KeyboardShortcut =
     WithModifiers<['Ctrl', 'Alt', 'Shift'], KeyboardKey>|'Unsupported';
@@ -236,8 +233,10 @@ export function bindElementAriaLabelWithState(
  */
 export function setInkdropEffect(el: HTMLElement): void {
   const tpl = instantiateTemplate('#inkdrop-template');
+  const ripple =
+      assertInstanceof(tpl.querySelector('.inkdrop-ripple'), HTMLElement);
   el.appendChild(tpl);
-  el.addEventListener('click', (e) => {
+  el.addEventListener('click', async (e) => {
     const tRect =
         assertInstanceof(e.target, HTMLElement).getBoundingClientRect();
     const elRect = el.getBoundingClientRect();
@@ -249,7 +248,7 @@ export function setInkdropEffect(el: HTMLElement): void {
     el.style.setProperty('--drop-x', `${dropX}px`);
     el.style.setProperty('--drop-y', `${dropY}px`);
     el.style.setProperty('--drop-radius', `${radius}px`);
-    animate.playOnChild(el);
+    await animate.play(ripple);
   });
 }
 
@@ -430,3 +429,19 @@ export async function loadImage(
     image.src = src;
   });
 }
+
+/**
+ * Gets the mapping from name to enum value for a number enum.
+ *
+ * Note that in TypeScript, number enum contains both mapping from name to
+ * value and value to name, which most of the time isn't what we want.
+ */
+export function getNumberEnumMapping<T extends number>(
+    enumType: {[key: string]: T|string}): {[key: string]: T} {
+  return Object.fromEntries(Object.entries(enumType).flatMap(([k, v]) => {
+    if (typeof v === 'string') {
+      return [];
+    }
+    return [[k, v]];
+  }));
+}
