@@ -22,9 +22,9 @@ import './network_config_toggle.js';
 import './network_password_input.js';
 import './network_shared.css.js';
 
+import {assert, assertNotReached} from '//resources/ash/common/assert.js';
 import {I18nBehavior} from '//resources/ash/common/i18n_behavior.js';
 import {loadTimeData} from '//resources/ash/common/load_time_data.m.js';
-import {assert, assertNotReached} from '//resources/ash/common/assert.js';
 import {flush, Polymer} from '//resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 import {CertificateType, ConfigProperties, CrosNetworkConfigRemote, EAPConfigProperties, GlobalPolicy, HiddenSsidMode, IPSecConfigProperties, L2TPConfigProperties, ManagedBoolean, ManagedEAPProperties, ManagedInt32, ManagedIPSecProperties, ManagedL2TPProperties, ManagedOpenVPNProperties, ManagedProperties, ManagedString, ManagedStringList, ManagedWireGuardProperties, NetworkCertificate, OpenVPNConfigProperties, SecurityType, StartConnectResult, SubjectAltName, VpnType, WireGuardConfigProperties} from 'chrome://resources/mojo/chromeos/services/network_config/public/mojom/cros_network_config.mojom-webui.js';
 import {ConnectionStateType, IPConfigType, NetworkType, OncSource, PolicySource} from 'chrome://resources/mojo/chromeos/services/network_config/public/mojom/network_types.mojom-webui.js';
@@ -72,6 +72,33 @@ const WireGuardKeyConfigType = {
 
 /** @type {string}  */ const PLACEHOLDER_CREDENTIAL = '(credential)';
 
+/**
+ * A light-weight regular expression for testing an IPv4 address string. Note
+ * that this is not a complete check and thus some invalid input can also be
+ * accepted.
+ * @type {RegExp}
+ * @private
+ */
+const IPV4_ADDR_REGEX = /^([0-9]+\.){3}[0-9]+$/i;
+
+/**
+ * A light-weight regular expression for testing an IPv6 address string. Note
+ * that this is not a complete check and thus some invalid input can also be
+ * accepted.
+ * @type {RegExp}
+ * @private
+ */
+const IPV6_ADDR_REGEX = /^(\:?[0-9a-f]{0,4}){2,8}$/i;
+
+/**
+ * A light-weight regular expression for testing an IP CIDR string (e.g.,
+ * 192.168.1.0/24). Both IPv4 and IPv6 are accepted. Note that this is not a
+ * complete check and thus some invalid input can also be accepted.
+ * @type {RegExp}
+ * @private
+ */
+const IP_CIDR_REGEX = /^[0-9a-f\.\:]+\/[0-9]+?$/i;
+
 Polymer({
   _template: getTemplate(),
   is: 'network-config',
@@ -610,6 +637,11 @@ Polymer({
         return;
       }
       this.eapProperties_.subjectAltNameMatch = sanm;
+      if (!this.eapConfigServerCaCertAllowed_()) {
+        this.setError_('missingEapDefaultServerCaSubjectVerification');
+        this.propertiesSent_ = false;
+        return;
+      }
     }
     const propertiesToSet = this.getPropertiesToSet_();
     if (this.managedProperties_.source === OncSource.kNone) {
@@ -990,6 +1022,7 @@ Polymer({
    */
   getWireGuardConfigProperties_(wireguard) {
     const config = {
+      ipAddresses: this.getActiveStringList_(wireguard.ipAddresses) ?? [],
       privateKey: OncMojo.getActiveString(wireguard.privateKey),
       peers: [],
     };
@@ -997,7 +1030,7 @@ Polymer({
       for (const peer of wireguard.peers.activeValue) {
         const peerCopied = Object.assign({}, peer);
         if (this.hasGuid_()) {
-          // Shill does not return exact value for crendential fields, showing
+          // Shill does not return exact value for credential fields, showing
           // a placeholder here.
           peerCopied.presharedKey = PLACEHOLDER_CREDENTIAL;
         }
@@ -1077,12 +1110,11 @@ Polymer({
             break;
           }
           assert(vpn.wireguard);
-          assert(managedProperties.staticIpConfig);
           configVpn.wireguard =
               this.getWireGuardConfigProperties_(vpn.wireguard);
+          this.ipAddressInput_ = configVpn.wireguard.ipAddresses.join(',');
           const staticIpConfig = managedProperties.staticIpConfig;
-          this.ipAddressInput_ = staticIpConfig.ipAddress.activeValue;
-          if (staticIpConfig.nameServers) {
+          if (staticIpConfig && staticIpConfig.nameServers) {
             this.nameServersInput_ =
                 staticIpConfig.nameServers.activeValue.join(',');
           }
@@ -1794,12 +1826,6 @@ Polymer({
         this.managedProperties_.source !== OncSource.kNone) {
       return false;
     }
-
-    // Insecure WiFi networks are always shared.
-    if (this.mojoType_ === NetworkType.kWiFi &&
-        this.securityType_ === SecurityType.kNone) {
-      return false;
-    }
     return true;
   },
 
@@ -1949,17 +1975,45 @@ Polymer({
   },
 
   /**
-   * @param {WireGuardConfigProperties|null|undefined} wireguard
-   * @param {string|undefined} ipAddress
+   * Checks if the input ipAddresses is a comma-delimited string which contains
+   * IP addresses (v4, v6, or both).
+   * @param {string|undefined} ipAddresses
    * @return {boolean}
    * @private
    */
-  isWireGuardConfigurationValid_(wireguard, ipAddress) {
+  isValidWireGuardIpAddresses_(ipAddresses) {
+    if (!ipAddresses) {
+      return false;
+    }
+    // Currently shill only supports at most 1 IPv4 + 1 IPv6 address.
+    let v4Count = 0;
+    let v6Count = 0;
+    for (const ipAddress of ipAddresses.split(',')) {
+      if (ipAddress.match(IPV4_ADDR_REGEX)) {
+        v4Count++;
+      } else if (ipAddress.match(IPV6_ADDR_REGEX)) {
+        v6Count++;
+      } else {
+        return false;
+      }
+    }
+    if (v4Count > 1 || v6Count > 1) {
+      return false;
+    }
+    return v4Count + v6Count > 0;
+  },
+
+  /**
+   * @param {WireGuardConfigProperties|null|undefined} wireguard
+   * @param {string|undefined} ipAddresses
+   * @return {boolean}
+   * @private
+   */
+  isWireGuardConfigurationValid_(wireguard, ipAddresses) {
     if (!wireguard) {
       return false;
     }
-    // ipAddress should be a valid IPv4 address
-    if (!ipAddress || !ipAddress.match(/^([0-9]+\.){3}[0-9]+$/i)) {
+    if (!this.isValidWireGuardIpAddresses_(ipAddresses)) {
       return false;
     }
     if (this.isWireGuardUserPrivateKeyInputActive_ &&
@@ -1979,10 +2033,9 @@ Polymer({
     if (!peer.endpoint || !peer.endpoint.match(/^[a-zA-Z0-9\-\.]+:[0-9]+$/i)) {
       return false;
     }
-    // allowedIps should be comma-seperated list of IP/cidr
+    // allowedIps should be comma-separated list of IP/cidr.
     if (!peer.allowedIps ||
-        !peer.allowedIps.match(
-            /^([0-9\.]+(\/[0-9]+)?,)*[0-9\.]+(\/[0-9]+)?$/i)) {
+        !peer.allowedIps.split(',').every(s => s.match(IP_CIDR_REGEX))) {
       return false;
     }
     return true;
@@ -2182,9 +2235,9 @@ Polymer({
     assert(!!wireguard);
     propertiesToSet.typeConfig.vpn.host = 'wireguard';
     propertiesToSet.ipAddressConfigType = 'Static';
+    wireguard.ipAddresses = this.ipAddressInput_.split(',');
     propertiesToSet.staticIpConfig = {
       gateway: this.ipAddressInput_,
-      ipAddress: this.ipAddressInput_,
       routingPrefix: 32,
       type: IPConfigType.kIPv4,
     };
@@ -2440,4 +2493,38 @@ Polymer({
       this.setError_('');
     }
   },
+
+  /**
+   * Verifies if the selected server CA certificate can be used for the selected
+   * EAP method. This method returns false is the selected EAP method requires a
+   * server CA certificate and the user selected the default certificate without
+   * configuring the domain suffix match or subject alternative match and
+   * without explicitly allowing insecure connections via Chrome flags.
+   * Otherwise returns true.
+   * @return {boolean}
+   * @private
+   */
+  eapConfigServerCaCertAllowed_() {
+    if (loadTimeData.getBoolean(
+            'eapDefaultCasWithoutSubjectVerificationAllowed')) {
+      return true;
+    }
+
+    const outer = this.eapProperties_.outer;
+    if (!(outer === 'EAP-TLS' || outer === 'EAP-TTLS' || outer === 'PEAP')) {
+      return true;
+    }
+
+    if (this.selectedServerCaHash_ !== DEFAULT_HASH) {
+      // Does not use default CA server certs.
+      return true;
+    }
+
+    if (this.eapProperties_.domainSuffixMatch.length != 0 ||
+        this.eapProperties_.subjectAltNameMatch.length != 0) {
+      return true;
+    }
+
+    return false;
+  },
 });
