@@ -14,6 +14,7 @@
 #include "base/files/file_util.h"
 #include "base/memory/ref_counted_memory.h"
 #include "base/task/thread_pool.h"
+#include "chromeos/ash/components/install_attributes/install_attributes.h"
 #include "chromeos/constants/chromeos_features.h"
 #include "content/public/browser/web_contents.h"
 #include "content/public/browser/web_ui.h"
@@ -38,9 +39,27 @@ DemoModeAppUntrustedUIConfig::CreateWebUIController(content::WebUI* web_ui) {
       web_ui, component_path_producer_.Run());
 }
 
+// This is a paired down version of DemoSession::IsDeviceInDemoMode that doesn't
+// rely on DemoSession::DemoModeConfig, reimplemented to temporarily avoid the
+// dependency issues of migrating DemoModeConfig to //ash.
+//
+// TODO(b/260117078): After DemoModeConfig is deleted, move this method to
+// //ash/cpp/public and replace all references to
+// DemoSession::IsDeviceInDemoMode with this now-public //ash method.
+bool IsDeviceInDemoMode() {
+  bool is_demo_device_mode = InstallAttributes::Get()->GetMode() ==
+                             policy::DeviceMode::DEVICE_MODE_DEMO;
+  bool is_demo_device_domain =
+      InstallAttributes::Get()->GetDomain() == policy::kDemoModeDomain;
+  // We check device mode and domain to allow for dev/test
+  // setup that is done by manual enrollment into demo domain. Device mode is
+  // not set to DeviceMode::DEVICE_MODE_DEMO then.
+  return is_demo_device_mode || is_demo_device_domain;
+}
+
 bool DemoModeAppUntrustedUIConfig::IsWebUIEnabled(
     content::BrowserContext* browser_context) {
-  return chromeos::features::IsDemoModeSWAEnabled();
+  return chromeos::features::IsDemoModeSWAEnabled() && IsDeviceInDemoMode();
 }
 
 scoped_refptr<base::RefCountedMemory> ReadFile(
