@@ -25,6 +25,7 @@
 #include "chromeos/ash/components/network/network_type_pattern.h"
 #include "chromeos/ash/components/network/onc/network_onc_utils.h"
 #include "chromeos/ash/components/network/system_token_cert_db_storage.h"
+#include "chromeos/ash/components/network/technology_state_controller.h"
 #include "chromeos/ash/services/network_config/cros_network_config.h"
 #include "chromeos/ash/services/network_config/in_process_instance.h"
 #include "chromeos/services/network_config/public/mojom/cros_network_config.mojom.h"
@@ -39,8 +40,7 @@
 #include "testing/gtest/include/gtest/gtest.h"
 #include "third_party/cros_system_api/dbus/shill/dbus-constants.h"
 
-namespace ash {
-namespace diagnostics {
+namespace ash::diagnostics {
 
 namespace {
 
@@ -182,8 +182,8 @@ class NetworkHealthProviderTest : public testing::Test {
     managed_network_configuration_handler->SetPolicy(
         ::onc::ONC_SOURCE_DEVICE_POLICY,
         /*userhash=*/std::string(),
-        /*network_configs_onc=*/base::Value(base::Value::Type::LIST),
-        /*global_network_config=*/base::Value(base::Value::Type::DICTIONARY));
+        /*network_configs_onc=*/base::Value::List(),
+        /*global_network_config=*/base::Value::Dict());
 
     EXPECT_TRUE(temp_dir_.CreateUniqueTempDir());
     network_health_provider_ = std::make_unique<NetworkHealthProvider>();
@@ -299,8 +299,10 @@ class NetworkHealthProviderTest : public testing::Test {
     NetworkTypePattern pattern = type == shill::kTypeEthernet
                                      ? NetworkTypePattern::Ethernet()
                                      : NetworkTypePattern::WiFi();
-    NetworkHandler::Get()->network_state_handler()->SetTechnologyEnabled(
-        pattern, enabled, network_handler::ErrorCallback());
+    NetworkHandler::Get()
+        ->technology_state_controller()
+        ->SetTechnologiesEnabled(pattern, enabled,
+                                 network_handler::ErrorCallback());
     base::RunLoop().RunUntilIdle();
   }
 
@@ -357,66 +359,61 @@ class NetworkHealthProviderTest : public testing::Test {
     base::RunLoop().RunUntilIdle();
   }
 
-  void SetCellularProperty(std::string property, base::Value value) {
+  void SetCellularProperty(std::string property, base::ValueView value) {
     network_handler_test_helper_->SetServiceProperty(kCellular0DevicePath,
-                                                     property, value);
+                                                     property, value.ToValue());
     base::RunLoop().RunUntilIdle();
   }
 
   void SetCellularIccid(std::string iccid) {
-    SetCellularProperty(shill::kIccidProperty, base::Value(iccid));
+    SetCellularProperty(shill::kIccidProperty, iccid);
   }
 
   void SetCellularNetworkTechnology(std::string technology) {
-    SetCellularProperty(shill::kNetworkTechnologyProperty,
-                        base::Value(technology));
+    SetCellularProperty(shill::kNetworkTechnologyProperty, technology);
   }
 
   void SetCellularEid(std::string eid) {
-    SetCellularProperty(shill::kEidProperty, base::Value(eid));
+    SetCellularProperty(shill::kEidProperty, eid);
   }
 
   void SetCellularSignalStrength(int signal_strength) {
-    SetCellularProperty(shill::kSignalStrengthProperty,
-                        base::Value(signal_strength));
+    SetCellularProperty(shill::kSignalStrengthProperty, signal_strength);
   }
 
   void SetCellularSimLockStatus(std::string lock_type, bool sim_locked) {
-    base::Value sim_lock_status(base::Value::Type::DICTIONARY);
-    sim_lock_status.SetKey(shill::kSIMLockEnabledProperty,
-                           base::Value(sim_locked));
-    sim_lock_status.SetKey(shill::kSIMLockTypeProperty, base::Value(lock_type));
-    sim_lock_status.SetKey(shill::kSIMLockRetriesLeftProperty, base::Value(3));
+    base::Value::Dict sim_lock_status;
+    sim_lock_status.Set(shill::kSIMLockEnabledProperty, sim_locked);
+    sim_lock_status.Set(shill::kSIMLockTypeProperty, lock_type);
+    sim_lock_status.Set(shill::kSIMLockRetriesLeftProperty, 3);
     network_handler_test_helper_->device_test()->SetDeviceProperty(
         kCellular0DevicePath, shill::kSIMLockStatusProperty,
-        std::move(sim_lock_status),
+        base::Value(std::move(sim_lock_status)),
         /*notify_changed=*/true);
 
     base::RunLoop().RunUntilIdle();
   }
 
   void SetCellularRoamingState(std::string roaming_state) {
-    SetCellularProperty(shill::kRoamingStateProperty,
-                        base::Value(roaming_state));
+    SetCellularProperty(shill::kRoamingStateProperty, roaming_state);
   }
 
-  void SetWifiProperty(std::string property, base::Value value) {
+  void SetWifiProperty(std::string property, base::ValueView value) {
     network_handler_test_helper_->SetServiceProperty(kWlan0DevicePath, property,
-                                                     value);
+                                                     value.ToValue());
     base::RunLoop().RunUntilIdle();
   }
 
   void SetWifiSignalStrength(int signal_strength) {
-    SetWifiProperty(shill::kSignalStrengthProperty,
-                    base::Value(signal_strength));
+    SetWifiProperty(shill::kSignalStrengthProperty, signal_strength);
   }
 
   void SetWifiFrequency(int frequency) {
-    SetWifiProperty(shill::kWifiFrequency, base::Value(frequency));
+    SetWifiProperty(shill::kWifiFrequency, frequency);
   }
 
   void SetWifiBssid(std::string bssid) {
-    SetWifiProperty(shill::kWifiBSsid, base::Value(bssid));
+    SetWifiProperty(shill::kWifiBSsid, bssid);
   }
 
   void SetEthernetMacAddress(const std::string& mac_address) {
@@ -464,11 +461,11 @@ class NetworkHealthProviderTest : public testing::Test {
   void SetWifiSecurity(const std::string& securityClass,
                        const std::string& eapKeyMgmt) {
     SetWifiSecurity(securityClass);
-    SetWifiProperty(shill::kEapKeyMgmtProperty, base::Value(eapKeyMgmt));
+    SetWifiProperty(shill::kEapKeyMgmtProperty, eapKeyMgmt);
   }
 
   void SetWifiSecurity(const std::string& securityClass) {
-    SetWifiProperty(shill::kSecurityClassProperty, base::Value(securityClass));
+    SetWifiProperty(shill::kSecurityClassProperty, securityClass);
   }
 
   void SetupObserver(FakeNetworkListObserver* observer) {
@@ -1483,5 +1480,4 @@ TEST_F(NetworkHealthProviderTest, ResetReceiverOnBindInterface) {
   base::RunLoop().RunUntilIdle();
 }
 
-}  // namespace diagnostics
-}  // namespace ash
+}  // namespace ash::diagnostics
