@@ -15,6 +15,7 @@
 #include "ash/public/cpp/tablet_mode.h"
 #include "ash/shell.h"
 #include "ash/system/diagnostics/keyboard_input_log.h"
+#include "ash/system/diagnostics/mojom/input.mojom.h"
 #include "ash/webui/diagnostics_ui/backend/common/histogram_util.h"
 #include "ash/webui/diagnostics_ui/backend/input/event_watcher_factory.h"
 #include "ash/webui/diagnostics_ui/backend/input/input_data_event_watcher.h"
@@ -374,6 +375,8 @@ void InputDataProvider::UnforwardKeyboardInput(uint32_t id) {
     keyboard_input_log_ptr_->CreateLogAndRemoveKeyboard(id);
   }
 
+  healthd_event_reporter_.ReportKeyboardDiagnosticEvent(id, keyboards_[id]);
+
   // If there are no more watchers, unblock shortcuts
   if (keyboard_watchers_.empty()) {
     BlockShortcuts(/*should_block=*/false);
@@ -608,6 +611,8 @@ void InputDataProvider::SendInputKeyEvent(uint32_t id,
     keyboard_input_log_ptr_->RecordKeyPressForKeyboard(id, event.Clone());
   }
 
+  healthd_event_reporter_.AddKeyEventForNextReport(id, event);
+
   const auto& observers = *keyboard_observers_[id];
   for (const auto& observer : observers) {
     observer->OnKeyEvent(event->Clone());
