@@ -3,7 +3,10 @@
 // found in the LICENSE file.
 
 #include "ash/webui/eche_app_ui/eche_stream_status_change_handler.h"
+#include <memory>
 
+#include "ash/webui/eche_app_ui/apps_launch_info_provider.h"
+#include "ash/webui/eche_app_ui/eche_connection_status_handler.h"
 #include "base/task/single_thread_task_runner.h"
 #include "base/test/task_environment.h"
 #include "testing/gtest/include/gtest/gtest.h"
@@ -89,11 +92,18 @@ class EcheStreamStatusChangeHandlerTest : public testing::Test {
 
   // testing::Test:
   void SetUp() override {
-    handler_ = std::make_unique<EcheStreamStatusChangeHandler>();
+    connection_status_handler_ =
+        std::make_unique<eche_app::EcheConnectionStatusHandler>();
+    apps_launch_info_provider_ = std::make_unique<AppsLaunchInfoProvider>(
+        connection_status_handler_.get());
+    handler_ = std::make_unique<EcheStreamStatusChangeHandler>(
+        apps_launch_info_provider_.get(), connection_status_handler_.get());
     handler_->AddObserver(&fake_observer_);
   }
 
   void TearDown() override {
+    apps_launch_info_provider_.reset();
+    connection_status_handler_.reset();
     handler_->RemoveObserver(&fake_observer_);
     handler_.reset();
   }
@@ -120,6 +130,9 @@ class EcheStreamStatusChangeHandlerTest : public testing::Test {
 
  private:
   FakeObserver fake_observer_;
+  std::unique_ptr<eche_app::EcheConnectionStatusHandler>
+      connection_status_handler_;
+  std::unique_ptr<AppsLaunchInfoProvider> apps_launch_info_provider_;
   std::unique_ptr<EcheStreamStatusChangeHandler> handler_;
 };
 
