@@ -8,6 +8,7 @@
 #include "ash/system/eche/eche_tray.h"
 #include "ash/webui/eche_app_ui/eche_stream_status_change_handler.h"
 #include "ash/webui/eche_app_ui/feature_status_provider.h"
+#include "ash/webui/eche_app_ui/mojom/eche_app.mojom-shared.h"
 #include "ash/webui/eche_app_ui/mojom/eche_app.mojom.h"
 #include "base/scoped_observation.h"
 #include "url/gurl.h"
@@ -26,6 +27,8 @@ void LaunchBubble(const GURL& url,
                   const gfx::Image& icon,
                   const std::u16string& visible_name,
                   const std::u16string& phone_name,
+                  eche_app::mojom::ConnectionStatus last_connection_status,
+                  eche_app::mojom::AppStreamLaunchEntryPoint entry_point,
                   EcheTray::GracefulCloseCallback graceful_close_callback,
                   EcheTray::GracefulGoBackCallback graceful_go_back_callback);
 
