@@ -3,12 +3,15 @@
 // found in the LICENSE file.
 
 #include "ash/webui/eche_app_ui/eche_tray_stream_status_observer.h"
+#include <memory>
 
 #include "ash/constants/ash_features.h"
 #include "ash/system/eche/eche_tray.h"
 #include "ash/system/status_area_widget_test_helper.h"
 #include "ash/test/ash_test_base.h"
 #include "ash/test/test_ash_web_view_factory.h"
+#include "ash/webui/eche_app_ui/apps_launch_info_provider.h"
+#include "ash/webui/eche_app_ui/eche_connection_status_handler.h"
 #include "ash/webui/eche_app_ui/eche_stream_status_change_handler.h"
 #include "ash/webui/eche_app_ui/fake_feature_status_provider.h"
 #include "base/test/scoped_feature_list.h"
@@ -59,15 +62,21 @@ class EcheTrayStreamStatusObserverTest : public AshTestBase {
     AshTestBase::SetUp();
     eche_tray_ =
         ash::StatusAreaWidgetTestHelper::GetStatusAreaWidget()->eche_tray();
-
+    connection_status_handler_ =
+        std::make_unique<EcheConnectionStatusHandler>();
+    apps_launch_info_provider_ = std::make_unique<AppsLaunchInfoProvider>(
+        connection_status_handler_.get());
     stream_status_change_handler_ =
-        std::make_unique<EcheStreamStatusChangeHandler>();
+        std::make_unique<EcheStreamStatusChangeHandler>(
+            apps_launch_info_provider_.get(), connection_status_handler_.get());
     observer_ = std::make_unique<EcheTrayStreamStatusObserver>(
         stream_status_change_handler_.get(), &fake_feature_status_provider_);
   }
 
   void TearDown() override {
     observer_.reset();
+    apps_launch_info_provider_.reset();
+    connection_status_handler_.reset();
     stream_status_change_handler_.reset();
     AshTestBase::TearDown();
   }
@@ -87,6 +96,8 @@ class EcheTrayStreamStatusObserverTest : public AshTestBase {
  private:
   base::test::ScopedFeatureList scoped_feature_list_;
   EcheTray* eche_tray_ = nullptr;
+  std::unique_ptr<EcheConnectionStatusHandler> connection_status_handler_;
+  std::unique_ptr<AppsLaunchInfoProvider> apps_launch_info_provider_;
   std::unique_ptr<EcheStreamStatusChangeHandler> stream_status_change_handler_;
   std::unique_ptr<EcheTrayStreamStatusObserver> observer_;
   FakeFeatureStatusProvider fake_feature_status_provider_;
@@ -97,6 +108,8 @@ class EcheTrayStreamStatusObserverTest : public AshTestBase {
 
 TEST_F(EcheTrayStreamStatusObserverTest, LaunchBubble) {
   LaunchBubble(GURL("http://google.com"), gfx::Image(), u"app 1", u"your phone",
+               eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+               eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST,
                base::BindOnce(&GracefulCloseFunction),
                base::BindRepeating(&GracefulGoBackFunction));
 
@@ -115,6 +128,8 @@ TEST_F(EcheTrayStreamStatusObserverTest, OnStartStreaming) {
   EXPECT_FALSE(eche_tray()->get_bubble_wrapper_for_test());
 
   LaunchBubble(GURL("http://google.com"), gfx::Image(), u"app 1", u"your phone",
+               eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+               eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST,
                base::BindOnce(&GracefulCloseFunction),
                base::BindRepeating(&GracefulGoBackFunction));
 
@@ -135,6 +150,8 @@ TEST_F(EcheTrayStreamStatusObserverTest, OnStartStreaming) {
 
 TEST_F(EcheTrayStreamStatusObserverTest, OnStreamStatusChanged) {
   LaunchBubble(GURL("http://google.com"), gfx::Image(), u"app 1", u"your phone",
+               eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+               eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST,
                base::BindOnce(&GracefulCloseFunction),
                base::BindRepeating(&GracefulGoBackFunction));
   OnStreamStatusChanged(mojom::StreamStatus::kStreamStatusStarted);
@@ -157,6 +174,8 @@ TEST_F(EcheTrayStreamStatusObserverTest,
   ResetUnloadWebContent();
   SetStatus(FeatureStatus::kConnecting);
   LaunchBubble(GURL("http://google.com"), gfx::Image(), u"app 1", u"your phone",
+               eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+               eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST,
                base::BindOnce(&GracefulCloseFunction),
                base::BindRepeating(&GracefulGoBackFunction));
   OnStreamStatusChanged(mojom::StreamStatus::kStreamStatusStarted);
@@ -180,6 +199,8 @@ TEST_F(EcheTrayStreamStatusObserverTest,
   ResetUnloadWebContent();
   SetStatus(FeatureStatus::kConnecting);
   LaunchBubble(GURL("http://google.com"), gfx::Image(), u"app 1", u"your phone",
+               eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+               eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST,
                base::BindOnce(&GracefulCloseFunction),
                base::BindRepeating(&GracefulGoBackFunction));
   OnStreamStatusChanged(mojom::StreamStatus::kStreamStatusStarted);
@@ -203,6 +224,8 @@ TEST_F(EcheTrayStreamStatusObserverTest,
   ResetUnloadWebContent();
   SetStatus(FeatureStatus::kConnecting);
   LaunchBubble(GURL("http://google.com"), gfx::Image(), u"app 1", u"your phone",
+               eche_app::mojom::ConnectionStatus::kConnectionStatusDisconnected,
+               eche_app::mojom::AppStreamLaunchEntryPoint::APPS_LIST,
                base::BindOnce(&GracefulCloseFunction),
                base::BindRepeating(&GracefulGoBackFunction));
   OnStreamStatusChanged(mojom::StreamStatus::kStreamStatusStarted);
