@@ -47,6 +47,12 @@ const notificationGenerator =
 
 const displayStreamHandler = ash.echeApp.mojom.DisplayStreamHandler.getRemote();
 
+const streamOrientationObserver =
+    ash.echeApp.mojom.StreamOrientationObserver.getRemote();
+
+const connectionStatusObserver =
+    ash.echeApp.mojom.ConnectionStatusObserver.getRemote();
+
 const streamActionObserverRouter =
     new ash.echeApp.mojom.StreamActionObserverCallbackRouter();
 // Set up a message pipe to the browser process to monitor stream action.
@@ -189,6 +195,25 @@ guestMessagePipe.registerHandler(Message.START_STREAMING, async () => {
       ash.echeApp.mojom.StreamStatus.kStreamStatusStarted);
 });
 
+// Register CHANGE_ORIENTATION.
+guestMessagePipe.registerHandler(
+    Message.CHANGE_ORIENTATION, async (message) => {
+      console.log(
+          `echeapi browser_proxy.js ` +
+          `onStreamOrientationChanged ${message.isLandscape}`);
+      streamOrientationObserver.onStreamOrientationChanged(message.isLandscape);
+    });
+
+// Register CONNECTION_STATUS_CHANGED.
+guestMessagePipe.registerHandler(
+    Message.CONNECTION_STATUS_CHANGED, async (message) => {
+      console.log(
+          `echeapi browser_proxy.js ` +
+          `onConnectionStatusChanged ${message.connectionStatus}`);
+      connectionStatusObserver.onConnectionStatusChanged(
+          message.connectionStatus);
+    });
+
 // We can't access hash change event inside iframe so parse the notification
 // info from the anchor part of the url when hash is changed and send them to
 // untrusted section via message pipes.
