@@ -18,6 +18,12 @@ class FilesInternalsUIDelegate {
 
   virtual bool GetSmbfsEnableVerboseLogging() const = 0;
   virtual void SetSmbfsEnableVerboseLogging(bool enabled) = 0;
+
+  virtual bool GetOfficeSetupComplete() const = 0;
+  virtual void SetOfficeSetupComplete(bool complete) = 0;
+
+  virtual bool GetAlwaysMoveOfficeFiles() const = 0;
+  virtual void SetAlwaysMoveOfficeFiles(bool always_move) = 0;
 };
 
 }  // namespace ash
