@@ -3,17 +3,20 @@
 // found in the LICENSE file.
 
 #include "ash/webui/help_app_ui/search/search_handler.h"
+#include <cstddef>
 
 #include "ash/webui/help_app_ui/search/search.mojom-test-utils.h"
+#include "ash/webui/help_app_ui/search/search_concept.h"
 #include "ash/webui/help_app_ui/search/search_tag_registry.h"
+#include "base/files/file_util.h"
+#include "base/files/scoped_temp_dir.h"
 #include "base/strings/utf_string_conversions.h"
 #include "base/test/metrics/histogram_tester.h"
 #include "base/test/task_environment.h"
 #include "mojo/public/cpp/bindings/remote.h"
 #include "testing/gtest/include/gtest/gtest.h"
 
-namespace ash {
-namespace help_app {
+namespace ash::help_app {
 namespace {
 
 class FakeObserver : public mojom::SearchResultsObserver {
@@ -50,11 +53,76 @@ class HelpAppSearchHandlerTest : public testing::Test {
   void SetUp() override {
     handler_.BindInterface(handler_remote_.BindNewPipeAndPassReceiver());
 
-    handler_remote_->Observe(observer_.GenerateRemote());
+    handler_remote_->Observe(search_results_observer_.GenerateRemote());
     handler_remote_.FlushForTesting();
+
+    ASSERT_TRUE(temp_dir_.CreateUniqueTempDir());
+  }
+
+  void SetupInitialPersistenceSearchConcepts() {
+    SearchConcept persistence(GetPersistencePath());
+    std::vector<mojom::SearchConceptPtr> search_concepts;
+    mojom::SearchConceptPtr new_concept_1 = mojom::SearchConcept::New(
+        /*id=*/"test-id-1",
+        /*title=*/u"Title 1",
+        /*main_category=*/u"Help",
+        /*tags=*/std::vector<std::u16string>{u"Test tag", u"Tag 2"},
+        /*tag_locale=*/"en",
+        /*url_path_with_parameters=*/"help",
+        /*locale=*/"");
+    mojom::SearchConceptPtr new_concept_2 = mojom::SearchConcept::New(
+        /*id=*/"test-id-2",
+        /*title=*/u"Title 2",
+        /*main_category=*/u"Help",
+        /*tags=*/std::vector<std::u16string>{u"Another test tag"},
+        /*tag_locale=*/"en",
+        /*url_path_with_parameters=*/"help",
+        /*locale=*/"");
+    search_concepts.push_back(std::move(new_concept_1));
+    search_concepts.push_back(std::move(new_concept_2));
+    persistence.UpdateSearchConcepts(search_concepts);
+    task_environment_.RunUntilIdle();
+    EXPECT_TRUE(base::PathExists(GetPersistencePath()));
+  }
+
+  void SimulateWebDataUpdate() {
+    std::vector<mojom::SearchConceptPtr> new_search_concepts;
+    mojom::SearchConceptPtr new_concept_1 = mojom::SearchConcept::New(
+        /*id=*/"test-id-1",
+        /*title=*/u"Title 1",
+        /*main_category=*/u"Help",
+        /*tags=*/std::vector<std::u16string>{u"Printing"},
+        /*tag_locale=*/"en",
+        /*url_path_with_parameters=*/"help",
+        /*locale=*/"");
+    new_search_concepts.push_back(std::move(new_concept_1));
+    mojom::SearchHandlerAsyncWaiter(handler_remote_.get())
+        .Update(std::move(new_search_concepts));
+    handler_remote_.FlushForTesting();
+    task_environment_.RunUntilIdle();
+  }
+
+  base::FilePath GetTempPath() { return temp_dir_.GetPath(); }
+
+  base::FilePath GetPersistencePath() {
+    return temp_dir_.GetPath()
+        .AppendASCII("help_app/")
+        .AppendASCII("persistence.pb");
+  }
+
+  void OnRead(size_t expected_size,
+              std::vector<mojom::SearchConceptPtr> search_concepts) {
+    EXPECT_EQ(search_concepts.size(), expected_size);
+  }
+
+  base::OnceCallback<void(std::vector<mojom::SearchConceptPtr>)> ReadCallback(
+      size_t expected_size) {
+    return base::BindOnce(&HelpAppSearchHandlerTest::OnRead,
+                          base::Unretained(this), expected_size);
   }
 
   base::test::TaskEnvironment task_environment_;
+
   std::unique_ptr<local_search_service::LocalSearchServiceProxy>
       local_search_service_proxy_ =
           std::make_unique<local_search_service::LocalSearchServiceProxy>(
@@ -62,7 +130,8 @@ class HelpAppSearchHandlerTest : public testing::Test {
   SearchTagRegistry search_tag_registry_;
   SearchHandler handler_;
   mojo::Remote<mojom::SearchHandler> handler_remote_;
-  FakeObserver observer_;
+  FakeObserver search_results_observer_;
+  base::ScopedTempDir temp_dir_;
 };
 
 TEST_F(HelpAppSearchHandlerTest, UpdateAndSearch) {
@@ -92,7 +161,7 @@ TEST_F(HelpAppSearchHandlerTest, UpdateAndSearch) {
   handler_remote_.FlushForTesting();
   task_environment_.RunUntilIdle();
 
-  EXPECT_EQ(1u, observer_.num_calls());
+  EXPECT_EQ(1u, search_results_observer_.num_calls());
 
   std::vector<mojom::SearchResultPtr> search_results;
 
@@ -202,21 +271,6 @@ TEST_F(HelpAppSearchHandlerTest, SearchStatusNotReadyAndEmptyIndex) {
       "Discover.SearchHandler.SearchResultStatus", 0, 1);
 }
 
-TEST_F(HelpAppSearchHandlerTest, SearchStatusNotReadyAndOtherStatus) {
-  base::HistogramTester histogram_tester;
-  std::vector<mojom::SearchResultPtr> search_results;
-
-  // The empty search query makes the LSS respond with kEmptyQuery rather than
-  // kEmptyIndex.
-  mojom::SearchHandlerAsyncWaiter(handler_remote_.get())
-      .Search(u"", /*max_num_results=*/3u, &search_results);
-
-  EXPECT_TRUE(search_results.empty());
-  // 1 is kNotReadyAndOtherStatus.
-  histogram_tester.ExpectUniqueSample(
-      "Discover.SearchHandler.SearchResultStatus", 1, 1);
-}
-
 TEST_F(HelpAppSearchHandlerTest, SearchStatusReadyAndSuccess) {
   // Add one item to the search index.
   std::vector<mojom::SearchConceptPtr> search_concepts;
@@ -297,5 +351,119 @@ TEST_F(HelpAppSearchHandlerTest, SearchStatusReadyAndOtherStatus) {
       "Discover.SearchHandler.SearchResultStatus", 4, 1);
 }
 
-}  // namespace help_app
-}  // namespace ash
+TEST_F(HelpAppSearchHandlerTest, InitializeWithoutPersistence) {
+  // Load when persistence not exist.
+  EXPECT_FALSE(base::PathExists(GetPersistencePath()));
+  handler_.OnProfileDirAvailable(GetTempPath());
+  handler_remote_.FlushForTesting();
+  task_environment_.RunUntilIdle();
+
+  // Nothing is updated.
+  EXPECT_EQ(0u, search_results_observer_.num_calls());
+
+  // Web data comes.
+  SimulateWebDataUpdate();
+
+  // Updated from web data.
+  EXPECT_EQ(1u, search_results_observer_.num_calls());
+
+  // Check the persistence is generated.
+  EXPECT_TRUE(base::PathExists(GetPersistencePath()));
+  SearchConcept persistence(GetPersistencePath());
+  persistence.GetSearchConcepts(ReadCallback(1u));
+}
+
+TEST_F(HelpAppSearchHandlerTest, InitializeWithPersistence) {
+  // Add persistence to disk.
+  SetupInitialPersistenceSearchConcepts();
+
+  // Load from persistence.
+  handler_.OnProfileDirAvailable(GetTempPath());
+  handler_remote_.FlushForTesting();
+  task_environment_.RunUntilIdle();
+
+  // Updated from persistence.
+  EXPECT_EQ(1u, search_results_observer_.num_calls());
+
+  std::vector<mojom::SearchResultPtr> search_results;
+
+  // There should be results.
+  mojom::SearchHandlerAsyncWaiter(handler_remote_.get())
+      .Search(u"test tag",
+              /*max_num_results=*/3u, &search_results);
+  EXPECT_EQ(search_results.size(), 2u);
+}
+
+TEST_F(HelpAppSearchHandlerTest, PersistenceUpdateWithNewData) {
+  // Add persistence to disk.
+  SetupInitialPersistenceSearchConcepts();
+
+  // Load from persistence.
+  handler_.OnProfileDirAvailable(GetTempPath());
+  handler_remote_.FlushForTesting();
+  task_environment_.RunUntilIdle();
+
+  // Updated from persistence.
+  EXPECT_EQ(1u, search_results_observer_.num_calls());
+
+  // Web data comes.
+  SimulateWebDataUpdate();
+
+  // Updated from new data.
+  EXPECT_EQ(2u, search_results_observer_.num_calls());
+
+  std::vector<mojom::SearchResultPtr> search_results;
+
+  // There should be new results.
+  mojom::SearchHandlerAsyncWaiter(handler_remote_.get())
+      .Search(u"Printing", /*max_num_results=*/3u, &search_results);
+  EXPECT_EQ(search_results.size(), 1u);
+
+  // There should be no old results.
+  mojom::SearchHandlerAsyncWaiter(handler_remote_.get())
+      .Search(u"test tag",
+              /*max_num_results=*/3u, &search_results);
+  EXPECT_EQ(search_results.size(), 0u);
+
+  // Check the persistence is also updated.
+  SearchConcept persistence(GetPersistencePath());
+  persistence.GetSearchConcepts(ReadCallback(1u));
+}
+
+TEST_F(HelpAppSearchHandlerTest, NewDataComesBeforePersistenceLoad) {
+  // Add persistence to disk.
+  SetupInitialPersistenceSearchConcepts();
+
+  // Web data comes.
+  SimulateWebDataUpdate();
+
+  // Updated from web data.
+  EXPECT_EQ(1u, search_results_observer_.num_calls());
+
+  // Load from persistence after the new data comes.
+  handler_.OnProfileDirAvailable(GetTempPath());
+  handler_remote_.FlushForTesting();
+  task_environment_.RunUntilIdle();
+
+  // No update from persistence.
+  EXPECT_EQ(1u, search_results_observer_.num_calls());
+
+  std::vector<mojom::SearchResultPtr> search_results;
+
+  // There should be new results.
+  mojom::SearchHandlerAsyncWaiter(handler_remote_.get())
+      .Search(u"Printing", /*max_num_results=*/3u, &search_results);
+  EXPECT_EQ(search_results.size(), 1u);
+
+  // There should be no persistence results.
+  mojom::SearchHandlerAsyncWaiter(handler_remote_.get())
+      .Search(u"test tag",
+              /*max_num_results=*/3u, &search_results);
+  EXPECT_EQ(search_results.size(), 0u);
+
+  // Check the persistence is also updated.
+  SearchConcept persistence(GetPersistencePath());
+  persistence.GetSearchConcepts(ReadCallback(1u));
+}
+
+}  // namespace ash::help_app
