@@ -1,4 +1,4 @@
-// Copyright 2021 The Chromium Authors. All rights reserved.
+// Copyright 2021 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,6 +7,7 @@
 
 #include <memory>
 
+#include "ash/webui/os_feedback_ui/backend/feedback_service_provider.h"
 #include "ash/webui/os_feedback_ui/backend/help_content_provider.h"
 #include "ash/webui/os_feedback_ui/mojom/os_feedback_ui.mojom.h"
 #include "ui/webui/mojo_web_ui_controller.h"
@@ -27,13 +28,16 @@ class OSFeedbackUI : public ui::MojoWebUIController {
   OSFeedbackUI& operator=(const OSFeedbackUI&) = delete;
   ~OSFeedbackUI() override;
 
+  void BindInterface(
+      mojo::PendingReceiver<os_feedback_ui::mojom::FeedbackServiceProvider>
+          receiver);
   void BindInterface(
       mojo::PendingReceiver<os_feedback_ui::mojom::HelpContentProvider>
           receiver);
 
  private:
-  std::unique_ptr<OsFeedbackDelegate> feedback_delegate_;
-  std::unique_ptr<feedback::HelpContentProvider> helpContentProvider_;
+  std::unique_ptr<feedback::HelpContentProvider> help_content_provider_;
+  std::unique_ptr<feedback::FeedbackServiceProvider> feedback_service_provider_;
 
   WEB_UI_CONTROLLER_TYPE_DECL();
 };
