@@ -12,7 +12,7 @@ import '../../css/common.css.js';
 import {IronListElement} from 'chrome://resources/polymer/v3_0/iron-list/iron-list.js';
 import {afterNextRender} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 
-import {AmbientModeAlbum, TopicSource} from '../personalization_app.mojom-webui.js';
+import {AmbientModeAlbum, TopicSource} from '../../personalization_app.mojom-webui.js';
 import {WithPersonalizationStore} from '../personalization_store.js';
 import {getCountText, isRecentHighlightsAlbum} from '../utils.js';
 
