@@ -4,13 +4,14 @@
 
 import {Url} from 'chrome://resources/mojo/url/mojom/url.mojom-webui.js';
 
-import {AmbientModeAlbum, AmbientObserverInterface, AmbientObserverReceiver, AmbientProviderInterface, AmbientUiVisibility, AnimationTheme, TemperatureUnit, TopicSource} from '../personalization_app.mojom-webui.js';
+import {AmbientModeAlbum, AmbientObserverInterface, AmbientObserverReceiver, AmbientProviderInterface, AmbientUiVisibility, AnimationTheme, TemperatureUnit, TopicSource} from '../../personalization_app.mojom-webui.js';
+import {isAmbientModeAllowed, isPersonalizationJellyEnabled} from '../load_time_booleans.js';
 import {logGooglePhotosPreviewsLoadTime} from '../personalization_metrics_logger.js';
 import {Paths} from '../personalization_router_element.js';
 import {PersonalizationStore} from '../personalization_store.js';
 import {isNonEmptyArray, isRecentHighlightsAlbum} from '../utils.js';
 
-import {setAlbumsAction, setAmbientModeEnabledAction, setAmbientUiVisibilityAction, setAnimationThemeAction, setGooglePhotosAlbumsPreviewsAction, setTemperatureUnitAction, setTopicSourceAction} from './ambient_actions.js';
+import {setAlbumsAction, setAmbientModeEnabledAction, setAmbientUiVisibilityAction, setAnimationThemeAction, setPreviewsAction, setTemperatureUnitAction, setTopicSourceAction} from './ambient_actions.js';
 import {getAmbientProvider} from './ambient_interface_provider.js';
 
 /** @fileoverview listens for updates on ambient mode changes. */
@@ -22,13 +23,13 @@ let instance: AmbientObserver|null = null;
  */
 export class AmbientObserver implements AmbientObserverInterface {
   // Allow logging first load performance if the user began on a page where
-  // google photos preview images are loaded immediately.
-  static shouldLogGooglePhotosPreviewsLoadPerformance: boolean =
+  // preview images are loaded immediately.
+  static shouldLogPreviewsLoadPerformance: boolean =
       window.location.pathname === Paths.ROOT ||
       window.location.pathname === Paths.AMBIENT;
 
   static initAmbientObserverIfNeeded(): void {
-    if (!instance) {
+    if (isAmbientModeAllowed() && !instance) {
       instance = new AmbientObserver();
     }
   }
@@ -58,9 +59,8 @@ export class AmbientObserver implements AmbientObserverInterface {
   onAmbientModeEnabledChanged(ambientModeEnabled: boolean) {
     // Only record google photos previews load performance if ambient mode
     // starts enabled.
-    AmbientObserver.shouldLogGooglePhotosPreviewsLoadPerformance =
-        AmbientObserver.shouldLogGooglePhotosPreviewsLoadPerformance &&
-        ambientModeEnabled;
+    AmbientObserver.shouldLogPreviewsLoadPerformance =
+        AmbientObserver.shouldLogPreviewsLoadPerformance && ambientModeEnabled;
     const store = PersonalizationStore.getInstance();
     store.dispatch(setAmbientModeEnabledAction(ambientModeEnabled));
   }
@@ -72,12 +72,13 @@ export class AmbientObserver implements AmbientObserverInterface {
 
   onTopicSourceChanged(topicSource: TopicSource) {
     const store = PersonalizationStore.getInstance();
-    // If the first time receiving `topicSource` and it is already set to
-    // `kGooglePhotos`, allow logging google photos load performance.
-    AmbientObserver.shouldLogGooglePhotosPreviewsLoadPerformance =
-        AmbientObserver.shouldLogGooglePhotosPreviewsLoadPerformance &&
+    // If the first time receiving `topicSource`, allow logging load
+    // performance.
+    AmbientObserver.shouldLogPreviewsLoadPerformance =
+        AmbientObserver.shouldLogPreviewsLoadPerformance &&
         store.data.ambient.topicSource === null &&
-        topicSource === TopicSource.kGooglePhotos;
+        (topicSource === TopicSource.kGooglePhotos ||
+         isPersonalizationJellyEnabled());
     store.dispatch(setTopicSourceAction(topicSource));
   }
 
@@ -106,22 +107,24 @@ export class AmbientObserver implements AmbientObserverInterface {
     store.dispatch(setAlbumsAction(albums));
   }
 
-  onGooglePhotosAlbumsPreviewsFetched(previews: Url[]) {
+  onPreviewsFetched(previews: Url[]) {
     const store = PersonalizationStore.getInstance();
 
     // Only log performance metrics if this is the first time receiving google
     // photos previews.
-    AmbientObserver.shouldLogGooglePhotosPreviewsLoadPerformance =
-        AmbientObserver.shouldLogGooglePhotosPreviewsLoadPerformance &&
-        (!store.data.ambient.googlePhotosAlbumsPreviews ||
-         store.data.ambient.googlePhotosAlbumsPreviews.length === 0);
+    // When Jelly disabled: log google photos albums only.
+    // When Jelly enabled: log both art galleries and google photos albums.
+    AmbientObserver.shouldLogPreviewsLoadPerformance =
+        AmbientObserver.shouldLogPreviewsLoadPerformance &&
+        (!store.data.ambient.previews ||
+         store.data.ambient.previews.length === 0);
 
-    store.dispatch(setGooglePhotosAlbumsPreviewsAction(previews));
+    store.dispatch(setPreviewsAction(previews));
 
-    if (AmbientObserver.shouldLogGooglePhotosPreviewsLoadPerformance &&
+    if (AmbientObserver.shouldLogPreviewsLoadPerformance &&
         isNonEmptyArray(previews)) {
       logGooglePhotosPreviewsLoadTime();
-      AmbientObserver.shouldLogGooglePhotosPreviewsLoadPerformance = false;
+      AmbientObserver.shouldLogPreviewsLoadPerformance = false;
     }
   }
 
