@@ -15,12 +15,12 @@ import './animation_theme_list_element.js';
 import './toggle_row_element.js';
 import './topic_source_list_element.js';
 
-import {loadTimeData} from 'chrome://resources/ash/common/load_time_data.m.js';
 import {assert} from 'chrome://resources/js/assert_ts.js';
 import {afterNextRender} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 
-import {AmbientModeAlbum, AnimationTheme, TemperatureUnit, TopicSource} from '../personalization_app.mojom-webui.js';
-import {isAmbientModeAllowed, Paths} from '../personalization_router_element.js';
+import {AmbientModeAlbum, AnimationTheme, TemperatureUnit, TopicSource} from '../../personalization_app.mojom-webui.js';
+import {isAmbientModeAllowed, isPersonalizationJellyEnabled} from '../load_time_booleans.js';
+import {Paths} from '../personalization_router_element.js';
 import {WithPersonalizationStore} from '../personalization_store.js';
 
 import {setAmbientModeEnabled} from './ambient_controller.js';
@@ -63,15 +63,15 @@ export class AmbientSubpage extends WithPersonalizationStore {
         type: Number,
         value: null,
       },
-      loadingSettings_: {
+      loading_: {
         type: Boolean,
         computed:
-            'computeLoadingSettings_(albums_, temperatureUnit_, topicSource_)',
+            'computeLoading_(ambientModeEnabled_, albums_, temperatureUnit_, topicSource_)',
       },
-      isAmbientSubpageUiChangeEnabled_: {
+      isPersonalizationJellyEnabled_: {
         type: Boolean,
         value() {
-          return loadTimeData.getBoolean('isAmbientSubpageUiChangeEnabled');
+          return isPersonalizationJellyEnabled();
         },
       },
     };
@@ -84,7 +84,7 @@ export class AmbientSubpage extends WithPersonalizationStore {
   private animationTheme_: AnimationTheme|null;
   private temperatureUnit_: TemperatureUnit|null;
   private topicSource_: TopicSource|null;
-  private isAmbientSubpageUiChangeEnabled_: boolean;
+  private isPersonalizationJellyEnabled_: boolean;
 
   // Refetch albums if the user is currently viewing ambient subpage, focuses
   // another window, and then re-focuses personalization app.
@@ -191,19 +191,9 @@ export class AmbientSubpage extends WithPersonalizationStore {
     return path === Paths.AMBIENT_ALBUMS;
   }
 
-  private shouldShowZeroState_(): boolean {
-    // TODO(b/253470693): Remove after Ambient subpage UI change is released.
-    return this.ambientModeEnabled_ === false &&
-        !this.isAmbientSubpageUiChangeEnabled_;
-  }
-
-  private isLoadingAmbientMode_(): boolean {
-    return this.ambientModeEnabled_ === null;
-  }
-
-  private computeLoadingSettings_(): boolean {
-    return this.albums_ === null || this.topicSource_ === null ||
-        this.temperatureUnit_ === null;
+  private computeLoading_(): boolean {
+    return this.ambientModeEnabled_ === null || this.albums_ === null ||
+        this.topicSource_ === null || this.temperatureUnit_ === null;
   }
 
   private getPlaceholders_(x: number): number[] {
