@@ -8,6 +8,7 @@
 
 import 'chrome://resources/cr_elements/cr_button/cr_button.js';
 import '../../css/common.css.js';
+import '../../css/cros_button_style.css.js';
 import 'chrome://resources/cr_elements/cr_toggle/cr_toggle.js';
 import 'chrome://resources/polymer/v3_0/iron-a11y-keys/iron-a11y-keys.js';
 import 'chrome://resources/polymer/v3_0/iron-selector/iron-selector.js';
@@ -18,7 +19,7 @@ import {SkColor} from 'chrome://resources/mojo/skia/public/mojom/skcolor.mojom-w
 import {IronA11yKeysElement} from 'chrome://resources/polymer/v3_0/iron-a11y-keys/iron-a11y-keys.js';
 import {IronSelectorElement} from 'chrome://resources/polymer/v3_0/iron-selector/iron-selector.js';
 
-import {ColorScheme, SampleColorScheme} from '../personalization_app.mojom-webui.js';
+import {ColorScheme, SampleColorScheme} from '../../personalization_app.mojom-webui.js';
 import {WithPersonalizationStore} from '../personalization_store.js';
 import {convertToRgbHexStr} from '../utils.js';
 
@@ -26,6 +27,7 @@ import {getTemplate} from './dynamic_color_element.html.js';
 import {initializeDynamicColorData, setColorSchemePref, setStaticColorPref} from './theme_controller.js';
 import {getThemeProvider} from './theme_interface_provider.js';
 import {ThemeObserver} from './theme_observer.js';
+import {DEFAULT_COLOR_SCHEME, DEFAULT_STATIC_COLOR, isAutomaticSeedColorEnabled} from './utils.js';
 
 export interface DynamicColorElement {
   $: {
@@ -36,9 +38,6 @@ export interface DynamicColorElement {
   };
 }
 
-const DEFAULT_STATIC_COLOR = hexColorToSkColor('#4285f4');
-const DEFAULT_COLOR_SCHEME = ColorScheme.kTonalSpot;
-
 export class DynamicColorElement extends WithPersonalizationStore {
   static get is() {
     return 'dynamic-color';
@@ -63,11 +62,10 @@ export class DynamicColorElement extends WithPersonalizationStore {
         type: Object,
         readOnly: true,
         value: [
-          // TODO(b/254479499): Replace colors when the spec is ready.
           '#4285f4',
-          '#bdc1c6',
-          '#edd0e4',
-          '#eadecd',
+          '#ffd6d6',
+          '#485045',
+          '#cbbfff',
         ],
       },
       sampleColorSchemes_: {
@@ -144,23 +142,19 @@ export class DynamicColorElement extends WithPersonalizationStore {
   }
 
   private isAutomaticSeedColorEnabled_(colorScheme: ColorScheme|null) {
-    return colorScheme === null || colorScheme !== ColorScheme.kStatic;
+    return isAutomaticSeedColorEnabled(colorScheme);
   }
 
   private getColorSchemeAriaChecked_(
-      colorScheme: string, colorSchemeSelected: string): 'true'|'false' {
-    if (!colorSchemeSelected) {
-      return 'false';
-    }
-    return colorSchemeSelected === colorScheme ? 'true' : 'false';
+      colorScheme: number, colorSchemeSelected: number|null): 'true'|'false' {
+    const checkedColorScheme = colorSchemeSelected || DEFAULT_COLOR_SCHEME;
+    return checkedColorScheme === colorScheme ? 'true' : 'false';
   }
 
   private getStaticColorAriaChecked_(
       staticColor: string, staticColorSelected: SkColor|null): 'true'|'false' {
-    if (!staticColorSelected) {
-      return 'false';
-    }
-    return staticColor === convertToRgbHexStr(staticColorSelected.value) ?
+    const checkedStaticColor = staticColorSelected || DEFAULT_STATIC_COLOR;
+    return staticColor === convertToRgbHexStr(checkedStaticColor.value) ?
         'true' :
         'false';
   }
@@ -206,11 +200,19 @@ export class DynamicColorElement extends WithPersonalizationStore {
     e.detail.keyboardEvent.preventDefault();
   }
 
-  private getTabIndex_(id: string): string {
-    return id === String(DEFAULT_COLOR_SCHEME) ||
-            hexColorToSkColor(id) === DEFAULT_STATIC_COLOR ?
-        '0' :
-        '-1';
+  /**
+   * Returns the tab index for the color scheme buttons.
+   */
+  private getColorSchemeTabIndex_(id: number): string {
+    return id === DEFAULT_COLOR_SCHEME ? '0' : '-1';
+  }
+
+  /**
+   * Returns the tab index for the static color buttons.
+   */
+  private getStaticColorTabIndex_(id: string): string {
+    return hexColorToSkColor(id).value === DEFAULT_STATIC_COLOR.value ? '0' :
+                                                                        '-1';
   }
 }
 
