@@ -6,9 +6,10 @@ import {assert} from 'chrome://resources/js/assert_ts.js';
 import {BigBuffer} from 'chrome://resources/mojo/mojo/public/mojom/base/big_buffer.mojom-webui.js';
 import {Url} from 'chrome://resources/mojo/url/mojom/url.mojom-webui.js';
 
-import {UserImage} from '../personalization_app.mojom-webui.js';
+import {UserImage} from '../../personalization_app.mojom-webui.js';
 import {PersonalizationState} from '../personalization_state.js';
-import {getSanitizedDefaultImageUrl} from '../utils.js';
+
+import {AVATAR_PLACEHOLDER_URL} from './utils.js';
 
 /**
  * @fileoverview Utility functions to derive a user image URL to display from
@@ -58,15 +59,20 @@ function bufferToPngObjectUrl(value: BigBuffer): Url|null {
   }
 }
 
+/**
+ * The placeholder url is used as the user image url for invalid or unknown
+ * urls.
+ */
+const placeHolderUrl = {
+  url: AVATAR_PLACEHOLDER_URL,
+};
+
 /**
  * Derive a user image |Url| from |PersonalizationState|. Return a |Url| rather
  * than |string| to avoid copies on potentially large data URLs.
  */
 export function selectUserImageUrl(state: PersonalizationState): Url|null {
   const userImage = state.user.image;
-  const placeHolderUrl = {
-    url: 'chrome://theme/IDR_PROFILE_AVATAR_PLACEHOLDER_LARGE',
-  };
 
   if (!userImage) {
     return null;
@@ -81,7 +87,7 @@ export function selectUserImageUrl(state: PersonalizationState): Url|null {
     case 'invalidImage':
       return placeHolderUrl;
     case 'defaultImage':
-      return getSanitizedDefaultImageUrl(userImage.defaultImage!.url);
+      return userImage.defaultImage!.url;
     case 'profileImage':
       return state.user.profileImage;
     case 'externalImage':
