@@ -3,6 +3,8 @@
 // found in the LICENSE file.
 
 #include "ash/webui/personalization_app/test/fake_personalization_app_theme_provider.h"
+#include "fake_personalization_app_theme_provider.h"
+#include "third_party/skia/include/core/SkColor.h"
 
 namespace ash::personalization_app {
 
@@ -43,4 +45,29 @@ void FakePersonalizationAppThemeProvider::IsColorModeAutoScheduleEnabled(
   std::move(callback).Run(/*enabled=*/false);
 }
 
+void FakePersonalizationAppThemeProvider::SetColorScheme(
+    ash::ColorScheme color_scheme) {
+  return;
+}
+
+void FakePersonalizationAppThemeProvider::SetStaticColor(
+    ::SkColor static_color) {
+  return;
+}
+
+void FakePersonalizationAppThemeProvider::GetColorScheme(
+    GetColorSchemeCallback callback) {
+  std::move(callback).Run(ash::ColorScheme::kTonalSpot);
+}
+
+void FakePersonalizationAppThemeProvider::GenerateSampleColorSchemes(
+    GenerateSampleColorSchemesCallback callback) {
+  std::vector<ash::SampleColorScheme> samples;
+  std::move(callback).Run(samples);
+}
+
+void FakePersonalizationAppThemeProvider::GetStaticColor(
+    GetStaticColorCallback callback) {
+  std::move(callback).Run(SK_ColorBLUE);
+}
 }  // namespace ash::personalization_app
