@@ -5,7 +5,7 @@
 #ifndef ASH_WEBUI_PRINT_MANAGEMENT_PRINT_MANAGEMENT_UI_H_
 #define ASH_WEBUI_PRINT_MANAGEMENT_PRINT_MANAGEMENT_UI_H_
 
-#include "ash/webui/print_management/mojom/printing_manager.mojom-forward.h"
+#include "chromeos/components/print_management/mojom/printing_manager.mojom-forward.h"
 #include "mojo/public/cpp/bindings/pending_receiver.h"
 #include "ui/webui/mojo_web_ui_controller.h"
 
@@ -17,10 +17,11 @@ namespace printing_manager {
 class PrintManagementUI : public ui::MojoWebUIController {
  public:
   using BindPrintingMetadataProviderCallback = base::RepeatingCallback<void(
-      mojo::PendingReceiver<mojom::PrintingMetadataProvider>)>;
+      mojo::PendingReceiver<chromeos::printing::printing_manager::mojom::
+                                PrintingMetadataProvider>)>;
 
   // |callback_| should bind the pending receiver to an implementation of
-  // mojom::PrintingMetadataProvider.
+  // chromeos::printing::printing_manager::mojom::PrintingMetadataProvider.
   PrintManagementUI(content::WebUI* web_ui,
                     BindPrintingMetadataProviderCallback callback_);
   ~PrintManagementUI() override;
@@ -28,10 +29,13 @@ class PrintManagementUI : public ui::MojoWebUIController {
   PrintManagementUI(const PrintManagementUI&) = delete;
   PrintManagementUI& operator=(const PrintManagementUI&) = delete;
 
-  // Instantiates implementor of the mojom::PrintingManager mojo interface by
-  // passing the pending receiver that will be internally bound.
+  // Instantiates implementor of the
+  // chromeos::printing::printing_manager::mojom::PrintingManager mojo interface
+  // by passing the pending receiver that will be internally bound.
   void BindInterface(
-      mojo::PendingReceiver<mojom::PrintingMetadataProvider> receiver);
+      mojo::PendingReceiver<
+          chromeos::printing::printing_manager::mojom::PrintingMetadataProvider>
+          receiver);
 
  private:
   const BindPrintingMetadataProviderCallback bind_pending_receiver_callback_;
