@@ -14,9 +14,9 @@ import './print_management_shared.css.js';
 import './strings.m.js';
 
 import {loadTimeData} from 'chrome://resources/ash/common/load_time_data.m.js';
+import {FocusRowMixin} from 'chrome://resources/cr_elements/focus_row_mixin.js';
 import {I18nMixin} from 'chrome://resources/cr_elements/i18n_mixin.js';
 import {assert, assertNotReached} from 'chrome://resources/js/assert_ts.js';
-import {FocusRowMixin} from 'chrome://resources/js/focus_row_mixin.js';
 import {String16} from 'chrome://resources/mojo/mojo/public/mojom/base/string16.mojom-webui.js';
 import {Time} from 'chrome://resources/mojo/mojo/public/mojom/base/time.mojom-webui.js';
 import {IronA11yAnnouncer} from 'chrome://resources/polymer/v3_0/iron-a11y-announcer/iron-a11y-announcer.js';
@@ -434,7 +434,16 @@ export class PrintJobEntryElement extends PrintJobEntryElementBase {
       totalPages: number,
       ): number {
     assert(printedPages >= 0);
+    // TODO(b/235534580): Remove print statements once resolved.
+    if (totalPages <= 0) {
+      console.error('Total pages should be > 0. totalPages: ' + totalPages);
+    }
     assert(totalPages > 0);
+    if (printedPages > totalPages) {
+      console.error(
+          'Total pages should be more than printed pages. totalPages: ' +
+          totalPages + ' printedPages: ' + printedPages);
+    }
     assert(printedPages <= totalPages);
     return (printedPages * 100) / totalPages;
   }
