@@ -11,6 +11,7 @@
 
 #include "ash/constants/ash_features.h"
 #include "ash/public/cpp/network_config_service.h"
+#include "ash/system/diagnostics/diagnostics_log_controller.h"
 #include "ash/webui/shimless_rma/backend/shimless_rma_delegate.h"
 #include "ash/webui/shimless_rma/backend/version_updater.h"
 #include "ash/webui/shimless_rma/mojom/shimless_rma.mojom.h"
@@ -21,11 +22,14 @@
 #include "base/files/file_path.h"
 #include "base/functional/bind.h"
 #include "base/logging.h"
+#include "base/task/task_traits.h"
+#include "base/task/thread_pool.h"
 #include "chromeos/ash/components/dbus/rmad/rmad.pb.h"
 #include "chromeos/ash/components/dbus/rmad/rmad_client.h"
 #include "chromeos/ash/components/network/network_state.h"
 #include "chromeos/ash/components/network/network_state_handler.h"
 #include "chromeos/ash/components/network/network_type_pattern.h"
+#include "chromeos/ash/components/network/technology_state_controller.h"
 #include "chromeos/ash/services/network_config/in_process_instance.h"
 #include "chromeos/dbus/power/power_manager_client.h"
 #include "chromeos/services/network_config/public/mojom/cros_network_config.mojom.h"
@@ -68,7 +72,9 @@ network_mojom::NetworkFilterPtr GetConfiguredWiFiFilter() {
 
 ShimlessRmaService::ShimlessRmaService(
     std::unique_ptr<ShimlessRmaDelegate> shimless_rma_delegate)
-    : shimless_rma_delegate_(std::move(shimless_rma_delegate)) {
+    : shimless_rma_delegate_(std::move(shimless_rma_delegate)),
+      task_runner_(base::ThreadPool::CreateSequencedTaskRunner(
+          {base::MayBlock(), base::TaskShutdownBehavior::SKIP_ON_SHUTDOWN})) {
   RmadClient::Get()->AddObserver(this);
 
   // Enable accessibility features.
@@ -193,9 +199,11 @@ void ShimlessRmaService::BeginFinalization(BeginFinalizationCallback callback) {
       // Enable WiFi on the device.
       NetworkStateHandler* network_state_handler =
           NetworkHandler::Get()->network_state_handler();
+      TechnologyStateController* technology_state_controller =
+          NetworkHandler::Get()->technology_state_controller();
       if (!network_state_handler->IsTechnologyEnabled(
               NetworkTypePattern::WiFi())) {
-        network_state_handler->SetTechnologyEnabled(
+        technology_state_controller->SetTechnologiesEnabled(
             NetworkTypePattern::WiFi(), /*enabled=*/true,
             network_handler::ErrorCallback());
       }
@@ -924,9 +932,32 @@ void ShimlessRmaService::GetLog(GetLogCallback callback) {
 }
 
 void ShimlessRmaService::SaveLog(SaveLogCallback callback) {
-  RmadClient::Get()->SaveLog(base::BindOnce(&ShimlessRmaService::OnSaveLog,
-                                            weak_ptr_factory_.GetWeakPtr(),
-                                            std::move(callback)));
+  if (features::IsLogControllerForDiagnosticsAppEnabled() &&
+      diagnostics::DiagnosticsLogController::IsInitialized()) {
+    task_runner_->PostTaskAndReplyWithResult(
+        FROM_HERE,
+        base::BindOnce(
+            &diagnostics::DiagnosticsLogController::
+                GenerateSessionStringOnBlockingPool,
+            // base::Unretained safe here because ~DiagnosticsLogController is
+            // called during shutdown of ash::Shell and will out-live
+            // ShimlessRmaService.
+            base::Unretained(diagnostics::DiagnosticsLogController::Get())),
+        base::BindOnce(&ShimlessRmaService::OnDiagnosticsLogReady,
+                       weak_ptr_factory_.GetWeakPtr(), std::move(callback)));
+    return;
+  }
+
+  OnDiagnosticsLogReady(std::move(callback), "");
+}
+
+void ShimlessRmaService::OnDiagnosticsLogReady(
+    SaveLogCallback callback,
+    const std::string& diagnostics_log_text) {
+  RmadClient::Get()->SaveLog(
+      diagnostics_log_text,
+      base::BindOnce(&ShimlessRmaService::OnSaveLog,
+                     weak_ptr_factory_.GetWeakPtr(), std::move(callback)));
 }
 
 void ShimlessRmaService::OnGetLog(GetLogCallback callback,
