@@ -5,12 +5,13 @@
 #include "ash/webui/shortcut_customization_ui/backend/accelerator_layout_table.h"
 #include <string>
 
-#include "ash/public/cpp/accelerators.h"
 #include "ash/public/cpp/accelerators_util.h"
 #include "ash/public/mojom/accelerator_info.mojom.h"
 #include "ash/strings/grit/ash_strings.h"
 #include "base/check_op.h"
+#include "base/no_destructor.h"
 #include "base/notreached.h"
+#include "chromeos/strings/grit/chromeos_strings.h"
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/events/event_constants.h"
 #include "ui/events/keycodes/keyboard_codes_posix.h"
@@ -18,6 +19,43 @@
 namespace ash {
 
 namespace {
+
+// This map is for KeyboardCodes that don't return a key_display from
+// `KeycodeToKeyString`. The string values here were arbitrarily chosen
+// based on the VKEY enum name.
+const base::flat_map<ui::KeyboardCode, std::u16string>& GetKeyDisplayMap() {
+  static auto key_display_map =
+      base::NoDestructor(base::flat_map<ui::KeyboardCode, std::u16string>({
+          {ui::KeyboardCode::VKEY_MICROPHONE_MUTE_TOGGLE,
+           u"MicrophoneMuteToggle"},
+          {ui::KeyboardCode::VKEY_KBD_BACKLIGHT_TOGGLE,
+           u"KeyboardBacklightToggle"},
+          {ui::KeyboardCode::VKEY_KBD_BRIGHTNESS_UP, u"KeyboardBrightnessUp"},
+          {ui::KeyboardCode::VKEY_KBD_BRIGHTNESS_DOWN,
+           u"KeyboardBrightnessDown"},
+          {ui::KeyboardCode::VKEY_SLEEP, u"Sleep"},
+          {ui::KeyboardCode::VKEY_NEW, u"NewTab"},
+          {ui::KeyboardCode::VKEY_PRIVACY_SCREEN_TOGGLE,
+           u"PrivacyScreenToggle"},
+          {ui::KeyboardCode::VKEY_ALL_APPLICATIONS, u"OpenLauncher"},
+          {ui::KeyboardCode::VKEY_DICTATE, u"ToggleDictation"},
+          {ui::KeyboardCode::VKEY_WLAN, u"ToggleWifi"},
+          {ui::KeyboardCode::VKEY_EMOJI_PICKER, u"EmojiPicker"},
+          {ui::KeyboardCode::VKEY_HOME, u"home"},
+          {ui::KeyboardCode::VKEY_END, u"end"},
+          {ui::KeyboardCode::VKEY_DELETE, u"delete"},
+          {ui::KeyboardCode::VKEY_INSERT, u"insert"},
+          {ui::KeyboardCode::VKEY_PRIOR, u"page up"},
+          {ui::KeyboardCode::VKEY_NEXT, u"page down"},
+          {ui::KeyboardCode::VKEY_SPACE, u"space"},
+          {ui::KeyboardCode::VKEY_TAB, u"tab"},
+          {ui::KeyboardCode::VKEY_ESCAPE, u"esc"},
+          {ui::KeyboardCode::VKEY_RETURN, u"enter"},
+          {ui::KeyboardCode::VKEY_BACK, u"backspace"},
+      }));
+  return *key_display_map;
+}
+
 std::u16string GetTextForModifier(ui::EventFlags modifier) {
   switch (modifier) {
     case ui::EF_SHIFT_DOWN:
@@ -48,7 +86,7 @@ TextAcceleratorPart::TextAcceleratorPart(ui::EventFlags modifier) {
 }
 
 TextAcceleratorPart::TextAcceleratorPart(ui::KeyboardCode key_code) {
-  text = KeycodeToKeyString(key_code);
+  text = GetKeyDisplay(key_code);
   type = mojom::TextAcceleratorPartType::kKey;
 }
 
@@ -106,20 +144,6 @@ const NonConfigurableActionsMap& GetNonConfigurableActionsMap() {
                 TextAcceleratorPart(TextAcceleratorDelimiter::kPlusSign),
                 TextAcceleratorPart(ui::KeyboardCode::VKEY_1),
                 TextAcceleratorPart(ui::KeyboardCode::VKEY_8)})},
-          {NonConfigurableActions::kBrowserFindNext,
-           NonConfigurableAcceleratorDetails(
-               IDS_AMBIENT_ACCELERATOR_FIND_NEXT,
-               {TextAcceleratorPart(ui::EF_CONTROL_DOWN),
-                TextAcceleratorPart(ui::KeyboardCode::VKEY_G),
-                TextAcceleratorPart(ui::KeyboardCode::VKEY_RETURN)})},
-          {NonConfigurableActions::kBrowserFindPrevious,
-           NonConfigurableAcceleratorDetails(
-               IDS_AMBIENT_ACCELERATOR_FIND_PREVIOUS,
-               {TextAcceleratorPart(ui::EF_CONTROL_DOWN),
-                TextAcceleratorPart(ui::EF_SHIFT_DOWN),
-                TextAcceleratorPart(ui::KeyboardCode::VKEY_G),
-                TextAcceleratorPart(ui::EF_SHIFT_DOWN),
-                TextAcceleratorPart(ui::KeyboardCode::VKEY_RETURN)})},
           {NonConfigurableActions::kAmbientOpenLinkInTab,
            NonConfigurableAcceleratorDetails(
                IDS_AMBIENT_ACCELERATOR_OPEN_LINK_IN_TAB,
@@ -144,28 +168,10 @@ const NonConfigurableActionsMap& GetNonConfigurableActionsMap() {
                {TextAcceleratorPart(ui::EF_ALT_DOWN),
                 TextAcceleratorPart(ui::EF_SHIFT_DOWN),
                 TextAcceleratorPart(ui::KeyboardCode::VKEY_TAB)})},
-          {NonConfigurableActions::kBrowserFocusSearch,
-           NonConfigurableAcceleratorDetails(
-               IDS_AMBIENT_ACCELERATOR_FOCUS_SEARCH,
-               {TextAcceleratorPart(ui::EF_CONTROL_DOWN),
-                TextAcceleratorPart(ui::KeyboardCode::VKEY_K),
-                TextAcceleratorPart(ui::KeyboardCode::VKEY_E)})},
-          {NonConfigurableActions::kBrowserReload,
-           NonConfigurableAcceleratorDetails(
-               IDS_AMBIENT_ACCELERATOR_RELOAD,
-               {TextAcceleratorPart(ui::KeyboardCode::VKEY_BROWSER_REFRESH),
-                TextAcceleratorPart(ui::EF_CONTROL_DOWN),
-                TextAcceleratorPart(ui::KeyboardCode::VKEY_R)})},
           {NonConfigurableActions::kBrowserRightClick,
            NonConfigurableAcceleratorDetails(
                IDS_AMBIENT_ACCELERATOR_RIGHT_CLICK,
                {TextAcceleratorPart(ui::EF_ALT_DOWN)})},
-          {NonConfigurableActions::kBrowserShowAppMenu,
-           NonConfigurableAcceleratorDetails(
-               IDS_AMBIENT_ACCELERATOR_SHOW_APP_MENU,
-               {TextAcceleratorPart(ui::EF_CONTROL_DOWN),
-                TextAcceleratorPart(ui::KeyboardCode::VKEY_E),
-                TextAcceleratorPart(ui::KeyboardCode::VKEY_F)})},
           {NonConfigurableActions::kAmbientLaunchNumberedApp,
            NonConfigurableAcceleratorDetails(
                IDS_AMBIENT_ACCELERATOR_LAUNCH_NUMBERED_APP,
@@ -209,6 +215,47 @@ const NonConfigurableActionsMap& GetNonConfigurableActionsMap() {
                 TextAcceleratorPart(ui::EF_ALT_DOWN),
                 TextAcceleratorPart(ui::KeyboardCode::VKEY_I),
                 TextAcceleratorPart(ui::KeyboardCode::VKEY_ESCAPE)})},
+          {NonConfigurableActions::kAmbientSwitchFocus,
+           NonConfigurableAcceleratorDetails(
+               IDS_AMBIENT_ACCELERATOR_SWITCH_FOCUS,
+               {TextAcceleratorPart(ui::EF_CONTROL_DOWN),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_BROWSER_BACK),
+                TextAcceleratorPart(ui::EF_CONTROL_DOWN),
+                TextAcceleratorPart(ui::EF_SHIFT_DOWN),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_BROWSER_BACK)})},
+          {NonConfigurableActions::kAmbientMoveAppsInGrid,
+           NonConfigurableAcceleratorDetails(
+               IDS_AMBIENT_ACCELERATOR_MOVE_APPS_IN_GRID,
+               {TextAcceleratorPart(ui::EF_CONTROL_DOWN),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_LEFT),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_RIGHT),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_UP),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_DOWN)})},
+          {NonConfigurableActions::kAmbientMoveAppsInOutFolder,
+           NonConfigurableAcceleratorDetails(
+               IDS_AMBIENT_ACCELERATOR_MOVE_APPS_IN_OUT_FOLDER,
+               {TextAcceleratorPart(ui::EF_CONTROL_DOWN),
+                TextAcceleratorPart(ui::EF_SHIFT_DOWN),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_LEFT),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_RIGHT),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_UP),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_DOWN)})},
+          {NonConfigurableActions::kAmbientOpenLinkInTabBackground,
+           NonConfigurableAcceleratorDetails(
+               IDS_AMBIENT_ACCELERATOR_OPEN_LINK_IN_TAB_BACKGROUND,
+               {TextAcceleratorPart(ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kBrowserStopDragTab,
+           NonConfigurableAcceleratorDetails(
+               IDS_BROWSER_ACCELERATOR_STOP_DRAG_TAB,
+               {TextAcceleratorPart(ui::KeyboardCode::VKEY_ESCAPE)})},
+          {NonConfigurableActions::kAmbientActivateIndexedDesk,
+           NonConfigurableAcceleratorDetails(
+               IDS_AMBIENT_ACCELERATOR_ACTIVATE_INDEXED_DESK,
+               {TextAcceleratorPart(ui::EF_SHIFT_DOWN),
+                TextAcceleratorPart(ui::EF_COMMAND_DOWN),
+                TextAcceleratorPart(TextAcceleratorDelimiter::kPlusSign),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_1),
+                TextAcceleratorPart(ui::KeyboardCode::VKEY_8)})},
           // Ambient accelerators that only contain plain text (no
           // replacements).
           {NonConfigurableActions::kAmbientDragLinkInNewTab,
@@ -319,25 +366,37 @@ const NonConfigurableActionsMap& GetNonConfigurableActionsMap() {
                {ui::Accelerator(ui::VKEY_OEM_PLUS, ui::EF_CONTROL_DOWN)})},
           {NonConfigurableActions::kBrowserFocusToolbar,
            NonConfigurableAcceleratorDetails({ui::Accelerator(
-               ui::VKEY_T, ui::EF_SHIFT_DOWN | ui::EF_CONTROL_DOWN)})},
+               ui::VKEY_T, ui::EF_SHIFT_DOWN | ui::EF_ALT_DOWN)})},
           {NonConfigurableActions::kBrowserFocusInactivePopupForAccessibility,
            NonConfigurableAcceleratorDetails({ui::Accelerator(
-               ui::VKEY_A, ui::EF_SHIFT_DOWN | ui::EF_CONTROL_DOWN)})},
+               ui::VKEY_A, ui::EF_SHIFT_DOWN | ui::EF_ALT_DOWN)})},
           {NonConfigurableActions::kBrowserBottomPage,
            NonConfigurableAcceleratorDetails(
                {ui::Accelerator(ui::VKEY_RIGHT, ui::EF_COMMAND_DOWN)})},
           {NonConfigurableActions::kBrowserTopPage,
            NonConfigurableAcceleratorDetails(
                {ui::Accelerator(ui::VKEY_LEFT, ui::EF_COMMAND_DOWN)})},
-          {NonConfigurableActions::kBrowserNextPane,
-           NonConfigurableAcceleratorDetails({ui::Accelerator(
-               ui::VKEY_PRIOR, ui::EF_CONTROL_DOWN | ui::EF_SHIFT_DOWN)})},
-          {NonConfigurableActions::kBrowserPageDown,
-           NonConfigurableAcceleratorDetails(
-               {ui::Accelerator(ui::VKEY_DOWN, ui::EF_COMMAND_DOWN)})},
           {NonConfigurableActions::kBrowserPageUp,
            NonConfigurableAcceleratorDetails(
                {ui::Accelerator(ui::VKEY_UP, ui::EF_COMMAND_DOWN)})},
+          {NonConfigurableActions::kBrowserPageDown,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_DOWN, ui::EF_COMMAND_DOWN)})},
+          {NonConfigurableActions::kAmbientDeleteNextWord,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_BACK, ui::EF_COMMAND_DOWN)})},
+          // TODO(longbowei): Re-enable these shortcuts. these conflict with
+          // kBrowserTopPage(Search + <) and kBrowserBottomPage(Search + >);
+          //    {NonConfigurableActions::kAmbientGoToBeginningOfLine,
+          //    NonConfigurableAcceleratorDetails(
+          //        {ui::Accelerator(ui::VKEY_LEFT, ui::EF_COMMAND_DOWN)})},
+          //    {NonConfigurableActions::kAmbientGoToEndOfLine,
+          //    NonConfigurableAcceleratorDetails(
+          //        {ui::Accelerator(ui::VKEY_RIGHT, ui::EF_COMMAND_DOWN)})},
+          {NonConfigurableActions::kBrowserNextPane,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_BROWSER_BACK,
+                                ui::EF_CONTROL_DOWN | ui::EF_SHIFT_DOWN)})},
           {NonConfigurableActions::kAmbientOpenRightClickMenu,
            NonConfigurableAcceleratorDetails({ui::Accelerator(
                ui::VKEY_VOLUME_UP, ui::EF_COMMAND_DOWN | ui::EF_SHIFT_DOWN)})},
@@ -347,25 +406,104 @@ const NonConfigurableActionsMap& GetNonConfigurableActionsMap() {
           {NonConfigurableActions::kAmbientCaretBrowsing,
            NonConfigurableAcceleratorDetails({ui::Accelerator(
                ui::VKEY_7, ui::EF_CONTROL_DOWN | ui::EF_COMMAND_DOWN)})},
-          {NonConfigurableActions::kSixPackDelete,
+          {NonConfigurableActions::kBrowserAutoComplete,
            NonConfigurableAcceleratorDetails(
-               {ui::Accelerator(ui::VKEY_BACK, ui::EF_COMMAND_DOWN)})},
-          {NonConfigurableActions::kSixPackHome,
+               {ui::Accelerator(ui::VKEY_RETURN, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kBrowserHome,
            NonConfigurableAcceleratorDetails(
-               {ui::Accelerator(ui::VKEY_LEFT, ui::EF_COMMAND_DOWN)})},
-          {NonConfigurableActions::kSixPackPageUp,
+               {ui::Accelerator(ui::VKEY_HOME, ui::EF_ALT_DOWN)})},
+          {NonConfigurableActions::kBrowserSelectNextTab,
            NonConfigurableAcceleratorDetails(
-               {ui::Accelerator(ui::VKEY_UP, ui::EF_COMMAND_DOWN)})},
-          {NonConfigurableActions::kSixPackEnd,
-           NonConfigurableAcceleratorDetails(
-               {ui::Accelerator(ui::VKEY_RIGHT, ui::EF_COMMAND_DOWN)})},
-          {NonConfigurableActions::kSixPackPageDown,
-           NonConfigurableAcceleratorDetails(
-               {ui::Accelerator(ui::VKEY_DOWN, ui::EF_COMMAND_DOWN)})},
-          {NonConfigurableActions::kSixPackInsert,
+               {ui::Accelerator(ui::VKEY_TAB, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kBrowserSelectPreviousTab,
            NonConfigurableAcceleratorDetails({ui::Accelerator(
-               ui::VKEY_BACK, ui::EF_SHIFT_DOWN | ui::EF_COMMAND_DOWN)})},
+               ui::VKEY_TAB, ui::EF_CONTROL_DOWN | ui::EF_SHIFT_DOWN)})},
+          {NonConfigurableActions::kAmbientCopy,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_C, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kAmbientCut,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_X, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kAmbientPaste,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_V, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kAmbientPastePlainText,
+           NonConfigurableAcceleratorDetails({ui::Accelerator(
+               ui::VKEY_V, ui::EF_CONTROL_DOWN | ui::EF_SHIFT_DOWN)})},
+          {NonConfigurableActions::kAmbientDeletePreviousWord,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_BACK, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kAmbientUndo,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_Z, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kAmbientRedo,
+           NonConfigurableAcceleratorDetails({ui::Accelerator(
+               ui::VKEY_Z, ui::EF_CONTROL_DOWN | ui::EF_SHIFT_DOWN)})},
+          {NonConfigurableActions::kAmbientContentContextSelectAll,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_A, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kAmbientSelectTextToBeginning,
+           NonConfigurableAcceleratorDetails({ui::Accelerator(
+               ui::VKEY_LEFT, ui::EF_COMMAND_DOWN | ui::EF_SHIFT_DOWN)})},
+          {NonConfigurableActions::kAmbientSelectTextToEndOfLine,
+           NonConfigurableAcceleratorDetails({ui::Accelerator(
+               ui::VKEY_RIGHT, ui::EF_COMMAND_DOWN | ui::EF_SHIFT_DOWN)})},
+          {NonConfigurableActions::kAmbientSelectPreviousWord,
+           NonConfigurableAcceleratorDetails({ui::Accelerator(
+               ui::VKEY_LEFT, ui::EF_CONTROL_DOWN | ui::EF_SHIFT_DOWN)})},
+          {NonConfigurableActions::kAMbientSelectNextWord,
+           NonConfigurableAcceleratorDetails({ui::Accelerator(
+               ui::VKEY_RIGHT, ui::EF_CONTROL_DOWN | ui::EF_SHIFT_DOWN)})},
+          {NonConfigurableActions::kAmbientGoToBeginningOfDocument,
+           NonConfigurableAcceleratorDetails({ui::Accelerator(
+               ui::VKEY_LEFT, ui::EF_CONTROL_DOWN | ui::EF_COMMAND_DOWN)})},
+          {NonConfigurableActions::kAmbientGoToEndOfDocument,
+           NonConfigurableAcceleratorDetails({ui::Accelerator(
+               ui::VKEY_RIGHT, ui::EF_CONTROL_DOWN | ui::EF_COMMAND_DOWN)})},
+          {NonConfigurableActions::kAmbientMoveStartOfPreviousWord,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_LEFT, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kAmbientMoveToEndOfWord,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_RIGHT, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kBrowserFindNext,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_G, ui::EF_CONTROL_DOWN),
+                // TODO(longbowei): Confirm if we want to keep this accelerator
+                // or remove it.
+                ui::Accelerator(ui::VKEY_RETURN, ui::EF_NONE)})},
+          {NonConfigurableActions::kBrowserFindPrevious,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_G,
+                                ui::EF_CONTROL_DOWN | ui::EF_SHIFT_DOWN),
+                // TODO(longbowei): Confirm if we want to keep this accelerator
+                // or remove it.
+                ui::Accelerator(ui::VKEY_RETURN, ui::EF_SHIFT_DOWN)})},
+          {NonConfigurableActions::kBrowserFocusSearch,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_K, ui::EF_CONTROL_DOWN),
+                ui::Accelerator(ui::VKEY_E, ui::EF_CONTROL_DOWN)})},
+          {NonConfigurableActions::kBrowserShowAppMenu,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_E, ui::EF_ALT_DOWN),
+                ui::Accelerator(ui::VKEY_F, ui::EF_ALT_DOWN)})},
+          {NonConfigurableActions::kBrowserReload,
+           NonConfigurableAcceleratorDetails(
+               {ui::Accelerator(ui::VKEY_BROWSER_REFRESH, ui::EF_NONE),
+                ui::Accelerator(ui::VKEY_R, ui::EF_CONTROL_DOWN)})},
       });
   return *nonConfigurableActionsMap;
 }
+
+std::u16string GetKeyDisplay(ui::KeyboardCode key_code) {
+  // If there's an entry for this key_code in our
+  // map, return that entry's value.
+  auto it = GetKeyDisplayMap().find(key_code);
+  if (it != GetKeyDisplayMap().end()) {
+    return it->second;
+  } else {
+    // Otherwise, get the key_display from a util function.
+    return KeycodeToKeyString(key_code);
+  }
+}
 }  // namespace ash
