@@ -6,7 +6,7 @@ import {TimeTicks} from 'chrome://resources/mojo/mojo/public/mojom/base/time.moj
 
 import {keyToIconNameMap} from './input_key.js';
 import {stringToMojoString16} from './mojo_utils.js';
-import {AcceleratorCategory, AcceleratorSource, AcceleratorState, AcceleratorSubcategory, AcceleratorType, LayoutStyle, Modifier, MojoAcceleratorConfig, MojoAcceleratorInfo, MojoLayoutInfo, TextAcceleratorPartType} from './shortcut_types.js';
+import {AcceleratorCategory, AcceleratorSource, AcceleratorState, AcceleratorSubcategory, AcceleratorType, LayoutStyle, Modifier, MojoAcceleratorConfig, MojoAcceleratorInfo, MojoLayoutInfo, MojoSearchResult, TextAcceleratorPartType} from './shortcut_types.js';
 
 const fakeTimestamp: TimeTicks = {
   internalValue: BigInt(0),
@@ -64,25 +64,6 @@ const cycleTabsAccelerator: MojoAcceleratorInfo = {
   },
 };
 
-const sixPackDeleteAccelerator: MojoAcceleratorInfo = {
-  type: AcceleratorType.kDefault,
-  state: AcceleratorState.kEnabled,
-  locked: true,
-  layoutProperties: {
-    standardAccelerator: {
-      keyDisplay: stringToMojoString16('backspace'),
-      accelerator: {
-        modifiers: Modifier.COMMAND,
-        keyCode: 8,
-        keyState: 0,
-        timeStamp: fakeTimestamp,
-      },
-    },
-    textAccelerator: undefined,
-
-  },
-};
-
 export const fakeAcceleratorConfig: MojoAcceleratorConfig = {
   [AcceleratorSource.kAsh]: {
     // Snap Window Left
@@ -166,7 +147,6 @@ export const fakeAcceleratorConfig: MojoAcceleratorConfig = {
     // New Tab
     [0]: [newTabAccelerator],
     [1]: [cycleTabsAccelerator],
-    [2]: [sixPackDeleteAccelerator],
   },
 };
 
@@ -174,69 +154,150 @@ export const fakeAmbientConfig: MojoAcceleratorConfig = {
   [AcceleratorSource.kAmbient]: {
     [0]: [newTabAccelerator],
     [1]: [cycleTabsAccelerator],
-    [2]: [sixPackDeleteAccelerator],
   },
 };
 
 export const fakeLayoutInfo: MojoLayoutInfo[] = [
   {
-    category: AcceleratorCategory.kTabsAndWindows,
-    subCategory: AcceleratorSubcategory.kGeneral,
+    category: AcceleratorCategory.kWindowsAndDesks,
+    subCategory: AcceleratorSubcategory.kWindows,
     description: stringToMojoString16('Snap Window Left'),
     style: LayoutStyle.kDefault,
     source: AcceleratorSource.kAsh,
     action: 0,
   },
   {
-    category: AcceleratorCategory.kTabsAndWindows,
-    subCategory: AcceleratorSubcategory.kGeneral,
+    category: AcceleratorCategory.kWindowsAndDesks,
+    subCategory: AcceleratorSubcategory.kWindows,
     description: stringToMojoString16('Snap Window Right'),
     style: LayoutStyle.kDefault,
     source: AcceleratorSource.kAsh,
     action: 1,
   },
   {
-    category: AcceleratorCategory.kTabsAndWindows,
-    subCategory: AcceleratorSubcategory.kSystemApps,
+    category: AcceleratorCategory.kWindowsAndDesks,
+    subCategory: AcceleratorSubcategory.kDesks,
     description: stringToMojoString16('Create Desk'),
     style: LayoutStyle.kDefault,
     source: AcceleratorSource.kAsh,
     action: 2,
   },
   {
-    category: AcceleratorCategory.kTabsAndWindows,
-    subCategory: AcceleratorSubcategory.kSystemApps,
+    category: AcceleratorCategory.kWindowsAndDesks,
+    subCategory: AcceleratorSubcategory.kDesks,
     description: stringToMojoString16('Remove Desk'),
     style: LayoutStyle.kDefault,
     source: AcceleratorSource.kAsh,
     action: 3,
   },
   {
-    category: AcceleratorCategory.kPageAndWebBrowser,
-    subCategory: AcceleratorSubcategory.kSystemControls,
+    category: AcceleratorCategory.kBrowser,
+    subCategory: AcceleratorSubcategory.kTabs,
     description: stringToMojoString16('New Tab'),
     style: LayoutStyle.kDefault,
     source: AcceleratorSource.kAmbient,
     action: 0,
   },
   {
-    category: AcceleratorCategory.kTabsAndWindows,
-    subCategory: AcceleratorSubcategory.kSystemApps,
-    description: stringToMojoString16('Go to tabs 1 through 8'),
+    category: AcceleratorCategory.kWindowsAndDesks,
+    subCategory: AcceleratorSubcategory.kWindows,
+    description: stringToMojoString16('Go to windows 1 through 8'),
     style: LayoutStyle.kText,
     source: AcceleratorSource.kAmbient,
     action: 1,
   },
+];
+
+export const fakeSearchResults: MojoSearchResult[] = [
   {
-    category: AcceleratorCategory.kEventRewriter,
-    subCategory: AcceleratorSubcategory.kSixPackKeys,
-    description: stringToMojoString16('Delete'),
-    style: LayoutStyle.kDefault,
-    source: AcceleratorSource.kAmbient,
-    action: 2,
+    acceleratorLayoutInfo: {
+      category: AcceleratorCategory.kWindowsAndDesks,
+      subCategory: AcceleratorSubcategory.kWindows,
+      description: stringToMojoString16('Snap Window Left'),
+      style: LayoutStyle.kDefault,
+      source: AcceleratorSource.kAsh,
+      action: 0,
+    },
+    acceleratorInfos: [{
+      type: AcceleratorType.kDefault,
+      state: AcceleratorState.kEnabled,
+      locked: true,
+      layoutProperties: {
+        standardAccelerator: {
+          keyDisplay: stringToMojoString16('['),
+          accelerator: {
+            modifiers: Modifier.ALT,
+            keyCode: 219,
+            keyState: 0,
+            timeStamp: fakeTimestamp,
+          },
+        },
+        textAccelerator: undefined,
+      },
+    }],
+    relevanceScore: 0.8,
+  },
+  {
+    acceleratorLayoutInfo: {
+      category: AcceleratorCategory.kWindowsAndDesks,
+      subCategory: AcceleratorSubcategory.kWindows,
+      description: stringToMojoString16('Snap Window Right'),
+      style: LayoutStyle.kDefault,
+      source: AcceleratorSource.kAsh,
+      action: 1,
+    },
+    acceleratorInfos: [{
+      type: AcceleratorType.kDefault,
+      state: AcceleratorState.kEnabled,
+      locked: false,
+      layoutProperties: {
+        standardAccelerator: {
+          keyDisplay: stringToMojoString16(']'),
+          accelerator: {
+            modifiers: Modifier.ALT,
+            keyCode: 221,
+            keyState: 0,
+            timeStamp: fakeTimestamp,
+          },
+        },
+        textAccelerator: undefined,
+      },
+    }],
+    relevanceScore: 0.6,
+  },
+  {
+    acceleratorLayoutInfo: {
+      category: AcceleratorCategory.kWindowsAndDesks,
+      subCategory: AcceleratorSubcategory.kDesks,
+      description: stringToMojoString16('Create Desk'),
+      style: LayoutStyle.kDefault,
+      source: AcceleratorSource.kAsh,
+      action: 2,
+    },
+    acceleratorInfos: [{
+      type: AcceleratorType.kDefault,
+      state: AcceleratorState.kEnabled,
+      locked: false,
+      layoutProperties: {
+        standardAccelerator: {
+          keyDisplay: stringToMojoString16('+'),
+          accelerator: {
+            modifiers: Modifier.COMMAND | Modifier.SHIFT,
+            keyCode: 187,
+            keyState: 0,
+            timeStamp: fakeTimestamp,
+          },
+        },
+        textAccelerator: undefined,
+      },
+    }],
+    relevanceScore: 0.4,
   },
 ];
 
+export const SnapWindowLeftSearchResult: MojoSearchResult =
+    fakeSearchResults[0];
+
 // The following code is used to add fake accelerator entries for each icon.
 // When useFakeProvider is true, this will display all available icons for
 // the purposes of debugging.
@@ -263,8 +324,8 @@ const createFakeMojoAccelInfo = (keyDisplay: string): MojoAcceleratorInfo => {
 const createFakeMojoLayoutInfo =
     (description: string, action: number): MojoLayoutInfo => {
       return {
-        category: AcceleratorCategory.kPageAndWebBrowser,
-        subCategory: AcceleratorSubcategory.kSystemControls,
+        category: AcceleratorCategory.kBrowser,
+        subCategory: AcceleratorSubcategory.kTabs,
         description: stringToMojoString16(description),
         style: LayoutStyle.kDefault,
         source: AcceleratorSource.kAmbient,
