@@ -6,9 +6,11 @@ import './accelerator_edit_dialog.js';
 import './shortcut_input.js';
 import './shortcuts_page.js';
 import '../strings.m.js';
+import './search/search_box.js';
 import '../css/shortcut_customization_shared.css.js';
 import 'chrome://resources/ash/common/navigation_view_panel.js';
 import 'chrome://resources/ash/common/page_toolbar.js';
+import 'chrome://resources/mojo/mojo/public/js/mojo_bindings_lite.js';
 import 'chrome://resources/polymer/v3_0/iron-icon/iron-icon.js';
 
 import {NavigationViewPanelElement} from 'chrome://resources/ash/common/navigation_view_panel.js';
@@ -16,14 +18,16 @@ import {I18nMixin} from 'chrome://resources/cr_elements/i18n_mixin.js';
 import {PolymerElementProperties} from 'chrome://resources/polymer/v3_0/polymer/interfaces.js';
 import {PolymerElement} from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
 
+import {AcceleratorsUpdatedObserverInterface, AcceleratorsUpdatedObserverReceiver} from '../mojom-webui/ash/webui/shortcut_customization_ui/mojom/shortcut_customization.mojom-webui.js';
+
 import {AcceleratorEditDialogElement} from './accelerator_edit_dialog.js';
 import {RequestUpdateAcceleratorEvent} from './accelerator_edit_view.js';
 import {AcceleratorLookupManager} from './accelerator_lookup_manager.js';
 import {ShowEditDialogEvent} from './accelerator_row.js';
 import {getShortcutProvider} from './mojo_interface_provider.js';
 import {getTemplate} from './shortcut_customization_app.html.js';
-import {AcceleratorInfo, AcceleratorSource, AcceleratorState, AcceleratorType, MojoAcceleratorConfig, MojoLayoutInfo, ShortcutProviderInterface, StandardAcceleratorInfo} from './shortcut_types.js';
-import {getCategoryNameStringId, isCustomizationDisabled} from './shortcut_utils.js';
+import {AcceleratorConfigResult, AcceleratorInfo, AcceleratorSource, MojoAcceleratorConfig, MojoLayoutInfo, ShortcutProviderInterface} from './shortcut_types.js';
+import {getCategoryNameStringId, isCustomizationDisabled, isSearchEnabled} from './shortcut_utils.js';
 
 export interface ShortcutCustomizationAppElement {
   $: {
@@ -48,7 +52,8 @@ declare global {
 const ShortcutCustomizationAppElementBase = I18nMixin(PolymerElement);
 
 export class ShortcutCustomizationAppElement extends
-    ShortcutCustomizationAppElementBase {
+    ShortcutCustomizationAppElementBase implements
+        AcceleratorsUpdatedObserverInterface {
   static get is(): string {
     return 'shortcut-customization-app';
   }
@@ -96,6 +101,7 @@ export class ShortcutCustomizationAppElement extends
   private shortcutProvider: ShortcutProviderInterface = getShortcutProvider();
   private acceleratorlookupManager: AcceleratorLookupManager =
       AcceleratorLookupManager.getInstance();
+  private acceleratorsUpdatedReceiver: AcceleratorsUpdatedObserverReceiver;
 
   override connectedCallback(): void {
     super.connectedCallback();
@@ -109,6 +115,7 @@ export class ShortcutCustomizationAppElement extends
 
   override disconnectedCallback(): void {
     super.disconnectedCallback();
+    this.acceleratorsUpdatedReceiver.$.close();
     this.removeEventListener('show-edit-dialog', this.showDialog);
     this.removeEventListener('edit-dialog-closed', this.onDialogClosed);
     this.removeEventListener(
@@ -119,6 +126,11 @@ export class ShortcutCustomizationAppElement extends
     // Kickoff fetching accelerators by first fetching the accelerator configs.
     this.shortcutProvider.getAccelerators().then(
         ({config}) => this.onAcceleratorConfigFetched(config));
+
+    // Fetch the hasLauncherButton value.
+    this.shortcutProvider.hasLauncherButton().then(({hasLauncherButton}) => {
+      this.acceleratorlookupManager.setHasLauncherButton(hasLauncherButton);
+    });
   }
 
   private onAcceleratorConfigFetched(config: MojoAcceleratorConfig): void {
@@ -133,6 +145,23 @@ export class ShortcutCustomizationAppElement extends
     this.acceleratorlookupManager.setAcceleratorLayoutLookup(layoutInfos);
     // Notify pages to update their accelerators.
     this.$.navigationPanel.notifyEvent('updateAccelerators');
+
+    // After fetching initial accelerators, start observing for any changes.
+    this.acceleratorsUpdatedReceiver =
+        new AcceleratorsUpdatedObserverReceiver(this);
+    this.shortcutProvider.addObserver(
+        this.acceleratorsUpdatedReceiver.$.bindNewPipeAndPassRemote());
+  }
+
+  // AcceleratorsUpdatedObserverInterface:
+  onAcceleratorsUpdated(config: MojoAcceleratorConfig): void {
+    this.acceleratorlookupManager.setAcceleratorLookup(config);
+    this.$.navigationPanel.notifyEvent('updateSubsections');
+
+    // Update the hasLauncherButton value every time accelerators are updated.
+    this.shortcutProvider.hasLauncherButton().then(({hasLauncherButton}) => {
+      this.acceleratorlookupManager.setHasLauncherButton(hasLauncherButton);
+    });
   }
 
   private addNavigationSelectors(layoutInfos: MojoLayoutInfo[]): void {
@@ -166,14 +195,8 @@ export class ShortcutCustomizationAppElement extends
   private onRequestUpdateAccelerators(e: RequestUpdateAcceleratorEvent): void {
     this.$.navigationPanel.notifyEvent('updateSubsections');
     const updatedAccels =
-        this.acceleratorlookupManager
-            .getStandardAcceleratorInfos(e.detail.source, e.detail.action)
-            ?.filter((accel: StandardAcceleratorInfo) => {
-              // Hide accelerators that are default and disabled.
-              return !(
-                  accel.type === AcceleratorType.kDefault &&
-                  accel.state === AcceleratorState.kDisabledByUser);
-            });
+        this.acceleratorlookupManager.getStandardAcceleratorInfos(
+            e.detail.source, e.detail.action);
 
     this.shadowRoot!.querySelector<AcceleratorEditDialogElement>('#editDialog')!
         .updateDialogAccelerators(updatedAccels as AcceleratorInfo[]);
@@ -188,7 +211,12 @@ export class ShortcutCustomizationAppElement extends
   }
 
   protected onConfirmRestoreButtonClicked(): void {
-    // TODO(jimmyxgong): Implement this function.
+    this.shortcutProvider.restoreAllDefaults().then(({result}) => {
+      // TODO(jimmyxgong): Explore error state with restore all.
+      if (result.result === AcceleratorConfigResult.kSuccess) {
+        this.closeRestoreAllDialog();
+      }
+    });
   }
 
   protected closeRestoreAllDialog(): void {
@@ -199,6 +227,11 @@ export class ShortcutCustomizationAppElement extends
     return isCustomizationDisabled();
   }
 
+  protected shouldHideSearchBox(): boolean {
+    // Hide the search box when flag is disabled.
+    return !isSearchEnabled();
+  }
+
   static get template(): HTMLTemplateElement {
     return getTemplate();
   }
