@@ -14,6 +14,11 @@ export const isCustomizationDisabled = (): boolean => {
   return !loadTimeData.getBoolean('isCustomizationEnabled');
 };
 
+// Returns true if search is enabled via the feature flag.
+export const isSearchEnabled = (): boolean => {
+  return loadTimeData.getBoolean('isSearchEnabled');
+};
+
 export const areAcceleratorsEqual =
     (accelA: Accelerator, accelB: Accelerator): boolean => {
       // This picking of types is necessary because Accelerators are a subset
@@ -66,22 +71,24 @@ const categoryPrefix = 'category';
 export const getCategoryNameStringId =
     (category: AcceleratorCategory): string => {
       switch (category) {
-        case AcceleratorCategory.kTabsAndWindows:
-          return `${categoryPrefix}TabsAndWindows`;
-        case AcceleratorCategory.kPageAndWebBrowser:
-          return `${categoryPrefix}PageAndWebBrowser`;
-        case AcceleratorCategory.kSystemAndDisplaySettings:
-          return `${categoryPrefix}SystemAndDisplaySettings`;
-        case AcceleratorCategory.kTextEditing:
-          return `${categoryPrefix}TextEditing`;
+        case AcceleratorCategory.kGeneral:
+          return `${categoryPrefix}General`;
+        case AcceleratorCategory.kDevice:
+          return `${categoryPrefix}Device`;
+        case AcceleratorCategory.kBrowser:
+          return `${categoryPrefix}Browser`;
+        case AcceleratorCategory.kText:
+          return `${categoryPrefix}Text`;
+        case AcceleratorCategory.kWindowsAndDesks:
+          return `${categoryPrefix}WindowsAndDesks`;
+        case AcceleratorCategory.kDebug:
+          return `${categoryPrefix}Debug`;
         case AcceleratorCategory.kAccessibility:
           return `${categoryPrefix}Accessibility`;
         case AcceleratorCategory.kDebug:
           return `${categoryPrefix}Debug`;
         case AcceleratorCategory.kDeveloper:
           return `${categoryPrefix}Developer`;
-        case AcceleratorCategory.kEventRewriter:
-          return `${categoryPrefix}EventRewriter`;
         default: {
           // If this case is reached, then an invalid category was passed in.
           assertNotReached();
@@ -93,14 +100,42 @@ const subcategoryPrefix = 'subcategory';
 export const getSubcategoryNameStringId =
     (subcategory: AcceleratorSubcategory): string => {
       switch (subcategory) {
+        case AcceleratorSubcategory.kGeneralControls:
+          return `${subcategoryPrefix}GeneralControls`;
+        case AcceleratorSubcategory.kApps:
+          return `${subcategoryPrefix}Apps`;
+        case AcceleratorSubcategory.kMedia:
+          return `${subcategoryPrefix}Media`;
+        case AcceleratorSubcategory.kInputs:
+          return `${subcategoryPrefix}Inputs`;
+        case AcceleratorSubcategory.kDisplay:
+          return `${subcategoryPrefix}Display`;
         case AcceleratorSubcategory.kGeneral:
           return `${subcategoryPrefix}General`;
-        case AcceleratorSubcategory.kSystemApps:
-          return `${subcategoryPrefix}SystemApps`;
-        case AcceleratorSubcategory.kSystemControls:
-          return `${subcategoryPrefix}SystemControls`;
-        case AcceleratorSubcategory.kSixPackKeys:
-          return `${subcategoryPrefix}SixPackKeys`;
+        case AcceleratorSubcategory.kBrowserNavigation:
+          return `${subcategoryPrefix}BrowserNavigation`;
+        case AcceleratorSubcategory.kPages:
+          return `${subcategoryPrefix}Pages`;
+        case AcceleratorSubcategory.kTabs:
+          return `${subcategoryPrefix}Tabs`;
+        case AcceleratorSubcategory.kBookmarks:
+          return `${subcategoryPrefix}Bookmarks`;
+        case AcceleratorSubcategory.kDeveloperTools:
+          return `${subcategoryPrefix}DeveloperTools`;
+        case AcceleratorSubcategory.kTextNavigation:
+          return `${subcategoryPrefix}TextNavigation`;
+        case AcceleratorSubcategory.kTextEditing:
+          return `${subcategoryPrefix}TextEditing`;
+        case AcceleratorSubcategory.kWindows:
+          return `${subcategoryPrefix}Windows`;
+        case AcceleratorSubcategory.kDesks:
+          return `${subcategoryPrefix}Desks`;
+        case AcceleratorSubcategory.kChromeVox:
+          return `${subcategoryPrefix}ChromeVox`;
+        case AcceleratorSubcategory.kVisibility:
+          return `${subcategoryPrefix}Visibility`;
+        case AcceleratorSubcategory.kAccessibilityNavigation:
+          return `${subcategoryPrefix}AccessibilityNavigation`;
         default: {
           // If this case is reached, then an invalid category was passed in.
           assertNotReached();
