@@ -5,9 +5,8 @@
 #ifndef ASH_WEBUI_SHORTCUT_CUSTOMIZATION_UI_SHORTCUT_CUSTOMIZATION_APP_UI_H_
 #define ASH_WEBUI_SHORTCUT_CUSTOMIZATION_UI_SHORTCUT_CUSTOMIZATION_APP_UI_H_
 
-#include <memory>
-
-#include "ash/webui/shortcut_customization_ui/backend/accelerator_configuration_provider.h"
+#include "ash/webui/shortcut_customization_ui/backend/search/search.mojom.h"
+#include "ash/webui/shortcut_customization_ui/backend/search/search_handler.h"
 #include "ash/webui/shortcut_customization_ui/mojom/shortcut_customization.mojom.h"
 #include "ash/webui/shortcut_customization_ui/url_constants.h"
 #include "ash/webui/system_apps/public/system_web_app_ui_config.h"
@@ -44,8 +43,11 @@ class ShortcutCustomizationAppUI : public ui::MojoWebUIController {
           shortcut_customization::mojom::AcceleratorConfigurationProvider>
           receiver);
 
+  void BindInterface(
+      mojo::PendingReceiver<shortcut_customization::mojom::SearchHandler>
+          receiver);
+
  private:
-  std::unique_ptr<shortcut_ui::AcceleratorConfigurationProvider> provider_;
   WEB_UI_CONTROLLER_TYPE_DECL();
 };
 
