@@ -13,7 +13,6 @@
 #include "ash/wm/desks/desks_util.h"
 #include "ash/wm/float/float_controller.h"
 #include "ash/wm/screen_pinning_controller.h"
-#include "ash/wm/splitview/split_view_controller.h"
 #include "ash/wm/splitview/split_view_metrics_controller.h"
 #include "ash/wm/window_positioning_utils.h"
 #include "ash/wm/window_state.h"
@@ -36,6 +35,7 @@
 #include "ui/display/display.h"
 #include "ui/display/display_observer.h"
 #include "ui/display/screen.h"
+#include "ui/display/types/display_constants.h"
 #include "ui/wm/core/window_util.h"
 
 namespace ash {
@@ -62,15 +62,47 @@ gfx::Size GetWindowMaximumSize(aura::Window* window) {
                             : gfx::Size();
 }
 
-// Called to ensure the window is moved to the correct display when entering the
+// Moves the window to the specified display if necessary.
+void MoveWindowToDisplayAsNeeded(aura::Window* window, int64_t display_id) {
+  if (!window || display_id == display::kInvalidDisplayId) {
+    return;
+  }
+  aura::Window* root = Shell::GetRootWindowForDisplayId(display_id);
+  if (!root || root == window->GetRootWindow()) {
+    // No need to move unless window is rooted in a different display.
+    return;
+  }
+  root->GetChildById(window->parent()->GetId())->AddChild(window);
+}
+
+// Ensures the window is moved to the correct display when entering the
 // next state, taking into account whether it's restoring or not.
-void MoveWindowToDisplay(WindowState* window_state) {
+void EnsureWindowInCorrectDisplay(WindowState* window_state,
+                                  WindowStateType previous_state_type) {
+  if (window_state->IsMinimized()) {
+    return;
+  }
+
+  // When restoring, we want to use the restore bounds to calculate which
+  // display it should be moved to, hence the check for IsRestoring() and
+  // HasRestoreBounds(), otherwise we move the window according to its current
+  // bounds. A special case is when we come out of minimized state, where the
+  // current bounds is the bounds of the new state we're going back to, so we
+  // use that to move the window.
+  // The check for IsMaximizedOrFullscreenOrPinned() was moved from
+  // EnterToNextState(), which preserves some legacy behavior that may not be
+  // relevant anymore. It may be needed for the case of maximizing to another
+  // display then restoring, which should remain on the other display.
+  // TODO(aluh): Look into removing check for IsMaximizedOrFullscreenOrPinned().
   const gfx::Rect window_bounds =
-      window_state->HasRestoreBounds()
+      ((window_state->IsMaximizedOrFullscreenOrPinned() ||
+        window_state->IsRestoring(previous_state_type)) &&
+       window_state->HasRestoreBounds() &&
+       !chromeos::IsMinimizedWindowStateType(previous_state_type))
           ? window_state->GetRestoreBoundsInScreen()
           : window_state->GetCurrentBoundsInScreen();
 
-  // Move only if the restore bounds is outside of
+  // Move only if the window bounds is outside of
   // the display. There is no information about in which
   // display it should be restored, so this is best guess.
   // TODO(oshima): Restore information should contain the
@@ -81,24 +113,36 @@ void MoveWindowToDisplay(WindowState* window_state) {
                                .bounds();
 
   if (!display_area.Intersects(window_bounds)) {
-    const display::Display& display =
-        display::Screen::GetScreen()->GetDisplayMatching(window_bounds);
-    RootWindowController* new_root_controller =
-        Shell::Get()->GetRootWindowControllerWithDisplayId(display.id());
-    if (new_root_controller->GetRootWindow() !=
-        window_state->window()->GetRootWindow()) {
-      aura::Window* new_container =
-          new_root_controller->GetRootWindow()->GetChildById(
-              window_state->window()->parent()->GetId());
-      new_container->AddChild(window_state->window());
-    }
+    int64_t display_id =
+        display::Screen::GetScreen()->GetDisplayMatching(window_bounds).id();
+    MoveWindowToDisplayAsNeeded(window_state->window(), display_id);
   }
 }
 
+// Returns true if next state should be entered from the current state.
+bool ShouldEnterNextState(WindowStateType current_state,
+                          WindowStateType next_state,
+                          WindowState* window_state) {
+  if (current_state != next_state) {
+    return true;
+  }
+  // This handles the case where a window is already fullscreen on a display
+  // and we want to fullscreen it on a different display.
+  // TODO(aluh): Consider handling earlier, before call to EnterToNextState(),
+  // so we don't have to special case here. May run into tricky restore
+  // state/bounds corner cases.
+  if (next_state == chromeos::WindowStateType::kFullscreen &&
+      window_state->GetFullscreenTargetDisplayId() !=
+          display::kInvalidDisplayId) {
+    return true;
+  }
+  return false;
+}
+
 }  // namespace
 
 DefaultState::DefaultState(WindowStateType initial_state_type)
-    : BaseState(initial_state_type), stored_window_state_(nullptr) {}
+    : BaseState(initial_state_type) {}
 
 DefaultState::~DefaultState() = default;
 
@@ -219,8 +263,12 @@ void DefaultState::HandleWorkspaceEvents(WindowState* window_state,
       if (in_fullscreen && window_state->IsMaximized())
         return;
 
+      // TODO(b/272091660): Consider having a more graceful algorithm for
+      // floated windows as they may have been purposefully placed semi
+      // offscreen.
       UpdateBoundsForDisplayOrWorkAreaBoundsChange(
-          window_state, /*ensure_full_window_visibility=*/false);
+          window_state,
+          /*ensure_full_window_visibility=*/window_state->IsFloated());
       return;
     }
     case WM_EVENT_SYSTEM_UI_AREA_CHANGED:
@@ -366,8 +414,9 @@ void DefaultState::HandleTransitionEvents(WindowState* window_state,
     return;
   }
 
-  if (type == WM_EVENT_SNAP_PRIMARY || type == WM_EVENT_SNAP_SECONDARY)
+  if (type == WM_EVENT_SNAP_PRIMARY || type == WM_EVENT_SNAP_SECONDARY) {
     HandleWindowSnapping(window_state, type);
+  }
 
   if (next_state_type == current_state_type && window_state->IsSnapped()) {
     DCHECK(window_state->snap_ratio());
@@ -442,9 +491,9 @@ void DefaultState::SetBounds(WindowState* window_state,
 
 void DefaultState::EnterToNextState(WindowState* window_state,
                                     WindowStateType next_state_type) {
-  // Do nothing if  we're already in the same state.
-  if (state_type_ == next_state_type)
+  if (!ShouldEnterNextState(state_type_, next_state_type, window_state)) {
     return;
+  }
 
   WindowStateType previous_state_type = state_type_;
   state_type_ = next_state_type;
@@ -462,7 +511,6 @@ void DefaultState::EnterToNextState(WindowState* window_state,
 
   // Unfloat floated window when exiting float state to another state.
   if (previous_state_type == WindowStateType::kFloated) {
-    // Remove float window from float container.
     float_controller->UnfloatImpl(window);
   }
 
@@ -481,9 +529,6 @@ void DefaultState::EnterToNextState(WindowState* window_state,
       window_state->SaveCurrentBoundsForRestore();
     }
 
-    if (window_state->IsMaximizedOrFullscreenOrPinned())
-      MoveWindowToDisplay(window_state);
-
     UpdateBoundsFromState(window_state, previous_state_type);
     UpdateMinimizedState(window_state, previous_state_type);
   }
@@ -539,6 +584,11 @@ void DefaultState::UpdateBoundsFromState(WindowState* window_state,
   aura::Window* window = window_state->window();
   gfx::Rect bounds_in_parent;
 
+  // A window can be rooted in a different display than its bounds, in cases
+  // such as creating a new window with bounds in a different display, or
+  // restoring to a previous state that was in a different display.
+  EnsureWindowInCorrectDisplay(window_state, previous_state_type);
+
   switch (state_type_) {
     case WindowStateType::kPrimarySnapped:
     case WindowStateType::kSecondarySnapped:
@@ -587,6 +637,8 @@ void DefaultState::UpdateBoundsFromState(WindowState* window_state,
     case WindowStateType::kFullscreen:
     case WindowStateType::kPinned:
     case WindowStateType::kTrustedPinned:
+      MoveWindowToDisplayAsNeeded(window_state->window(),
+                                  window_state->GetFullscreenTargetDisplayId());
       bounds_in_parent = screen_util::GetFullscreenWindowBoundsInParent(window);
       break;
 
@@ -612,20 +664,19 @@ void DefaultState::UpdateBoundsFromState(WindowState* window_state,
   if (window_state->IsMinimized())
     return;
 
-  if (IsMinimizedWindowStateType(previous_state_type) ||
-      window_state->IsFullscreen() || window_state->IsPinned() ||
-      window_state->bounds_animation_type() ==
-          WindowState::BoundsChangeAnimationType::kNone) {
+  if (bool to_float = state_type_ == WindowStateType::kFloated;
+      to_float || previous_state_type == WindowStateType::kFloated) {
+    // Float and unfloat have their own animation.
+    window_state->SetBoundsDirectCrossFade(bounds_in_parent, to_float);
+  } else if (IsMinimizedWindowStateType(previous_state_type) ||
+             window_state->IsFullscreen() || window_state->IsPinned() ||
+             window_state->bounds_animation_type() ==
+                 WindowState::BoundsChangeAnimationType::kNone) {
     window_state->SetBoundsDirect(bounds_in_parent);
   } else if (window_state->IsMaximized() ||
              IsMaximizedOrFullscreenOrPinnedWindowStateType(
                  previous_state_type)) {
     window_state->SetBoundsDirectCrossFade(bounds_in_parent);
-  } else if (window_state->IsFloated() &&
-             previous_state_type == WindowStateType::kFloated) {
-    // This can happen during the tablet -> clamshell transition. Use cross fade
-    // animation for better performance.
-    window_state->SetBoundsDirectCrossFade(bounds_in_parent);
   } else if (window_state->is_dragged()) {
     // SetBoundsDirectAnimated does not work when the window gets reparented.
     // TODO(oshima): Consider fixing it and re-enable the animation.
