@@ -11,8 +11,8 @@
 #include "ash/wm/desks/desks_histogram_enums.h"
 #include "ash/wm/desks/root_window_desk_switch_animator.h"
 #include "ash/wm/overview/overview_controller.h"
-#include "base/callback.h"
 #include "base/check.h"
+#include "base/functional/callback.h"
 #include "ui/compositor/layer.h"
 #include "ui/compositor/layer_animation_observer.h"
 #include "ui/compositor/layer_animation_sequence.h"
