@@ -9,6 +9,7 @@
 #include "ash/wm/desks/desk.h"
 #include "ash/wm/desks/desks_controller.h"
 #include "ash/wm/desks/desks_util.h"
+#include "ash/wm/overview/overview_controller.h"
 #include "ui/aura/window_tree_host.h"
 #include "ui/compositor/compositor.h"
 
@@ -74,6 +75,14 @@ bool DeskAnimationBase::EndSwipeAnimation() {
   return false;
 }
 
+bool DeskAnimationBase::CanEnterOverview() const {
+  return is_overview_toggle_allowed_;
+}
+
+bool DeskAnimationBase::CanEndOverview() const {
+  return is_overview_toggle_allowed_;
+}
+
 void DeskAnimationBase::OnStartingDeskScreenshotTaken(int ending_desk_index) {
   DCHECK(!desk_switch_animators_.empty());
 
@@ -118,9 +127,7 @@ void DeskAnimationBase::OnEndingDeskScreenshotTaken() {
   // see an animation but expect to. If the gesture has ended, and has been
   // determined to be fast, we will start the animation to delete `this`.
   const bool skip_start_animation =
-      is_continuous_gesture_animation_ &&
-      (!features::AreDesksTrackpadSwipeImprovementsEnabled() ||
-       !did_continuous_gesture_end_fast_);
+      is_continuous_gesture_animation_ && !did_continuous_gesture_end_fast_;
   if (skip_start_animation)
     return;
 
@@ -162,4 +169,26 @@ DeskAnimationBase::GetDeskSwitchAnimatorAtIndexForTesting(size_t index) const {
   return desk_switch_animators_[index].get();
 }
 
+void DeskAnimationBase::ActivateDeskDuringAnimation(
+    const Desk* desk,
+    bool update_window_activation) {
+  // Normally we do not allow toggling overview while there is an active
+  // animation. The only exception is when we are doing a desk activation and
+  // are starting the animation in overview. The desk switch animations require
+  // taking a screenshot of the starting and ending desks before animating
+  // between the two screenshots, and these screenshots need to represent what
+  // the new desk will look like for the user. If we start the animation in
+  // overview, we want to allow `ActivateDeskInternal()` to end overview on the
+  // old active desk (and enter overview on the new active desk if the overview
+  // desk navigation feature is enabled). Once `ActivateDeskInternal()` finishes
+  // updating the active desk and overview states, we immediately set
+  // `is_overview_toggle_allowed_` to false to prevent any subsequent overview
+  // toggling (i.e. user input).
+  is_overview_toggle_allowed_ =
+      features::IsOverviewDeskNavigationEnabled() &&
+      Shell::Get()->overview_controller()->InOverviewSession();
+  controller_->ActivateDeskInternal(desk, update_window_activation);
+  is_overview_toggle_allowed_ = false;
+}
+
 }  // namespace ash
