@@ -34,6 +34,7 @@ class ASH_EXPORT DeskActivationAnimation : public DeskAnimationBase {
   bool Replace(bool moving_left, DesksSwitchSource source) override;
   bool UpdateSwipeAnimation(float scroll_delta_x) override;
   bool EndSwipeAnimation() override;
+  bool CanEnterOverview() const override;
   void OnStartingDeskScreenshotTakenInternal(int ending_desk_index) override;
   void OnDeskSwitchAnimationFinishedInternal() override;
   LatencyReportCallback GetLatencyReportCallback() const override;
@@ -42,10 +43,12 @@ class ASH_EXPORT DeskActivationAnimation : public DeskAnimationBase {
  private:
   FRIEND_TEST_ALL_PREFIXES(DeskActivationAnimationTest,
                            AnimatingAfterFastSwipe);
+  FRIEND_TEST_ALL_PREFIXES(OverviewDeskNavigationTest,
+                           ShortSwipeStaysInOverview);
 
   // Prepares the desk associated with |index| for taking a screenshot. Exits
   // overview and splitview if necessary and then activates the desk. Restores
-  // splitview if necessary after activating the desk.
+  // splitview or overview if necessary after activating the desk.
   void PrepareDeskForScreenshot(int index);
 
   // The switch source that requested this animation.
@@ -66,6 +69,9 @@ class ASH_EXPORT DeskActivationAnimation : public DeskAnimationBase {
   // Used to measure the presentation time of a continuous gesture swipe.
   std::unique_ptr<ui::PresentationTimeRecorder> presentation_time_recorder_;
 
+  // Callback that is run after the animation is finished for testing purposes.
+  base::OnceClosure on_animation_finished_callback_for_testing_;
+
   base::WeakPtrFactory<DeskActivationAnimation> weak_ptr_factory_{this};
 };
 
