@@ -11,6 +11,7 @@
 #include "ash/app_list/app_list_controller_impl.h"
 #include "ash/constants/ash_features.h"
 #include "ash/constants/notifier_catalogs.h"
+#include "ash/public/cpp/app_types_util.h"
 #include "ash/public/cpp/desk_template.h"
 #include "ash/public/cpp/shelf_model.h"
 #include "ash/public/cpp/shelf_types.h"
@@ -55,6 +56,7 @@
 #include "base/containers/unique_ptr_adapters.h"
 #include "base/cxx17_backports.h"
 #include "base/debug/crash_logging.h"
+#include "base/debug/dump_without_crashing.h"
 #include "base/functional/bind.h"
 #include "base/guid.h"
 #include "base/i18n/number_formatting.h"
@@ -62,6 +64,7 @@
 #include "base/metrics/histogram_macros.h"
 #include "base/notreached.h"
 #include "base/ranges/algorithm.h"
+#include "base/strings/stringprintf.h"
 #include "base/strings/utf_string_conversions.h"
 #include "base/task/single_thread_task_runner.h"
 #include "base/time/time.h"
@@ -604,6 +607,7 @@ void DesksController::NewDesk(DesksCreationRemovalSource source) {
     observer.OnDeskAdded(new_desk);
 
   if (!is_first_ever_desk) {
+    desks_restore_util::UpdatePrimaryUserDeskGuidsPrefs();
     desks_restore_util::UpdatePrimaryUserDeskNamesPrefs();
     desks_restore_util::UpdatePrimaryUserDeskMetricsPrefs();
     UMA_HISTOGRAM_ENUMERATION(kNewDeskHistogramName, source);
@@ -611,6 +615,10 @@ void DesksController::NewDesk(DesksCreationRemovalSource source) {
   }
 }
 
+bool DesksController::HasDesk(const Desk* desk) const {
+  return base::Contains(desks_, desk, &std::unique_ptr<Desk>::get);
+}
+
 void DesksController::RemoveDesk(const Desk* desk,
                                  DesksCreationRemovalSource source,
                                  DeskCloseType close_type) {
@@ -660,6 +668,7 @@ void DesksController::ReorderDesk(int old_index, int new_index) {
   // 1. Update desk name and metrics lists in the user prefs to maintain the
   // right order.
   desks_restore_util::UpdatePrimaryUserDeskNamesPrefs();
+  desks_restore_util::UpdatePrimaryUserDeskGuidsPrefs();
   desks_restore_util::UpdatePrimaryUserDeskMetricsPrefs();
 
   // 2. For multi-profile switching, update all affected active desk index in
@@ -998,6 +1007,12 @@ void DesksController::RestoreNameOfDeskAtIndex(std::u16string name,
   desks_[index]->SetName(std::move(name), /*set_by_user=*/true);
 }
 
+void DesksController::RestoreGuidOfDeskAtIndex(base::GUID guid, size_t index) {
+  DCHECK(guid.is_valid());
+  DCHECK_LT(index, desks_.size());
+  desks_[index]->SetGuid(std::move(guid));
+}
+
 void DesksController::RestoreCreationTimeOfDeskAtIndex(base::Time creation_time,
                                                        size_t index) {
   DCHECK_LT(index, desks_.size());
@@ -1145,11 +1160,19 @@ const Desk* DesksController::CreateNewDeskForSavedDesk(
   if (animation_)
     animation_.reset();
 
-  // Desk name was set to a default name upon creation. If
-  // `customized_desk_name` is not empty, override desk name to be
-  // `customized_desk_name` or `customized_desk_name ({counter})` to resolve
-  // naming conflicts.
-  std::u16string desk_name = CreateUniqueDeskName(customized_desk_name);
+  // Call `HideSavedDeskLibrary` before the new desk is created to update the
+  // state of the library button, otherwise the library button will be laid out
+  // with the wrong state when the new desk is created.
+  if (template_type == DeskTemplateType::kTemplate ||
+      template_type == DeskTemplateType::kFloatingWorkspace) {
+    if (auto* session =
+            Shell::Get()->overview_controller()->overview_session()) {
+      session->HideSavedDeskLibrary();
+      for (auto& grid : session->grid_list()) {
+        grid->RemoveAllItemsForSavedDeskLaunch();
+      }
+    }
+  }
 
   switch (template_type) {
     case DeskTemplateType::kTemplate:
@@ -1167,6 +1190,12 @@ const Desk* DesksController::CreateNewDeskForSavedDesk(
 
   Desk* desk = desks().back().get();
 
+  // Desk name was set to a default name upon creation. If
+  // `customized_desk_name` is not empty, override desk name to be
+  // `customized_desk_name` or `customized_desk_name ({counter})` to resolve
+  // naming conflicts.
+  std::u16string desk_name = CreateUniqueDeskName(customized_desk_name);
+
   if (!desk_name.empty()) {
     desk->SetName(desk_name, /*set_by_user=*/true);
     Shell::Get()
@@ -1199,13 +1228,6 @@ const Desk* DesksController::CreateNewDeskForSavedDesk(
       }
     }
 
-    if (auto* session =
-            Shell::Get()->overview_controller()->overview_session()) {
-      session->HideSavedDeskLibrary();
-      for (auto& grid : session->grid_list())
-        grid->RemoveAllItemsForSavedDeskLaunch();
-    }
-
     ActivateDesk(desk, DesksSwitchSource::kLaunchTemplate);
     DCHECK(!animation_);
   }
@@ -1221,7 +1243,7 @@ bool DesksController::OnSingleInstanceAppLaunchingFromSavedDesk(
   aura::Window* existing_app_instance_window = nullptr;
   Desk* src_desk = nullptr;
   for (auto& desk : desks()) {
-    for (aura::Window* window : desk->windows()) {
+    for (aura::Window* window : desk->GetAllAssociatedWindows()) {
       const std::string* const app_id_ptr = window->GetProperty(kAppIDKey);
       if (app_id_ptr && *app_id_ptr == app_id) {
         existing_app_instance_window = window;
@@ -1268,6 +1290,15 @@ bool DesksController::OnSingleInstanceAppLaunchingFromSavedDesk(
       src_desk->MoveWindowToDesk(existing_app_instance_window, target_desk,
                                  existing_app_instance_window->GetRootWindow(),
                                  /*unminimize=*/false);
+      // If the floated window is the single instance window, we need to let
+      // float controller handle move window to desk, as floated window
+      // doesn't belong to desk container.
+      if (WindowState::Get(existing_app_instance_window)->IsFloated()) {
+        Shell::Get()->float_controller()->OnMovingFloatedWindowToDesk(
+            existing_app_instance_window, src_desk, target_desk,
+            existing_app_instance_window->GetRootWindow());
+      }
+
       MaybeUpdateShelfItems(
           /*windows_on_inactive_desk=*/{},
           /*windows_on_active_desk=*/{existing_app_instance_window});
@@ -1551,10 +1582,6 @@ void DesksController::OnAnimationFinished(DeskAnimationBase* animation) {
   animation_.reset();
 }
 
-bool DesksController::HasDesk(const Desk* desk) const {
-  return base::Contains(desks_, desk, &std::unique_ptr<Desk>::get);
-}
-
 bool DesksController::HasDeskWithName(const std::u16string& desk_name) const {
   return base::Contains(desks_, desk_name, &Desk::name);
 }
@@ -1827,6 +1854,7 @@ void DesksController::RemoveDeskInternal(const Desk* desk,
   }
 
   desks_restore_util::UpdatePrimaryUserDeskNamesPrefs();
+  desks_restore_util::UpdatePrimaryUserDeskGuidsPrefs();
   desks_restore_util::UpdatePrimaryUserDeskMetricsPrefs();
 
   DCHECK_LE(available_container_ids_.size(), desks_util::GetMaxNumberOfDesks());
@@ -1954,7 +1982,7 @@ void DesksController::FinalizeDeskRemoval(RemovedDeskData* removed_desk_data) {
     // reuse that container. Since floated window doesn't belong to desk
     // container, handle it separately.
     aura::Window* floated_window = nullptr;
-    if (chromeos::wm::features::IsFloatWindowEnabled()) {
+    if (chromeos::wm::features::IsWindowLayoutMenuEnabled()) {
       floated_window =
           Shell::Get()->float_controller()->FindFloatedWindowOfDesk(
               removed_desk);
@@ -2021,7 +2049,11 @@ void DesksController::CleanUpClosedAppWindowsTask(
     // logic. However, the desk controller has waited for the app window to
     // close cleanly before this.
     if (widget) {
-      widget->CloseNow();
+      // TODO(b/276351837): Remove this ARC check once we have a better way of
+      // closing ARC++ windows.
+      if (!IsArcWindow(window)) {
+        widget->CloseNow();
+      }
     } else {
       // If the window does not have a widget, we add it to the
       // `widgetless_windows` tracker to check back on later.
@@ -2030,7 +2062,7 @@ void DesksController::CleanUpClosedAppWindowsTask(
   }
 
   // We post a delayed task to check that all of the windows in
-  // `widgetless_windows` eventually end up closing.
+  // `widgetless_windows eventually end up closing.
   base::SingleThreadTaskRunner::GetCurrentDefault()->PostDelayedTask(
       FROM_HERE,
       base::BindOnce(&ReportNumberOfZombieWindows,
@@ -2093,7 +2125,22 @@ void DesksController::RestackVisibleOnAllDesksWindowsOnActiveDesk() {
     auto* desk_container =
         visible_on_all_desks_window->GetRootWindow()->GetChildById(
             active_desk_->container_id());
-    DCHECK_EQ(desk_container, visible_on_all_desks_window->parent());
+    if (desk_container != visible_on_all_desks_window->parent()) {
+      // TODO(b/252556509): Clean this up when the root cause has been resolved.
+      // This can sometimes happen and we're still trying to nail down the root
+      // cause. Rather than proceeding to stack the window (which will crash),
+      // we'll log some info and skip the window.
+      SCOPED_CRASH_KEY_NUMBER("Restack", "adw_type",
+                              visible_on_all_desks_window->GetType());
+      SCOPED_CRASH_KEY_NUMBER(
+          "Restack", "adw_app_type",
+          visible_on_all_desks_window->GetProperty(aura::client::kAppType));
+      SCOPED_CRASH_KEY_STRING32(
+          "Restack", "adw_app_id",
+          full_restore::GetAppId(visible_on_all_desks_window));
+      base::debug::DumpWithoutCrashing();
+      continue;
+    }
 
     // Search through the MRU list for the next element that shares the same
     // parent. This will be used to stack |visible_on_all_desks_window| in
@@ -2122,7 +2169,7 @@ const Desk* DesksController::FindDeskOfWindow(aura::Window* window) const {
 
   // Floating windows are stored in float container, their relationship with
   // desks can be found in `FloatedWindowInfo`.
-  if (chromeos::wm::features::IsFloatWindowEnabled() &&
+  if (chromeos::wm::features::IsWindowLayoutMenuEnabled() &&
       WindowState::Get(window)->IsFloated()) {
     return Shell::Get()->float_controller()->FindDeskOfFloatedWindow(window);
   }
