@@ -183,6 +183,8 @@ class ASH_EXPORT DesksController : public chromeos::DesksHelper,
   // Creates a new desk. CanCreateDesks() must be checked before calling this.
   void NewDesk(DesksCreationRemovalSource source);
 
+  bool HasDesk(const Desk* desk) const;
+
   // Removes and deletes the given `desk`. `desk` must already exist, and
   // CanRemoveDesks() must be checked before this.
   // This will trigger the `DeskRemovalAnimation` if the active desk is being
@@ -255,6 +257,9 @@ class ASH_EXPORT DesksController : public chromeos::DesksHelper,
   // users are not allowed to set empty names.
   void RestoreNameOfDeskAtIndex(std::u16string name, size_t index);
 
+  // Sets the `uuid_` of the desk at `index` to the supplied `guid`.
+  void RestoreGuidOfDeskAtIndex(base::GUID guid, size_t index);
+
   // Restores the creation time of the desk at |index|.
   void RestoreCreationTimeOfDeskAtIndex(base::Time creation_time, size_t index);
 
@@ -376,6 +381,11 @@ class ASH_EXPORT DesksController : public chromeos::DesksHelper,
   // Otherwise returns `base`.
   std::u16string CreateUniqueDeskName(const std::u16string& base) const;
 
+  // Saves metrics and resets `temporary_removed_desk_` if `toast_id` is empty
+  // or it matches the toast ID stored in `temporary_removed_desk_`.
+  void MaybeCommitPendingDeskRemoval(
+      const std::string& toast_id = std::string());
+
  private:
   class DeskTraversalsMetricsHelper;
   class RemovedDeskData;
@@ -386,8 +396,6 @@ class ASH_EXPORT DesksController : public chromeos::DesksHelper,
 
   void OnAnimationFinished(DeskAnimationBase* animation);
 
-  bool HasDesk(const Desk* desk) const;
-
   bool HasDeskWithName(const std::u16string& desk_name) const;
 
   // Activates the given `desk` and deactivates the currently active one. `desk`
@@ -420,11 +428,6 @@ class ASH_EXPORT DesksController : public chromeos::DesksHelper,
   // this function in the combine desks process.
   void FinalizeDeskRemoval(RemovedDeskData* removed_desk_data);
 
-  // Saves metrics and resets `temporary_removed_desk_` if `toast_id` is empty
-  // or it matches the toast ID stored in `temporary_removed_desk_`.
-  void MaybeCommitPendingDeskRemoval(
-      const std::string& toast_id = std::string());
-
   // Forcefully cleans up app windows that should be closed.
   void CleanUpClosedAppWindowsTask(
       std::unique_ptr<aura::WindowTracker> closing_window_tracker);
