@@ -11,12 +11,10 @@
 #include "ash/resources/vector_icons/vector_icons.h"
 #include "ash/shell.h"
 #include "ash/strings/grit/ash_strings.h"
-#include "ash/style/ash_color_id.h"
-#include "ash/style/ash_color_provider.h"
-#include "ash/style/close_button.h"
+#include "ash/style/icon_button.h"
 #include "ash/style/pill_button.h"
 #include "ash/style/style_util.h"
-#include "ash/wm/desks/desks_textfield.h"
+#include "ash/wm/desks/desk_textfield.h"
 #include "ash/wm/desks/templates/saved_desk_dialog_controller.h"
 #include "ash/wm/desks/templates/saved_desk_grid_view.h"
 #include "ash/wm/desks/templates/saved_desk_icon_container.h"
@@ -40,6 +38,7 @@
 #include "ui/base/l10n/l10n_util.h"
 #include "ui/base/l10n/time_format.h"
 #include "ui/base/metadata/metadata_impl_macros.h"
+#include "ui/chromeos/styles/cros_tokens_color_mappings.h"
 #include "ui/color/color_id.h"
 #include "ui/compositor/layer.h"
 #include "ui/gfx/geometry/insets.h"
@@ -127,10 +126,8 @@ SavedDeskItemView::SavedDeskItemView(std::unique_ptr<DeskTemplate> saved_desk)
 
   const std::u16string saved_desk_name = saved_desk_->template_name();
   DCHECK(!saved_desk_name.empty());
-  auto* color_provider = AshColorProvider::Get();
   const bool is_admin_managed =
       saved_desk_->source() == DeskTemplateSource::kPolicy;
-
   SetFocusBehavior(views::View::FocusBehavior::ALWAYS);
 
   views::Builder<SavedDeskItemView>(this)
@@ -139,10 +136,11 @@ SavedDeskItemView::SavedDeskItemView(std::unique_ptr<DeskTemplate> saved_desk)
       .SetAccessibleName(saved_desk_name)
       .SetCallback(std::move(launch_template_callback))
       .SetBackground(views::CreateThemedRoundedRectBackground(
-          kColorAshShieldAndBase80, kCornerRadius))
+          cros_tokens::kCrosSysSystemBaseElevated, kCornerRadius))
       .SetBorder(std::make_unique<views::HighlightBorder>(
           kCornerRadius, views::HighlightBorder::Type::kHighlightBorder1,
           /*use_light_colors=*/false))
+      // TODO(b/274025495): Update Shadow for SavedDeskItemView.
       .AddChildren(
           views::Builder<views::FlexLayoutView>()
               .SetOrientation(views::LayoutOrientation::kVertical)
@@ -189,12 +187,10 @@ SavedDeskItemView::SavedDeskItemView(std::unique_ptr<DeskTemplate> saved_desk)
                               .SetPreferredSize(
                                   gfx::Size(kManagedStatusIndicatorSize,
                                             kManagedStatusIndicatorSize))
-                              .SetImage(gfx::CreateVectorIcon(
+                              .SetImage(ui::ImageModel::FromVectorIcon(
                                   chromeos::kEnterpriseIcon,
-                                  kManagedStatusIndicatorSize,
-                                  color_provider->GetContentLayerColor(
-                                      AshColorProvider::ContentLayerType::
-                                          kIconColorSecondary)))
+                                  cros_tokens::kCrosSysSecondary,
+                                  kManagedStatusIndicatorSize))
                               .SetProperty(
                                   views::kFlexBehaviorKey,
                                   views::FlexSpecification(
@@ -204,6 +200,7 @@ SavedDeskItemView::SavedDeskItemView(std::unique_ptr<DeskTemplate> saved_desk)
                   views::Builder<views::Label>()
                       .CopyAddressTo(&time_view_)
                       .SetHorizontalAlignment(gfx::ALIGN_LEFT)
+                      .SetEnabledColorId(cros_tokens::kCrosSysSecondary)
                       .SetText(
                           is_admin_managed
                               ? l10n_util::GetStringUTF16(
@@ -246,17 +243,18 @@ SavedDeskItemView::SavedDeskItemView(std::unique_ptr<DeskTemplate> saved_desk)
   // Users cannot delete admin templates.
   if (!is_admin_managed) {
     delete_button_ =
-        hover_container_->AddChildView(std::make_unique<CloseButton>(
+        hover_container_->AddChildView(std::make_unique<IconButton>(
             base::BindRepeating(&SavedDeskItemView::OnDeleteButtonPressed,
                                 weak_ptr_factory_.GetWeakPtr()),
-            CloseButton::Type::kMedium, &kDeleteIcon,
-            kColorAshControlBackgroundColorInactive));
+            IconButton::Type::kXSmall, &kDeleteIcon,
+            /*is_togglable=*/false,
+            /*has_border=*/false));
     delete_button_->SetTooltipText(l10n_util::GetStringUTF16(
         IDS_ASH_DESKS_TEMPLATES_DELETE_DIALOG_CONFIRM_BUTTON));
   }
 
   // Use a border to create spacing between `name_view_`s background (set in
-  // `DesksTextfield`) and the actual text. Shift the parent by the same amount
+  // `DeskTextfield`) and the actual text. Shift the parent by the same amount
   // so that the text stays aligned with the text in `time_view`. We shift the
   // parent here and not `name_view_` itself otherwise its bounds will be
   // outside the parent bounds and the background will get clipped.
@@ -275,7 +273,7 @@ SavedDeskItemView::SavedDeskItemView(std::unique_ptr<DeskTemplate> saved_desk)
   focus_ring->SetHasFocusPredicate([](views::View* view) {
     return static_cast<SavedDeskItemView*>(view)->IsViewHighlighted();
   });
-  focus_ring->SetColorId(ui::kColorAshFocusRing);
+  focus_ring->SetColorId(cros_tokens::kCrosSysFocusRing);
 
   SetEventTargeter(std::make_unique<views::ViewTargeter>(this));
 
@@ -426,15 +424,6 @@ void SavedDeskItemView::Layout() {
                 launch_button_preferred_size));
 }
 
-void SavedDeskItemView::OnThemeChanged() {
-  views::View::OnThemeChanged();
-  auto* color_provider = AshColorProvider::Get();
-
-  time_view_->SetBackgroundColor(SK_ColorTRANSPARENT);
-  time_view_->SetEnabledColor(color_provider->GetContentLayerColor(
-      AshColorProvider::ContentLayerType::kTextColorSecondary));
-}
-
 void SavedDeskItemView::OnViewFocused(views::View* observed_view) {
   // `this` is a button which observes itself. Here we only care about focus on
   // `name_view_`.
@@ -614,9 +603,9 @@ void SavedDeskItemView::ContentsChanged(views::Textfield* sender,
   // names to have an unbounded length. Therefore we trim if needed at
   // `kMaxLength` UTF-16 boundary. Note that we don't care about code point
   // boundaries in this case.
-  if (new_contents.size() > DesksTextfield::kMaxLength) {
+  if (new_contents.size() > DeskTextfield::kMaxLength) {
     std::u16string trimmed_new_contents = new_contents;
-    trimmed_new_contents.resize(DesksTextfield::kMaxLength);
+    trimmed_new_contents.resize(DeskTextfield::kMaxLength);
     name_view_->SetText(trimmed_new_contents);
   }
 
