@@ -24,7 +24,7 @@ SavedDeskNameView::SavedDeskNameView() {
   SetFontList(GetFontList().Derive(kNameFontSizeDeltaDp, gfx::Font::NORMAL,
                                    gfx::Font::Weight::MEDIUM));
 
-  // The focus ring is created in `DesksTextfield`'s constructor.
+  // The focus ring is created in `DeskTextfield`'s constructor.
   views::FocusRing* focus_ring = views::FocusRing::Get(this);
   DCHECK(focus_ring);
   focus_ring->SetHaloInset(-kFocusRingGapDp);
@@ -37,12 +37,12 @@ void SavedDeskNameView::OnContentsChanged() {
 }
 
 gfx::Size SavedDeskNameView::CalculatePreferredSize() const {
-  return gfx::Size(DesksTextfield::CalculatePreferredSize().width(),
+  return gfx::Size(DeskTextfield::CalculatePreferredSize().width(),
                    kSavedDeskNameViewHeight);
 }
 
 void SavedDeskNameView::OnGestureEvent(ui::GestureEvent* event) {
-  DesksTextfield::OnGestureEvent(event);
+  DeskTextfield::OnGestureEvent(event);
   // Stop propagating this event so that the parent of `this`, which is a button
   // does not get the event.
   event->StopPropagation();
@@ -53,7 +53,7 @@ void SavedDeskNameView::SetViewName(const std::u16string& name) {
   PreferredSizeChanged();
 }
 
-BEGIN_METADATA(SavedDeskNameView, DesksTextfield)
+BEGIN_METADATA(SavedDeskNameView, DeskTextfield)
 END_METADATA
 
 }  // namespace ash
