@@ -13,7 +13,10 @@
 #include "base/scoped_observation.h"
 #include "components/desks_storage/core/desk_model.h"
 #include "components/desks_storage/core/desk_model_observer.h"
-#include "ui/aura/window.h"
+
+namespace aura {
+class Window;
+}  // namespace aura
 
 namespace ash {
 
@@ -34,7 +37,9 @@ class ASH_EXPORT SavedDeskPresenter : desks_storage::DeskModelObserver {
   SavedDeskPresenter& operator=(const SavedDeskPresenter&) = delete;
   ~SavedDeskPresenter() override;
 
-  bool should_show_templates_ui() { return should_show_templates_ui_; }
+  bool should_show_saved_desk_library() {
+    return should_show_saved_desk_library_;
+  }
 
   // Retrieve the current and max count for a given saved desk type. Note that
   // these are snapshots of the model state, which may not match the current UI
@@ -48,12 +53,13 @@ class ASH_EXPORT SavedDeskPresenter : desks_storage::DeskModelObserver {
                                             ash::DeskTemplateType type,
                                             const base::GUID& uuid) const;
 
-  // Update the buttons of the desks templates UI and the visibility of the
-  // templates grid. The grid contents are not updated. Updates
-  // `should_show_templates_ui_`.
-  void UpdateDesksTemplatesUI();
+  // Update UI for saved desk library. More specifically, it updates the
+  // visibility of the library button, save desk button, and the saved desk
+  // grid. The grid contents are not updated. It also updates
+  // `should_show_saved_desk_library_`.
+  void UpdateUIForSavedDeskLibrary();
 
-  // Calls the DeskModel to get all the template entries, with a callback to
+  // Calls the DeskModel to get all the saved desk entries, with a callback to
   // `OnGetAllEntries`. `saved_desk_name` is used for the name overwrite nudge
   // for duplicate desk names.
   void GetAllEntries(const base::GUID& item_to_focus,
@@ -73,13 +79,13 @@ class ASH_EXPORT SavedDeskPresenter : desks_storage::DeskModelObserver {
   // callback to `OnAddOrUpdateEntry`. If there are unsupported apps on the
   // active desk, a dialog will open up and we may or may not save the desk
   // asynchronously based on the user's decision.
-  void MaybeSaveActiveDeskAsTemplate(DeskTemplateType template_type,
-                                     aura::Window* root_window_to_show);
+  void MaybeSaveActiveDeskAsSavedDesk(DeskTemplateType template_type,
+                                      aura::Window* root_window_to_show);
 
-  // Saves or updates the `desk_template` to the model.
-  void SaveOrUpdateDeskTemplate(bool is_update,
-                                aura::Window* const root_window,
-                                std::unique_ptr<DeskTemplate> desk_template);
+  // Saves or updates the `saved_desk` to the model.
+  void SaveOrUpdateSavedDesk(bool is_update,
+                             aura::Window* const root_window,
+                             std::unique_ptr<DeskTemplate> saved_desk);
 
   // desks_storage::DeskModelObserver:
   void DeskModelLoaded() override {}
@@ -103,13 +109,14 @@ class ASH_EXPORT SavedDeskPresenter : desks_storage::DeskModelObserver {
                      desks_storage::DeskModel::DeleteEntryStatus status);
 
   // Callback after adding or updating an entry. Will then call
-  // `AddOrUpdateUIEntries` to update the UI by adding or updating the template.
+  // `AddOrUpdateUIEntries` to update the UI by adding or updating the saved
+  // desk.
   void OnAddOrUpdateEntry(
       bool was_update,
       aura::Window* const root_window,
       const std::u16string& saved_desk_name,
       desks_storage::DeskModel::AddOrUpdateEntryStatus status,
-      std::unique_ptr<DeskTemplate> desk_template);
+      std::unique_ptr<DeskTemplate> saved_desk);
 
   // Helper functions for updating the UI.
   void AddOrUpdateUIEntries(
@@ -135,9 +142,9 @@ class ASH_EXPORT SavedDeskPresenter : desks_storage::DeskModelObserver {
                           desks_storage::DeskModelObserver>
       desk_model_observation_{this};
 
-  // If the user has at least one template entry, the desk templates ui should
-  // be shown. Otherwise, it should be invisible.
-  bool should_show_templates_ui_ = false;
+  // If the user has at least one saved desk entry, the saved desk library
+  // should be shown. Otherwise, it should be invisible.
+  bool should_show_saved_desk_library_ = false;
 
   // Test closure that runs after the UI has been updated async after a call to
   // the model.
