@@ -22,9 +22,11 @@
 #include "ash/wm/tablet_mode/tablet_mode_window_state.h"
 #include "ash/wm/window_state.h"
 #include "ash/wm/window_util.h"
+#include "ash/wm/wm_default_layout_manager.h"
 #include "ash/wm/wm_event.h"
 #include "ash/wm/work_area_insets.h"
 #include "ash/wm/workspace/workspace_event_handler.h"
+#include "ash/wm/workspace/workspace_layout_manager.h"
 #include "base/check.h"
 #include "base/check_op.h"
 #include "base/metrics/histogram_functions.h"
@@ -40,8 +42,6 @@
 #include "ui/display/screen.h"
 #include "ui/wm/core/coordinate_conversion.h"
 
-using MagnetismCorner = ash::FloatController::MagnetismCorner;
-
 namespace ash {
 
 namespace {
@@ -73,6 +73,22 @@ void UpdateWindowBoundsForTablet(
     WindowState::BoundsChangeAnimationType animation_type) {
   WindowState* window_state = WindowState::Get(window);
   DCHECK(window_state);
+  // TODO(b/264962634): Remove this workaround.
+  // Currently `TabletModeWindowState::UpdateWindowPosition` uses
+  // `Window::SetBoundsDirect` which directly changes the bounds without waiting
+  // for the ack from clients (e.g. ARC++). So we need to ensure to emit
+  // `SetBoundsWMEvent` instead. Otherwise, the window bounds are updated only
+  // in Chrome-side whereas ARC++ doesn’t know the changes. (See comments in
+  // `TabletModeWindowState::UpdateWindowPosition`.)
+  if (window->GetProperty(aura::client::kAppType) ==
+      static_cast<int>(AppType::ARC_APP)) {
+    const SetBoundsWMEvent event(
+        TabletModeWindowState::GetBoundsInTabletMode(window_state),
+        /*animate=*/animation_type !=
+            WindowState::BoundsChangeAnimationType::kNone);
+    window_state->OnWMEvent(&event);
+    return;
+  }
   TabletModeWindowState::UpdateWindowPosition(window_state, animation_type);
 }
 
@@ -98,6 +114,24 @@ void ShowFloatedWindow(aura::Window* floated_window) {
   floated_window->Show();
 }
 
+class FloatLayoutManager : public WmDefaultLayoutManager {
+ public:
+  FloatLayoutManager() = default;
+  FloatLayoutManager(const FloatLayoutManager&) = delete;
+  FloatLayoutManager& operator=(const FloatLayoutManager&) = delete;
+  ~FloatLayoutManager() override = default;
+
+  // WmDefaultLayoutManager:
+  void SetChildBounds(aura::Window* child,
+                      const gfx::Rect& requested_bounds) override {
+    // This should result in sending a bounds change WMEvent to properly support
+    // client-controlled windows (e.g. ARC++).
+    WindowState* window_state = WindowState::Get(child);
+    SetBoundsWMEvent event(requested_bounds);
+    window_state->OnWMEvent(&event);
+  }
+};
+
 }  // namespace
 
 // -----------------------------------------------------------------------------
@@ -159,10 +193,20 @@ class FloatController::FloatedWindowInfo : public aura::WindowObserver {
 
   void OnUntuckAnimationEnded() { scoped_window_tucker_.reset(); }
 
-  void MaybeUntuckWindow() {
+  void MaybeUntuckWindow(bool animate) {
     // The order here matters: `is_tucked_for_tablet_` must be set to false
-    // before `AnimateUntuck()` gets the untucked window bounds.
+    // before `TabletModeWindowState::UpdateWindowPosition()` or
+    // `AnimateUntuck()` gets the untucked window bounds.
     is_tucked_for_tablet_ = false;
+
+    if (!animate) {
+      scoped_window_tucker_.reset();
+      TabletModeWindowState::UpdateWindowPosition(
+          WindowState::Get(floated_window_),
+          WindowState::BoundsChangeAnimationType::kNone);
+      return;
+    }
+
     if (scoped_window_tucker_) {
       scoped_window_tucker_->AnimateUntuck(
           base::BindOnce(&FloatedWindowInfo::OnUntuckAnimationEnded,
@@ -384,16 +428,34 @@ void FloatController::MaybeUntuckFloatedWindowForTablet(
     aura::Window* floated_window) {
   auto* floated_window_info = MaybeGetFloatedWindowInfo(floated_window);
   DCHECK(floated_window_info);
-  floated_window_info->MaybeUntuckWindow();
+  floated_window_info->MaybeUntuckWindow(/*animate=*/true);
 }
 
 bool FloatController::IsFloatedWindowTuckedForTablet(
     const aura::Window* floated_window) const {
   auto* floated_window_info = MaybeGetFloatedWindowInfo(floated_window);
-  DCHECK(floated_window_info);
+  // This can be called during state transition, where window is getting into
+  // float state but float info is not created, return false as default tuck
+  // status is false.
+  if (!floated_window_info) {
+    return false;
+  }
   return floated_window_info->is_tucked_for_tablet();
 }
 
+bool FloatController::IsFloatedWindowAlignedWithShelf(
+    aura::Window* floated_window) const {
+  auto* floated_window_info = MaybeGetFloatedWindowInfo(floated_window);
+  DCHECK(floated_window_info);
+  if (floated_window_info->is_tucked_for_tablet()) {
+    return false;
+  }
+
+  MagnetismCorner magnetism_corner = floated_window_info->magnetism_corner();
+  return magnetism_corner == MagnetismCorner::kBottomLeft ||
+         magnetism_corner == MagnetismCorner::kBottomRight;
+}
+
 views::Widget* FloatController::GetTuckHandleWidget(
     const aura::Window* floated_window) const {
   auto* floated_window_info = MaybeGetFloatedWindowInfo(floated_window);
@@ -401,35 +463,43 @@ views::Widget* FloatController::GetTuckHandleWidget(
   return floated_window_info->GetTuckHandleWidget();
 }
 
-void FloatController::OnDragCompletedForTablet(
-    aura::Window* floated_window,
-    const gfx::PointF& last_location_in_parent) {
+void FloatController::OnDragCompletedForTablet(aura::Window* floated_window) {
   auto* floated_window_info = MaybeGetFloatedWindowInfo(floated_window);
   DCHECK(floated_window_info);
 
   // Use the display bounds since the user may drag on to the shelf or spoken
   // feedback bar.
-  const gfx::RectF display_bounds(
+  const gfx::Point display_bounds_center =
       display::Screen::GetScreen()
           ->GetDisplayNearestWindow(floated_window->GetRootWindow())
-          .bounds());
+          .bounds()
+          .CenterPoint();
+  const int display_bounds_center_x = display_bounds_center.x();
+  const int display_bounds_center_y = display_bounds_center.y();
 
   // Check which corner to magnetize to based on which quadrant of the display
-  // the mouse/touch was released. If it somehow falls outside, then magnetize
-  // to the previous location.
-  gfx::RectF display_bounds_left, display_bounds_right;
-  display_bounds.SplitVertically(&display_bounds_left, &display_bounds_right);
-  const float center_y = display_bounds.CenterPoint().y();
-  MagnetismCorner magnetism_corner = floated_window_info->magnetism_corner();
-  if (display_bounds_left.InclusiveContains(last_location_in_parent)) {
-    magnetism_corner = last_location_in_parent.y() < center_y
-                           ? MagnetismCorner::kTopLeft
-                           : MagnetismCorner::kBottomLeft;
-  } else if (display_bounds_right.InclusiveContains(last_location_in_parent)) {
-    magnetism_corner = last_location_in_parent.y() < center_y
-                           ? MagnetismCorner::kTopRight
-                           : MagnetismCorner::kBottomRight;
+  // the centerpoint of the window was on touch released. Not that the
+  // centerpoint may be offscreen.
+  const gfx::Point float_window_center =
+      floated_window->GetBoundsInScreen().CenterPoint();
+  const int float_window_center_x = float_window_center.x();
+  const int float_window_center_y = float_window_center.y();
+  MagnetismCorner magnetism_corner;
+  if (float_window_center_x < display_bounds_center_x &&
+      float_window_center_y < display_bounds_center_y) {
+    magnetism_corner = MagnetismCorner::kTopLeft;
+  } else if (float_window_center_x >= display_bounds_center_x &&
+             float_window_center_y < display_bounds_center_y) {
+    magnetism_corner = MagnetismCorner::kTopRight;
+  } else if (float_window_center_x < display_bounds_center_x &&
+             float_window_center_y >= display_bounds_center_y) {
+    magnetism_corner = MagnetismCorner::kBottomLeft;
+  } else {
+    DCHECK_GE(float_window_center_x, display_bounds_center_x);
+    DCHECK_GE(float_window_center_y, display_bounds_center_y);
+    magnetism_corner = MagnetismCorner::kBottomRight;
   }
+
   floated_window_info->set_magnetism_corner(magnetism_corner);
   UpdateWindowBoundsForTablet(floated_window,
                               WindowState::BoundsChangeAnimationType::kAnimate);
@@ -551,8 +621,13 @@ void FloatController::OnMovingFloatedWindowToDesk(aura::Window* floated_window,
                                          .id());
   }
 
-  // Hide `floated_window` since it's been moved to an inactive desk.
-  HideFloatedWindow(floated_window);
+  // Update `floated_window` visibility based on target desk's activation
+  // status.
+  if (target_desk->is_active()) {
+    ShowFloatedWindow(floated_window);
+  } else {
+    HideFloatedWindow(floated_window);
+  }
   active_desk->NotifyContentChanged();
   target_desk->NotifyContentChanged();
 }
@@ -578,7 +653,7 @@ void FloatController::OnTabletModeStarted() {
 
 void FloatController::OnTabletModeEnding() {
   for (auto& [window, info] : floated_window_info_map_)
-    info->MaybeUntuckWindow();
+    info->MaybeUntuckWindow(/*animate=*/true);
 }
 
 void FloatController::OnTabletControllerDestroyed() {
@@ -592,10 +667,17 @@ void FloatController::OnDeskActivationChanged(const Desk* activated,
   // update the floated windows' visibility. Therefore, here we hide the floated
   // window belonging to the deactivated desk, and show the one belonging to the
   // activated desk.
-  if (auto* deactivated_desk_floated_window =
-          FindFloatedWindowOfDesk(deactivated)) {
-    HideFloatedWindow(deactivated_desk_floated_window);
+  auto deactivated_desk_floated_window_info_iter = base::ranges::find_if(
+      floated_window_info_map_, [deactivated](const auto& floated_window_info) {
+        return floated_window_info.second->desk() == deactivated;
+      });
+  if (deactivated_desk_floated_window_info_iter !=
+      floated_window_info_map_.end()) {
+    deactivated_desk_floated_window_info_iter->second->MaybeUntuckWindow(
+        /*animate=*/false);
+    HideFloatedWindow(deactivated_desk_floated_window_info_iter->first);
   }
+
   if (auto* activated_desk_floated_window =
           FindFloatedWindowOfDesk(activated)) {
     ShowFloatedWindow(activated_desk_floated_window);
@@ -604,14 +686,13 @@ void FloatController::OnDeskActivationChanged(const Desk* activated,
 
 void FloatController::OnDisplayMetricsChanged(const display::Display& display,
                                               uint32_t metrics) {
-  // TODO(sammiequon): Make this work for clamshell mode too.
   // The work area can change while entering or exiting tablet mode. The float
   // window changes related with those changes are handled in
   // `OnTabletModeStarting`, `OnTabletModeEnding` or attaching/detaching window
   // states.
   display::TabletState tablet_state = chromeos::TabletState::Get()->state();
   if (tablet_state == display::TabletState::kEnteringTabletMode ||
-      tablet_state == display::TabletState::kEnteringTabletMode) {
+      tablet_state == display::TabletState::kExitingTabletMode) {
     return;
   }
 
@@ -639,6 +720,8 @@ void FloatController::OnRootWindowAdded(aura::Window* root_window) {
   workspace_event_handlers_[root_window] =
       std::make_unique<WorkspaceEventHandler>(
           root_window->GetChildById(kShellWindowId_FloatContainer));
+  root_window->GetChildById(kShellWindowId_FloatContainer)
+      ->SetLayoutManager(std::make_unique<FloatLayoutManager>());
 }
 
 void FloatController::OnRootWindowWillShutdown(aura::Window* root_window) {
@@ -700,6 +783,13 @@ void FloatController::FloatImpl(aura::Window* window) {
   const Desk* desk = desks_util::GetDeskForContext(window);
   DCHECK(desk);
 
+  // TODO(b/267363112): Allow a floated window to be assigned to all desks.
+  // If window is visible to all desks, unset it.
+  if (desks_util::IsWindowVisibleOnAllWorkspaces(window)) {
+    window->SetProperty(aura::client::kWindowWorkspaceKey,
+                        aura::client::kWindowWorkspaceUnassignedWorkspace);
+  }
+
   auto* previously_floated_window = FindFloatedWindowOfDesk(desk);
   // Add floated window to `floated_window_info_map_`.
   // Note: this has to be called before `ResetFloatedWindow`. Because in the
