@@ -19,13 +19,16 @@
 #include "base/time/time.h"
 #include "ui/aura/null_window_targeter.h"
 #include "ui/aura/scoped_window_targeter.h"
-#include "ui/compositor/layer.h"
+#include "ui/aura/window_targeter.h"
+#include "ui/base/metadata/metadata_header_macros.h"
+#include "ui/base/metadata/metadata_impl_macros.h"
 #include "ui/gfx/canvas.h"
 #include "ui/gfx/geometry/transform.h"
 #include "ui/gfx/geometry/transform_util.h"
 #include "ui/gfx/paint_vector_icon.h"
 #include "ui/views/animation/animation_builder.h"
 #include "ui/views/controls/button/button.h"
+#include "ui/views/view_targeter_delegate.h"
 #include "ui/wm/core/window_util.h"
 #include "ui/wm/public/activation_client.h"
 
@@ -36,6 +39,9 @@ namespace {
 constexpr int kTuckHandleWidth = 20;
 constexpr int kTuckHandleHeight = 92;
 
+// The tuck handle can be tapped slightly outside its bounds.
+constexpr gfx::Insets kTuckHandleExtraTapInset = gfx::Insets::VH(-8, -16);
+
 // The distance from the edge of the tucked window to the edge of the screen
 // during the bounce.
 constexpr int kTuckOffscreenPaddingDp = 20;
@@ -68,19 +74,23 @@ const gfx::Rect GetTuckHandleBounds(bool left, const gfx::Rect& window_bounds) {
 }  // namespace
 
 // -----------------------------------------------------------------------------
-// ScopedWindowTucker::TuckHandle:
+// TuckHandleView:
 
 // Represents a tuck handle that untucks floated windows from offscreen.
-class ScopedWindowTucker::TuckHandle : public views::Button {
+class TuckHandleView : public views::Button,
+                       public views::ViewTargeterDelegate {
  public:
-  TuckHandle(base::RepeatingClosure callback, bool left)
+  METADATA_HEADER(TuckHandleView);
+
+  TuckHandleView(base::RepeatingClosure callback, bool left)
       : views::Button(callback), left_(left) {
     SetFlipCanvasOnPaintForRTLUI(false);
     SetFocusBehavior(FocusBehavior::NEVER);
+    SetEventTargeter(std::make_unique<views::ViewTargeter>(this));
   }
-  TuckHandle(const TuckHandle&) = delete;
-  TuckHandle& operator=(const TuckHandle&) = delete;
-  ~TuckHandle() override = default;
+  TuckHandleView(const TuckHandleView&) = delete;
+  TuckHandleView& operator=(const TuckHandleView&) = delete;
+  ~TuckHandleView() override = default;
 
   // views::Button:
   void OnThemeChanged() override {
@@ -95,15 +105,26 @@ class ScopedWindowTucker::TuckHandle : public views::Button {
       canvas->Scale(-1, 1);
     }
 
-    // We draw two icons on top of each other because we need separate
+    // We draw three icons on top of each other because we need separate
     // themeing on different parts which is not supported by `VectorIcon`.
-    const SkColor container_color = ColorUtil::GetSecondToneColor(
-        DarkLightModeControllerImpl::Get()->IsDarkModeEnabled()
-            ? SK_ColorWHITE
-            : SK_ColorBLACK);
-    const gfx::ImageSkia& tuck_container = gfx::CreateVectorIcon(
-        kTuckHandleContainerIcon, kTuckHandleWidth, container_color);
-    canvas->DrawImageInt(tuck_container, 0, 0);
+    const bool dark_mode =
+        DarkLightModeControllerImpl::Get()->IsDarkModeEnabled();
+
+    // Paint the container bottom layer with default 80% opacity.
+    const SkColor bottom_color = ColorUtil::GetSecondToneColor(
+        dark_mode ? gfx::kGoogleGrey500 : gfx::kGoogleGrey600);
+    const gfx::ImageSkia& tuck_container_bottom = gfx::CreateVectorIcon(
+        kTuckHandleContainerBottomIcon, kTuckHandleWidth, bottom_color);
+    canvas->DrawImageInt(tuck_container_bottom, 0, 0);
+
+    // Paint the container top layer. This is mostly transparent, with 12%
+    // opacity.
+    const SkColor color = dark_mode ? gfx::kGoogleGrey200 : gfx::kGoogleGrey600;
+    const SkColor top_color =
+        SkColorSetA(color, std::round(SkColorGetA(color) * 0.12f));
+    const gfx::ImageSkia& tuck_container_top = gfx::CreateVectorIcon(
+        kTuckHandleContainerTopIcon, kTuckHandleWidth, top_color);
+    canvas->DrawImageInt(tuck_container_top, 0, 0);
 
     const gfx::ImageSkia& tuck_icon = gfx::CreateVectorIcon(
         kTuckHandleChevronIcon, kTuckHandleWidth, SK_ColorWHITE);
@@ -111,30 +132,13 @@ class ScopedWindowTucker::TuckHandle : public views::Button {
   }
 
   void OnGestureEvent(ui::GestureEvent* event) override {
-    float detail_x = 0.0, detail_y = 0.0;
-    const ui::GestureEventDetails details = event->details();
-    switch (event->type()) {
-      case ui::ET_GESTURE_SWIPE:
-        // Since ET_GESTURE_SWIPE events don't have a numeric value, set
-        // `detail_x` as an arbitrary positive or negative value.
-        detail_x = details.swipe_right() ? 1.0 : -1.0;
-        break;
-      case ui::ET_SCROLL_FLING_START:
-        detail_x = details.velocity_x();
-        detail_y = details.velocity_y();
-        break;
-      case ui::ET_GESTURE_SCROLL_BEGIN:
-        detail_x = details.scroll_x_hint();
-        detail_y = details.scroll_y_hint();
-        break;
-      case ui::ET_GESTURE_SCROLL_UPDATE:
-        detail_x = details.scroll_x();
-        detail_y = details.scroll_y();
-        break;
-      default:
-        views::Button::OnGestureEvent(event);
-        return;
+    if (event->type() != ui::ET_GESTURE_SCROLL_BEGIN) {
+      views::Button::OnGestureEvent(event);
+      return;
     }
+    const ui::GestureEventDetails details = event->details();
+    const float detail_x = details.scroll_x_hint(),
+                detail_y = details.scroll_y_hint();
 
     // Ignore vertical gestures.
     if (std::fabs(detail_x) <= std::fabs(detail_y))
@@ -145,9 +149,16 @@ class ScopedWindowTucker::TuckHandle : public views::Button {
     if ((left_ && detail_x > 0) || (!left_ && detail_x < 0)) {
       NotifyClick(*event);
       event->SetHandled();
+      event->StopPropagation();
     }
   }
 
+  // views::ViewTargeterDelegate:
+  bool DoesIntersectRect(const views::View* target,
+                         const gfx::Rect& rect) const override {
+    return true;
+  }
+
  private:
   // Whether the tuck handle is on the left or right edge of the screen. A
   // left tuck handle will have the chevron arrow pointing right and vice
@@ -155,6 +166,9 @@ class ScopedWindowTucker::TuckHandle : public views::Button {
   const bool left_;
 };
 
+BEGIN_METADATA(TuckHandleView, views::Button)
+END_METADATA
+
 // -----------------------------------------------------------------------------
 
 ScopedWindowTucker::ScopedWindowTucker(aura::Window* window, bool left)
@@ -171,12 +185,16 @@ ScopedWindowTucker::ScopedWindowTucker(aura::Window* window, bool left)
   params.name = "TuckHandleWidget";
   tuck_handle_widget_->Init(std::move(params));
 
-  tuck_handle_widget_->SetContentsView(std::make_unique<TuckHandle>(
+  tuck_handle_widget_->SetContentsView(std::make_unique<TuckHandleView>(
       base::BindRepeating(&ScopedWindowTucker::UntuckWindow,
                           base::Unretained(this)),
       left));
   tuck_handle_widget_->Show();
 
+  auto targeter = std::make_unique<aura::WindowTargeter>();
+  targeter->SetInsets(kTuckHandleExtraTapInset);
+  tuck_handle_widget_->GetNativeWindow()->SetEventTargeter(std::move(targeter));
+
   // Activate the most recent window that is not minimized and not the tucked
   // `window_`, otherwise activate the app list.
   auto mru_windows =
