@@ -38,8 +38,8 @@ class ASH_EXPORT OverviewItemView : public WindowMiniView,
     kVisible,
   };
 
-  // If |show_preview| is true, this class will contain a child view which
-  // mirrors |window|.
+  // If `show_preview` is true, this class will contain a child view which
+  // mirrors `window`.
   OverviewItemView(OverviewItem* overview_item,
                    views::Button::PressedCallback close_callback,
                    aura::Window* window,
@@ -48,23 +48,24 @@ class ASH_EXPORT OverviewItemView : public WindowMiniView,
   OverviewItemView& operator=(const OverviewItemView&) = delete;
   ~OverviewItemView() override;
 
-  // Fades the app icon and title out if |visibility| is kInvisible, in
-  // otherwise. If |close_button_| is not null, also fades the close button in
-  // if |visibility| is kVisible, out otherwise. Sets
-  // |current_header_visibility_| to |visibility|.
-  void SetHeaderVisibility(HeaderVisibility visibility);
+  // Fades the app icon and title out if `visibility` is kInvisible, in
+  // otherwise. If `close_button_` is not null, also fades the close button in
+  // if `visibility` is kVisible, out otherwise. Sets
+  // `current_header_visibility_` to `visibility`. Fades in if `animate` is
+  // true, otherwise shows immediately.
+  void SetHeaderVisibility(HeaderVisibility visibility, bool animate);
 
   // Hides the close button instantaneously, and then fades it in slowly and
-  // with a long delay. Sets |current_header_visibility_| to kVisible. Assumes
-  // that |close_button_| is not null, and that |current_header_visibility_| is
+  // with a long delay. Sets `current_header_visibility_` to kVisible. Assumes
+  // that `close_button_` is not null, and that `current_header_visibility_` is
   // not kInvisible.
   void HideCloseInstantlyAndThenShowItSlowly();
 
-  // Called when |overview_item_| is about to be restored to its original state
+  // Called when `overview_item_` is about to be restored to its original state
   // outside of overview.
   void OnOverviewItemWindowRestoring();
 
-  // Refreshes |preview_view_| so that its content is up-to-date. Used by tab
+  // Refreshes `preview_view_` so that its content is up-to-date. Used by tab
   // dragging.
   void RefreshPreviewView();
 
@@ -97,7 +98,7 @@ class ASH_EXPORT OverviewItemView : public WindowMiniView,
 
  private:
   // The OverviewItem which owns the widget which houses this view. Non-null
-  // until |OnOverviewItemWindowRestoring| is called.
+  // until `OnOverviewItemWindowRestoring` is called.
   OverviewItem* overview_item_;
 
   CloseButton* close_button_;
