@@ -60,80 +60,6 @@ bool IsPastLeftOrRightEdge(const gfx::Rect& bounds, const gfx::Rect& area) {
   return bounds.x() < area.x() || bounds.right() > area.right();
 }
 
-void CollectFreeResizeAreaMetric(const char* metric_name,
-                                 aura::Window* window) {
-  aura::Window* root_window = window->GetRootWindow();
-  const gfx::Rect bounds = window->GetBoundsInRootWindow();
-  const int root_window_area =
-      root_window->bounds().width() * root_window->bounds().height();
-  const int window_area = bounds.width() * bounds.height();
-  if (root_window_area != 0) {
-    const int percentage =
-        std::round(float(window_area) / float(root_window_area) * 100.f);
-    base::UmaHistogramPercentageObsoleteDoNotUse(metric_name, percentage);
-  }
-}
-
-int ComputeIntersectionArea(const gfx::Rect& ninth, const gfx::Rect& bounds) {
-  gfx::Rect intersection = ninth;
-  intersection.Intersect(bounds);
-  return intersection.width() * intersection.height();
-}
-
-gfx::Rect ScaleRect(const gfx::Rect& rect, int scale) {
-  return gfx::Rect(rect.x() * scale, rect.y() * scale, rect.width() * scale,
-                   rect.height() * scale);
-}
-
-void CollectPositionMetric(const gfx::Rect& bounds_in_screen,
-                           const gfx::Rect& area_in_screen) {
-  const int width = area_in_screen.width();
-  const int height = area_in_screen.height();
-  // Scale by three to avoid truncation.
-  const gfx::Rect area = ScaleRect(area_in_screen, 3);
-  const gfx::Rect bounds = ScaleRect(bounds_in_screen, 3);
-
-  // Choose corners first, then edges, and finally middle in the case of a tie.
-  // This is based on the enum integer values.
-  // For this to work, all of the 9 buckets need to have the same area.
-  std::pair<int, AshPipPosition> area_ninths[9] = {
-      {ComputeIntersectionArea(
-           gfx::Rect(area.x() + width, area.y() + height, width, height),
-           bounds),
-       AshPipPosition::MIDDLE},
-      {ComputeIntersectionArea(
-           gfx::Rect(area.x() + width, area.y(), width, height), bounds),
-       AshPipPosition::TOP_MIDDLE},
-      {ComputeIntersectionArea(
-           gfx::Rect(area.x(), area.y() + height, width, height), bounds),
-       AshPipPosition::MIDDLE_LEFT},
-      {ComputeIntersectionArea(
-           gfx::Rect(area.x() + 2 * width, area.y() + height, width, height),
-           bounds),
-       AshPipPosition::MIDDLE_RIGHT},
-      {ComputeIntersectionArea(
-           gfx::Rect(area.x() + width, area.y() + 2 * height, width, height),
-           bounds),
-       AshPipPosition::BOTTOM_MIDDLE},
-      {ComputeIntersectionArea(gfx::Rect(area.x(), area.y(), width, height),
-                               bounds),
-       AshPipPosition::TOP_LEFT},
-      {ComputeIntersectionArea(
-           gfx::Rect(area.x() + 2 * width, area.y(), width, height), bounds),
-       AshPipPosition::TOP_RIGHT},
-      {ComputeIntersectionArea(
-           gfx::Rect(area.x(), area.y() + 2 * height, width, height), bounds),
-       AshPipPosition::BOTTOM_LEFT},
-      {ComputeIntersectionArea(gfx::Rect(area.x() + 2 * width,
-                                         area.y() + 2 * height, width, height),
-                               bounds),
-       AshPipPosition::BOTTOM_RIGHT}};
-
-  std::sort(area_ninths, area_ninths + std::size(area_ninths));
-  UMA_HISTOGRAM_ENUMERATION(kAshPipPositionHistogramName,
-                            area_ninths[8].second);
-}
-
 }  // namespace
 
 PipWindowResizer::PipWindowResizer(WindowState* window_state)
@@ -144,8 +70,6 @@ PipWindowResizer::PipWindowResizer(WindowState* window_state)
   if (is_resize) {
     UMA_HISTOGRAM_ENUMERATION(kAshPipEventsHistogramName,
                               AshPipEvents::FREE_RESIZE);
-    CollectFreeResizeAreaMetric(kAshPipFreeResizeInitialAreaHistogramName,
-                                GetTarget());
   } else {
     // Don't allow swipe-to-dismiss for resizes.
     gfx::Rect area =
@@ -254,15 +178,6 @@ void PipWindowResizer::Drag(const gfx::PointF& location_in_parent,
 
 void PipWindowResizer::CompleteDrag() {
   const bool is_resize = details().bounds_change & kBoundsChange_Resizes;
-  if (is_resize) {
-    CollectFreeResizeAreaMetric(kAshPipFreeResizeFinishAreaHistogramName,
-                                GetTarget());
-  } else {
-    // Collect final position on drag-move.
-    display::Display display = window_state()->GetDisplay();
-    gfx::Rect area = CollisionDetectionUtils::GetMovementArea(display);
-    CollectPositionMetric(GetTarget()->GetBoundsInScreen(), area);
-  }
 
   window_state()->OnCompleteDrag(last_location_in_screen_);
 
