@@ -27,6 +27,7 @@
 #include "ash/wm/window_util.h"
 #include "base/i18n/rtl.h"
 #include "base/strings/utf_string_conversions.h"
+#include "chromeos/constants/chromeos_features.h"
 #include "ui/aura/window.h"
 #include "ui/aura/window_observer.h"
 #include "ui/base/l10n/l10n_util.h"
@@ -285,6 +286,7 @@ class SplitViewDragIndicators::SplitViewDragIndicatorsView
     const bool previews_only =
         window_dragging_state == WindowDraggingState::kFromShelf ||
         window_dragging_state == WindowDraggingState::kFromTop ||
+        window_dragging_state == WindowDraggingState::kFromFloat ||
         split_view_controller->InSplitViewMode();
     const bool can_dragged_window_be_snapped =
         dragged_window_ &&
