@@ -52,7 +52,10 @@ bool TabletModeToggleFullscreenEventHandler::ProcessEvent(
     const ui::TouchEvent& event) {
   switch (event.type()) {
     case ui::ET_TOUCH_PRESSED: {
-      DCHECK(!drag_data_);
+      // Another drag is already underway from another finger.
+      if (drag_data_) {
+        return false;
+      }
 
       aura::Window* active_window = window_util::GetActiveWindow();
       if (!active_window || !CanToggleFullscreen(active_window))
