@@ -1580,21 +1580,6 @@ TEST_F(TabletModeWindowManagerTest, DontChangeBoundsForMinimizedWindow) {
   EXPECT_EQ(window->bounds(), rect);
 }
 
-// Test that if a window is currently in tab-dragging process, its window bounds
-// should not updated.
-TEST_F(TabletModeWindowManagerTest, DontChangeBoundsForTabDraggingWindow) {
-  gfx::Rect rect(0, 0, 200, 200);
-  std::unique_ptr<aura::Window> window(
-      CreateWindow(aura::client::WINDOW_TYPE_NORMAL, rect));
-  // Now put the window in tab-dragging process.
-  window->SetProperty(kIsDraggingTabsKey, true);
-
-  TabletModeWindowManager* manager = CreateTabletModeWindowManager();
-  ASSERT_TRUE(manager);
-  EXPECT_EQ(1, manager->GetNumberOfManagedWindows());
-  EXPECT_EQ(window->bounds(), rect);
-}
-
 // Make sure that transient children should not be maximized.
 TEST_F(TabletModeWindowManagerTest, DontMaximizeTransientChild) {
   gfx::Rect rect(0, 0, 200, 200);
@@ -1754,10 +1739,13 @@ TEST_F(TabletModeWindowManagerTest,
   EXPECT_TRUE(split_view_controller()->IsWindowInSplitView(window.get()));
   // Check the window is moved to 1/3 snapped position.
   EXPECT_EQ(window->bounds().width(),
-            1200 * 0.33 - kSplitviewDividerShortSideLength / 2);
-  // Exit tablet mode and verify the window stays in the same position.
+            std::round(1200 * chromeos::kOneThirdSnapRatio) -
+                kSplitviewDividerShortSideLength / 2);
+  // Exit tablet mode and verify the window stays near the same position.
   DestroyTabletModeWindowManager();
-  EXPECT_EQ(window->bounds().width(), 1200 * 0.33);
+  EXPECT_NEAR(window->bounds().width(),
+              std::round(1200 * chromeos::kOneThirdSnapRatio),
+              kSplitviewDividerShortSideLength / 2);
 
   // Now test the 2 windows case.
   std::unique_ptr<aura::Window> window2(
@@ -1775,65 +1763,83 @@ TEST_F(TabletModeWindowManagerTest,
   EXPECT_TRUE(split_view_controller()->IsWindowInSplitView(window2.get()));
   // Check |window| and |window2| is moved to 1/3 snapped position.
   EXPECT_EQ(window->bounds().width(),
-            1200 * 0.33 - kSplitviewDividerShortSideLength / 2);
+            std::round(1200 * chromeos::kOneThirdSnapRatio) -
+                kSplitviewDividerShortSideLength / 2);
   EXPECT_EQ(window2->bounds().width(),
             1200 - window->bounds().width() - kSplitviewDividerShortSideLength);
-  // Exit tablet mode and verify the windows stay in the same position.
+  // Exit tablet mode and verify the windows stay near the same position.
   DestroyTabletModeWindowManager();
-  EXPECT_EQ(window->bounds().width(), 1200 * 0.33);
-  EXPECT_EQ(window2->bounds().width(), 1200 - window->bounds().width());
+  EXPECT_NEAR(window->bounds().width(),
+              std::round(1200 * chromeos::kOneThirdSnapRatio),
+              kSplitviewDividerShortSideLength / 2);
+  EXPECT_NEAR(window2->bounds().width(), 1200 - window->bounds().width(),
+              kSplitviewDividerShortSideLength / 2);
 }
 
 // Tests partial split clamshell <-> tablet transition.
 TEST_F(TabletModeWindowManagerTest, PartialClamshellTabletTransitionTest) {
   // 1. Create a window and snap to primary 2/3.
-  auto window = CreateTestWindow();
+  auto window1 = CreateTestWindow();
   OverviewController* overview_controller = Shell::Get()->overview_controller();
   const WMEvent snap_primary_two_third(WM_EVENT_SNAP_PRIMARY,
                                        chromeos::kTwoThirdSnapRatio);
-  WindowState::Get(window.get())->OnWMEvent(&snap_primary_two_third);
-  // Enter tablet mode and verify that overview is open and the window and
+  WindowState::Get(window1.get())->OnWMEvent(&snap_primary_two_third);
+  // Enter tablet mode and verify that overview opens and the window and
   // divider are at 2/3.
   CreateTabletModeWindowManager();
   EXPECT_TRUE(overview_controller->InOverviewSession());
-  EXPECT_TRUE(split_view_controller()->IsWindowInSplitView(window.get()));
+  EXPECT_TRUE(split_view_controller()->IsWindowInSplitView(window1.get()));
   const gfx::Rect work_area_bounds =
       display::Screen::GetScreen()->GetPrimaryDisplay().work_area();
-  gfx::Rect divider_bounds =
-      split_view_controller()->split_view_divider()->GetDividerBoundsInScreen(
-          /*is_dragging=*/false);
-  ASSERT_NEAR(work_area_bounds.width() * 0.67f, window->bounds().width(),
-              divider_bounds.width());
-  ASSERT_NEAR(work_area_bounds.width() * 0.67f, divider_bounds.x(),
-              divider_bounds.width());
+  int divider_origin_x = split_view_controller()
+                             ->split_view_divider()
+                             ->GetDividerBoundsInScreen(
+                                 /*is_dragging=*/false)
+                             .x();
+  const int divider_delta = kSplitviewDividerShortSideLength / 2;
+  EXPECT_EQ(std::round(work_area_bounds.width() * chromeos::kTwoThirdSnapRatio),
+            window1->bounds().width() + divider_delta);
+  EXPECT_EQ(std::round(work_area_bounds.width() * chromeos::kTwoThirdSnapRatio),
+            divider_origin_x + divider_delta);
   // Exit tablet mode and verify the window stays in the same position.
   DestroyTabletModeWindowManager();
-  EXPECT_EQ(work_area_bounds.width() * 0.67f, window->bounds().width());
+  EXPECT_EQ(std::round(work_area_bounds.width() * chromeos::kTwoThirdSnapRatio),
+            window1->bounds().width());
 
-  // 2. Create another window and snap to secondary 1/3.
+  // 2. Create another window and snap to secondary at 1/3.
   auto window2 = CreateTestWindow();
   const WMEvent snap_secondary_one_third(WM_EVENT_SNAP_SECONDARY,
                                          chromeos::kOneThirdSnapRatio);
   WindowState::Get(window2.get())->OnWMEvent(&snap_secondary_one_third);
-  EXPECT_EQ(work_area_bounds.width() * 0.33f, window2->bounds().width());
+  EXPECT_EQ(std::round(work_area_bounds.width() * chromeos::kOneThirdSnapRatio),
+            window2->bounds().width());
   // Enter tablet mode and verify the windows are in splitview and the window
   // bounds and divider are at 2/3.
   CreateTabletModeWindowManager();
-  EXPECT_TRUE(split_view_controller()->IsWindowInSplitView(window.get()));
+  EXPECT_TRUE(split_view_controller()->IsWindowInSplitView(window1.get()));
   EXPECT_TRUE(split_view_controller()->IsWindowInSplitView(window2.get()));
-  divider_bounds =
-      split_view_controller()->split_view_divider()->GetDividerBoundsInScreen(
-          /*is_dragging=*/false);
-  ASSERT_NEAR(work_area_bounds.width() * 0.67f, window->bounds().width(),
-              divider_bounds.width());
-  ASSERT_NEAR(work_area_bounds.width() * 0.33f, window2->bounds().width(),
-              divider_bounds.width());
-  ASSERT_NEAR(work_area_bounds.width() * 0.67f, divider_bounds.x(),
-              divider_bounds.width());
-  // Exit tablet mode and verify the windows are the same.
+  divider_origin_x = split_view_controller()
+                         ->split_view_divider()
+                         ->GetDividerBoundsInScreen(
+                             /*is_dragging=*/false)
+                         .x();
+
+  EXPECT_EQ(std::round(work_area_bounds.width() * chromeos::kTwoThirdSnapRatio),
+            window1->bounds().width() + divider_delta);
+  EXPECT_EQ(std::round(work_area_bounds.width() * chromeos::kOneThirdSnapRatio),
+            window2->bounds().width() + divider_delta);
+  EXPECT_EQ(
+      std::round(work_area_bounds.width() * chromeos::kTwoThirdSnapRatio) -
+          divider_delta,
+      divider_origin_x);
+
+  // Exit tablet mode and verify the windows are still at 2/3, with allowance
+  // for the divider width since it is only there in tablet mode.
   DestroyTabletModeWindowManager();
-  EXPECT_EQ(work_area_bounds.width() * 0.67f, window->bounds().width());
-  EXPECT_EQ(work_area_bounds.width() * 0.33f, window2->bounds().width());
+  EXPECT_EQ(std::round(work_area_bounds.width() * chromeos::kTwoThirdSnapRatio),
+            window1->bounds().width());
+  EXPECT_EQ(std::round(work_area_bounds.width() * chromeos::kOneThirdSnapRatio),
+            window2->bounds().width());
 }
 
 // Test that when switching from clamshell mode to tablet mode, if overview mode
