@@ -82,8 +82,9 @@ class ResizeLoopWindowObserver : public aura::WindowObserver {
   ResizeLoopWindowObserver& operator=(const ResizeLoopWindowObserver&) = delete;
 
   ~ResizeLoopWindowObserver() override {
-    if (window_)
+    if (window_) {
       window_->RemoveObserver(this);
+    }
   }
 
   bool in_resize_loop() const { return in_resize_loop_; }
@@ -1186,6 +1187,35 @@ TEST_F(ToplevelWindowEventHandlerTest, ExplicitDragWithChildWindow) {
   EXPECT_EQ(gfx::Rect(41, 21, 100, 100), w1->bounds());
 }
 
+// Test that if a display is detached during dragging, the drag will be ended.
+TEST_F(ToplevelWindowEventHandlerTest, DetachDisplayDuringDragging) {
+  UpdateDisplay("800x600,1200x800");
+  aura::Window::Windows root_windows = Shell::GetAllRootWindows();
+  ASSERT_EQ(2U, root_windows.size());
+  const display::Display display1 =
+      display::Screen::GetScreen()->GetDisplayNearestWindow(root_windows[1]);
+
+  // Move the window to the second display and start drag the window.
+  std::unique_ptr<aura::Window> dragged_window(CreateWindow(HTCAPTION));
+  dragged_window->SetBoundsInScreen(gfx::Rect(900, 0, 50, 60), display1);
+  EXPECT_EQ(dragged_window->GetRootWindow(), root_windows[1]);
+
+  ui::test::EventGenerator generator(root_windows[1], dragged_window.get());
+  generator.PressLeftButton();
+  generator.MoveMouseBy(20, 10);
+
+  EXPECT_TRUE(WindowState::Get(dragged_window.get())->is_dragged());
+  ToplevelWindowEventHandler* event_handler =
+      Shell::Get()->toplevel_window_event_handler();
+  EXPECT_TRUE(event_handler->is_drag_in_progress());
+  EXPECT_EQ(dragged_window->GetRootWindow(), root_windows[1]);
+
+  // Detach the display.
+  UpdateDisplay("800x600");
+  base::RunLoop().RunUntilIdle();
+  EXPECT_FALSE(WindowState::Get(dragged_window.get())->is_dragged());
+}
+
 namespace {
 
 // Provides common setup and convenience for a handful of tests.
@@ -1235,26 +1265,6 @@ class ToplevelWindowEventHandlerDragTest : public AshTestBase {
 
 }  // namespace
 
-// In tablet mode, the window's resizability shouldn't be taken into account
-// when dragging from the top. Regression test for https://crbug.com/1444132
-TEST_F(ToplevelWindowEventHandlerDragTest,
-       NonResizableWindowsCanBeDraggedInTabletMode) {
-  TabletModeControllerTestApi().EnterTabletMode();
-
-  dragged_window_->SetProperty(aura::client::kResizeBehaviorKey,
-                               aura::client::kResizeBehaviorNone);
-
-  SendGestureEvent(gfx::Point(100, 0), 0, 5, ui::ET_GESTURE_SCROLL_BEGIN);
-  SendGestureEvent(gfx::Point(600, 500), 600, 500,
-                   ui::ET_GESTURE_SCROLL_UPDATE);
-  EXPECT_TRUE(WindowState::Get(dragged_window_.get())->is_dragged());
-
-  OverviewController* overview_controller = Shell::Get()->overview_controller();
-  EXPECT_TRUE(overview_controller->InOverviewSession());
-  EXPECT_TRUE(overview_controller->overview_session()->IsWindowInOverview(
-      non_dragged_window_.get()));
-}
-
 // Contrary to tablet mode, in non-tablet mode, non resizable windows cannot be
 // dragged.
 TEST_F(ToplevelWindowEventHandlerDragTest,
@@ -1287,29 +1297,6 @@ TEST_F(ToplevelWindowEventHandlerDragTest, WindowDestroyedDuringDragging) {
   EXPECT_FALSE(event_handler->is_drag_in_progress());
 }
 
-// Test that if window destroyed during resize/dragging in tablet mode, no crash
-// should happen.
-TEST_F(ToplevelWindowEventHandlerDragTest,
-       WindowDestroyedDuringDraggingInTabletMode) {
-  TabletModeControllerTestApi().EnterTabletMode();
-
-  SendGestureEvent(gfx::Point(0, 0), 0, 5, ui::ET_GESTURE_SCROLL_BEGIN);
-  SendGestureEvent(gfx::Point(700, 500), 700, 500,
-                   ui::ET_GESTURE_SCROLL_UPDATE);
-  EXPECT_TRUE(WindowState::Get(dragged_window_.get())->is_dragged());
-  ToplevelWindowEventHandler* event_handler =
-      Shell::Get()->toplevel_window_event_handler();
-  EXPECT_TRUE(event_handler->is_drag_in_progress());
-  OverviewController* overview_controller = Shell::Get()->overview_controller();
-  EXPECT_TRUE(overview_controller->InOverviewSession());
-  EXPECT_FALSE(overview_controller->overview_session()->IsWindowInOverview(
-      dragged_window_.get()));
-
-  dragged_window_.reset();
-  EXPECT_FALSE(event_handler->is_drag_in_progress());
-  EXPECT_TRUE(overview_controller->InOverviewSession());
-}
-
 // Showing the resize shadows when the mouse is over the window edges is
 // tested in resize_shadow_and_cursor_test.cc
 
