@@ -7,17 +7,25 @@
 #include <memory>
 #include <utility>
 
+#include "ash/style/ash_color_id.h"
 #include "ash/style/ash_color_provider.h"
+#include "ash/wm/overview/overview_constants.h"
 #include "ash/wm/window_preview_view.h"
-#include "ash/wm/wm_highlight_item_border.h"
+#include "chromeos/constants/chromeos_features.h"
 #include "chromeos/ui/base/window_properties.h"
 #include "ui/accessibility/ax_enums.mojom.h"
 #include "ui/accessibility/ax_node_data.h"
 #include "ui/aura/client/aura_constants.h"
 #include "ui/aura/window.h"
 #include "ui/base/metadata/metadata_impl_macros.h"
+#include "ui/chromeos/styles/cros_tokens_color_mappings.h"
 #include "ui/compositor/layer.h"
+#include "ui/gfx/geometry/insets.h"
+#include "ui/gfx/geometry/rounded_corners_f.h"
 #include "ui/gfx/image/image_skia_operations.h"
+#include "ui/views/background.h"
+#include "ui/views/controls/focus_ring.h"
+#include "ui/views/controls/highlight_path_generator.h"
 #include "ui/views/controls/image_view.h"
 #include "ui/views/controls/label.h"
 #include "ui/views/layout/box_layout.h"
@@ -34,6 +42,10 @@ constexpr int kLabelFontDelta = 2;
 // Values of the backdrop.
 constexpr int kBackdropBorderRoundingDp = 4;
 
+constexpr int kFocusRingCornerRadius = 20;
+
+constexpr gfx::Insets kHeaderInsets = gfx::Insets::TLBR(0, 10, 0, 10);
+
 std::u16string GetWindowTitle(aura::Window* window) {
   aura::Window* transient_root = wm::GetTransientRoot(window);
   const std::u16string* overview_title =
@@ -51,18 +63,30 @@ constexpr gfx::Size WindowMiniView::kIconSize;
 constexpr int WindowMiniView::kHeaderPaddingDp;
 
 void WindowMiniView::SetBackdropVisibility(bool visible) {
-  if (!backdrop_view_ && !visible)
+  if (!backdrop_view_ && !visible) {
     return;
+  }
 
   if (!backdrop_view_) {
-    backdrop_view_ = AddChildView(std::make_unique<views::View>());
-    backdrop_view_->SetPaintToLayer(ui::LAYER_SOLID_COLOR);
+    // Always put the backdrop view under other children.
+    backdrop_view_ = AddChildViewAt(std::make_unique<views::View>(), 0);
+    backdrop_view_->SetPaintToLayer();
+    backdrop_view_->SetBackground(views::CreateThemedSolidBackground(
+        chromeos::features::IsJellyrollEnabled()
+            ? cros_tokens::kCrosSysScrim
+            : static_cast<ui::ColorId>(
+                  kColorAshControlBackgroundColorInactive)));
+
     ui::Layer* layer = backdrop_view_->layer();
     layer->SetFillsBoundsOpaquely(false);
-    layer->SetColor(AshColorProvider::Get()->GetControlsLayerColor(
-        AshColorProvider::ControlsLayerType::kControlBackgroundColorInactive));
-    layer->SetRoundedCornerRadius(
-        gfx::RoundedCornersF(kBackdropBorderRoundingDp));
+
+    const gfx::RoundedCornersF rounded_corder_radius =
+        chromeos::features::IsJellyrollEnabled()
+            ? gfx::RoundedCornersF(0, 0, kWindowMiniViewCornerRadius,
+                                   kWindowMiniViewCornerRadius)
+            : gfx::RoundedCornersF(kBackdropBorderRoundingDp);
+
+    layer->SetRoundedCornerRadius(rounded_corder_radius);
     layer->SetIsFastRoundedCorner(true);
     backdrop_view_->SetCanProcessEventsWithinSubtree(false);
     Layout();
@@ -71,8 +95,9 @@ void WindowMiniView::SetBackdropVisibility(bool visible) {
 }
 
 void WindowMiniView::SetShowPreview(bool show) {
-  if (show == !!preview_view_)
+  if (show == !!preview_view_) {
     return;
+  }
 
   if (!show) {
     RemoveChildView(preview_view_);
@@ -81,8 +106,9 @@ void WindowMiniView::SetShowPreview(bool show) {
     return;
   }
 
-  if (!source_window_)
+  if (!source_window_) {
     return;
+  }
 
   preview_view_ = AddChildView(std::make_unique<WindowPreviewView>(
       source_window_,
@@ -93,22 +119,45 @@ void WindowMiniView::SetShowPreview(bool show) {
 }
 
 void WindowMiniView::UpdatePreviewRoundedCorners(bool show) {
-  if (!preview_view())
+  if (!preview_view()) {
     return;
+  }
 
   ui::Layer* layer = preview_view()->layer();
   DCHECK(layer);
   const float scale = layer->transform().To2dScale().x();
   const float rounding = views::LayoutProvider::Get()->GetCornerRadiusMetric(
       views::Emphasis::kLow);
-  const gfx::RoundedCornersF radii(show ? rounding / scale : 0.0f);
+  gfx::RoundedCornersF radii;
+
+  if (!show) {
+    radii = gfx::RoundedCornersF();
+  } else {
+    if (chromeos::features::IsJellyrollEnabled()) {
+      // Corner radius is applied to the previw view only if the
+      // `backdrop_view_` is not visible.
+      if (backdrop_view_ && backdrop_view_->GetVisible()) {
+        radii = gfx::RoundedCornersF();
+      } else {
+        radii = gfx::RoundedCornersF(0, 0, kWindowMiniViewCornerRadius / scale,
+                                     kWindowMiniViewCornerRadius / scale);
+      }
+    } else {
+      radii = gfx::RoundedCornersF(rounding / scale);
+    }
+  }
+
   layer->SetRoundedCornerRadius(radii);
   layer->SetIsFastRoundedCorner(true);
 }
 
-void WindowMiniView::UpdateBorderState(bool show) {
-  border_ptr_->SetFocused(show);
-  SchedulePaint();
+void WindowMiniView::UpdateFocusState(bool focus) {
+  if (is_focused_ == focus) {
+    return;
+  }
+
+  is_focused_ = focus;
+  views::FocusRing::Get(this)->SchedulePaint();
 }
 
 gfx::Rect WindowMiniView::GetHeaderBounds() const {
@@ -122,19 +171,35 @@ gfx::Size WindowMiniView::GetPreviewViewSize() const {
   return preview_view_->GetPreferredSize();
 }
 
-WindowMiniView::WindowMiniView(aura::Window* source_window)
+WindowMiniView::WindowMiniView(aura::Window* source_window, int border_inset)
     : source_window_(source_window) {
   SetPaintToLayer();
   layer()->SetFillsBoundsOpaquely(false);
 
+  // TODO(conniekxu|sammiequon): Remove the border once the calculation method
+  // for the bounds of the OverviewItemView is redone.
+  SetBorder(views::CreateEmptyBorder(gfx::Insets(border_inset)));
+
   window_observation_.Observe(source_window);
 
   header_view_ = AddChildView(std::make_unique<views::View>());
   header_view_->SetPaintToLayer();
   header_view_->layer()->SetFillsBoundsOpaquely(false);
+
+  gfx::Insets header_insets(0);
+  if (chromeos::features::IsJellyrollEnabled()) {
+    header_view_->SetBackground(views::CreateThemedRoundedRectBackground(
+        chromeos::features::IsJellyrollEnabled()
+            ? cros_tokens::kCrosSysHeader
+            : static_cast<ui::ColorId>(kColorAshShieldAndBase80),
+        /*top_radius=*/kWindowMiniViewCornerRadius,
+        /*bottom_radius=*/0, /*for_border_thickness=*/0));
+    header_insets = kHeaderInsets;
+  }
+
   views::BoxLayout* layout =
       header_view_->SetLayoutManager(std::make_unique<views::BoxLayout>(
-          views::BoxLayout::Orientation::kHorizontal, gfx::Insets(),
+          views::BoxLayout::Orientation::kHorizontal, header_insets,
           kHeaderPaddingDp));
 
   title_label_ = header_view_->AddChildView(
@@ -146,10 +211,17 @@ WindowMiniView::WindowMiniView(aura::Window* source_window)
       kLabelFontDelta, gfx::Font::NORMAL, gfx::Font::Weight::MEDIUM));
   layout->SetFlexForView(title_label_, 1);
 
-  auto border =
-      std::make_unique<WmHighlightItemBorder>(kBackdropBorderRoundingDp);
-  border_ptr_ = border.get();
-  SetBorder(std::move(border));
+  // In order to show the focus ring out of the content view, `border_inset`
+  // needs to be counted when setting the insets for the focus ring.
+  views::InstallRoundRectHighlightPathGenerator(
+      this, gfx::Insets(kFocusRingHaloInset + border_inset),
+      chromeos::features::IsJellyrollEnabled() ? kFocusRingCornerRadius
+                                               : kBackdropBorderRoundingDp);
+  views::FocusRing::Install(this);
+  views::FocusRing* focus_ring = views::FocusRing::Get(this);
+  focus_ring->SetColorId(ui::kColorAshFocusRing);
+  focus_ring->SetHasFocusPredicate(
+      [&](views::View* view) { return is_focused_; });
 }
 
 void WindowMiniView::UpdateIconView() {
@@ -157,10 +229,12 @@ void WindowMiniView::UpdateIconView() {
   aura::Window* transient_root = wm::GetTransientRoot(source_window_);
   // Prefer kAppIconKey over kWindowIconKey as the app icon is typically larger.
   gfx::ImageSkia* icon = transient_root->GetProperty(aura::client::kAppIconKey);
-  if (!icon || icon->size().IsEmpty())
+  if (!icon || icon->size().IsEmpty()) {
     icon = transient_root->GetProperty(aura::client::kWindowIconKey);
-  if (!icon)
+  }
+  if (!icon) {
     return;
+  }
 
   if (!icon_view_) {
     icon_view_ =
@@ -179,8 +253,9 @@ gfx::Rect WindowMiniView::GetContentAreaBounds() const {
 
 void WindowMiniView::Layout() {
   const gfx::Rect content_area_bounds = GetContentAreaBounds();
-  if (backdrop_view_)
+  if (backdrop_view_) {
     backdrop_view_->SetBoundsRect(content_area_bounds);
+  }
 
   if (preview_view_) {
     gfx::Rect preview_bounds = content_area_bounds;
@@ -189,6 +264,7 @@ void WindowMiniView::Layout() {
   }
 
   header_view_->SetBoundsRect(GetHeaderBounds());
+  views::View::Layout();
 }
 
 void WindowMiniView::GetAccessibleNodeData(ui::AXNodeData* node_data) {
@@ -196,8 +272,9 @@ void WindowMiniView::GetAccessibleNodeData(ui::AXNodeData* node_data) {
   // shortly by the owner (OverviewItem/WindowCycleView) but there may be a
   // small window where `source_window_` is null. Speculative fix for
   // https://crbug.com/1274775.
-  if (!source_window_)
+  if (!source_window_) {
     return;
+  }
 
   node_data->role = ax::mojom::Role::kWindow;
   node_data->SetName(wm::GetTransientRoot(source_window_)->GetTitle());
@@ -214,15 +291,17 @@ void WindowMiniView::OnWindowPropertyChanged(aura::Window* window,
                                              intptr_t old) {
   // Update the icon if it changes in the middle of an overview or alt tab
   // session (due to device scale factor change or other).
-  if (key != aura::client::kAppIconKey && key != aura::client::kWindowIconKey)
+  if (key != aura::client::kAppIconKey && key != aura::client::kWindowIconKey) {
     return;
+  }
 
   UpdateIconView();
 }
 
 void WindowMiniView::OnWindowDestroying(aura::Window* window) {
-  if (window != source_window_)
+  if (window != source_window_) {
     return;
+  }
 
   window_observation_.Reset();
   source_window_ = nullptr;
