@@ -11,6 +11,7 @@
 #include "ash/constants/ash_features.h"
 #include "ash/metrics/pip_uma.h"
 #include "ash/public/cpp/shell_window_ids.h"
+#include "ash/public/cpp/window_properties.h"
 #include "ash/root_window_controller.h"
 #include "ash/scoped_animation_disabler.h"
 #include "ash/screen_util.h"
@@ -23,10 +24,7 @@
 #include "ash/wm/float/tablet_mode_float_window_resizer.h"
 #include "ash/wm/overview/overview_controller.h"
 #include "ash/wm/pip/pip_window_resizer.h"
-#include "ash/wm/tablet_mode/tablet_mode_browser_window_drag_delegate.h"
 #include "ash/wm/tablet_mode/tablet_mode_controller.h"
-#include "ash/wm/tablet_mode/tablet_mode_window_drag_delegate.h"
-#include "ash/wm/tablet_mode/tablet_mode_window_resizer.h"
 #include "ash/wm/toplevel_window_event_handler.h"
 #include "ash/wm/window_animations.h"
 #include "ash/wm/window_positioning_utils.h"
@@ -284,8 +282,9 @@ void MaybeRecordResizeHandleUsage(aura::Window* window,
                                   const gfx::PointF& location_in_parent) {
   gfx::Rect* resize_bounds_in_pip =
       window->GetProperty(kWindowPipResizeHandleBoundsKey);
-  if (!resize_bounds_in_pip)
+  if (!resize_bounds_in_pip) {
     return;
+  }
 
   gfx::Point point_in_pip = gfx::ToRoundedPoint(location_in_parent);
   aura::Window::ConvertPointToTarget(window->parent(), window, &point_in_pip);
@@ -311,68 +310,15 @@ std::unique_ptr<WindowResizer> CreateWindowResizerForTabletMode(
     return std::make_unique<TabletModeFloatWindowResizer>(window_state);
   }
 
-  // Window dragging from top and tab dragging are disabled if "WebUITabStrip"
-  // feature is enabled. "WebUITabStrip" will be enabled on 81 for Krane and on
-  // 82 for all other boards.
-  if (features::IsWebUITabStripEnabled())
-    return nullptr;
-
-  // Only maximized/fullscreen/snapped window can be dragged from the top of
-  // the screen.
-  if (!window_state->IsMaximized() && !window_state->IsFullscreen() &&
-      !window_state->IsSnapped()) {
-    return nullptr;
-  }
-
-  AppType app_type =
-      static_cast<AppType>(window->GetProperty(aura::client::kAppType));
-  // App windows can be dragged from the client area (see
-  // ToplevelWindowEventHandler).
-  if (app_type != AppType::BROWSER && app_type != AppType::LACROS &&
-      window_component == HTCLIENT) {
-    DCHECK_EQ(source, ::wm::WINDOW_MOVE_SOURCE_TOUCH);
-    window_state->CreateDragDetails(point_in_parent, HTCLIENT,
-                                    ::wm::WINDOW_MOVE_SOURCE_TOUCH);
-    std::unique_ptr<WindowResizer> window_resizer =
-        std::make_unique<TabletModeWindowResizer>(
-            window_state, std::make_unique<TabletModeWindowDragDelegate>());
-    return std::make_unique<DragWindowResizer>(std::move(window_resizer),
-                                               window_state);
-  }
-
-  // Only allow drag that happens on caption or top area. Note: for a maximized
-  // or fullscreen window, the window component here is always HTCAPTION, but
-  // for a snapped window, the window component here can either be HTCAPTION or
-  // HTTOP.
-  if (window_component != HTCAPTION && window_component != HTTOP)
-    return nullptr;
-
-  // Note: only browser windows and chrome app windows are included here.
-  // For browser windows, this piece of codes will be called no matter the
-  // drag happens on the tab(s) or on the non-tabstrip caption or top area.
-  // But for app window, this piece of codes will only be called if the chrome
-  // app window has its customized caption area and can't be hidden in tablet
-  // mode (and thus the drag for this type of chrome app window always happens
-  // on caption or top area). The case where the caption area of the chrome app
-  // window can be hidden is handled above.
-  if (app_type != AppType::BROWSER && app_type != AppType::CHROME_APP &&
-      app_type != AppType::LACROS)
-    return nullptr;
-
-  window_state->CreateDragDetails(point_in_parent, window_component, source);
-  std::unique_ptr<WindowResizer> window_resizer =
-      std::make_unique<TabletModeWindowResizer>(
-          window_state,
-          std::make_unique<TabletModeBrowserWindowDragDelegate>());
-  return std::make_unique<DragWindowResizer>(std::move(window_resizer),
-                                             window_state);
+  return nullptr;
 }
 
 // When dragging, drags events have to moved pass this threshold before the
 // window bounds start changing.
 int GetDraggingThreshold(const DragDetails& details) {
-  if (details.window_component != HTCAPTION)
+  if (details.window_component != HTCAPTION) {
     return 0;
+  }
 
   WindowStateType state = details.initial_state_type;
 #if DCHECK_IS_ON()
@@ -393,8 +339,9 @@ int GetDraggingThreshold(const DragDetails& details) {
 
 void ResetFrameRestoreLookKey(WindowState* window_state) {
   aura::Window* window = window_state->window();
-  if (window->GetProperty(kFrameRestoreLookKey))
+  if (window->GetProperty(kFrameRestoreLookKey)) {
     window->SetProperty(kFrameRestoreLookKey, false);
+  }
 }
 
 // Returns a work area that excludes area that can trigger snaps.
@@ -407,8 +354,9 @@ gfx::Rect GetNonSnapWorkArea(const display::Display& display,
   // component reducing work area on that edge.
   // 1. Add tolerance to maximize triggering area, which is also shared with
   // top snap area for vertical snap.
-  if (area.y() == display.bounds().y())
+  if (area.y() == display.bounds().y()) {
     insets.set_top(kScreenEdgeInsetForSnappingTop);
+  }
 
   // 2. Add tolerance to left and right snap area for horizontal snap, or
   // bottom snap area for vertical snap.
@@ -416,10 +364,12 @@ gfx::Rect GetNonSnapWorkArea(const display::Display& display,
     // Without the left shelf, i.e. the left edge of work area aligns with that
     // of the display, add snap area tolerance to the left edge. On contrary,
     // users need to drag pass the right edge of the left shelf to trigger snap.
-    if (area.x() == display.bounds().x())
+    if (area.x() == display.bounds().x()) {
       insets.set_left(kScreenEdgeInsetForSnappingSides);
-    if (area.right() == display.bounds().right())
+    }
+    if (area.right() == display.bounds().right()) {
       insets.set_right(kScreenEdgeInsetForSnappingSides);
+    }
   } else {
     // Always add tolerance for bottom snapping work area regardless of whether
     // there is any bottom component that alters work area or not to reduce
@@ -444,10 +394,12 @@ DragTriggerArea GetActiveDragAreaForSnapAndMaximize(
   // if the location is far left beyond the left edge of |non_snap_area| of
   // landscape display, the drag is in |DragTriggerArea::kLeft| snappable area.
   if (is_horizontal) {
-    if (location_in_screen.x() <= non_snap_area.x())
+    if (location_in_screen.x() <= non_snap_area.x()) {
       return DragTriggerArea::kLeft;
-    if (location_in_screen.x() >= non_snap_area.right() - 1)
+    }
+    if (location_in_screen.x() >= non_snap_area.right() - 1) {
       return DragTriggerArea::kRight;
+    }
   } else if (location_in_screen.y() >= non_snap_area.bottom() - 1) {
     return DragTriggerArea::kBottom;
   }
@@ -473,8 +425,9 @@ WorkspaceWindowResizer::SnapType GetSnapType(
 
   // In snap horizontal orientation, i.e. no snap top, triggering top area only
   // triggers maximize.
-  if (is_horizontal && drag_area == DragTriggerArea::kTop)
+  if (is_horizontal && drag_area == DragTriggerArea::kTop) {
     return WorkspaceWindowResizer::SnapType::kMaximize;
+  }
 
   switch (drag_area) {
     case DragTriggerArea::kLeft:
@@ -516,13 +469,15 @@ void CrossFadeAnimation(aura::Window* window,
 bool IsTransitionFromTopToMaximize(WorkspaceWindowResizer::SnapType from_type,
                                    WorkspaceWindowResizer::SnapType to_type,
                                    const display::Display& display) {
-  if (to_type != WorkspaceWindowResizer::SnapType::kMaximize)
+  if (to_type != WorkspaceWindowResizer::SnapType::kMaximize) {
     return false;
+  }
 
   const chromeos::OrientationType orientation =
       GetSnapDisplayOrientation(display);
-  if (chromeos::IsLandscapeOrientation(orientation))
+  if (chromeos::IsLandscapeOrientation(orientation)) {
     return false;
+  }
 
   const bool is_primary = chromeos::IsPrimaryOrientation(orientation);
   return is_primary ? from_type == WorkspaceWindowResizer::SnapType::kPrimary
@@ -542,14 +497,18 @@ std::unique_ptr<WindowResizer> CreateWindowResizer(
   DCHECK(window_state);
 
   // A resizer already exists; don't create a new one.
-  if (window_state->drag_details())
+  if (window_state->drag_details()) {
     return nullptr;
+  }
 
-  // When running in single app mode or not in an active user session, we
-  // should not create window resizer.
+  // When running in single app mode and open a resizable window or not in an
+  // active user session, we should not create window resizer.
+  // Note: a resizable window in single app mode means a kiosk
+  // troubleshooting tool window, it should be movable and resizable.
   SessionControllerImpl* session_controller =
       Shell::Get()->session_controller();
-  if (session_controller->IsRunningInAppMode() ||
+  if ((session_controller->IsRunningInAppMode() &&
+       !window_state->CanResize()) ||
       session_controller->GetSessionState() !=
           session_manager::SessionState::ACTIVE) {
     return nullptr;
@@ -567,8 +526,9 @@ std::unique_ptr<WindowResizer> CreateWindowResizer(
   }
 
   // No need to return a resizer when the window cannot get resized.
-  if (!window_state->CanResize() && window_component != HTCAPTION)
+  if (!window_state->CanResize() && window_component != HTCAPTION) {
     return nullptr;
+  }
 
   const bool maximized = window_state->IsMaximized();
   if (!maximized && !window_state->IsNormalOrSnapped() &&
@@ -588,8 +548,9 @@ std::unique_ptr<WindowResizer> CreateWindowResizer(
 
   int bounds_change =
       WindowResizer::GetBoundsChangeForWindowComponent(window_component);
-  if (bounds_change == WindowResizer::kBoundsChangeDirection_None)
+  if (bounds_change == WindowResizer::kBoundsChangeDirection_None) {
     return nullptr;
+  }
 
   window_state->CreateDragDetails(point_in_parent, window_component, source);
 
@@ -627,10 +588,12 @@ class WindowSize {
  public:
   WindowSize(int size, int min, int max) : size_(size), min_(min), max_(max) {
     // Grow the min/max bounds to include the starting size.
-    if (is_underflowing())
+    if (is_underflowing()) {
       min_ = size_;
-    if (is_overflowing())
+    }
+    if (is_overflowing()) {
       max_ = size_;
+    }
   }
 
   bool is_at_capacity(bool shrinking) const {
@@ -678,11 +641,13 @@ class WindowSize {
 constexpr int WorkspaceWindowResizer::kMinOnscreenHeight;
 
 WorkspaceWindowResizer::~WorkspaceWindowResizer() {
-  if (did_lock_cursor_)
+  if (did_lock_cursor_) {
     Shell::Get()->cursor_manager()->UnlockCursor();
+  }
 
-  if (instance == this)
+  if (instance == this) {
     instance = nullptr;
+  }
 }
 
 // static
@@ -735,12 +700,14 @@ void WorkspaceWindowResizer::Drag(const gfx::PointF& location_in_parent,
             base::WeakPtr<WorkspaceWindowResizer> resizer(
                 weak_ptr_factory_.GetWeakPtr());
             window_state()->window()->SetProperty(kFrameRestoreLookKey, true);
-            if (!resizer)
+            if (!resizer) {
               return;
+            }
             CrossFadeAnimation(window_state()->window(), bounds,
                                /*maximize=*/false);
-            if (!resizer)
+            if (!resizer) {
               return;
+            }
 
             base::RecordAction(
                 base::UserMetricsAction("WindowDrag_Unmaximize"));
@@ -754,8 +721,9 @@ void WorkspaceWindowResizer::Drag(const gfx::PointF& location_in_parent,
     did_move_or_resize_ = true;
   }
 
-  if (!attached_windows_.empty())
+  if (!attached_windows_.empty()) {
     LayoutAttachedWindows(&bounds);
+  }
   if (bounds != GetTarget()->bounds()) {
     // SetBounds needs to be called to update the layout which affects where the
     // phantom window is drawn. Keep track if the window was destroyed during
@@ -763,8 +731,9 @@ void WorkspaceWindowResizer::Drag(const gfx::PointF& location_in_parent,
     base::WeakPtr<WorkspaceWindowResizer> resizer(
         weak_ptr_factory_.GetWeakPtr());
     SetBoundsDuringResize(bounds);
-    if (!resizer)
+    if (!resizer) {
       return;
+    }
   }
 
   if (tab_dragging_recorder_) {
@@ -785,8 +754,9 @@ void WorkspaceWindowResizer::Drag(const gfx::PointF& location_in_parent,
   // continue performing any snap or maximize logic. Otherwise, resize top edge
   // to the top of display will fire maximize |dwell_countdown_timer_|
   // (crbug.com/1251859).
-  if (details().window_component != HTCAPTION)
+  if (details().window_component != HTCAPTION) {
     return;
+  }
 
   gfx::PointF location_in_screen = location_in_parent;
   ::wm::ConvertPointToScreen(GetTarget()->parent(), &location_in_screen);
@@ -807,7 +777,7 @@ void WorkspaceWindowResizer::Drag(const gfx::PointF& location_in_parent,
           gfx::ToRoundedPoint(location_in_screen));
   const SnapType snap_type = GetSnapType(display, location_in_screen);
   // Start dwell countdown if move window to the top of screen.
-  if (IsSnapTopOrMaximize(snap_type)) {
+  if (IsSnapTopOrMaximize(snap_type, display)) {
     if (can_snap_to_maximize_) {
       const bool drag_passed_threshold =
           dwell_location_in_screen_.has_value() &&
@@ -817,7 +787,7 @@ void WorkspaceWindowResizer::Drag(const gfx::PointF& location_in_parent,
       // snap before setting a timer for maximize phantom to show up.
       if (!snap_phantom_window_controller_ &&
           snap_type != SnapType::kMaximize) {
-        UpdateSnapPhantomWindow(snap_type);
+        UpdateSnapPhantomWindow(snap_type, display);
       }
 
       // Start maximize phantom window dwell time if it is not already running
@@ -829,8 +799,8 @@ void WorkspaceWindowResizer::Drag(const gfx::PointF& location_in_parent,
             FROM_HERE,
             snap_type != SnapType::kMaximize ? kDwellLongTime : kDwellTime,
             base::BindOnce(&WorkspaceWindowResizer::UpdateSnapPhantomWindow,
-                           weak_ptr_factory_.GetWeakPtr(),
-                           SnapType::kMaximize));
+                           weak_ptr_factory_.GetWeakPtr(), SnapType::kMaximize,
+                           display));
         // Cancel maximization if drag passed threshold.
         // Window can still be maximized in next dwell cycle if stays at top of
         // display.
@@ -842,7 +812,7 @@ void WorkspaceWindowResizer::Drag(const gfx::PointF& location_in_parent,
     }
     dwell_location_in_screen_ = location_in_screen;
   } else {
-    UpdateSnapPhantomWindow(snap_type);
+    UpdateSnapPhantomWindow(snap_type, display);
     if (dwell_countdown_timer_.IsRunning()) {
       dwell_countdown_timer_.Stop();
     }
@@ -858,8 +828,9 @@ void WorkspaceWindowResizer::CompleteDrag() {
   window_state()->OnCompleteDrag(last_location_in_screen);
   EndDragForAttachedWindows(/*revert_drag=*/false);
 
-  if (!did_move_or_resize_)
+  if (!did_move_or_resize_) {
     return;
+  }
 
   ResetFrameRestoreLookKey(window_state());
   window_state()->set_bounds_changed_by_user(true);
@@ -868,8 +839,9 @@ void WorkspaceWindowResizer::CompleteDrag() {
   // If the window's state type changed over the course of the drag do not snap
   // the window. This happens when the user minimizes or maximizes the window
   // using a keyboard shortcut while dragging it.
-  if (window_state()->GetStateType() != details().initial_state_type)
+  if (window_state()->GetStateType() != details().initial_state_type) {
     return;
+  }
 
   // Update window state if the window has been snapped.
   if (snap_type_ != SnapType::kNone) {
@@ -878,9 +850,9 @@ void WorkspaceWindowResizer::CompleteDrag() {
       // parent's bounds and would not put window to different display.
       gfx::Rect bounds = details().source == ::wm::WINDOW_MOVE_SOURCE_TOUCH
                              ? restore_bounds_for_gesture_
-                             : details().restore_bounds_in_parent.IsEmpty()
-                                   ? details().initial_bounds_in_parent
-                                   : details().restore_bounds_in_parent;
+                         : details().restore_bounds_in_parent.IsEmpty()
+                             ? details().initial_bounds_in_parent
+                             : details().restore_bounds_in_parent;
       window_state()->SetRestoreBoundsInParent(bounds);
     }
 
@@ -924,7 +896,7 @@ void WorkspaceWindowResizer::CompleteDrag() {
         NOTREACHED();
         type = WM_EVENT_MAXIMIZE;
         break;
-    };
+    }
 
     const WMEvent event(type);
     window_state()->OnWMEvent(&event);
@@ -1001,8 +973,9 @@ void WorkspaceWindowResizer::RevertDrag() {
   window_state()->set_bounds_changed_by_user(initial_bounds_changed_by_user_);
   snap_phantom_window_controller_.reset();
 
-  if (!did_move_or_resize_)
+  if (!did_move_or_resize_) {
     return;
+  }
 
   ResetFrameRestoreLookKey(window_state());
   GetTarget()->SetBounds(details().initial_bounds_in_parent);
@@ -1063,10 +1036,12 @@ void WorkspaceWindowResizer::FlingOrSwipe(ui::GestureEvent* event) {
   } else {
     DCHECK_EQ(event->type(), ui::ET_GESTURE_SWIPE);
     DCHECK_GT(event->details().touch_points(), 0);
-    if (event->details().touch_points() == 1)
+    if (event->details().touch_points() == 1) {
       return;
-    if (!WindowState::Get(GetTarget())->IsNormalOrSnapped())
+    }
+    if (!WindowState::Get(GetTarget())->IsNormalOrSnapped()) {
       return;
+    }
 
     CompleteDrag();
 
@@ -1140,8 +1115,9 @@ WorkspaceWindowResizer::WorkspaceWindowResizer(
   // and clear gesture states. See https://crbug.com/1162541.
   const gfx::Rect parent_local_bounds(
       window_state->window()->parent()->bounds().size());
-  if (!parent_local_bounds.Intersects(restore_bounds_for_gesture_))
+  if (!parent_local_bounds.Intersects(restore_bounds_for_gesture_)) {
     restore_bounds_for_gesture_.AdjustToFit(parent_local_bounds);
+  }
 
   std::unique_ptr<ash::PresentationTimeRecorder> recorder =
       window_state->OnDragStarted(details().window_component);
@@ -1188,10 +1164,11 @@ void WorkspaceWindowResizer::LayoutAttachedWindows(gfx::Rect* bounds) {
   // attached windows can grow without exceeding their max size constraints.
   // Adding the pixels back to the main window effectively prevents the main
   // window from resizing too far.
-  if (details().window_component == HTRIGHT)
+  if (details().window_component == HTRIGHT) {
     bounds->set_width(bounds->width() + leftovers);
-  else
+  } else {
     bounds->set_height(bounds->height() + leftovers);
+  }
 
   DCHECK_EQ(attached_windows_.size(), sizes.size());
   int last = PrimaryAxisCoordinate(bounds->right(), bounds->bottom());
@@ -1221,8 +1198,9 @@ int WorkspaceWindowResizer::CalculateAttachedSizes(
   if (delta > 0) {
     // If the attached windows don't fit when at their initial size, we will
     // have to shrink them by how much they overflow.
-    if (total_initial_size_ >= available_size)
+    if (total_initial_size_ >= available_size) {
       grow_attached_by = available_size - total_initial_size_;
+    }
   } else {
     // If we're shrinking, we grow the attached so the total size remains
     // constant.
@@ -1239,8 +1217,9 @@ int WorkspaceWindowResizer::CalculateAttachedSizes(
     grow_attached_by = leftovers;
   }
 
-  for (size_t i = 0; i < window_sizes.size(); ++i)
-    sizes->push_back(window_sizes[i].size());
+  for (const auto& window_size : window_sizes) {
+    sizes->push_back(window_size.size());
+  }
 
   return leftover_pixels;
 }
@@ -1249,10 +1228,10 @@ int WorkspaceWindowResizer::GrowFairly(int pixels,
                                        std::vector<WindowSize>* sizes) const {
   bool shrinking = pixels < 0;
   std::vector<WindowSize*> nonfull_windows;
-  for (size_t i = 0; i < sizes->size(); ++i) {
-    WindowSize& current_window_size = (*sizes)[i];
-    if (!current_window_size.is_at_capacity(shrinking))
+  for (auto& current_window_size : *sizes) {
+    if (!current_window_size.is_at_capacity(shrinking)) {
       nonfull_windows.push_back(&current_window_size);
+    }
   }
   std::vector<float> ratios;
   CalculateGrowthRatios(nonfull_windows, &ratios);
@@ -1262,8 +1241,9 @@ int WorkspaceWindowResizer::GrowFairly(int pixels,
   for (size_t i = 0; i < nonfull_windows.size(); ++i) {
     int grow_by = pixels * ratios[i];
     // Put any leftover pixels into the last window.
-    if (i == nonfull_windows.size() - 1 && add_leftover_pixels_to_last)
+    if (i == nonfull_windows.size() - 1 && add_leftover_pixels_to_last) {
       grow_by = remaining_pixels;
+    }
     int remainder = nonfull_windows[i]->Add(grow_by);
     int consumed = grow_by - remainder;
     remaining_pixels -= consumed;
@@ -1284,11 +1264,13 @@ void WorkspaceWindowResizer::CalculateGrowthRatios(
     std::vector<float>* out_ratios) const {
   DCHECK(out_ratios->empty());
   int total_value = 0;
-  for (size_t i = 0; i < sizes.size(); ++i)
-    total_value += sizes[i]->size();
+  for (auto* size : sizes) {
+    total_value += size->size();
+  }
 
-  for (size_t i = 0; i < sizes.size(); ++i)
-    out_ratios->push_back((static_cast<float>(sizes[i]->size())) / total_value);
+  for (auto* size : sizes) {
+    out_ratios->push_back((static_cast<float>(size->size())) / total_value);
+  }
 }
 
 void WorkspaceWindowResizer::CreateBucketsForAttached(
@@ -1359,8 +1341,9 @@ bool WorkspaceWindowResizer::UpdateMagnetismWindow(
 
   // Avoid magnetically snapping windows that are not resizable.
   // TODO(oshima): change this to window.type() == TYPE_NORMAL.
-  if (!window_state()->CanResize())
+  if (!window_state()->CanResize()) {
     return false;
+  }
 
   // Check the child windows of the root of the display in which the mouse
   // cursor is. It doesn't make sense to do magnetism with windows on other
@@ -1375,12 +1358,14 @@ bool WorkspaceWindowResizer::UpdateMagnetismWindow(
   for (auto i = children.rbegin();
        i != children.rend() && !matcher.AreEdgesObscured(); ++i) {
     // Ignore already attached windows.
-    if (base::Contains(attached_windows_, *i))
+    if (base::Contains(attached_windows_, *i)) {
       continue;
+    }
 
     WindowState* other_state = WindowState::Get(*i);
-    if (!other_state)
+    if (!other_state) {
       continue;
+    }
 
     if (other_state->window() == GetTarget() ||
         !other_state->window()->IsVisible() ||
@@ -1424,18 +1409,21 @@ void WorkspaceWindowResizer::AdjustBoundsForMainWindow(int sticky_size,
     if (sticky_size > 0) {
       // Possibly stick to edge except when a mouse pointer is outside the
       // work area.
-      if (display.work_area().Contains(last_location_in_screen))
+      if (display.work_area().Contains(last_location_in_screen)) {
         StickToWorkAreaOnMove(work_area, sticky_size, bounds);
+      }
       MagneticallySnapToOtherWindows(display, bounds);
     }
   } else if (sticky_size > 0) {
     MagneticallySnapResizeToOtherWindows(display, bounds);
-    if (!magnetism_window_ && sticky_size > 0)
+    if (!magnetism_window_ && sticky_size > 0) {
       StickToWorkAreaOnResize(work_area, sticky_size, bounds);
+    }
   }
 
-  if (attached_windows_.empty())
+  if (attached_windows_.empty()) {
     return;
+  }
 
   if (details().window_component == HTRIGHT) {
     bounds->set_width(std::min(bounds->width(),
@@ -1521,10 +1509,13 @@ int WorkspaceWindowResizer::PrimaryAxisCoordinate(int x, int y) const {
   return 0;
 }
 
-bool WorkspaceWindowResizer::IsSnapTopOrMaximize(SnapType type) const {
-  if (type == SnapType::kMaximize)
+bool WorkspaceWindowResizer::IsSnapTopOrMaximize(
+    SnapType type,
+    const display::Display& display) const {
+  if (type == SnapType::kMaximize) {
     return true;
-  switch (GetSnapDisplayOrientation(GetDisplay())) {
+  }
+  switch (GetSnapDisplayOrientation(display)) {
     case chromeos::OrientationType::kPortraitPrimary:
       return type == SnapType::kPrimary;
     case chromeos::OrientationType::kPortraitSecondary:
@@ -1535,11 +1526,14 @@ bool WorkspaceWindowResizer::IsSnapTopOrMaximize(SnapType type) const {
 }
 
 void WorkspaceWindowResizer::UpdateSnapPhantomWindow(
-    const SnapType target_snap_type) {
-  if (snap_type_ == target_snap_type)
+    const SnapType target_snap_type,
+    const display::Display& display) {
+  if (snap_type_ == target_snap_type) {
     return;
-  if (!did_move_or_resize_ || details().window_component != HTCAPTION)
+  }
+  if (!did_move_or_resize_ || details().window_component != HTCAPTION) {
     return;
+  }
 
   SnapType last_type = snap_type_;
   snap_type_ = target_snap_type;
@@ -1553,12 +1547,13 @@ void WorkspaceWindowResizer::UpdateSnapPhantomWindow(
   }
 
   const bool is_top_to_maximize =
-      IsTransitionFromTopToMaximize(last_type, snap_type_, GetDisplay());
+      IsTransitionFromTopToMaximize(last_type, snap_type_, display);
   // Reset the controller if switching snap types unless we want to transform
   // snap top to maximize so that we can have a fade in show animation when
   // switching to the new snap type.
-  if (snap_type_ != last_type && !is_top_to_maximize)
+  if (snap_type_ != last_type && !is_top_to_maximize) {
     snap_phantom_window_controller_.reset();
+  }
 
   // Update phantom window with snapped guide bounds.
   if (!snap_phantom_window_controller_) {
@@ -1567,18 +1562,16 @@ void WorkspaceWindowResizer::UpdateSnapPhantomWindow(
   }
 
   gfx::Rect phantom_bounds;
-  const display::Display display = GetDisplay();
-
   switch (snap_type_) {
     case SnapType::kPrimary:
       phantom_bounds = GetSnappedWindowBounds(
-          display.work_area(), display, GetTarget(),
-          ash::SnapViewType::kPrimary, kDefaultSnapRatio);
+          display.work_area(), display, GetTarget(), SnapViewType::kPrimary,
+          chromeos::kDefaultSnapRatio);
       break;
     case SnapType::kSecondary:
       phantom_bounds = GetSnappedWindowBounds(
-          display.work_area(), display, GetTarget(),
-          ash::SnapViewType::kSecondary, kDefaultSnapRatio);
+          display.work_area(), display, GetTarget(), SnapViewType::kSecondary,
+          chromeos::kDefaultSnapRatio);
       break;
     case SnapType::kMaximize:
       phantom_bounds = display.work_area();
@@ -1601,8 +1594,8 @@ void WorkspaceWindowResizer::UpdateSnapPhantomWindow(
   } else {
     snap_phantom_window_controller_->Show(phantom_bounds);
     // Show the maximize cue on top-snap phantom.
-    if (IsSnapTopOrMaximize(snap_type_) && snap_type_ != SnapType::kMaximize &&
-        snap_type_ != last_type) {
+    if (IsSnapTopOrMaximize(snap_type_, display) &&
+        snap_type_ != SnapType::kMaximize && snap_type_ != last_type) {
       snap_phantom_window_controller_->ShowMaximizeCue();
     }
   }
@@ -1616,8 +1609,9 @@ void WorkspaceWindowResizer::UpdateSnapPhantomWindow(
 }
 
 void WorkspaceWindowResizer::RestackWindows() {
-  if (attached_windows_.empty())
+  if (attached_windows_.empty()) {
     return;
+  }
   // Build a map from index in children to window, returning if there is a
   // window with a different parent.
   using IndexToWindowMap = std::map<size_t, aura::Window*>;
@@ -1625,11 +1619,13 @@ void WorkspaceWindowResizer::RestackWindows() {
   aura::Window* parent = GetTarget()->parent();
   const std::vector<aura::Window*>& windows(parent->children());
   map[base::ranges::find(windows, GetTarget()) - windows.begin()] = GetTarget();
-  for (auto i = attached_windows_.begin(); i != attached_windows_.end(); ++i) {
-    if ((*i)->parent() != parent)
+  for (auto* attached_window : attached_windows_) {
+    if (attached_window->parent() != parent) {
       return;
-    size_t index = base::ranges::find(windows, *i) - windows.begin();
-    map[index] = *i;
+    }
+    size_t index =
+        base::ranges::find(windows, attached_window) - windows.begin();
+    map[index] = attached_window;
   }
 
   // Reorder the windows starting at the topmost.
@@ -1637,8 +1633,9 @@ void WorkspaceWindowResizer::RestackWindows() {
   for (auto i = map.rbegin(); i != map.rend();) {
     aura::Window* window = i->second;
     ++i;
-    if (i != map.rend())
+    if (i != map.rend()) {
       parent->StackChildBelow(i->second, window);
+    }
   }
 }
 
@@ -1652,16 +1649,18 @@ WorkspaceWindowResizer::SnapType WorkspaceWindowResizer::GetSnapType(
   switch (snap_type) {
     case SnapType::kPrimary:
     case SnapType::kSecondary:
-      if (!window_state()->CanSnapOnDisplay(display))
+      if (!window_state()->CanSnapOnDisplay(display)) {
         snap_type = SnapType::kNone;
+      }
       break;
     case SnapType::kMaximize:
-      if (!window_state()->CanMaximize() || !can_snap_to_maximize_)
+      if (!window_state()->CanMaximize() || !can_snap_to_maximize_) {
         snap_type = SnapType::kNone;
+      }
       break;
     case SnapType::kNone:
       break;
-  };
+  }
   return snap_type;
 }
 
@@ -1675,7 +1674,8 @@ bool WorkspaceWindowResizer::AreBoundsValidSnappedBounds(
   SnapViewType snapped_type = state_type == WindowStateType::kPrimarySnapped
                                   ? SnapViewType::kPrimary
                                   : SnapViewType::kSecondary;
-  const float snap_ratio = state->snap_ratio().value_or(kDefaultSnapRatio);
+  const float snap_ratio =
+      state->snap_ratio().value_or(chromeos::kDefaultSnapRatio);
   gfx::Rect snapped_bounds = GetSnappedWindowBounds(
       screen_util::GetDisplayWorkAreaBoundsInParent(window),
       display::Screen::GetScreen()->GetDisplayNearestWindow(window), window,
@@ -1730,8 +1730,9 @@ void WorkspaceWindowResizer::SetWindowStateTypeFromGesture(
 }
 
 void WorkspaceWindowResizer::StartDragForAttachedWindows() {
-  if (attached_windows_.empty())
+  if (attached_windows_.empty()) {
     return;
+  }
 
   // The component of the attached windows is always the opposite component of
   // the main window.
@@ -1739,10 +1740,11 @@ void WorkspaceWindowResizer::StartDragForAttachedWindows() {
   DCHECK(main_window_component == HTRIGHT || main_window_component == HTBOTTOM);
 
   int window_component = HTNOWHERE;
-  if (main_window_component == HTRIGHT)
+  if (main_window_component == HTRIGHT) {
     window_component = HTLEFT;
-  else if (main_window_component == HTBOTTOM)
+  } else if (main_window_component == HTBOTTOM) {
     window_component = HTTOP;
+  }
   DCHECK(window_component == HTLEFT || window_component == HTTOP);
 
   for (auto* window : attached_windows_) {
@@ -1755,33 +1757,19 @@ void WorkspaceWindowResizer::StartDragForAttachedWindows() {
 }
 
 void WorkspaceWindowResizer::EndDragForAttachedWindows(bool revert_drag) {
-  if (attached_windows_.empty())
+  if (attached_windows_.empty()) {
     return;
+  }
 
   for (auto* window : attached_windows_) {
     WindowState* window_state = WindowState::Get(window);
-    if (revert_drag)
+    if (revert_drag) {
       window_state->OnRevertDrag(last_location_in_parent_);
-    else
+    } else {
       window_state->OnCompleteDrag(last_location_in_parent_);
+    }
     window_state->DeleteDragDetails();
   }
 }
 
-display::Display WorkspaceWindowResizer::GetDisplay() const {
-  display::Screen* screen = display::Screen::GetScreen();
-  display::Display display;
-  if (details().source == ::wm::WINDOW_MOVE_SOURCE_TOUCH) {
-    display = screen->GetDisplayNearestWindow(GetTarget());
-  } else {
-    // The |Display| object returned by |CursorManager::GetDisplay| may be
-    // stale, but will have the correct id.
-    // TODO(oshima): Change the API so |GetDisplay| just returns a display id.
-    screen->GetDisplayWithDisplayId(
-        Shell::Get()->cursor_manager()->GetDisplay().id(), &display);
-  }
-  DCHECK(display.is_valid());
-  return display;
-}
-
 }  // namespace ash
