@@ -131,15 +131,17 @@ class ASH_EXPORT WorkspaceWindowResizer : public WindowResizer {
   int PrimaryAxisSize(const gfx::Size& size) const;
   int PrimaryAxisCoordinate(int x, int y) const;
 
-  // From a given snap |type| and a current display orientation, returns true
-  // if the snap is snap top or maximize. This function is used to decide if
-  // we need to show the phantom window for top snap or maximize or not.
-  bool IsSnapTopOrMaximize(SnapType type) const;
+  // From a given snap |type| and the current |display|, returns true if the
+  // snap is snap top or maximize. This function is used to decide if we need
+  // to show the phantom window for top snap or maximize or not.
+  bool IsSnapTopOrMaximize(SnapType type,
+                           const display::Display& display) const;
 
   // Updates the bounds of the phantom window where the snap bounds are
   // calculated from GetSnappedWindowBounds() given a |target_snap_type| and
-  // maximize bounds is from full display work area.
-  void UpdateSnapPhantomWindow(const SnapType target_snap_type);
+  // maximize bounds is from the current |display|'s full work area.
+  void UpdateSnapPhantomWindow(const SnapType target_snap_type,
+                               const display::Display& display);
 
   // Restacks the windows z-order position so that one of the windows is at the
   // top of the z-order, and the rest directly underneath it.
@@ -165,10 +167,6 @@ class ASH_EXPORT WorkspaceWindowResizer : public WindowResizer {
   void StartDragForAttachedWindows();
   void EndDragForAttachedWindows(bool revert_drag);
 
-  // Gets the display associated with GetTarget() if touch dragging. Gets the
-  // display associated with the cursor if mouse dragging.
-  display::Display GetDisplay() const;
-
   WindowState* window_state() { return window_state_; }
   const WindowState* window_state() const { return window_state_; }
 
