@@ -9,23 +9,25 @@
 #include "base/allocator/partition_allocator/starscan/pcscan.h"
 
 #include "base/allocator/partition_allocator/partition_alloc-inl.h"
-#include "base/allocator/partition_allocator/partition_alloc.h"
 #include "base/allocator/partition_allocator/partition_alloc_base/compiler_specific.h"
 #include "base/allocator/partition_allocator/partition_alloc_base/cpu.h"
 #include "base/allocator/partition_allocator/partition_alloc_base/logging.h"
+#include "base/allocator/partition_allocator/partition_alloc_buildflags.h"
 #include "base/allocator/partition_allocator/partition_alloc_config.h"
 #include "base/allocator/partition_allocator/partition_alloc_constants.h"
+#include "base/allocator/partition_allocator/partition_alloc_for_testing.h"
 #include "base/allocator/partition_allocator/partition_root.h"
 #include "base/allocator/partition_allocator/starscan/stack/stack.h"
 #include "base/allocator/partition_allocator/tagging.h"
 #include "build/build_config.h"
 #include "testing/gtest/include/gtest/gtest.h"
 
-#if PA_CONFIG(ALLOW_PCSCAN)
+#if BUILDFLAG(USE_STARSCAN)
 
 namespace partition_alloc::internal {
 
 namespace {
+
 struct DisableStackScanningScope final {
   DisableStackScanningScope() {
     if (PCScan::IsStackScanningEnabled()) {
@@ -34,13 +36,15 @@ struct DisableStackScanningScope final {
     }
   }
   ~DisableStackScanningScope() {
-    if (changed_)
+    if (changed_) {
       PCScan::EnableStackScanning();
+    }
   }
 
  private:
   bool changed_ = false;
 };
+
 }  // namespace
 
 class PartitionAllocPCScanTestBase : public testing::Test {
@@ -100,11 +104,13 @@ class PartitionAllocPCScanTestBase : public testing::Test {
 
  private:
   // Leverage the already-templated version outside `internal::`.
-  partition_alloc::PartitionAllocator allocator_;
+  partition_alloc::PartitionAllocatorAllowLeaksForTesting allocator_;
 };
 
+namespace {
+
 // The test that expects free() being quarantined only when tag overflow occurs.
-class PartitionAllocPCScanWithMTETest : public PartitionAllocPCScanTestBase {};
+using PartitionAllocPCScanWithMTETest = PartitionAllocPCScanTestBase;
 
 // The test that expects every free() being quarantined.
 class PartitionAllocPCScanTest : public PartitionAllocPCScanTestBase {
@@ -115,8 +121,6 @@ class PartitionAllocPCScanTest : public PartitionAllocPCScanTestBase {
   }
 };
 
-namespace {
-
 using SlotSpan = ThreadSafePartitionRoot::SlotSpan;
 
 struct FullSlotSpanAllocation {
@@ -203,8 +207,6 @@ struct List final : ListBase {
   }
 };
 
-}  // namespace
-
 TEST_F(PartitionAllocPCScanTest, ArbitraryObjectInQuarantine) {
   using ListType = List<8>;
 
@@ -240,8 +242,6 @@ TEST_F(PartitionAllocPCScanTest, LastObjectInQuarantine) {
   EXPECT_TRUE(IsInQuarantine(full_slot_span.last));
 }
 
-namespace {
-
 template <typename SourceList, typename ValueList>
 void TestDanglingReference(PartitionAllocPCScanTest& test,
                            SourceList* source,
@@ -285,8 +285,6 @@ void TestDanglingReferenceNotVisited(PartitionAllocPCScanTest& test,
   EXPECT_TRUE(IsInFreeList(value_root.ObjectToSlotStart(value)));
 }
 
-}  // namespace
-
 TEST_F(PartitionAllocPCScanTest, DanglingReferenceSameBucket) {
   using SourceList = List<8>;
   using ValueList = SourceList;
@@ -411,8 +409,6 @@ TEST_F(PartitionAllocPCScanTest, DanglingReferenceFromFullPage) {
   TestDanglingReference(*this, source, value, root());
 }
 
-namespace {
-
 template <size_t Size>
 struct ListWithInnerReference {
   char buffer1[Size];
@@ -432,8 +428,6 @@ struct ListWithInnerReference {
   }
 };
 
-}  // namespace
-
 // Disabled due to consistent failure http://crbug.com/1242407
 #if BUILDFLAG(IS_ANDROID)
 #define MAYBE_DanglingInnerReference DISABLED_DanglingInnerReference
@@ -587,7 +581,6 @@ TEST_F(PartitionAllocPCScanTest, DoubleFree) {
 #endif  // PA_CONFIG(STARSCAN_EAGER_DOUBLE_FREE_DETECTION_ENABLED)
 #endif  // defined(GTEST_HAS_DEATH_TEST) && !BUILDFLAG(IS_ANDROID)
 
-namespace {
 template <typename SourceList, typename ValueList>
 void TestDanglingReferenceWithSafepoint(PartitionAllocPCScanTest& test,
                                         SourceList* source,
@@ -628,7 +621,6 @@ void TestDanglingReferenceWithSafepoint(PartitionAllocPCScanTest& test,
     EXPECT_TRUE(IsInFreeList(test.root().ObjectToSlotStart(value)));
   }
 }
-}  // namespace
 
 TEST_F(PartitionAllocPCScanTest, Safepoint) {
   using SourceList = List<64>;
@@ -643,49 +635,65 @@ TEST_F(PartitionAllocPCScanTest, Safepoint) {
   TestDanglingReferenceWithSafepoint(*this, source, value, root());
 }
 
-TEST_F(PartitionAllocPCScanTest, StackScanning) {
-  using ValueList = List<8>;
-
-  PCScan::EnableStackScanning();
-
-  static void* dangling_reference = nullptr;
-  // Set to nullptr if the test is retried.
-  dangling_reference = nullptr;
-
-  // Create and set dangling reference in the global.
-  [this]() PA_NOINLINE {
+class PartitionAllocPCScanStackScanningTest : public PartitionAllocPCScanTest {
+ protected:
+  // Creates and sets a dangling reference in `dangling_reference_`.
+  PA_NOINLINE void CreateDanglingReference() {
+    using ValueList = List<8>;
     auto* value = ValueList::Create(root(), nullptr);
     ValueList::Destroy(root(), value);
-    dangling_reference = value;
-  }();
+    dangling_reference_ = value;
+  }
 
-  [this]() PA_NOINLINE {
+  PA_NOINLINE void SetupAndRunTest() {
     // Register the top of the stack to be the current pointer.
     PCScan::NotifyThreadCreated(GetStackPointer());
-    [this]() PA_NOINLINE {
-      // This writes the pointer to the stack.
-      [[maybe_unused]] auto* volatile stack_ref = dangling_reference;
-      // Call the non-inline function that would scan the stack. Don't execute
-      // the rest of the actions inside the function, since otherwise it would
-      // be tail-call optimized and the parent frame's stack with the dangling
-      // pointer would be missed.
-      [this]() PA_NOINLINE {
-        // Schedule PCScan but don't scan.
-        SchedulePCScan();
-        // Enter safepoint and scan from mutator. This will scan the stack.
-        JoinPCScanAsMutator();
-      }();
-      // Check that the object is still quarantined since it's referenced by
-      // |dangling_reference|.
-      EXPECT_TRUE(IsInQuarantine(dangling_reference));
-      // Check that value is not in the freelist.
-      EXPECT_FALSE(IsInFreeList(root().ObjectToSlotStart(dangling_reference)));
-      // Run sweeper.
-      FinishPCScanAsScanner();
-      // Check that |dangling_reference| still exists.
-      EXPECT_FALSE(IsInFreeList(root().ObjectToSlotStart(dangling_reference)));
-    }();
-  }();
+    RunTest();
+  }
+
+  PA_NOINLINE void RunTest() {
+    // This writes the pointer to the stack.
+    [[maybe_unused]] auto* volatile stack_ref = dangling_reference_;
+    // Call the non-inline function that would scan the stack. Don't execute
+    // the rest of the actions inside the function, since otherwise it would
+    // be tail-call optimized and the parent frame's stack with the dangling
+    // pointer would be missed.
+    ScanStack();
+    // Check that the object is still quarantined since it's referenced by
+    // |dangling_reference_|.
+    EXPECT_TRUE(IsInQuarantine(dangling_reference_));
+    // Check that value is not in the freelist.
+    EXPECT_FALSE(IsInFreeList(root().ObjectToSlotStart(dangling_reference_)));
+    // Run sweeper.
+    FinishPCScanAsScanner();
+    // Check that |dangling_reference_| still exists.
+    EXPECT_FALSE(IsInFreeList(root().ObjectToSlotStart(dangling_reference_)));
+  }
+
+  PA_NOINLINE void ScanStack() {
+    // Schedule PCScan but don't scan.
+    SchedulePCScan();
+    // Enter safepoint and scan from mutator. This will scan the stack.
+    JoinPCScanAsMutator();
+  }
+
+  static void* dangling_reference_;
+};
+
+// static
+void* PartitionAllocPCScanStackScanningTest::dangling_reference_ = nullptr;
+
+// The test currently fails on some platform due to the stack dangling reference
+// not being found.
+TEST_F(PartitionAllocPCScanStackScanningTest, DISABLED_StackScanning) {
+  PCScan::EnableStackScanning();
+
+  // Set to nullptr if the test is retried.
+  dangling_reference_ = nullptr;
+
+  CreateDanglingReference();
+
+  SetupAndRunTest();
 }
 
 TEST_F(PartitionAllocPCScanTest, DontScanUnusedRawSize) {
@@ -861,7 +869,9 @@ TEST_F(PartitionAllocPCScanWithMTETest, QuarantineOnlyOnTagOverflow) {
 }
 #endif  // PA_CONFIG(HAS_MEMORY_TAGGING)
 
+}  // namespace
+
 }  // namespace partition_alloc::internal
 
-#endif  // PA_CONFIG(ALLOW_PCSCAN)
+#endif  // BUILDFLAG(USE_STARSCAN)
 #endif  // defined(MEMORY_TOOL_REPLACES_ALLOCATOR)
