@@ -12,13 +12,10 @@ import android.content.ContentResolver;
 import android.content.Context;
 import android.content.Intent;
 import android.content.pm.PackageManager;
-import android.content.res.ColorStateList;
 import android.content.res.Resources;
 import android.content.res.Resources.NotFoundException;
 import android.graphics.Bitmap;
-import android.graphics.Color;
 import android.graphics.ImageDecoder;
-import android.graphics.PorterDuff;
 import android.graphics.drawable.Drawable;
 import android.hardware.display.DisplayManager;
 import android.net.Uri;
@@ -28,27 +25,24 @@ import android.os.StrictMode;
 import android.os.UserManager;
 import android.provider.MediaStore;
 import android.provider.Settings;
-import android.text.Html;
-import android.text.Spanned;
-import android.text.TextUtils;
 import android.view.Display;
 import android.view.View;
 import android.view.Window;
 import android.view.WindowManager;
-import android.view.inputmethod.EditorInfo;
-import android.view.inputmethod.InputMethodSubtype;
 import android.view.textclassifier.TextClassifier;
-import android.widget.EditText;
-import android.widget.ImageView;
 import android.widget.TextView;
 
 import androidx.annotation.NonNull;
 import androidx.annotation.Nullable;
+import androidx.annotation.OptIn;
 import androidx.annotation.RequiresApi;
-import androidx.core.widget.ImageViewCompat;
+import androidx.core.os.BuildCompat;
 
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
+import java.lang.reflect.Field;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -117,63 +111,15 @@ public class ApiCompatibilityUtils {
         }
     }
 
-    @RequiresApi(Build.VERSION_CODES.N)
-    private static class ApisN {
-        static String toHtml(Spanned spanned, int option) {
-            return Html.toHtml(spanned, option);
-        }
-
-        // This class is sufficiently small that it's fine if it doesn't verify for N devices.
-        @RequiresApi(Build.VERSION_CODES.N_MR1)
+    // This class is sufficiently small that it's fine if it doesn't verify for N devices.
+    @RequiresApi(Build.VERSION_CODES.N_MR1)
+    private static class ApisNMR1 {
         static boolean isDemoUser() {
             UserManager userManager =
                     (UserManager) ContextUtils.getApplicationContext().getSystemService(
                             Context.USER_SERVICE);
             return userManager.isDemoUser();
         }
-
-        static String getLocale(InputMethodSubtype inputMethodSubType) {
-            return inputMethodSubType.getLanguageTag();
-        }
-
-        static boolean isInMultiWindowMode(Activity activity) {
-            return activity.isInMultiWindowMode();
-        }
-    }
-
-    @RequiresApi(Build.VERSION_CODES.M)
-    private static class ApisM {
-        public static void setStatusBarIconColor(View rootView, boolean useDarkIcons) {
-            int systemUiVisibility = rootView.getSystemUiVisibility();
-            if (useDarkIcons) {
-                systemUiVisibility |= View.SYSTEM_UI_FLAG_LIGHT_STATUS_BAR;
-            } else {
-                systemUiVisibility &= ~View.SYSTEM_UI_FLAG_LIGHT_STATUS_BAR;
-            }
-            rootView.setSystemUiVisibility(systemUiVisibility);
-        }
-    }
-
-    private static class ApisLmr1 {
-        static void setAccessibilityTraversalBefore(View view, int viewFocusedAfter) {
-            view.setAccessibilityTraversalBefore(viewFocusedAfter);
-        }
-    }
-
-    /**
-     * Compares two long values numerically. The value returned is identical to what would be
-     * returned by {@link Long#compare(long, long)} which is available since API level 19.
-     */
-    public static int compareLong(long lhs, long rhs) {
-        return lhs < rhs ? -1 : (lhs == rhs ? 0 : 1);
-    }
-
-    /**
-     * Compares two boolean values. The value returned is identical to what would be returned by
-     * {@link Boolean#compare(boolean, boolean)} which is available since API level 19.
-     */
-    public static int compareBoolean(boolean lhs, boolean rhs) {
-        return lhs == rhs ? 0 : lhs ? 1 : -1;
     }
 
     /**
@@ -204,23 +150,7 @@ public class ApiCompatibilityUtils {
      * UnsupportedEncodingException.
      */
     public static byte[] getBytesUtf8(String str) {
-        try {
-            return str.getBytes("UTF-8");
-        } catch (UnsupportedEncodingException e) {
-            throw new IllegalStateException(e);
-        }
-    }
-
-    /**
-     * @see android.text.Html#toHtml(Spanned, int)
-     * @param option is ignored on below N
-     */
-    @SuppressWarnings("deprecation")
-    public static String toHtml(Spanned spanned, int option) {
-        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
-            return ApisN.toHtml(spanned, option);
-        }
-        return Html.toHtml(spanned);
+        return str.getBytes(StandardCharsets.UTF_8);
     }
 
     /**
@@ -245,16 +175,7 @@ public class ApiCompatibilityUtils {
      * @see android.view.Window#setStatusBarColor(int color).
      */
     public static void setStatusBarColor(Window window, int statusBarColor) {
-        // If both system bars are black, we can remove these from our layout,
-        // removing or shrinking the SurfaceFlinger overlay required for our views.
-        // This benefits battery usage on L and M.  However, this no longer provides a battery
-        // benefit as of N and starts to cause flicker bugs on O, so don't bother on O and up.
-        if (Build.VERSION.SDK_INT < Build.VERSION_CODES.O && statusBarColor == Color.BLACK
-                && window.getNavigationBarColor() == Color.BLACK) {
-            window.clearFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS);
-        } else {
-            window.addFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS);
-        }
+        window.addFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS);
         window.setStatusBarColor(statusBarColor);
     }
 
@@ -266,9 +187,13 @@ public class ApiCompatibilityUtils {
      * @param useDarkIcons Whether the status bar icons should be dark.
      */
     public static void setStatusBarIconColor(View rootView, boolean useDarkIcons) {
-        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
-            ApisM.setStatusBarIconColor(rootView, useDarkIcons);
+        int systemUiVisibility = rootView.getSystemUiVisibility();
+        if (useDarkIcons) {
+            systemUiVisibility |= View.SYSTEM_UI_FLAG_LIGHT_STATUS_BAR;
+        } else {
+            systemUiVisibility &= ~View.SYSTEM_UI_FLAG_LIGHT_STATUS_BAR;
         }
+        rootView.setSystemUiVisibility(systemUiVisibility);
     }
 
     /**
@@ -280,23 +205,6 @@ public class ApiCompatibilityUtils {
         return getDrawableForDensity(res, id, 0);
     }
 
-    public static void setImageTintList(ImageView view, @Nullable ColorStateList tintList) {
-        if (Build.VERSION.SDK_INT == Build.VERSION_CODES.LOLLIPOP) {
-            // Work around broken workaround in ImageViewCompat, see
-            // https://crbug.com/891609#c3.
-            if (tintList != null && view.getImageTintMode() == null) {
-                view.setImageTintMode(PorterDuff.Mode.SRC_IN);
-            }
-        }
-        ImageViewCompat.setImageTintList(view, tintList);
-
-        if (Build.VERSION.SDK_INT == Build.VERSION_CODES.LOLLIPOP) {
-            // Work around that the tint list is not cleared when setting tint list to null on L
-            // in some cases. See https://crbug.com/983686.
-            if (tintList == null) view.refreshDrawableState();
-        }
-    }
-
     /**
      * @see android.content.res.Resources#getDrawableForDensity(int id, int density).
      */
@@ -339,7 +247,7 @@ public class ApiCompatibilityUtils {
      * @return Whether the device is running in demo mode.
      */
     public static boolean isDemoUser() {
-        return Build.VERSION.SDK_INT >= Build.VERSION_CODES.N_MR1 && ApisN.isDemoUser();
+        return Build.VERSION.SDK_INT >= Build.VERSION_CODES.N_MR1 && ApisNMR1.isDemoUser();
     }
 
     /**
@@ -356,26 +264,12 @@ public class ApiCompatibilityUtils {
         }
     }
 
-    /**
-     * @see android.view.inputmethod.InputMethodSubType#getLocate()
-     */
-    @SuppressWarnings("deprecation")
-    public static String getLocale(InputMethodSubtype inputMethodSubType) {
-        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
-            return ApisN.getLocale(inputMethodSubType);
-        }
-        return inputMethodSubType.getLocale();
-    }
-
     /**
      * @param activity The {@link Activity} to check.
      * @return Whether or not {@code activity} is currently in Android N+ multi-window mode.
      */
     public static boolean isInMultiWindowMode(Activity activity) {
-        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
-            return ApisN.isInMultiWindowMode(activity);
-        }
-        return false;
+        return activity.isInMultiWindowMode();
     }
 
     /**
@@ -417,39 +311,31 @@ public class ApiCompatibilityUtils {
     }
 
     /**
-     * @see View#setAccessibilityTraversalBefore(int)
+     * Sets the mode {@link ActivityOptions#MODE_BACKGROUND_ACTIVITY_START_ALLOWED} to the
+     * given {@link ActivityOptions}. The options can be used to send {@link PendingIntent}
+     * passed to Chrome from a backgrounded app.
+     * @param options {@ActivityOptions} to set the required mode to.
      */
-    public static void setAccessibilityTraversalBefore(View view, int viewFocusedAfter) {
-        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.LOLLIPOP_MR1) {
-            ApisLmr1.setAccessibilityTraversalBefore(view, viewFocusedAfter);
+    @OptIn(markerClass = androidx.core.os.BuildCompat.PrereleaseSdkCheck.class)
+    public static void setActivityOptionsBackgroundActivityStartMode(
+            @NonNull ActivityOptions options) {
+        if (!BuildCompat.isAtLeastU()) return;
+
+        // options.setPendingIntentBackgroundActivityStartMode(
+        //     ActivityOptions.MODE_BACKGROUND_ACTIVITY_START_ALLOWED);
+        // TODO(crbug.com/1423489): Replace the reflection with the normal API.
+        try {
+            Method method = ActivityOptions.class.getMethod(
+                    "setPendingIntentBackgroundActivityStartMode", int.class);
+            Field field = ActivityOptions.class.getField("MODE_BACKGROUND_ACTIVITY_START_ALLOWED");
+            int mode = field.getInt(null);
+            method.invoke(options, mode);
+        } catch (IllegalAccessException | InvocationTargetException | NoSuchFieldException
+                | NoSuchMethodException | RuntimeException e) {
+            assert false : "PendingIntent from background activity may fail to run.";
         }
     }
 
-    /**
-     * Adds a content description to the provided EditText password field on versions of Android
-     * where the hint text is not used for accessibility. Does nothing if the EditText field does
-     * not have a password input type or the hint text is empty.  See https://crbug.com/911762.
-     *
-     * @param view The EditText password field.
-     */
-    public static void setPasswordEditTextContentDescription(EditText view) {
-        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) return;
-
-        if (isPasswordInputType(view.getInputType()) && !TextUtils.isEmpty(view.getHint())) {
-            view.setContentDescription(view.getHint());
-        }
-    }
-
-    private static boolean isPasswordInputType(int inputType) {
-        final int variation =
-                inputType & (EditorInfo.TYPE_MASK_CLASS | EditorInfo.TYPE_MASK_VARIATION);
-        return variation == (EditorInfo.TYPE_CLASS_TEXT | EditorInfo.TYPE_TEXT_VARIATION_PASSWORD)
-                || variation
-                == (EditorInfo.TYPE_CLASS_TEXT | EditorInfo.TYPE_TEXT_VARIATION_WEB_PASSWORD)
-                || variation
-                == (EditorInfo.TYPE_CLASS_NUMBER | EditorInfo.TYPE_NUMBER_VARIATION_PASSWORD);
-    }
-
     // Access this via ContextUtils.getProcessName().
     @SuppressWarnings("PrivateApi")
     static String getProcessName() {
