@@ -3,18 +3,18 @@
 // found in the LICENSE file.
 
 #include "base/containers/span_rust.h"
-#include "build/rust/rust_buildflags.h"
+#include "base/rust_buildflags.h"
 
 #include "testing/gtest/include/gtest/gtest.h"
 
-#if BUILDFLAG(TOOLCHAIN_HAS_RUST)
+#if BUILDFLAG(BUILD_RUST_BASE_CONVERSIONS)
 
 namespace base {
 namespace {
 
 TEST(BaseSpanRustTest, SliceConstruct) {
   uint8_t data[] = {0, 1, 2, 3, 4};
-  span<const uint8_t> data_span(data, 2);
+  span<const uint8_t> data_span(data, 2u);
   rust::Slice<const uint8_t> rust_slice = SpanToRustSlice(data_span);
   EXPECT_EQ(2ul, rust_slice.length());
   EXPECT_EQ(1, rust_slice[1]);
@@ -23,4 +23,4 @@ TEST(BaseSpanRustTest, SliceConstruct) {
 }  // namespace
 }  // namespace base
 
-#endif  // BUILDFLAG(TOOLCHAIN_HAS_RUST)
+#endif  // BUILDFLAG(BUILD_RUST_BASE_CONVERSIONS)
