@@ -12,8 +12,8 @@
 #include "base/allocator/partition_alloc_features.h"
 #include "base/allocator/partition_alloc_support.h"
 #include "base/allocator/partition_allocator/dangling_raw_ptr_checks.h"
-#include "base/allocator/partition_allocator/partition_alloc.h"
 #include "base/allocator/partition_allocator/partition_alloc_buildflags.h"
+#include "base/allocator/partition_allocator/partition_alloc_for_testing.h"  // nogncheck
 #include "base/functional/callback.h"
 #include "base/functional/disallow_unretained.h"
 #include "base/memory/ptr_util.h"
@@ -1819,53 +1819,53 @@ void HandleOOM(size_t unused_size) {
 // Basic set of options to mostly only enable `BackupRefPtr::kEnabled`.
 // This avoids the boilerplate of having too much options enabled for simple
 // testing purpose.
-static constexpr partition_alloc::PartitionOptions kOpts = {
-    partition_alloc::PartitionOptions::AlignedAlloc::kDisallowed,
-    partition_alloc::PartitionOptions::ThreadCache::kDisabled,
-    partition_alloc::PartitionOptions::Quarantine::kDisallowed,
-    partition_alloc::PartitionOptions::Cookie::kAllowed,
-    partition_alloc::PartitionOptions::BackupRefPtr::kEnabled,
-    partition_alloc::PartitionOptions::BackupRefPtrZapping::kEnabled,
-    partition_alloc::PartitionOptions::UseConfigurablePool::kNo,
+static constexpr partition_alloc::PartitionOptions
+    kOnlyEnableBackupRefPtrOptions = {
+        partition_alloc::PartitionOptions::AlignedAlloc::kDisallowed,
+        partition_alloc::PartitionOptions::ThreadCache::kDisabled,
+        partition_alloc::PartitionOptions::Quarantine::kDisallowed,
+        partition_alloc::PartitionOptions::Cookie::kAllowed,
+        partition_alloc::PartitionOptions::BackupRefPtr::kEnabled,
+        partition_alloc::PartitionOptions::BackupRefPtrZapping::kEnabled,
+        partition_alloc::PartitionOptions::UseConfigurablePool::kNo,
 };
 
 class BindUnretainedDanglingInternalFixture : public BindTest {
  public:
   void SetUp() override {
     partition_alloc::PartitionAllocGlobalInit(HandleOOM);
-    allocator_.init(kOpts);
     enabled_feature_list_.InitWithFeaturesAndParameters(
         {{features::kPartitionAllocUnretainedDanglingPtr, {{"mode", "crash"}}}},
         {/* disabled_features */});
     allocator::InstallUnretainedDanglingRawPtrChecks();
   }
+
   void TearDown() override {
     enabled_feature_list_.Reset();
     allocator::InstallUnretainedDanglingRawPtrChecks();
-    allocator_.root()->PurgeMemory(
-        partition_alloc::PurgeFlags::kDecommitEmptySlotSpans |
-        partition_alloc::PurgeFlags::kDiscardUnusedSystemPages);
-    partition_alloc::PartitionAllocGlobalUninitForTesting();
   }
 
   // In unit tests, allocations being tested need to live in a separate PA
   // root so the test code doesn't interfere with various counters. Following
   // methods are helpers for managing allocations inside the separate allocator
   // root.
-  template <typename T, typename... Args>
-  raw_ptr<T> Alloc(Args&&... args) {
+  template <typename T,
+            RawPtrTraits Traits = RawPtrTraits::kEmpty,
+            typename... Args>
+  raw_ptr<T, Traits> Alloc(Args&&... args) {
     void* ptr = allocator_.root()->Alloc(sizeof(T), "");
     T* p = new (reinterpret_cast<T*>(ptr)) T(std::forward<Args>(args)...);
-    return raw_ptr<T>(p);
+    return raw_ptr<T, Traits>(p);
   }
-  template <typename T>
-  void Free(raw_ptr<T>& ptr) {
+  template <typename T, RawPtrTraits Traits>
+  void Free(raw_ptr<T, Traits>& ptr) {
     allocator_.root()->Free(ptr);
   }
 
  private:
   test::ScopedFeatureList enabled_feature_list_;
-  partition_alloc::PartitionAllocator allocator_;
+  partition_alloc::PartitionAllocatorForTesting allocator_{
+      kOnlyEnableBackupRefPtrOptions};
 };
 
 class BindUnretainedDanglingTest
@@ -1885,6 +1885,11 @@ bool MayBeDanglingCheckFn(MayBeDangling<int> p) {
   return p != nullptr;
 }
 
+bool MayBeDanglingAndDummyTraitCheckFn(
+    MayBeDangling<int, RawPtrTraits::kDummyForTest> p) {
+  return p != nullptr;
+}
+
 class ClassWithWeakPtr {
  public:
   ClassWithWeakPtr() = default;
@@ -1910,6 +1915,25 @@ TEST_F(BindUnretainedDanglingTest, UnsafeDanglingPtr) {
   EXPECT_EQ(std::move(callback).Run(), true);
 }
 
+TEST_F(BindUnretainedDanglingTest, UnsafeDanglingPtrWithDummyTrait) {
+  raw_ptr<int, RawPtrTraits::kDummyForTest> p =
+      Alloc<int, RawPtrTraits::kDummyForTest>(3);
+  auto callback = base::BindOnce(MayBeDanglingAndDummyTraitCheckFn,
+                                 base::UnsafeDangling(p));
+  Free(p);
+  EXPECT_EQ(std::move(callback).Run(), true);
+}
+
+TEST_F(BindUnretainedDanglingTest,
+       UnsafeDanglingPtrWithDummyAndDanglingTraits) {
+  raw_ptr<int, RawPtrTraits::kDummyForTest | RawPtrTraits::kMayDangle> p =
+      Alloc<int, RawPtrTraits::kDummyForTest | RawPtrTraits::kMayDangle>(3);
+  auto callback = base::BindOnce(MayBeDanglingAndDummyTraitCheckFn,
+                                 base::UnsafeDangling(p));
+  Free(p);
+  EXPECT_EQ(std::move(callback).Run(), true);
+}
+
 TEST_F(BindUnretainedDanglingTest, UnsafeDanglingPtrNoRawPtrReceiver) {
   std::unique_ptr<ClassWithWeakPtr> r = std::make_unique<ClassWithWeakPtr>();
   int val = 0;
