@@ -1,4 +1,4 @@
-// Copyright 2018 The Chromium Authors. All rights reserved.
+// Copyright 2018 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,7 +6,8 @@
 
 #include <type_traits>
 
-#include "base/bind.h"
+#include "base/functional/bind.h"
+#include "base/logging.h"
 #include "base/memory/raw_ptr.h"
 #include "base/message_loop/message_pump_for_io.h"
 #include "base/message_loop/message_pump_for_ui.h"
@@ -38,20 +39,99 @@ namespace base {
 
 namespace {
 
+// On most platforms, the MessagePump impl controls when native work (e.g.
+// handling input messages) gets its turn. Tests below verify that by expecting
+// OnBeginWorkItem() calls that cover native work. In some configurations
+// however, the platform owns the message loop and is the one yielding to
+// Chrome's MessagePump to DoWork(). Under those configurations, it is not
+// possible to precisely account for OnBeginWorkItem() calls as they can occur
+// nondeterministically. For example, on some versions of iOS, the native loop
+// can surprisingly go through multiple cycles of
+// kCFRunLoopAfterWaiting=>kCFRunLoopBeforeWaiting before invoking Chrome's
+// RunWork() for the first time, triggering multiple  ScopedDoWorkItem 's for
+// potential native work before the first DoWork().
+constexpr bool ChromeControlsNativeEventProcessing(MessagePumpType pump_type) {
+#if BUILDFLAG(IS_MAC)
+  return pump_type != MessagePumpType::UI;
+#elif BUILDFLAG(IS_IOS)
+  return false;
+#else
+  return true;
+#endif
+}
+
 class MockMessagePumpDelegate : public MessagePump::Delegate {
  public:
-  MockMessagePumpDelegate() = default;
+  explicit MockMessagePumpDelegate(MessagePumpType pump_type)
+      : check_work_items_(ChromeControlsNativeEventProcessing(pump_type)),
+        native_work_item_accounting_is_on_(
+            !ChromeControlsNativeEventProcessing(pump_type)) {}
+
+  ~MockMessagePumpDelegate() override { ValidateNoOpenWorkItems(); }
 
   MockMessagePumpDelegate(const MockMessagePumpDelegate&) = delete;
   MockMessagePumpDelegate& operator=(const MockMessagePumpDelegate&) = delete;
 
-  // MessagePump::Delegate:
   void BeforeWait() override {}
   MOCK_METHOD0(DoWork, MessagePump::Delegate::NextWorkInfo());
   MOCK_METHOD0(DoIdleWork, bool());
 
-  MOCK_METHOD0(OnBeginWorkItem, void(void));
-  MOCK_METHOD0(OnEndWorkItem, void(void));
+  // Functions invoked directly by the message pump.
+  void OnBeginWorkItem() override {
+    any_work_begun_ = true;
+
+    if (check_work_items_) {
+      MockOnBeginWorkItem();
+    }
+
+    ++work_item_count_;
+  }
+
+  void OnEndWorkItem(int run_level_depth) override {
+    if (check_work_items_) {
+      MockOnEndWorkItem(run_level_depth);
+    }
+
+    EXPECT_EQ(run_level_depth, work_item_count_);
+
+    --work_item_count_;
+
+    // It's not possible to close more scopes than there are open ones.
+    EXPECT_GE(work_item_count_, 0);
+  }
+
+  int RunDepth() override { return work_item_count_; }
+
+  void ValidateNoOpenWorkItems() {
+    // Upon exiting there cannot be any open scopes.
+    EXPECT_EQ(work_item_count_, 0);
+
+    if (native_work_item_accounting_is_on_) {
+// Tests should trigger work beginning at least once except on iOS where
+// they need a call to MessagePumpUIApplication::Attach() to do so when on
+// the UI thread.
+#if !BUILDFLAG(IS_IOS)
+      EXPECT_TRUE(any_work_begun_);
+#endif
+    }
+  }
+
+  // Mock functions for asserting.
+  MOCK_METHOD0(MockOnBeginWorkItem, void(void));
+  MOCK_METHOD1(MockOnEndWorkItem, void(int));
+
+  // If native events are covered in the current configuration it's not
+  // possible to precisely test all assertions related to work items. This is
+  // because a number of speculative WorkItems are created during execution of
+  // such loops and it's not possible to determine their number before the
+  // execution of the test. In such configurations the functioning of the
+  // message pump is still verified by looking at the counts of opened and
+  // closed WorkItems.
+  const bool check_work_items_;
+  const bool native_work_item_accounting_is_on_;
+
+  int work_item_count_ = 0;
+  bool any_work_begun_ = false;
 };
 
 class MessagePumpTest : public ::testing::TestWithParam<MessagePumpType> {
@@ -65,31 +145,24 @@ class MessagePumpTest : public ::testing::TestWithParam<MessagePumpType> {
     if (GetParam() == MessagePumpType::UI) {
       // The Windows MessagePumpForUI may do native work from ::PeekMessage()
       // and labels itself as such.
-      EXPECT_CALL(delegate, OnBeginWorkItem);
-      EXPECT_CALL(delegate, OnEndWorkItem);
+      EXPECT_CALL(delegate, MockOnBeginWorkItem);
+      EXPECT_CALL(delegate, MockOnEndWorkItem);
 
       // If the above event was MessagePumpForUI's own kMsgHaveWork internal
       // event, it will process another event to replace it (ref.
       // ProcessPumpReplacementMessage).
-      EXPECT_CALL(delegate, OnBeginWorkItem).Times(AtMost(1));
-      EXPECT_CALL(delegate, OnEndWorkItem).Times(AtMost(1));
+      EXPECT_CALL(delegate, MockOnBeginWorkItem).Times(AtMost(1));
+      EXPECT_CALL(delegate, MockOnEndWorkItem).Times(AtMost(1));
     }
 #endif  // BUILDFLAG(IS_WIN)
   }
 
   void AddPostDoWorkExpectations(
       testing::StrictMock<MockMessagePumpDelegate>& delegate) {
-#if BUILDFLAG(IS_POSIX) && !BUILDFLAG(IS_NACL)
-    if ((GetParam() == MessagePumpType::UI &&
-         std::is_same<MessagePumpForUI, MessagePumpLibevent>::value) ||
-        (GetParam() == MessagePumpType::IO &&
-         std::is_same<MessagePumpForIO, MessagePumpLibevent>::value)) {
-      // MessagePumpLibEvent checks for native notifications once after
-      // processing a DoWork().
-      EXPECT_CALL(delegate, OnBeginWorkItem);
-      EXPECT_CALL(delegate, OnEndWorkItem);
-    }
-#endif  // BUILDFLAG(IS_POSIX) && !BUILDFLAG(IS_NACL)
+    // MessagePumpLibEvent checks for native notifications once after processing
+    // a DoWork() but only instantiates a ScopedDoWorkItem that triggers
+    // MessagePumpLibevent::OnLibeventNotification() which this test does not
+    // so there are no post-work expectations at the moment.
   }
 
   std::unique_ptr<MessagePump> message_pump_;
@@ -99,7 +172,7 @@ class MessagePumpTest : public ::testing::TestWithParam<MessagePumpType> {
 
 TEST_P(MessagePumpTest, QuitStopsWork) {
   testing::InSequence sequence;
-  testing::StrictMock<MockMessagePumpDelegate> delegate;
+  testing::StrictMock<MockMessagePumpDelegate> delegate(GetParam());
 
   AddPreDoWorkExpectations(delegate);
 
@@ -117,8 +190,8 @@ TEST_P(MessagePumpTest, QuitStopsWork) {
 
 TEST_P(MessagePumpTest, QuitStopsWorkWithNestedRunLoop) {
   testing::InSequence sequence;
-  testing::StrictMock<MockMessagePumpDelegate> delegate;
-  testing::StrictMock<MockMessagePumpDelegate> nested_delegate;
+  testing::StrictMock<MockMessagePumpDelegate> delegate(GetParam());
+  testing::StrictMock<MockMessagePumpDelegate> nested_delegate(GetParam());
 
   AddPreDoWorkExpectations(delegate);
 
@@ -160,8 +233,9 @@ TEST_P(MessagePumpTest, YieldToNativeRequestedSmokeTest) {
   // implemented on the MessagePumpForUI on android. However since we inject a
   // fake one for testing this is hard to test. This test ensures that setting
   // this boolean doesn't cause any MessagePump to explode.
+  testing::StrictMock<MockMessagePumpDelegate> delegate(GetParam());
+
   testing::InSequence sequence;
-  testing::StrictMock<MockMessagePumpDelegate> delegate;
 
   // Return an immediate task with |yield_to_native| set.
   AddPreDoWorkExpectations(delegate);
@@ -194,14 +268,16 @@ class TimerSlackTestDelegate : public MessagePump::Delegate {
     // We first schedule a delayed task far in the future with maximum timer
     // slack.
     message_pump_->SetTimerSlack(TIMER_SLACK_MAXIMUM);
-    message_pump_->ScheduleDelayedWork(TimeTicks::Now() + Hours(1));
+    const TimeTicks now = TimeTicks::Now();
+    message_pump_->ScheduleDelayedWork({now + Hours(1), now});
 
     // Since we have no other work pending, the pump will initially be idle.
     action_.store(NONE);
   }
 
   void OnBeginWorkItem() override {}
-  void OnEndWorkItem() override {}
+  void OnEndWorkItem(int run_level_depth) override {}
+  int RunDepth() override { return 0; }
   void BeforeWait() override {}
 
   MessagePump::Delegate::NextWorkInfo DoWork() override {
@@ -273,7 +349,7 @@ TEST_P(MessagePumpTest, TimerSlackWithLongDelays) {
 
 TEST_P(MessagePumpTest, RunWithoutScheduleWorkInvokesDoWork) {
   testing::InSequence sequence;
-  testing::StrictMock<MockMessagePumpDelegate> delegate;
+  testing::StrictMock<MockMessagePumpDelegate> delegate(GetParam());
 
   AddPreDoWorkExpectations(delegate);
 
@@ -289,8 +365,8 @@ TEST_P(MessagePumpTest, RunWithoutScheduleWorkInvokesDoWork) {
 
 TEST_P(MessagePumpTest, NestedRunWithoutScheduleWorkInvokesDoWork) {
   testing::InSequence sequence;
-  testing::StrictMock<MockMessagePumpDelegate> delegate;
-  testing::StrictMock<MockMessagePumpDelegate> nested_delegate;
+  testing::StrictMock<MockMessagePumpDelegate> delegate(GetParam());
+  testing::StrictMock<MockMessagePumpDelegate> nested_delegate(GetParam());
 
   AddPreDoWorkExpectations(delegate);
 
@@ -321,31 +397,4 @@ INSTANTIATE_TEST_SUITE_P(All,
                                            MessagePumpType::UI,
                                            MessagePumpType::IO));
 
-#if BUILDFLAG(IS_WIN)
-
-TEST(MessagePumpTestWin, WmQuitIsNotIgnoredWithEnableWmQuit) {
-  SingleThreadTaskExecutor task_executor(
-      MessagePumpType::UI_WITH_WM_QUIT_SUPPORT);
-
-  // Post a WM_QUIT message to the current thread.
-  ::PostQuitMessage(0);
-
-  // Post a task to the current thread, with a small delay to make it less
-  // likely that we process the posted task before looking for WM_* messages.
-  RunLoop run_loop;
-  task_executor.task_runner()->PostDelayedTask(FROM_HERE,
-                                               BindOnce(
-                                                   [](OnceClosure closure) {
-                                                     ADD_FAILURE();
-                                                     std::move(closure).Run();
-                                                   },
-                                                   run_loop.QuitClosure()),
-                                               TestTimeouts::tiny_timeout());
-
-  // Run the loop. It should not result in ADD_FAILURE() getting called.
-  run_loop.Run();
-}
-
-#endif  // BUILDFLAG(IS_WIN)
-
 }  // namespace base
