@@ -1,4 +1,4 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,9 +6,9 @@
 
 #import <UIKit/UIKit.h>
 
+#include "base/check.h"
 #include "base/command_line.h"
 #include "base/debug/debugger.h"
-#include "base/logging.h"
 #include "base/mac/scoped_nsobject.h"
 #include "base/message_loop/message_pump.h"
 #include "base/message_loop/message_pump_mac.h"
@@ -31,10 +31,32 @@
 // window displaying the app name. If a bunch of apps using MainHook are being
 // run in a row, this provides an indication of which one is currently running.
 
-static base::TestSuite* g_test_suite = NULL;
+static base::RunTestSuiteCallback g_test_suite_callback;
 static int g_argc;
 static char** g_argv;
 
+namespace {
+void PopulateUIWindow(UIWindow* window) {
+  [window setBackgroundColor:[UIColor whiteColor]];
+  [window makeKeyAndVisible];
+  CGRect bounds = [[UIScreen mainScreen] bounds];
+  // Add a label with the app name.
+  UILabel* label = [[[UILabel alloc] initWithFrame:bounds] autorelease];
+  label.text = [[NSProcessInfo processInfo] processName];
+  label.textAlignment = NSTextAlignmentCenter;
+  [window addSubview:label];
+
+  // An NSInternalInconsistencyException is thrown if the app doesn't have a
+  // root view controller. Set an empty one here.
+  [window setRootViewController:[[[UIViewController alloc] init] autorelease]];
+}
+
+bool IsSceneStartupEnabled() {
+  return [[NSBundle mainBundle].infoDictionary
+      objectForKey:@"UIApplicationSceneManifest"];
+}
+}
+
 @interface UIApplication (Testing)
 - (void)_terminateWithStatus:(int)status;
 @end
@@ -50,12 +72,40 @@ static char** g_argv;
 @end
 #endif  // TARGET_IPHONE_SIMULATOR
 
+// No-op scene delegate for unit tests. Note that this is created along with
+// the application delegate, so they need to be separate objects (the same
+// object can't be both the app and scene delegate, since new scene delegates
+// are created for each scene).
+@interface ChromeUnitTestSceneDelegate : NSObject <UIWindowSceneDelegate> {
+  base::scoped_nsobject<UIWindow> _window;
+}
+
+@end
+
 @interface ChromeUnitTestDelegate : NSObject <GoogleTestRunnerDelegate> {
   base::scoped_nsobject<UIWindow> _window;
 }
 - (void)runTests;
 @end
 
+@implementation ChromeUnitTestSceneDelegate
+
+- (void)scene:(UIScene*)scene
+    willConnectToSession:(UISceneSession*)session
+                 options:(UISceneConnectionOptions*)connectionOptions
+    API_AVAILABLE(ios(13)) {
+  // Yes, this is leaked, it's just to make what's running visible.
+  _window.reset([[UIWindow alloc]
+      initWithWindowScene:static_cast<UIWindowScene*>(scene)]);
+  PopulateUIWindow(_window);
+}
+
+- (void)sceneDidDisconnect:(UIScene*)scene API_AVAILABLE(ios(13)) {
+  _window.reset();
+}
+
+@end
+
 @implementation ChromeUnitTestDelegate
 
 - (BOOL)application:(UIApplication *)application
@@ -67,25 +117,19 @@ static char** g_argv;
   // calls override this behavior by ensuring that the software keyboard is
   // always shown.
   [[UIKeyboardImpl sharedInstance] setAutomaticMinimizationEnabled:NO];
-  [[UIKeyboardImpl sharedInstance] setSoftwareKeyboardShownByTouch:YES];
+  if (@available(iOS 15, *)) {
+  } else {
+    [[UIKeyboardImpl sharedInstance] setSoftwareKeyboardShownByTouch:YES];
+  }
 #endif  // TARGET_IPHONE_SIMULATOR
 
-  CGRect bounds = [[UIScreen mainScreen] bounds];
+  if (!IsSceneStartupEnabled()) {
+    CGRect bounds = [[UIScreen mainScreen] bounds];
 
-  // Yes, this is leaked, it's just to make what's running visible.
-  _window.reset([[UIWindow alloc] initWithFrame:bounds]);
-  [_window setBackgroundColor:[UIColor whiteColor]];
-  [_window makeKeyAndVisible];
-
-  // Add a label with the app name.
-  UILabel* label = [[[UILabel alloc] initWithFrame:bounds] autorelease];
-  label.text = [[NSProcessInfo processInfo] processName];
-  label.textAlignment = NSTextAlignmentCenter;
-  [_window addSubview:label];
-
-  // An NSInternalInconsistencyException is thrown if the app doesn't have a
-  // root view controller. Set an empty one here.
-  [_window setRootViewController:[[[UIViewController alloc] init] autorelease]];
+    // Yes, this is leaked, it's just to make what's running visible.
+    _window.reset([[UIWindow alloc] initWithFrame:bounds]);
+    PopulateUIWindow(_window);
+  }
 
   if ([self shouldRedirectOutputToFile])
     [self redirectOutput];
@@ -169,7 +213,7 @@ static char** g_argv;
 - (int)runGoogleTests {
   coverage_util::ConfigureCoverageReportPath();
 
-  int exitStatus = g_test_suite->Run();
+  int exitStatus = std::move(g_test_suite_callback).Run();
 
   if ([self shouldRedirectOutputToFile])
     [self writeOutputToNSLog];
@@ -212,29 +256,22 @@ void InitIOSTestMessageLoop() {
   MessagePump::OverrideMessagePumpForUIFactory(&CreateMessagePumpForUIForTests);
 }
 
-void InitIOSRunHook(TestSuite* suite, int argc, char* argv[]) {
-  g_test_suite = suite;
+void InitIOSRunHook(RunTestSuiteCallback callback) {
+  g_test_suite_callback = std::move(callback);
+}
+
+void InitIOSArgs(int argc, char* argv[]) {
   g_argc = argc;
   g_argv = argv;
 }
 
-void RunTestsFromIOSApp() {
-  // When TestSuite::Run is invoked it calls RunTestsFromIOSApp(). On the first
-  // invocation, this method fires up an iOS app via UIApplicationMain. Since
-  // UIApplicationMain does not return until the app exits, control does not
-  // return to the initial TestSuite::Run invocation, so the app invokes
-  // TestSuite::Run a second time and since |ran_hook| is true at this point,
-  // this method is a no-op and control returns to TestSuite:Run so that test
-  // are executed. Once the app exits, RunTestsFromIOSApp calls exit() so that
-  // control is not returned to the initial invocation of TestSuite::Run.
-  static bool ran_hook = false;
-  if (!ran_hook) {
-    ran_hook = true;
-    @autoreleasepool {
-      int exit_status =
-          UIApplicationMain(g_argc, g_argv, nil, @"ChromeUnitTestDelegate");
-      exit(exit_status);
-    }
+int RunTestsFromIOSApp() {
+  // When LaunchUnitTests is invoked it calls RunTestsFromIOSApp(). On its
+  // invocation, this method fires up an iOS app via UIApplicationMain. The
+  // TestSuite::Run will have be passed via InitIOSRunHook which will execute
+  // the TestSuite once the UIApplication is ready.
+  @autoreleasepool {
+    return UIApplicationMain(g_argc, g_argv, nil, @"ChromeUnitTestDelegate");
   }
 }
 
