@@ -184,7 +184,7 @@ TEST(ValuesTest, ConstructBinary) {
 
 TEST(ValuesTest, ConstructDict) {
   Value::Dict value;
-  EXPECT_EQ(Value::Type::DICTIONARY, Value(std::move(value)).type());
+  EXPECT_EQ(Value::Type::DICT, Value(std::move(value)).type());
 }
 
 TEST(ValuesTest, ConstructDictFromValueDict) {
@@ -441,7 +441,7 @@ TEST(ValuesTest, MoveConstructDictionary) {
 
   Value value(std::move(dict));
   Value moved_value(std::move(value));
-  EXPECT_EQ(Value::Type::DICTIONARY, moved_value.type());
+  EXPECT_EQ(Value::Type::DICT, moved_value.type());
   EXPECT_EQ(123, moved_value.GetDict().Find("Int")->GetInt());
 }
 
@@ -451,7 +451,7 @@ TEST(ValuesTest, MoveAssignDictionary) {
 
   Value blank;
   blank = Value(std::move(dict));
-  EXPECT_EQ(Value::Type::DICTIONARY, blank.type());
+  EXPECT_EQ(Value::Type::DICT, blank.type());
   EXPECT_EQ(123, blank.GetDict().Find("Int")->GetInt());
 }
 
@@ -462,7 +462,7 @@ TEST(ValuesTest, ConstructDictWithIterators) {
   Value blank;
   blank = Value(Value::Dict(std::make_move_iterator(values.begin()),
                             std::make_move_iterator(values.end())));
-  EXPECT_EQ(Value::Type::DICTIONARY, blank.type());
+  EXPECT_EQ(Value::Type::DICT, blank.type());
   EXPECT_EQ(123, blank.GetDict().Find("Int")->GetInt());
 }
 
@@ -817,176 +817,6 @@ TEST(ValuesTest, FindKeyConst) {
   EXPECT_EQ(nullptr, value.GetDict().Find("baz"));
 }
 
-TEST(ValuesTest, FindKeyOfType) {
-  Value::Dict dict;
-  dict.Set("null", Value());
-  dict.Set("bool", false);
-  dict.Set("int", 0);
-  dict.Set("double", 0.0);
-  dict.Set("string", std::string());
-  dict.Set("blob", Value(Value::BlobStorage()));
-  dict.Set("list", Value::List());
-  dict.Set("dict", Value::Dict());
-
-  Value value(std::move(dict));
-  EXPECT_NE(nullptr, value.FindKeyOfType("null", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::NONE));
-  EXPECT_NE(nullptr, value.FindKeyOfType("bool", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::BOOLEAN));
-  EXPECT_NE(nullptr, value.FindKeyOfType("int", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::INTEGER));
-  EXPECT_NE(nullptr, value.FindKeyOfType("double", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::DOUBLE));
-  EXPECT_NE(nullptr, value.FindKeyOfType("string", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::STRING));
-  EXPECT_NE(nullptr, value.FindKeyOfType("blob", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::BINARY));
-  EXPECT_NE(nullptr, value.FindKeyOfType("list", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::LIST));
-  EXPECT_NE(nullptr, value.FindKeyOfType("dict", Value::Type::DICTIONARY));
-}
-
-TEST(ValuesTest, FindKeyOfTypeConst) {
-  Value::Dict dict;
-  dict.Set("null", Value());
-  dict.Set("bool", false);
-  dict.Set("int", 0);
-  dict.Set("double", 0.0);
-  dict.Set("string", std::string());
-  dict.Set("blob", Value(Value::BlobStorage()));
-  dict.Set("list", Value::List());
-  dict.Set("dict", Value::Dict());
-
-  const Value value(std::move(dict));
-  EXPECT_NE(nullptr, value.FindKeyOfType("null", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("null", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::NONE));
-  EXPECT_NE(nullptr, value.FindKeyOfType("bool", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("bool", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::BOOLEAN));
-  EXPECT_NE(nullptr, value.FindKeyOfType("int", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("int", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::INTEGER));
-  EXPECT_NE(nullptr, value.FindKeyOfType("double", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("double", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::DOUBLE));
-  EXPECT_NE(nullptr, value.FindKeyOfType("string", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("string", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::STRING));
-  EXPECT_NE(nullptr, value.FindKeyOfType("blob", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("blob", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::BINARY));
-  EXPECT_NE(nullptr, value.FindKeyOfType("list", Value::Type::LIST));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("list", Value::Type::DICTIONARY));
-
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::NONE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::BOOLEAN));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::INTEGER));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::DOUBLE));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::STRING));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::BINARY));
-  EXPECT_EQ(nullptr, value.FindKeyOfType("dict", Value::Type::LIST));
-  EXPECT_NE(nullptr, value.FindKeyOfType("dict", Value::Type::DICTIONARY));
-}
-
 TEST(ValuesTest, FindBoolKey) {
   Value::Dict dict;
   dict.Set("null", Value());
@@ -1029,27 +859,6 @@ TEST(ValuesTest, FindIntKey) {
   EXPECT_EQ(absl::nullopt, dict.FindInt("dict"));
 }
 
-TEST(ValuesTest, FindDoubleKey) {
-  Value::Dict dict;
-  dict.Set("null", Value());
-  dict.Set("bool", false);
-  dict.Set("int", 0);
-  dict.Set("double", 0.0);
-  dict.Set("string", std::string());
-  dict.Set("blob", Value(Value::BlobStorage()));
-  dict.Set("list", Value::List());
-  dict.Set("dict", Value::Dict());
-
-  EXPECT_EQ(absl::nullopt, dict.FindDouble("null"));
-  EXPECT_EQ(absl::nullopt, dict.FindDouble("bool"));
-  EXPECT_NE(absl::nullopt, dict.FindDouble("int"));
-  EXPECT_NE(absl::nullopt, dict.FindDouble("double"));
-  EXPECT_EQ(absl::nullopt, dict.FindDouble("string"));
-  EXPECT_EQ(absl::nullopt, dict.FindDouble("blob"));
-  EXPECT_EQ(absl::nullopt, dict.FindDouble("list"));
-  EXPECT_EQ(absl::nullopt, dict.FindDouble("dict"));
-}
-
 TEST(ValuesTest, FindStringKey) {
   Value::Dict dict;
   dict.Set("null", Value());
@@ -1169,7 +978,7 @@ TEST(ValuesTest, SetKey) {
   dict2.Set(std::string("string"), Value(Value::Type::STRING));
   dict2.Set("blob", Value(Value::Type::BINARY));
   dict2.Set("list", Value(Value::Type::LIST));
-  dict2.Set("dict", Value(Value::Type::DICTIONARY));
+  dict2.Set("dict", Value(Value::Type::DICT));
 
   EXPECT_EQ(dict, dict2);
   EXPECT_EQ(Value(std::move(dict)), Value(std::move(dict2)));
@@ -1219,7 +1028,7 @@ TEST(ValuesTest, SetDoubleKey) {
   dict.Set("minus_one_key", -1.0);
   dict.Set("pi_key", 3.1415);
 
-  // NOTE: Use FindKey() instead of FindDoubleKey() because the latter will
+  // NOTE: Use Find() instead of FindDoubleKey() because the latter will
   // auto-convert integers to doubles as well.
   const Value* value;
 
@@ -1266,6 +1075,38 @@ TEST(ValuesTest, SetStringKey) {
   ASSERT_FALSE(value);
 }
 
+TEST(ValuesTest, RvalueSet) {
+  Value::Dict dict = Value::Dict()
+                         .Set("null", Value())
+                         .Set("bool", false)
+                         .Set("int", 42)
+                         .Set("double", 1.2)
+                         .Set("string", "value")
+                         .Set("u16-string", u"u16-value")
+                         .Set("std-string", std::string("std-value"))
+                         .Set("blob", Value::BlobStorage({1, 2}))
+                         .Set("list", Value::List().Append("value in list"))
+                         .Set("dict", Value::Dict().Set("key", "value"));
+
+  Value::Dict expected;
+  expected.Set("null", Value());
+  expected.Set("bool", false);
+  expected.Set("int", 42);
+  expected.Set("double", 1.2);
+  expected.Set("string", "value");
+  expected.Set("u16-string", u"u16-value");
+  expected.Set("std-string", std::string("std-value"));
+  expected.Set("blob", Value::BlobStorage({1, 2}));
+  Value::List nested_list;
+  nested_list.Append("value in list");
+  expected.Set("list", std::move(nested_list));
+  Value::Dict nested_dict;
+  nested_dict.Set("key", "value");
+  expected.Set("dict", std::move(nested_dict));
+
+  EXPECT_EQ(dict, expected);
+}
+
 TEST(ValuesTest, FindPath) {
   // Construct a dictionary path {root}.foo.bar = 123
   Value::Dict foo;
@@ -1314,26 +1155,6 @@ TEST(ValuesTest, SetPath) {
   EXPECT_FALSE(found);
 }
 
-TEST(ValuesTest, SetBoolPath) {
-  Value::Dict root;
-  Value* inserted = root.SetByDottedPath("foo.bar", true);
-  Value* found = root.FindByDottedPath("foo.bar");
-  ASSERT_TRUE(found);
-  EXPECT_EQ(inserted, found);
-  ASSERT_TRUE(found->is_bool());
-  EXPECT_TRUE(found->GetBool());
-
-  // Overwrite with a different value.
-  root.SetByDottedPath("foo.bar", false);
-  found = root.FindByDottedPath("foo.bar");
-  ASSERT_TRUE(found);
-  ASSERT_TRUE(found->is_bool());
-  EXPECT_FALSE(found->GetBool());
-
-  // Can't change existing non-dictionary keys.
-  ASSERT_FALSE(root.SetByDottedPath("foo.bar.zoo", true));
-}
-
 TEST(ValuesTest, SetIntPath) {
   Value::Dict root;
   Value* inserted = root.SetByDottedPath("foo.bar", 123);
@@ -1398,7 +1219,7 @@ TEST(ValuesTest, SetStringPath) {
   ASSERT_FALSE(root.SetByDottedPath("foo.bar.zoo", "ola mundo"));
 }
 
-TEST(ValuesTest, RemoveKey) {
+TEST(ValuesTest, Remove) {
   Value::Dict root;
   root.Set("one", Value(123));
 
@@ -1412,7 +1233,7 @@ TEST(ValuesTest, RemoveKey) {
   EXPECT_FALSE(root.Remove("one"));
 }
 
-TEST(ValuesTest, ExtractKey) {
+TEST(ValuesTest, Extract) {
   Value::Dict root;
   root.Set("one", Value(123));
 
@@ -1426,7 +1247,7 @@ TEST(ValuesTest, ExtractKey) {
   EXPECT_EQ(absl::nullopt, root.Extract("one"));
 }
 
-TEST(ValuesTest, RemovePath) {
+TEST(ValuesTest, RemoveByDottedPath) {
   Value::Dict root;
   root.SetByDottedPath("one.two.three", Value(123));
 
@@ -1542,6 +1363,45 @@ TEST(ValuesTest, List) {
   ASSERT_FALSE(Contains(mixed_list, false));
 }
 
+TEST(ValuesTest, RvalueAppend) {
+  Value::List list = Value::List()
+                         .Append(Value())
+                         .Append(false)
+                         .Append(42)
+                         .Append(1.2)
+                         .Append("value")
+                         .Append(u"u16-value")
+                         .Append(std::string("std-value"))
+                         .Append(Value::BlobStorage({1, 2}))
+                         .Append(Value::List().Append("value in list"))
+                         .Append(Value::Dict().Set("key", "value"));
+
+  Value::List expected;
+  expected.Append(Value());
+  expected.Append(false);
+  expected.Append(42);
+  expected.Append(1.2);
+  expected.Append("value");
+  expected.Append(u"u16-value");
+  expected.Append(std::string("std-value"));
+  expected.Append(Value::BlobStorage({1, 2}));
+  Value::List nested_list;
+  nested_list.Append("value in list");
+  expected.Append(std::move(nested_list));
+  Value::Dict nested_dict;
+  nested_dict.Set("key", "value");
+  expected.Append(std::move(nested_dict));
+
+  EXPECT_EQ(list, expected);
+}
+
+TEST(ValuesTest, ListWithCapacity) {
+  Value::List list_with_capacity =
+      Value::List::with_capacity(3).Append(true).Append(42).Append(88.8);
+
+  ASSERT_EQ(3u, list_with_capacity.size());
+}
+
 TEST(ValuesTest, BinaryValue) {
   // Default constructor creates a BinaryValue with a buffer of size 0.
   Value binary(Value::Type::BINARY);
@@ -1631,7 +1491,7 @@ TEST(ValuesTest, DictionarySetReturnsPointer) {
   {
     Value::Dict dict;
     Value* dict_ptr = dict.Set("foo.bar", Value::Dict());
-    EXPECT_EQ(Value::Type::DICTIONARY, dict_ptr->type());
+    EXPECT_EQ(Value::Type::DICT, dict_ptr->type());
   }
 
   {
@@ -1658,8 +1518,7 @@ TEST(ValuesTest, Clone) {
   list.Append(1);
   Value* list_weak = original_dict.Set("list", Value(std::move(list)));
 
-  Value* dict_weak =
-      original_dict.Set("dictionary", Value(Value::Type::DICTIONARY));
+  Value* dict_weak = original_dict.Set("dictionary", Value(Value::Type::DICT));
   dict_weak->GetDict().Set("key", "value");
 
   Value::Dict copy_dict = original_dict.Clone();
@@ -1884,7 +1743,7 @@ TEST(ValuesTest, Equals) {
 
   Value::List list;
   list.Append(Value());
-  list.Append(Value(Value::Type::DICTIONARY));
+  list.Append(Value(Value::Type::DICT));
   Value::List list_copy(list.Clone());
 
   Value* list_weak = dv.Set("f", std::move(list));
@@ -2114,47 +1973,6 @@ TEST(ValuesTest, Merge) {
   EXPECT_EQ("sub_merge_key_value_merge", *sub_merge_key_value);  // Merged in.
 }
 
-TEST(ValuesTest, MergeDictionaryDeepCopy) {
-  // Note: This test still uses the old and deprecated MergeDictionary() API, as
-  // the new API doesn't support what this test expects. The test expects that
-  // the dictionary passed as an argument to MergeDictionary() be left unchanged
-  // (which is pretty much implied anyway, by the constness). However, the new
-  // API, Value::Dict::Merge(), will std::move() any values from the dict
-  // argument.
-  //
-  // Just remove this test when the old API is removed.
-
-  Value::Dict child;
-  child.Set("test", "value");
-  EXPECT_EQ(1U, child.size());
-
-  std::string* value = child.FindString("test");
-  ASSERT_TRUE(value);
-  EXPECT_EQ("value", *value);
-
-  Value base(Value::Type::DICT);
-  base.GetDict().Set("dict", std::move(child));
-  EXPECT_EQ(1U, base.GetDict().size());
-
-  base::Value::Dict* original_child = base.GetDict().FindDict("dict");
-  EXPECT_FALSE(original_child->empty());
-
-  Value merged(Value::Type::DICT);
-  merged.MergeDictionary(&base);
-  EXPECT_EQ(1U, merged.GetDict().size());
-  base::Value::Dict* ptr = merged.GetDict().FindDict("dict");
-  EXPECT_FALSE(ptr->empty());
-  EXPECT_NE(original_child, ptr);
-  value = ptr->FindString("test");
-  ASSERT_TRUE(value);
-  EXPECT_EQ("value", *value);
-
-  original_child->Set("test", "overwrite");
-  value = ptr->FindString("test");
-  ASSERT_TRUE(value);
-  EXPECT_EQ("value", *value);
-}
-
 TEST(ValuesTest, DictionaryIterator) {
   Value::Dict dict;
   for (Value::Dict::iterator it = dict.begin(); it != dict.end(); ++it) {
@@ -2199,8 +2017,9 @@ TEST(ValuesTest, MutatingCopiedPairsInDictItemsMutatesUnderlyingValues) {
   // Because the non-const dict iterates over <const std::string&, Value&>
   // pairs, it's possible to alter iterated-over values in place even when
   // "copying" the key-value pair:
-  for (auto kv : dict)
+  for (auto kv : dict) {
     kv.second.GetString() = "replacement";
+  }
 
   std::string* found = dict.FindString("key");
   ASSERT_TRUE(found);
