@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -11,6 +11,8 @@
 #include <vector>
 
 #include "base/cxx17_backports.h"
+#include "base/notreached.h"
+#include "base/observer_list.h"
 #include "cc/animation/animation_delegate.h"
 #include "cc/animation/animation_events.h"
 #include "cc/animation/animation_host.h"
@@ -57,11 +59,11 @@ scoped_refptr<ElementAnimations> ElementAnimations::Create(
 ElementAnimations::ElementAnimations(AnimationHost* host, ElementId element_id)
     : animation_host_(host),
       element_id_(element_id),
-      has_element_in_active_list_(false),
-      has_element_in_pending_list_(false),
       needs_push_properties_(false),
-      active_maximum_scale_(kInvalidScale),
-      pending_maximum_scale_(kInvalidScale) {
+      transform_property_active_maximum_scale_(kInvalidScale),
+      transform_property_pending_maximum_scale_(kInvalidScale),
+      scale_property_active_maximum_scale_(kInvalidScale),
+      scale_property_pending_maximum_scale_(kInvalidScale) {
   InitAffectedElementTypes();
 }
 
@@ -72,19 +74,14 @@ void ElementAnimations::InitAffectedElementTypes() {
   DCHECK(animation_host_);
 
   DCHECK(animation_host_->mutator_host_client());
-  if (animation_host_->mutator_host_client()->IsElementInPropertyTrees(
-          element_id_, ElementListType::ACTIVE)) {
-    set_has_element_in_active_list(true);
-  }
-  if (animation_host_->mutator_host_client()->IsElementInPropertyTrees(
-          element_id_, ElementListType::PENDING)) {
-    set_has_element_in_pending_list(true);
-  }
 }
 
 gfx::TargetProperties ElementAnimations::GetPropertiesMaskForAnimationState() {
   gfx::TargetProperties properties;
   properties[TargetProperty::TRANSFORM] = true;
+  properties[TargetProperty::SCALE] = true;
+  properties[TargetProperty::ROTATE] = true;
+  properties[TargetProperty::TRANSLATE] = true;
   properties[TargetProperty::OPACITY] = true;
   properties[TargetProperty::FILTER] = true;
   properties[TargetProperty::BACKDROP_FILTER] = true;
@@ -103,51 +100,20 @@ void ElementAnimations::ClearAffectedElementTypes(
 
   // This method may get called from AnimationHost dtor so it is possible for
   // mutator_host_client() to be null.
-  if (has_element_in_active_list() && animation_host_->mutator_host_client()) {
+  if (animation_host_->mutator_host_client()) {
     animation_host_->mutator_host_client()->ElementIsAnimatingChanged(
         element_id_map, ElementListType::ACTIVE, disabled_state_mask,
         disabled_state);
-  }
-  set_has_element_in_active_list(false);
-
-  if (has_element_in_pending_list() && animation_host_->mutator_host_client()) {
     animation_host_->mutator_host_client()->ElementIsAnimatingChanged(
         element_id_map, ElementListType::PENDING, disabled_state_mask,
         disabled_state);
   }
-  set_has_element_in_pending_list(false);
 
   RemoveKeyframeEffectsFromTicking();
 }
 
-// TODO(crbug.com/1240712): the ReservedElementId should always be 'registered'.
-// Instead of calling this from AnimationHost::UpdateRegisteredElementIds, we
-// can ensure that the |has_element_in_active_list_| and the
-// |has_element_in_pending_list_| are true for ReservedElementId, and this
-// should result in animations ticking right away. With that, we do not need to
-// add anything to the |keyframe_effects_list_| for ReservedElementId.
-void ElementAnimations::ElementIdRegistered(ElementId element_id,
-                                            ElementListType list_type) {
-  DCHECK_EQ(element_id_, element_id);
-
-  bool had_element_in_any_list = has_element_in_any_list();
-
-  if (list_type == ElementListType::ACTIVE)
-    set_has_element_in_active_list(true);
-  else
-    set_has_element_in_pending_list(true);
-
-  if (!had_element_in_any_list)
-    UpdateKeyframeEffectsTickingState();
-}
-
-void ElementAnimations::ElementIdUnregistered(ElementId element_id,
-                                              ElementListType list_type) {
-  DCHECK_EQ(this->element_id(), element_id);
-  if (list_type == ElementListType::ACTIVE)
-    set_has_element_in_active_list(false);
-  else
-    set_has_element_in_pending_list(false);
+void ElementAnimations::RemoveKeyframeEffects() {
+  RemoveKeyframeEffectsFromTicking();
 }
 
 void ElementAnimations::AddKeyframeEffect(KeyframeEffect* keyframe_effect) {
@@ -197,11 +163,12 @@ bool ElementAnimations::AnimationsPreserveAxisAlignment() const {
   return true;
 }
 
-float ElementAnimations::MaximumScale(ElementListType list_type) const {
+float ElementAnimations::MaximumScale(ElementId element_id,
+                                      ElementListType list_type) const {
   float maximum_scale = kInvalidScale;
   for (auto& keyframe_effect : keyframe_effects_list_) {
-    maximum_scale =
-        std::max(maximum_scale, keyframe_effect.MaximumScale(list_type));
+    maximum_scale = std::max(
+        maximum_scale, keyframe_effect.MaximumScale(element_id, list_type));
   }
   return maximum_scale;
 }
@@ -271,9 +238,10 @@ void ElementAnimations::OnColorAnimated(const SkColor& value,
                                         gfx::KeyframeModel* keyframe_model) {
   DCHECK_EQ(keyframe_model->TargetProperty(),
             TargetProperty::CSS_CUSTOM_PROPERTY);
-  OnCustomPropertyAnimated(PaintWorkletInput::PropertyValue(value),
-                           KeyframeModel::ToCcKeyframeModel(keyframe_model),
-                           target_property_id);
+  // TODO(crbug/1308932): Remove FromColor and make all SkColor4f.
+  OnCustomPropertyAnimated(
+      PaintWorkletInput::PropertyValue(SkColor4f::FromColor(value)),
+      KeyframeModel::ToCcKeyframeModel(keyframe_model), target_property_id);
 }
 
 void ElementAnimations::OnTransformAnimated(
@@ -304,19 +272,43 @@ void ElementAnimations::InitClientAnimationState() {
   // (instead of only changed) recalculated current states to the client.
   pending_state_.Clear();
   active_state_.Clear();
-  active_maximum_scale_ = kInvalidScale;
-  pending_maximum_scale_ = kInvalidScale;
+  transform_property_active_maximum_scale_ = kInvalidScale;
+  transform_property_pending_maximum_scale_ = kInvalidScale;
+  scale_property_active_maximum_scale_ = kInvalidScale;
+  scale_property_pending_maximum_scale_ = kInvalidScale;
   UpdateClientAnimationState();
 }
 
+void ElementAnimations::UpdateMaximumScale(ElementId element_id,
+                                           ElementListType list_type,
+                                           float* cached_scale) {
+  if (element_id) {
+    float maximum_scale = MaximumScale(element_id, list_type);
+    if (*cached_scale != maximum_scale) {
+      animation_host_->mutator_host_client()->MaximumScaleChanged(
+          element_id, list_type, maximum_scale);
+      *cached_scale = maximum_scale;
+    }
+  } else {
+    *cached_scale = kInvalidScale;
+  }
+}
+
+#if DCHECK_IS_ON()
+static inline bool IsInvalidOrOne(float scale) {
+  return scale == kInvalidScale || scale == 1.f;
+}
+#endif
+
 void ElementAnimations::UpdateClientAnimationState() {
   if (!element_id())
     return;
   // For a custom property animation, or an animation that uses paint worklet,
   // it is not associated with any property node, and thus this function is not
   // needed.
-  if (element_id().GetStableId() == ElementId::kReservedElementId)
+  if (element_id() == kReservedElementIdForPaintWorklet) {
     return;
+  }
   DCHECK(animation_host_);
   if (!animation_host_->mutator_host_client())
     return;
@@ -350,41 +342,45 @@ void ElementAnimations::UpdateClientAnimationState() {
 
   PropertyToElementIdMap element_id_map = GetPropertyToElementIdMap();
   ElementId transform_element_id = element_id_map[TargetProperty::TRANSFORM];
+  ElementId scale_element_id = element_id_map[TargetProperty::SCALE];
+#if DCHECK_IS_ON()
+  ElementId rotate_element_id = element_id_map[TargetProperty::ROTATE];
+  ElementId translate_element_id = element_id_map[TargetProperty::TRANSLATE];
+#endif
 
-  if (has_element_in_active_list()) {
-    if (prev_active != active_state_) {
-      PropertyAnimationState diff_active = prev_active ^ active_state_;
-      animation_host_->mutator_host_client()->ElementIsAnimatingChanged(
-          element_id_map, ElementListType::ACTIVE, diff_active, active_state_);
-    }
-
-    float maximum_scale = transform_element_id
-                              ? MaximumScale(ElementListType::ACTIVE)
-                              : kInvalidScale;
-    if (maximum_scale != active_maximum_scale_) {
-      animation_host_->mutator_host_client()->MaximumScaleChanged(
-          transform_element_id, ElementListType::ACTIVE, maximum_scale);
-      active_maximum_scale_ = maximum_scale;
-    }
+  if (prev_active != active_state_) {
+    PropertyAnimationState diff_active = prev_active ^ active_state_;
+    animation_host_->mutator_host_client()->ElementIsAnimatingChanged(
+        element_id_map, ElementListType::ACTIVE, diff_active, active_state_);
   }
 
-  if (has_element_in_pending_list()) {
-    if (prev_pending != pending_state_) {
-      PropertyAnimationState diff_pending = prev_pending ^ pending_state_;
-      animation_host_->mutator_host_client()->ElementIsAnimatingChanged(
-          element_id_map, ElementListType::PENDING, diff_pending,
-          pending_state_);
-    }
+  UpdateMaximumScale(transform_element_id, ElementListType::ACTIVE,
+                     &transform_property_active_maximum_scale_);
+  UpdateMaximumScale(scale_element_id, ElementListType::ACTIVE,
+                     &scale_property_active_maximum_scale_);
+#if DCHECK_IS_ON()
+  DCHECK(
+      IsInvalidOrOne(MaximumScale(rotate_element_id, ElementListType::ACTIVE)));
+  DCHECK(IsInvalidOrOne(
+      MaximumScale(translate_element_id, ElementListType::ACTIVE)));
+#endif
 
-    float maximum_scale = transform_element_id
-                              ? MaximumScale(ElementListType::PENDING)
-                              : kInvalidScale;
-    if (maximum_scale != pending_maximum_scale_) {
-      animation_host_->mutator_host_client()->MaximumScaleChanged(
-          transform_element_id, ElementListType::PENDING, maximum_scale);
-      pending_maximum_scale_ = maximum_scale;
-    }
+  if (prev_pending != pending_state_) {
+    PropertyAnimationState diff_pending = prev_pending ^ pending_state_;
+    animation_host_->mutator_host_client()->ElementIsAnimatingChanged(
+        element_id_map, ElementListType::PENDING, diff_pending, pending_state_);
   }
+
+  UpdateMaximumScale(transform_element_id, ElementListType::PENDING,
+                     &transform_property_pending_maximum_scale_);
+  UpdateMaximumScale(scale_element_id, ElementListType::PENDING,
+                     &scale_property_pending_maximum_scale_);
+#if DCHECK_IS_ON()
+  DCHECK(IsInvalidOrOne(
+      MaximumScale(rotate_element_id, ElementListType::PENDING)));
+  DCHECK(IsInvalidOrOne(
+      MaximumScale(translate_element_id, ElementListType::PENDING)));
+#endif
 }
 
 void ElementAnimations::AttachToCurve(gfx::AnimationCurve* c) {
@@ -431,10 +427,12 @@ bool ElementAnimations::HasAnyKeyframeModel() const {
 }
 
 bool ElementAnimations::HasAnyAnimationTargetingProperty(
-    TargetProperty::Type property) const {
+    TargetProperty::Type property,
+    ElementId element_id) const {
   for (auto& keyframe_effect : keyframe_effects_list_) {
-    if (keyframe_effect.GetKeyframeModel(property))
-      return true;
+    if (gfx::KeyframeModel* model = keyframe_effect.GetKeyframeModel(property))
+      if (CalculateTargetElementId(this, model) == element_id)
+        return true;
   }
   return false;
 }
@@ -505,7 +503,7 @@ void ElementAnimations::OnCustomPropertyAnimated(
   DCHECK(animation_host_->mutator_host_client());
   // No-op background-color animations can have no unique_id. See
   // CompositorAnimations::IsNoOpBackgroundColorAnimation for details.
-  if (!ElementId::IsValid(keyframe_model->element_id().GetStableId())) {
+  if (!keyframe_model->element_id()) {
     return;
   }
   ElementId id = CalculateTargetElementId(this, keyframe_model);
@@ -543,10 +541,11 @@ void ElementAnimations::OnScrollOffsetAnimated(
       target_element_id, list_type, scroll_offset);
 }
 
-gfx::PointF ElementAnimations::ScrollOffsetForAnimation() const {
+absl::optional<gfx::PointF> ElementAnimations::ScrollOffsetForAnimation()
+    const {
   if (animation_host_)
     return animation_host_->GetScrollOffsetForAnimation(element_id());
-  return gfx::PointF();
+  return absl::nullopt;
 }
 
 PropertyToElementIdMap ElementAnimations::GetPropertyToElementIdMap() const {
@@ -642,8 +641,7 @@ bool ElementAnimations::KeyframeModelAffectsActiveElements(
   if (!keyframe_model)
     return true;
   return KeyframeModel::ToCcKeyframeModel(keyframe_model)
-             ->affects_active_elements() &&
-         has_element_in_active_list();
+      ->affects_active_elements();
 }
 
 bool ElementAnimations::KeyframeModelAffectsPendingElements(
@@ -654,8 +652,7 @@ bool ElementAnimations::KeyframeModelAffectsPendingElements(
   if (!keyframe_model)
     return true;
   return KeyframeModel::ToCcKeyframeModel(keyframe_model)
-             ->affects_pending_elements() &&
-         has_element_in_pending_list();
+      ->affects_pending_elements();
 }
 
 }  // namespace cc
