@@ -44,8 +44,22 @@ BASE_FEATURE(kRemoveMobileViewportDoubleTap,
              "RemoveMobileViewportDoubleTap",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
+// Design doc: bit.ly/scrollunification
+// Disabled on Windows due to crbug.com/1378021.
 BASE_FEATURE(kScrollUnification,
              "ScrollUnification",
+#if BUILDFLAG(IS_WIN)
+             base::FEATURE_DISABLED_BY_DEFAULT);
+#else
+             base::FEATURE_ENABLED_BY_DEFAULT);
+#endif
+
+BASE_FEATURE(kMainRepaintScrollPrefersNewContent,
+             "MainRepaintScrollPrefersNewContent",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
+BASE_FEATURE(kFlushGpuAtDraw,
+             "FlushGpuAtDraw",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
 BASE_FEATURE(kSchedulerSmoothnessForAnimatedScrolls,
@@ -82,7 +96,7 @@ BASE_FEATURE(kNormalPriorityImageDecoding,
 
 BASE_FEATURE(kSkipCommitsIfNotSynchronizingCompositorState,
              "SkipCommitsIfNotSynchronizingCompositorState",
-             base::FEATURE_ENABLED_BY_DEFAULT);
+             base::FEATURE_DISABLED_BY_DEFAULT);
 
 BASE_FEATURE(kUseDMSAAForTiles,
              "UseDMSAAForTiles",
@@ -112,4 +126,7 @@ BASE_FEATURE(kMoreAggressiveSolidColorDetection,
              "MoreAggressiveSolidColorDetection",
              base::FEATURE_DISABLED_BY_DEFAULT);
 
+BASE_FEATURE(kReducedFrameRateEstimation,
+             "kReducedFrameRateEstimation",
+             base::FEATURE_ENABLED_BY_DEFAULT);
 }  // namespace features
