@@ -72,6 +72,7 @@ static_assert(sizeof(Layer) == sizeof(SameSizeAsLayer),
 
 base::AtomicSequenceNumber g_next_layer_id;
 
+constexpr gfx::Transform Layer::kIdentityTransform;
 constexpr gfx::RoundedCornersF Layer::kNoRoundedCornersF;
 
 LayerDebugInfo::LayerDebugInfo() = default;
@@ -218,6 +219,10 @@ viz::ViewTransitionElementResourceId Layer::ViewTransitionResourceId() const {
   return viz::ViewTransitionElementResourceId();
 }
 
+bool Layer::IsSolidColorLayerForTesting() const {
+  return false;
+}
+
 void Layer::SetNeedsFullTreeSync() {
   if (!IsAttached())
     return;
@@ -714,8 +719,10 @@ void Layer::UpdateMaskFilterInfo(const gfx::RoundedCornersF* corner_radii,
   if (property_trees && effect_tree_index() != kInvalidPropertyNodeId &&
       (node =
            property_trees->effect_tree_mutable().Node(effect_tree_index()))) {
+    gfx::RectF effective_clip_rect = EffectiveClipRect();
+    effective_clip_rect += offset_to_transform_parent();
     node->mask_filter_info = gfx::MaskFilterInfo(
-        EffectiveClipRect(), inputs.corner_radii, inputs.gradient_mask);
+        effective_clip_rect, inputs.corner_radii, inputs.gradient_mask);
     node->effect_changed = true;
     property_trees->effect_tree_mutable().set_needs_update(true);
   } else {
@@ -1405,7 +1412,7 @@ void Layer::SetIsDrawable(bool is_drawable) {
     return;
 
   inputs_.Write(*this).is_drawable = is_drawable;
-  SetDrawsContent(HasDrawableContent());
+  UpdateDrawsContent();
 }
 
 void Layer::SetHideLayerAndSubtree(bool hide) {
@@ -1540,7 +1547,8 @@ bool Layer::HasDrawableContent() const {
   return inputs_.Read(*this).is_drawable;
 }
 
-void Layer::SetDrawsContent(bool value) {
+void Layer::UpdateDrawsContent() {
+  bool value = HasDrawableContent();
   DCHECK(inputs_.Read(*this).is_drawable || !value);
   if (!SetBitFlag(value, kDrawsContentFlagMask, /*invalidate=*/true))
     return;
