@@ -19,7 +19,6 @@
 #include "cc/trees/layer_tree_impl.h"
 #include "cc/trees/occlusion.h"
 #include "cc/trees/transform_node.h"
-#include "components/viz/common/display/de_jelly.h"
 #include "components/viz/common/quads/compositor_render_pass.h"
 #include "components/viz/common/quads/compositor_render_pass_draw_quad.h"
 #include "components/viz/common/quads/content_draw_quad_base.h"
@@ -35,9 +34,9 @@
 namespace cc {
 
 RenderSurfaceImpl::RenderSurfaceImpl(LayerTreeImpl* layer_tree_impl,
-                                     uint64_t stable_id)
+                                     ElementId id)
     : layer_tree_impl_(layer_tree_impl),
-      stable_id_(stable_id),
+      id_(id),
       effect_tree_index_(kInvalidPropertyNodeId),
       num_contributors_(0),
       has_contributing_layer_that_escapes_clip_(false),
@@ -47,6 +46,7 @@ RenderSurfaceImpl::RenderSurfaceImpl(LayerTreeImpl* layer_tree_impl,
       is_render_surface_list_member_(false),
       intersects_damage_under_(true),
       nearest_occlusion_immune_ancestor_(nullptr) {
+  DCHECK(id);
   damage_tracker_ = DamageTracker::Create();
 }
 
@@ -261,10 +261,6 @@ gfx::Rect RenderSurfaceImpl::CalculateClippedAccumulatedContentRect() {
   } else {
     clipped_accumulated_rect_in_target_space = clip_rect();
   }
-  if (layer_tree_impl_->settings().allow_de_jelly_effect) {
-    clipped_accumulated_rect_in_target_space.Inset(
-        gfx::Insets::VH(-viz::MaxDeJellyHeight(), 0));
-  }
   clipped_accumulated_rect_in_target_space.Intersect(
       accumulated_rect_in_target_space);
 
@@ -289,6 +285,15 @@ void RenderSurfaceImpl::CalculateContentRectFromAccumulatedContentRect(
   // use accumulated content rect, and then try to clip it.
   gfx::Rect surface_content_rect = CalculateClippedAccumulatedContentRect();
 
+  // Render passes induced for elements participating in a ViewTransition
+  // shouldn't be larger than max texture size.
+#if DCHECK_IS_ON()
+  if (OwningEffectNode()->view_transition_element_resource_id.IsValid()) {
+    DCHECK_LE(surface_content_rect.width(), max_texture_size);
+    DCHECK_LE(surface_content_rect.height(), max_texture_size);
+  }
+#endif
+
   // The RenderSurfaceImpl backing texture cannot exceed the maximum supported
   // texture size.
   surface_content_rect.set_width(
@@ -348,23 +353,16 @@ void RenderSurfaceImpl::AccumulateContentRectFromContributingRenderSurface(
 }
 
 bool RenderSurfaceImpl::SurfacePropertyChanged() const {
-  // Surface property changes are tracked as follows:
-  //
-  // - surface_property_changed_ is flagged when the clip_rect or content_rect
-  //   change. As of now, these are the only two properties that can be affected
-  //   by descendant layers.
-  //
-  // - all other property changes come from the surface's property tree nodes
-  //   (or some ancestor node that propagates its change to one of these nodes).
-  //
-  return surface_property_changed_ || AncestorPropertyChanged();
-}
-
-bool RenderSurfaceImpl::SurfacePropertyChangedOnlyFromDescendant() const {
-  return surface_property_changed_ && !AncestorPropertyChanged();
+  // |surface_property_changed_| is flagged when the clip_rect or content_rect
+  // change. As of now, these are the only two properties that can be affected
+  // by descendant layers.
+  return surface_property_changed_;
 }
 
 bool RenderSurfaceImpl::AncestorPropertyChanged() const {
+  // All property changes come from the surface's property tree nodes.
+  // (or some ancestor node that propagates its change to one of these nodes).
+  //
   const PropertyTrees* property_trees = layer_tree_impl_->property_trees();
   return ancestor_property_changed_ || property_trees->full_tree_damaged() ||
          property_trees->transform_tree()
