@@ -1,16 +1,17 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 #include "cc/metrics/compositor_frame_reporting_controller.h"
 
-#include <algorithm>
 #include <utility>
 #include <vector>
 
+#include "base/ranges/algorithm.h"
 #include "base/strings/strcat.h"
 #include "base/test/metrics/histogram_tester.h"
 #include "base/test/simple_test_tick_clock.h"
+#include "base/time/time.h"
 #include "cc/metrics/dropped_frame_counter.h"
 #include "cc/metrics/event_metrics.h"
 #include "cc/metrics/total_frame_counter.h"
@@ -33,7 +34,8 @@ class TestCompositorFrameReportingController
     : public CompositorFrameReportingController {
  public:
   TestCompositorFrameReportingController()
-      : CompositorFrameReportingController(/*should_report_metrics=*/true,
+      : CompositorFrameReportingController(/*should_report_histograms=*/true,
+                                           /*should_report_ukm=*/false,
                                            /*layer_tree_host_id=*/1) {}
 
   TestCompositorFrameReportingController(
@@ -177,7 +179,7 @@ class CompositorFrameReportingControllerTest : public testing::Test {
     submit_time_ = AdvanceNowByMs(10);
     ++current_token_;
     reporting_controller_.DidSubmitCompositorFrame(
-        *current_token_, current_id_, last_activated_id_,
+        *current_token_, submit_time_, current_id_, last_activated_id_,
         std::move(events_metrics),
         /*has_missing_content=*/false);
   }
@@ -256,22 +258,28 @@ class CompositorFrameReportingControllerTest : public testing::Test {
         EventMetrics::CreateForTesting(type, event_time, &test_tick_clock_));
   }
 
-  std::unique_ptr<EventMetrics> CreateScrollBeginEventMetrics() {
+  std::unique_ptr<EventMetrics> CreateScrollBeginEventMetrics(
+      ui::ScrollInputType input_type) {
     const base::TimeTicks event_time = AdvanceNowByMs(10);
+    const base::TimeTicks arrived_in_browser_main_timestamp = AdvanceNowByMs(3);
     AdvanceNowByMs(10);
     return SetupEventMetrics(ScrollEventMetrics::CreateForTesting(
-        ui::ET_GESTURE_SCROLL_BEGIN, ui::ScrollInputType::kWheel,
-        /*is_inertial=*/false, event_time, &test_tick_clock_));
+        ui::ET_GESTURE_SCROLL_BEGIN, input_type,
+        /*is_inertial=*/false, event_time, arrived_in_browser_main_timestamp,
+        &test_tick_clock_));
   }
 
   std::unique_ptr<EventMetrics> CreateScrollUpdateEventMetrics(
+      ui::ScrollInputType input_type,
       bool is_inertial,
       ScrollUpdateEventMetrics::ScrollUpdateType scroll_update_type) {
     const base::TimeTicks event_time = AdvanceNowByMs(10);
+    const base::TimeTicks arrived_in_browser_main_timestamp = AdvanceNowByMs(3);
     AdvanceNowByMs(10);
     return SetupEventMetrics(ScrollUpdateEventMetrics::CreateForTesting(
-        ui::ET_GESTURE_SCROLL_UPDATE, ui::ScrollInputType::kWheel, is_inertial,
-        scroll_update_type, /*delta=*/10.0f, event_time, &test_tick_clock_));
+        ui::ET_GESTURE_SCROLL_UPDATE, input_type, is_inertial,
+        scroll_update_type, /*delta=*/10.0f, event_time,
+        arrived_in_browser_main_timestamp, &test_tick_clock_));
   }
 
   std::unique_ptr<EventMetrics> CreatePinchEventMetrics(
@@ -287,12 +295,11 @@ class CompositorFrameReportingControllerTest : public testing::Test {
       const EventMetrics::List& events_metrics) {
     std::vector<base::TimeTicks> event_times;
     event_times.reserve(events_metrics.size());
-    std::transform(events_metrics.cbegin(), events_metrics.cend(),
-                   std::back_inserter(event_times),
-                   [](const auto& event_metrics) {
-                     return event_metrics->GetDispatchStageTimestamp(
-                         EventMetrics::DispatchStage::kGenerated);
-                   });
+    base::ranges::transform(events_metrics, std::back_inserter(event_times),
+                            [](const auto& event_metrics) {
+                              return event_metrics->GetDispatchStageTimestamp(
+                                  EventMetrics::DispatchStage::kGenerated);
+                            });
     return event_times;
   }
 
@@ -361,6 +368,7 @@ TEST_F(CompositorFrameReportingControllerTest, ActiveReporterCounts) {
 
   // BF -> BMF -> BF -> Commit
   // Should stay same.
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   EXPECT_EQ(2, reporting_controller_.ActiveReporters());
@@ -375,6 +383,7 @@ TEST_F(CompositorFrameReportingControllerTest, ActiveReporterCounts) {
   // for frame_2 in activate state.
   EXPECT_EQ(2, reporting_controller_.ActiveReporters());
 
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
@@ -385,7 +394,8 @@ TEST_F(CompositorFrameReportingControllerTest, ActiveReporterCounts) {
 
   last_activated_id_ = current_id_3;
   reporting_controller_.DidSubmitCompositorFrame(
-      0, current_id_3, last_activated_id_, {}, /*has_missing_content=*/false);
+      0, AdvanceNowByMs(10), current_id_3, last_activated_id_, {},
+      /*has_missing_content=*/false);
   EXPECT_EQ(0, reporting_controller_.ActiveReporters());
 
   // Start a frame and take it all the way to the activate stage.
@@ -543,12 +553,14 @@ TEST_F(CompositorFrameReportingControllerTest, DidNotProduceFrame) {
 
   reporting_controller_.WillBeginImplFrame(args_2);
   reporting_controller_.OnFinishImplFrame(current_id_2);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
   reporting_controller_.DidActivate();
-  reporting_controller_.DidSubmitCompositorFrame(
-      1, current_id_2, current_id_1, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(1, AdvanceNowByMs(10),
+                                                 current_id_2, current_id_1, {},
+                                                 /*has_missing_content=*/false);
   viz::FrameTimingDetails details = {};
   reporting_controller_.DidPresentCompositorFrame(1, details);
 
@@ -608,13 +620,15 @@ TEST_F(CompositorFrameReportingControllerTest,
                                            FrameSkippedReason::kWaitingOnMain);
 
   reporting_controller_.WillBeginImplFrame(args_3);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
   reporting_controller_.DidActivate();
   reporting_controller_.OnFinishImplFrame(current_id_3);
-  reporting_controller_.DidSubmitCompositorFrame(
-      1, current_id_3, current_id_1, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(1, AdvanceNowByMs(10),
+                                                 current_id_3, current_id_1, {},
+                                                 /*has_missing_content=*/false);
   viz::FrameTimingDetails details;
   details.presentation_feedback = {args_3.frame_time + args_3.interval,
                                    args_3.interval, 0};
@@ -647,7 +661,8 @@ TEST_F(CompositorFrameReportingControllerTest, MainFrameAborted) {
       current_id_, CommitEarlyOutReason::FINISHED_NO_UPDATES);
   reporting_controller_.OnFinishImplFrame(current_id_);
   reporting_controller_.DidSubmitCompositorFrame(
-      1, current_id_, last_activated_id_, {}, /*has_missing_content=*/false);
+      1, AdvanceNowByMs(10), current_id_, last_activated_id_, {},
+      /*has_missing_content=*/false);
 
   viz::FrameTimingDetails details = {};
   reporting_controller_.DidPresentCompositorFrame(1, details);
@@ -693,6 +708,7 @@ TEST_F(CompositorFrameReportingControllerTest, MainFrameAborted2) {
   reporting_controller_.WillBeginImplFrame(args_1);
   reporting_controller_.OnFinishImplFrame(current_id_1);
   reporting_controller_.WillBeginMainFrame(args_1);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
@@ -702,8 +718,9 @@ TEST_F(CompositorFrameReportingControllerTest, MainFrameAborted2) {
   reporting_controller_.OnFinishImplFrame(current_id_2);
   reporting_controller_.BeginMainFrameAborted(
       current_id_2, CommitEarlyOutReason::FINISHED_NO_UPDATES);
-  reporting_controller_.DidSubmitCompositorFrame(
-      1, current_id_2, current_id_1, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(1, AdvanceNowByMs(10),
+                                                 current_id_2, current_id_1, {},
+                                                 /*has_missing_content=*/false);
   viz::FrameTimingDetails details = {};
   reporting_controller_.DidPresentCompositorFrame(1, details);
   histogram_tester.ExpectTotalCount(
@@ -721,8 +738,9 @@ TEST_F(CompositorFrameReportingControllerTest, MainFrameAborted2) {
   histogram_tester.ExpectTotalCount(
       "CompositorLatency.SubmitCompositorFrameToPresentationCompositorFrame",
       2);
-  reporting_controller_.DidSubmitCompositorFrame(
-      2, current_id_2, current_id_1, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(2, AdvanceNowByMs(10),
+                                                 current_id_2, current_id_1, {},
+                                                 /*has_missing_content=*/false);
   reporting_controller_.DidPresentCompositorFrame(2, details);
   histogram_tester.ExpectTotalCount(
       "CompositorLatency.DroppedFrame.BeginImplFrameToSendBeginMainFrame", 0);
@@ -741,8 +759,9 @@ TEST_F(CompositorFrameReportingControllerTest, MainFrameAborted2) {
       2);
   reporting_controller_.WillBeginImplFrame(args_3);
   reporting_controller_.OnFinishImplFrame(current_id_3);
-  reporting_controller_.DidSubmitCompositorFrame(
-      3, current_id_3, current_id_1, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(3, AdvanceNowByMs(10),
+                                                 current_id_3, current_id_1, {},
+                                                 /*has_missing_content=*/false);
   reporting_controller_.DidPresentCompositorFrame(3, details);
   histogram_tester.ExpectTotalCount(
       "CompositorLatency.DroppedFrame.BeginImplFrameToSendBeginMainFrame", 0);
@@ -776,12 +795,14 @@ TEST_F(CompositorFrameReportingControllerTest, LongMainFrame) {
   reporting_controller_.WillBeginImplFrame(args_1);
   reporting_controller_.OnFinishImplFrame(current_id_1);
   reporting_controller_.WillBeginMainFrame(args_1);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
   reporting_controller_.DidActivate();
-  reporting_controller_.DidSubmitCompositorFrame(
-      1, current_id_1, current_id_1, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(1, AdvanceNowByMs(10),
+                                                 current_id_1, current_id_1, {},
+                                                 /*has_missing_content=*/false);
   reporting_controller_.DidPresentCompositorFrame(1, details);
 
   histogram_tester.ExpectTotalCount(
@@ -803,8 +824,9 @@ TEST_F(CompositorFrameReportingControllerTest, LongMainFrame) {
   reporting_controller_.WillBeginImplFrame(args_2);
   reporting_controller_.WillBeginMainFrame(args_2);
   reporting_controller_.OnFinishImplFrame(current_id_2);
-  reporting_controller_.DidSubmitCompositorFrame(
-      2, current_id_2, current_id_1, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(2, AdvanceNowByMs(10),
+                                                 current_id_2, current_id_1, {},
+                                                 /*has_missing_content=*/false);
   reporting_controller_.DidPresentCompositorFrame(2, details);
 
   // The reporting for the second frame is delayed until the main-thread
@@ -839,12 +861,14 @@ TEST_F(CompositorFrameReportingControllerTest, LongMainFrame) {
 
   reporting_controller_.WillBeginImplFrame(args_3);
   reporting_controller_.OnFinishImplFrame(current_id_3);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
   reporting_controller_.DidActivate();
-  reporting_controller_.DidSubmitCompositorFrame(
-      3, current_id_3, current_id_2, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(3, AdvanceNowByMs(10),
+                                                 current_id_3, current_id_2, {},
+                                                 /*has_missing_content=*/false);
   reporting_controller_.DidPresentCompositorFrame(3, details);
 
   // The main-thread responded, so the metrics for |args_2| should now be
@@ -890,12 +914,14 @@ TEST_F(CompositorFrameReportingControllerTest, LongMainFrame2) {
   reporting_controller_.WillBeginImplFrame(args_1);
   reporting_controller_.OnFinishImplFrame(current_id_1);
   reporting_controller_.WillBeginMainFrame(args_1);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
   reporting_controller_.DidActivate();
-  reporting_controller_.DidSubmitCompositorFrame(
-      1, current_id_1, current_id_1, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(1, AdvanceNowByMs(10),
+                                                 current_id_1, current_id_1, {},
+                                                 /*has_missing_content=*/false);
   reporting_controller_.DidPresentCompositorFrame(1, details);
 
   histogram_tester.ExpectTotalCount(
@@ -915,11 +941,13 @@ TEST_F(CompositorFrameReportingControllerTest, LongMainFrame2) {
   // The reporting for the second frame is delayed until activation happens.
   reporting_controller_.WillBeginImplFrame(args_2);
   reporting_controller_.WillBeginMainFrame(args_2);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.OnFinishImplFrame(current_id_2);
-  reporting_controller_.DidSubmitCompositorFrame(
-      2, current_id_2, current_id_1, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(2, AdvanceNowByMs(10),
+                                                 current_id_2, current_id_1, {},
+                                                 /*has_missing_content=*/false);
   reporting_controller_.DidPresentCompositorFrame(2, details);
 
   histogram_tester.ExpectTotalCount(
@@ -959,8 +987,9 @@ TEST_F(CompositorFrameReportingControllerTest, LongMainFrame2) {
   reporting_controller_.DidActivate();
   reporting_controller_.WillBeginImplFrame(args_3);
   reporting_controller_.OnFinishImplFrame(current_id_3);
-  reporting_controller_.DidSubmitCompositorFrame(
-      3, current_id_3, current_id_2, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(3, AdvanceNowByMs(10),
+                                                 current_id_3, current_id_2, {},
+                                                 /*has_missing_content=*/false);
   reporting_controller_.DidPresentCompositorFrame(3, details);
   histogram_tester.ExpectTotalCount(
       "CompositorLatency.BeginImplFrameToSendBeginMainFrame", 4);
@@ -1040,12 +1069,14 @@ TEST_F(CompositorFrameReportingControllerTest, ReportingMissedDeadlineFrame1) {
   reporting_controller_.WillBeginImplFrame(args_);
   reporting_controller_.OnFinishImplFrame(current_id_);
   reporting_controller_.WillBeginMainFrame(args_);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
   reporting_controller_.DidActivate();
-  reporting_controller_.DidSubmitCompositorFrame(
-      1, current_id_, current_id_, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(1, AdvanceNowByMs(10),
+                                                 current_id_, current_id_, {},
+                                                 /*has_missing_content=*/false);
   viz::FrameTimingDetails details = {};
   details.presentation_feedback.timestamp =
       args_.frame_time + args_.interval * 1.5 - base::Microseconds(100);
@@ -1078,12 +1109,14 @@ TEST_F(CompositorFrameReportingControllerTest, ReportingMissedDeadlineFrame2) {
   reporting_controller_.WillBeginImplFrame(args_);
   reporting_controller_.OnFinishImplFrame(current_id_);
   reporting_controller_.WillBeginMainFrame(args_);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
   reporting_controller_.DidActivate();
-  reporting_controller_.DidSubmitCompositorFrame(
-      1, current_id_, current_id_, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(1, AdvanceNowByMs(10),
+                                                 current_id_, current_id_, {},
+                                                 /*has_missing_content=*/false);
   viz::FrameTimingDetails details = {};
   details.presentation_feedback.timestamp =
       args_.frame_time + args_.interval * 1.5 + base::Microseconds(100);
@@ -1116,7 +1149,8 @@ TEST_F(CompositorFrameReportingControllerTest, LongCompositorAnimation) {
   reporting_controller_.WillBeginImplFrame(args_);
   reporting_controller_.OnFinishImplFrame(current_id_);
   reporting_controller_.DidSubmitCompositorFrame(
-      1, current_id_, last_activated_id_, {}, /*has_missing_content=*/false);
+      1, AdvanceNowByMs(10), current_id_, last_activated_id_, {},
+      /*has_missing_content=*/false);
   viz::FrameTimingDetails details = {};
   reporting_controller_.DidPresentCompositorFrame(*current_token_, details);
 
@@ -1244,15 +1278,25 @@ TEST_F(CompositorFrameReportingControllerTest,
   const bool kScrollIsInertial = true;
   const bool kScrollIsNotInertial = false;
   std::unique_ptr<EventMetrics> event_metrics_ptrs[] = {
-      CreateScrollBeginEventMetrics(),
+      CreateScrollBeginEventMetrics(ui::ScrollInputType::kWheel),
       CreateScrollUpdateEventMetrics(
-          kScrollIsNotInertial,
+          ui::ScrollInputType::kWheel, kScrollIsNotInertial,
           ScrollUpdateEventMetrics::ScrollUpdateType::kStarted),
       CreateScrollUpdateEventMetrics(
-          kScrollIsNotInertial,
+          ui::ScrollInputType::kWheel, kScrollIsNotInertial,
           ScrollUpdateEventMetrics::ScrollUpdateType::kContinued),
       CreateScrollUpdateEventMetrics(
-          kScrollIsInertial,
+          ui::ScrollInputType::kWheel, kScrollIsInertial,
+          ScrollUpdateEventMetrics::ScrollUpdateType::kContinued),
+      CreateScrollBeginEventMetrics(ui::ScrollInputType::kTouchscreen),
+      CreateScrollUpdateEventMetrics(
+          ui::ScrollInputType::kTouchscreen, kScrollIsNotInertial,
+          ScrollUpdateEventMetrics::ScrollUpdateType::kStarted),
+      CreateScrollUpdateEventMetrics(
+          ui::ScrollInputType::kTouchscreen, kScrollIsNotInertial,
+          ScrollUpdateEventMetrics::ScrollUpdateType::kContinued),
+      CreateScrollUpdateEventMetrics(
+          ui::ScrollInputType::kTouchscreen, kScrollIsInertial,
           ScrollUpdateEventMetrics::ScrollUpdateType::kContinued),
   };
   EXPECT_THAT(event_metrics_ptrs, Each(NotNull()));
@@ -1280,10 +1324,29 @@ TEST_F(CompositorFrameReportingControllerTest,
     const base::HistogramBase::Count count;
   } expected_counts[] = {
       {"EventLatency.GestureScrollBegin.Wheel.TotalLatency", 1},
+      {"EventLatency.GestureScrollBegin.Wheel.TotalLatency2", 1},
       {"EventLatency.FirstGestureScrollUpdate.Wheel.TotalLatency", 1},
+      {"EventLatency.FirstGestureScrollUpdate.Wheel.TotalLatency2", 1},
       {"EventLatency.GestureScrollUpdate.Wheel.TotalLatency", 1},
+      {"EventLatency.GestureScrollUpdate.Wheel.TotalLatency2", 1},
       {"EventLatency.InertialGestureScrollUpdate.Wheel.TotalLatency", 1},
-      {"EventLatency.TotalLatency", 4},
+      {"EventLatency.InertialGestureScrollUpdate.Wheel.TotalLatency", 1},
+      {"EventLatency.GestureScrollBegin.Touchscreen.TotalLatency2", 1},
+      {"EventLatency.FirstGestureScrollUpdate.Touchscreen.TotalLatency", 1},
+      {"EventLatency.FirstGestureScrollUpdate.Touchscreen.TotalLatency2", 1},
+      {"EventLatency.GestureScrollUpdate.Touchscreen.TotalLatency", 1},
+      {"EventLatency.GestureScrollUpdate.Touchscreen.TotalLatency2", 1},
+      {"EventLatency.InertialGestureScrollUpdate.Touchscreen.TotalLatency", 1},
+      {"EventLatency.InertialGestureScrollUpdate.Touchscreen.TotalLatency2", 1},
+      {"EventLatency.GestureScrollBegin.TotalLatency", 2},
+      {"EventLatency.GestureScrollBegin.TotalLatency2", 2},
+      {"EventLatency.FirstGestureScrollUpdate.TotalLatency", 2},
+      {"EventLatency.FirstGestureScrollUpdate.TotalLatency2", 2},
+      {"EventLatency.GestureScrollUpdate.TotalLatency", 2},
+      {"EventLatency.GestureScrollUpdate.TotalLatency2", 2},
+      {"EventLatency.InertialGestureScrollUpdate.TotalLatency", 2},
+      {"EventLatency.InertialGestureScrollUpdate.TotalLatency2", 2},
+      {"EventLatency.TotalLatency", 8},
   };
   for (const auto& expected_count : expected_counts) {
     histogram_tester.ExpectTotalCount(expected_count.name,
@@ -1299,15 +1362,51 @@ TEST_F(CompositorFrameReportingControllerTest,
       {"EventLatency.GestureScrollBegin.Wheel.TotalLatency",
        static_cast<base::HistogramBase::Sample>(
            (presentation_time - event_times[0]).InMicroseconds())},
+      {"EventLatency.GestureScrollBegin.Wheel.TotalLatency2",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[0]).InMicroseconds())},
       {"EventLatency.FirstGestureScrollUpdate.Wheel.TotalLatency",
        static_cast<base::HistogramBase::Sample>(
            (presentation_time - event_times[1]).InMicroseconds())},
+      {"EventLatency.FirstGestureScrollUpdate.Wheel.TotalLatency2",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[1]).InMicroseconds())},
       {"EventLatency.GestureScrollUpdate.Wheel.TotalLatency",
        static_cast<base::HistogramBase::Sample>(
            (presentation_time - event_times[2]).InMicroseconds())},
+      {"EventLatency.GestureScrollUpdate.Wheel.TotalLatency2",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[2]).InMicroseconds())},
       {"EventLatency.InertialGestureScrollUpdate.Wheel.TotalLatency",
        static_cast<base::HistogramBase::Sample>(
            (presentation_time - event_times[3]).InMicroseconds())},
+      {"EventLatency.InertialGestureScrollUpdate.Wheel.TotalLatency2",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[3]).InMicroseconds())},
+      {"EventLatency.GestureScrollBegin.Touchscreen.TotalLatency",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[4]).InMicroseconds())},
+      {"EventLatency.GestureScrollBegin.Touchscreen.TotalLatency2",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[4]).InMicroseconds())},
+      {"EventLatency.FirstGestureScrollUpdate.Touchscreen.TotalLatency",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[5]).InMicroseconds())},
+      {"EventLatency.FirstGestureScrollUpdate.Touchscreen.TotalLatency2",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[5]).InMicroseconds())},
+      {"EventLatency.GestureScrollUpdate.Touchscreen.TotalLatency",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[6]).InMicroseconds())},
+      {"EventLatency.GestureScrollUpdate.Touchscreen.TotalLatency2",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[6]).InMicroseconds())},
+      {"EventLatency.InertialGestureScrollUpdate.Touchscreen.TotalLatency",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[7]).InMicroseconds())},
+      {"EventLatency.InertialGestureScrollUpdate.Touchscreen.TotalLatency2",
+       static_cast<base::HistogramBase::Sample>(
+           (presentation_time - event_times[7]).InMicroseconds())},
   };
   for (const auto& expected_latency : expected_latencies) {
     histogram_tester.ExpectBucketCount(expected_latency.name,
@@ -1315,6 +1414,83 @@ TEST_F(CompositorFrameReportingControllerTest,
   }
 }
 
+TEST_F(CompositorFrameReportingControllerTest,
+       EventLatencyMainRepaintedScroll) {
+  base::HistogramTester histogram_tester;
+
+  // Set up two EventMetrics objects.
+  std::unique_ptr<EventMetrics> metrics_1 = CreateScrollUpdateEventMetrics(
+      ui::ScrollInputType::kWheel, /*is_inertial=*/false,
+      ScrollUpdateEventMetrics::ScrollUpdateType::kStarted);
+  metrics_1->set_requires_main_thread_update();
+  base::TimeTicks start_time_1 = metrics_1->GetDispatchStageTimestamp(
+      EventMetrics::DispatchStage::kGenerated);
+
+  // The second EventMetrics does not have set_requires_main_thread_update().
+  // (It's not very realistic for the same scroll gesture to produce two events
+  // with differing values for this bit, but let's test both conditions here.)
+  std::unique_ptr<EventMetrics> metrics_2 = CreateScrollUpdateEventMetrics(
+      ui::ScrollInputType::kWheel, /*is_inertial=*/false,
+      ScrollUpdateEventMetrics::ScrollUpdateType::kContinued);
+  base::TimeTicks start_time_2 = metrics_2->GetDispatchStageTimestamp(
+      EventMetrics::DispatchStage::kGenerated);
+
+  // Simulate a frame getting stuck in the main thread.
+  SimulateBeginImplFrame();
+  SimulateBeginMainFrame();
+  reporting_controller_.OnFinishImplFrame(current_id_);
+
+  // Submit a partial update with our events from the compositor thread.
+  EventMetrics::List metrics_list;
+  metrics_list.push_back(std::move(metrics_1));
+  metrics_list.push_back(std::move(metrics_2));
+  reporting_controller_.DidSubmitCompositorFrame(
+      *current_token_, AdvanceNowByMs(10), current_id_, {},
+      {{}, std::move(metrics_list)},
+      /*has_missing_content=*/false);
+
+  // Present the partial update.
+  viz::FrameTimingDetails details_1 = {};
+  details_1.presentation_feedback.timestamp = AdvanceNowByMs(10);
+  reporting_controller_.DidPresentCompositorFrame(*current_token_, details_1);
+
+  // Let the main thread finish its work.
+  SimulateCommit(nullptr);
+  SimulateActivate();
+
+  // Submit the final update.
+  SimulateBeginImplFrame();
+  reporting_controller_.OnFinishImplFrame(current_id_);
+  SimulateSubmitCompositorFrame({});
+
+  // Present the final update.
+  viz::FrameTimingDetails details_2 = {};
+  details_2.presentation_feedback.timestamp = AdvanceNowByMs(10);
+  reporting_controller_.DidPresentCompositorFrame(*current_token_, details_2);
+
+  // metrics_1 has requires_main_thread_update(), so its latency is based on the
+  // final-update presentation (details_2).
+  base::TimeDelta expected_latency_1 =
+      details_2.presentation_feedback.timestamp - start_time_1;
+  histogram_tester.ExpectBucketCount(
+      "EventLatency.FirstGestureScrollUpdate.Wheel.TotalLatency",
+      expected_latency_1.InMicroseconds(), 1);
+  histogram_tester.ExpectBucketCount(
+      "EventLatency.FirstGestureScrollUpdate.Wheel.TotalLatency2",
+      expected_latency_1.InMicroseconds(), 1);
+
+  // metrics_2 did NOT have requires_main_thread_update(), so its latency is
+  // based on the partial-update presentation (details_1).
+  base::TimeDelta expected_latency_2 =
+      details_1.presentation_feedback.timestamp - start_time_2;
+  histogram_tester.ExpectBucketCount(
+      "EventLatency.GestureScrollUpdate.Wheel.TotalLatency",
+      expected_latency_2.InMicroseconds(), 1);
+  histogram_tester.ExpectBucketCount(
+      "EventLatency.GestureScrollUpdate.Wheel.TotalLatency2",
+      expected_latency_2.InMicroseconds(), 1);
+}
+
 // Tests that EventLatency total latency histograms are reported properly for
 // pinch events when a frame is presented to the user.
 TEST_F(CompositorFrameReportingControllerTest,
@@ -1474,13 +1650,15 @@ TEST_F(CompositorFrameReportingControllerTest,
   // for the pending main-thread frame).
   SimulateBeginMainFrame();
   reporting_controller_.OnFinishImplFrame(current_id_);
-  reporting_controller_.DidSubmitCompositorFrame(1u, current_id_, {}, {},
+  reporting_controller_.DidSubmitCompositorFrame(1u, AdvanceNowByMs(10),
+                                                 current_id_, {}, {},
                                                  /*has_missing_content=*/false);
   viz::FrameTimingDetails details = {};
   details.presentation_feedback.timestamp = AdvanceNowByMs(10);
   reporting_controller_.DidPresentCompositorFrame(1u, details);
 
   // The main-thread responds now, triggering a commit and activation.
+  reporting_controller_.NotifyReadyToCommit(nullptr);
   reporting_controller_.WillCommit();
   reporting_controller_.DidCommit();
   reporting_controller_.WillActivate();
@@ -1493,8 +1671,9 @@ TEST_F(CompositorFrameReportingControllerTest,
   // and R2M.
   SimulateBeginMainFrame();
   reporting_controller_.OnFinishImplFrame(current_id_);
-  reporting_controller_.DidSubmitCompositorFrame(
-      1u, current_id_, previous_id, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(1u, AdvanceNowByMs(10),
+                                                 current_id_, previous_id, {},
+                                                 /*has_missing_content=*/false);
   details.presentation_feedback.timestamp = AdvanceNowByMs(10);
   reporting_controller_.DidPresentCompositorFrame(1u, details);
 
@@ -1524,7 +1703,8 @@ TEST_F(CompositorFrameReportingControllerTest,
   // main reporter and adopted by it.
   SimulateBeginImplFrame();
   reporting_controller_.OnFinishImplFrame(current_id_);
-  reporting_controller_.DidSubmitCompositorFrame(1u, current_id_, {}, {},
+  reporting_controller_.DidSubmitCompositorFrame(1u, AdvanceNowByMs(10),
+                                                 current_id_, {}, {},
                                                  /*has_missing_content=*/false);
 
   viz::FrameTimingDetails details_1 = {};
@@ -1547,7 +1727,8 @@ TEST_F(CompositorFrameReportingControllerTest,
   // failure, hence not adopted by the main reporter.
   SimulateBeginImplFrame();
   reporting_controller_.OnFinishImplFrame(current_id_);
-  reporting_controller_.DidSubmitCompositorFrame(2u, current_id_, {}, {},
+  reporting_controller_.DidSubmitCompositorFrame(2u, AdvanceNowByMs(10),
+                                                 current_id_, {}, {},
                                                  /*has_missing_content=*/false);
 
   viz::FrameTimingDetails details_2 = {};
@@ -1836,7 +2017,8 @@ TEST_F(CompositorFrameReportingControllerTest,
 
   SimulateBeginMainFrame();
   reporting_controller_.OnFinishImplFrame(current_id_);
-  reporting_controller_.DidSubmitCompositorFrame(1u, current_id_, {}, {},
+  reporting_controller_.DidSubmitCompositorFrame(1u, AdvanceNowByMs(10),
+                                                 current_id_, {}, {},
                                                  /*has_missing_content=*/false);
   viz::FrameTimingDetails details = {};
   details.presentation_feedback.timestamp = AdvanceNowByMs(10);
@@ -1856,8 +2038,9 @@ TEST_F(CompositorFrameReportingControllerTest,
   reporting_controller_.WillActivate();
   reporting_controller_.DidActivate();
 
-  reporting_controller_.DidSubmitCompositorFrame(
-      2u, current_id_, previous_id, {}, /*has_missing_content=*/false);
+  reporting_controller_.DidSubmitCompositorFrame(2u, AdvanceNowByMs(10),
+                                                 current_id_, previous_id, {},
+                                                 /*has_missing_content=*/false);
   details.presentation_feedback.timestamp = AdvanceNowByMs(10);
   reporting_controller_.DidPresentCompositorFrame(2u, details);
 
@@ -1909,5 +2092,64 @@ TEST_F(CompositorFrameReportingControllerTest,
   EXPECT_EQ(3u, dropped_counter_.total_frames());
 }
 
+TEST_F(CompositorFrameReportingControllerTest, MainFrameBeforeCommit) {
+  viz::BeginFrameArgs args1 = SimulateBeginFrameArgs({1, 1});
+  viz::BeginFrameArgs args2 = SimulateBeginFrameArgs({1, 2});
+  viz::BeginFrameArgs args3 = SimulateBeginFrameArgs({1, 3});
+  viz::BeginFrameArgs args4 = SimulateBeginFrameArgs({1, 4});
+
+  // Frame 1
+  reporting_controller_.WillBeginImplFrame(args1);
+  reporting_controller_.WillBeginMainFrame(args1);
+  reporting_controller_.NotifyReadyToCommit(nullptr);
+  // Frame 1 is ready to commit, so we can pipeline frame 2.
+  reporting_controller_.WillBeginImplFrame(args2);
+  reporting_controller_.WillBeginMainFrame(args2);
+  EXPECT_EQ(2, reporting_controller_.ActiveReporters());
+  EXPECT_TRUE(reporting_controller_.HasReporterAt(
+      CompositorFrameReportingController::PipelineStage::kBeginMainFrame));
+  EXPECT_TRUE(reporting_controller_.HasReporterAt(
+      CompositorFrameReportingController::PipelineStage::kReadyToCommit));
+
+  // Commit frame 1
+  reporting_controller_.WillCommit();
+  reporting_controller_.DidCommit();
+  // Frame 2 ready to commit
+  reporting_controller_.NotifyReadyToCommit(nullptr);
+  reporting_controller_.WillBeginImplFrame(args3);
+  EXPECT_EQ(3, reporting_controller_.ActiveReporters());
+  // Pipeline frame 3
+  reporting_controller_.WillBeginMainFrame(args3);
+  EXPECT_EQ(3, reporting_controller_.ActiveReporters());
+  EXPECT_TRUE(reporting_controller_.HasReporterAt(
+      CompositorFrameReportingController::PipelineStage::kBeginMainFrame));
+  EXPECT_TRUE(reporting_controller_.HasReporterAt(
+      CompositorFrameReportingController::PipelineStage::kReadyToCommit));
+  EXPECT_TRUE(reporting_controller_.HasReporterAt(
+      CompositorFrameReportingController::PipelineStage::kCommit));
+
+  // Activate frame 1
+  reporting_controller_.WillActivate();
+  reporting_controller_.DidActivate();
+  // Commit frame 2
+  reporting_controller_.WillCommit();
+  reporting_controller_.DidCommit();
+  // Frame 3 ready to commit
+  reporting_controller_.NotifyReadyToCommit(nullptr);
+  reporting_controller_.WillBeginImplFrame(args4);
+  EXPECT_EQ(4, reporting_controller_.ActiveReporters());
+  // Pipeline frame 4
+  reporting_controller_.WillBeginMainFrame(args4);
+  EXPECT_EQ(4, reporting_controller_.ActiveReporters());
+  EXPECT_TRUE(reporting_controller_.HasReporterAt(
+      CompositorFrameReportingController::PipelineStage::kBeginMainFrame));
+  EXPECT_TRUE(reporting_controller_.HasReporterAt(
+      CompositorFrameReportingController::PipelineStage::kReadyToCommit));
+  EXPECT_TRUE(reporting_controller_.HasReporterAt(
+      CompositorFrameReportingController::PipelineStage::kCommit));
+  EXPECT_TRUE(reporting_controller_.HasReporterAt(
+      CompositorFrameReportingController::PipelineStage::kActivate));
+}
+
 }  // namespace
 }  // namespace cc
