@@ -13,6 +13,7 @@
 #include "base/trace_event/trace_event.h"
 #include "cc/paint/clear_for_opaque_raster.h"
 #include "cc/paint/paint_op_buffer_iterator.h"
+#include "cc/paint/paint_op_writer.h"
 #include "cc/paint/scoped_raster_flags.h"
 #include "skia/ext/legacy_display_globals.h"
 #include "third_party/skia/include/core/SkColorSpace.h"
@@ -59,6 +60,10 @@ PaintOpBufferSerializer::~PaintOpBufferSerializer() = default;
 void PaintOpBufferSerializer::Serialize(const PaintOpBuffer& buffer,
                                         const std::vector<size_t>* offsets,
                                         const Preamble& preamble) {
+  TRACE_EVENT_BEGIN1("cc", "PaintOpBufferSerializer::Serialize",
+                     "total_op_count", buffer.total_op_count());
+  DCHECK_EQ(serialized_op_count_, 0u);
+
   std::unique_ptr<SkCanvas> canvas = MakeAnalysisCanvas(options_);
 
   // These PlaybackParams use the initial (identity) canvas matrix, as they are
@@ -67,11 +72,13 @@ void PaintOpBufferSerializer::Serialize(const PaintOpBuffer& buffer,
   // post-preamble canvas.
   PlaybackParams params = MakeParams(canvas.get());
 
-  int saveCount = canvas->getSaveCount();
+  int save_count = canvas->getSaveCount();
   Save(canvas.get(), params);
   SerializePreamble(canvas.get(), preamble, params);
   SerializeBuffer(canvas.get(), buffer, offsets);
-  RestoreToCount(canvas.get(), saveCount, params);
+  RestoreToCount(canvas.get(), save_count, params);
+  TRACE_EVENT_END1("cc", "PaintOpBufferSerializer::Serialize",
+                   "serialized_op_count", serialized_op_count_);
 }
 
 void PaintOpBufferSerializer::Serialize(const PaintOpBuffer& buffer) {
@@ -309,8 +316,8 @@ bool PaintOpBufferSerializer::SerializeOp(SkCanvas* canvas,
     return false;
   }
 
-  DCHECK_GE(bytes, 4u);
-  DCHECK_EQ(bytes % PaintOpBuffer::kPaintOpAlign, 0u);
+  ++serialized_op_count_;
+  DCHECK_GE(bytes, PaintOpWriter::kHeaderBytes);
   return true;
 }
 
