@@ -88,7 +88,7 @@ GpuRasterBufferProvider::RasterBufferImpl::RasterBufferImpl(
     : client_(client),
       backing_(backing),
       resource_size_(in_use_resource.size()),
-      resource_format_(in_use_resource.format()),
+      shared_image_format_(in_use_resource.format()),
       color_space_(in_use_resource.color_space()),
       resource_has_previous_content_(resource_has_previous_content),
       depends_on_at_raster_decodes_(depends_on_at_raster_decodes),
@@ -140,7 +140,7 @@ GpuRasterBufferProvider::GpuRasterBufferProvider(
     viz::ContextProvider* compositor_context_provider,
     viz::RasterContextProvider* worker_context_provider,
     bool use_gpu_memory_buffer_resources,
-    viz::ResourceFormat tile_format,
+    viz::SharedImageFormat tile_format,
     const gfx::Size& max_tile_size,
     bool unpremultiply_and_dither_low_bit_depth_tiles,
     RasterQueryQueue* const pending_raster_queries,
@@ -194,12 +194,12 @@ void GpuRasterBufferProvider::Flush() {
   compositor_context_provider_->ContextSupport()->FlushPendingWork();
 }
 
-viz::ResourceFormat GpuRasterBufferProvider::GetResourceFormat() const {
+viz::SharedImageFormat GpuRasterBufferProvider::GetFormat() const {
   return tile_format_;
 }
 
 bool GpuRasterBufferProvider::IsResourcePremultiplied() const {
-  return !ShouldUnpremultiplyAndDitherResource(GetResourceFormat());
+  return !ShouldUnpremultiplyAndDitherResource(GetFormat());
 }
 
 bool GpuRasterBufferProvider::IsResourceReadyToDraw(
@@ -363,10 +363,10 @@ void GpuRasterBufferProvider::RasterBufferImpl::RasterizeSource(
     } else if (client_->is_using_raw_draw_) {
       flags |= gpu::SHARED_IMAGE_USAGE_RAW_DRAW;
     }
-    backing_->mailbox =
-        sii->CreateSharedImage(resource_format_, resource_size_, color_space_,
-                               kTopLeft_GrSurfaceOrigin, kPremul_SkAlphaType,
-                               flags, gpu::kNullSurfaceHandle);
+    backing_->mailbox = sii->CreateSharedImage(
+        shared_image_format_, resource_size_, color_space_,
+        kTopLeft_GrSurfaceOrigin, kPremul_SkAlphaType, flags,
+        gpu::kNullSurfaceHandle);
     mailbox_needs_clear = true;
     ri->WaitSyncTokenCHROMIUM(sii->GenUnverifiedSyncToken().GetConstData());
   } else {
@@ -419,7 +419,7 @@ void GpuRasterBufferProvider::RasterBufferImpl::RasterizeSource(
 }
 
 bool GpuRasterBufferProvider::ShouldUnpremultiplyAndDitherResource(
-    viz::ResourceFormat format) const {
+    viz::SharedImageFormat format) const {
   // TODO(crbug.com/1151490): Re-enable for OOPR.
   return false;
 }
