@@ -1,4 +1,4 @@
-// Copyright 2011 The Chromium Authors. All rights reserved.
+// Copyright 2011 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -73,10 +73,14 @@ void ClearDamageForAllSurfaces(LayerImpl* root) {
 }
 
 void SetCopyRequest(LayerImpl* root) {
-  auto* root_node = root->layer_tree_impl()->property_trees()->effect_tree.Node(
-      root->effect_tree_index());
+  auto* root_node =
+      root->layer_tree_impl()->property_trees()->effect_tree_mutable().Node(
+          root->effect_tree_index());
   root_node->has_copy_request = true;
-  root->layer_tree_impl()->property_trees()->effect_tree.set_needs_update(true);
+  root->layer_tree_impl()
+      ->property_trees()
+      ->effect_tree_mutable()
+      .set_needs_update(true);
 }
 
 class DamageTrackerTest : public LayerTreeImplTestBase, public testing::Test {
@@ -250,7 +254,8 @@ class DamageTrackerTest : public LayerTreeImplTestBase, public testing::Test {
     // consideration.
     root->layer_tree_impl()
         ->property_trees()
-        ->effect_tree.Node(child1_->effect_tree_index())
+        ->effect_tree_mutable()
+        .Node(child1_->effect_tree_index())
         ->backdrop_filters.Append(
             FilterOperation::CreateZoomFilter(2.f /* zoom */, 0 /* inset */));
 
@@ -1074,7 +1079,7 @@ TEST_F(DamageTrackerTest, VerifyDamageForHighDPIImageFilter) {
   // Blur outset is 9px for a 3px blur, scaled up by DSF.
   int blur_outset = 9 * device_scale_factor;
   gfx::Rect expected_child_damage_rect(60, 60);
-  expected_child_damage_rect.Inset(-blur_outset, -blur_outset);
+  expected_child_damage_rect.Inset(-blur_outset);
   gfx::Rect expected_root_damage_rect(child_damage_rect);
   expected_root_damage_rect.Offset(200, 200);
   EXPECT_EQ(expected_root_damage_rect, root_damage_rect);
@@ -1323,8 +1328,8 @@ TEST_F(DamageTrackerTest, VerifyDamageForSurfaceChangeFromDescendantLayer) {
 }
 
 TEST_F(DamageTrackerTest, VerifyDamageForSurfaceChangeFromDescendantSurface) {
-  // If descendant surface changes position, the ancestor surface should be
-  // damaged with the old and new descendant surface regions.
+  // CASE 1: If descendant surface changes position, the ancestor surface should
+  //         be damaged with the old and new descendant surface regions.
 
   LayerImpl* root = CreateAndSetUpTestTreeWithTwoSurfaces();
   child1_->SetDrawsContent(true);
@@ -1357,6 +1362,37 @@ TEST_F(DamageTrackerTest, VerifyDamageForSurfaceChangeFromDescendantSurface) {
   EXPECT_TRUE(GetRenderSurface(child1_)
                   ->damage_tracker()
                   ->has_damage_from_contributing_content());
+
+  // CASE 2: Change render surface content rect should make
+  //         |has_damage_from_contributing_content| true.
+  ClearDamageForAllSurfaces(root);
+  CreateEffectNode(child2_).render_surface_reason = RenderSurfaceReason::kTest;
+  EmulateDrawingOneFrame(root);
+
+  // Surface property changed only from descendant.
+  child2_->SetBounds(gfx::Size(120, 140));
+  EmulateDrawingOneFrame(root);
+
+  EXPECT_TRUE(GetRenderSurface(root)
+                  ->damage_tracker()
+                  ->has_damage_from_contributing_content());
+
+  EXPECT_TRUE(GetRenderSurface(child2_)
+                  ->damage_tracker()
+                  ->has_damage_from_contributing_content());
+
+  // Surface property changed from both parent and descendant.
+  child2_->SetBounds(gfx::Size(220, 240));
+  root->layer_tree_impl()->SetOpacityMutated(child2_->element_id(), 0.5f);
+  EmulateDrawingOneFrame(root);
+
+  EXPECT_TRUE(GetRenderSurface(root)
+                  ->damage_tracker()
+                  ->has_damage_from_contributing_content());
+
+  EXPECT_TRUE(GetRenderSurface(child2_)
+                  ->damage_tracker()
+                  ->has_damage_from_contributing_content());
 }
 
 TEST_F(DamageTrackerTest, VerifyDamageForSurfaceChangeFromAncestorLayer) {
