@@ -134,10 +134,6 @@ class CC_EXPORT LayerTreeSettings {
   // deadlines.
   bool wait_for_all_pipeline_stages_before_draw = false;
 
-  // Determines whether mouse interactions on composited scrollbars are handled
-  // on the compositor thread.
-  bool compositor_threaded_scrollbar_scrolling = true;
-
   // If enabled, the scroll deltas will be a percentage of the target scroller.
   bool percent_based_scrolling = false;
 
@@ -181,9 +177,6 @@ class CC_EXPORT LayerTreeSettings {
   // Defaults to true.
   bool enable_occlusion = true;
 
-  // Whether experimental de-jelly effect is allowed.
-  bool allow_de_jelly_effect = false;
-
   // Whether the compositor should attempt to sync with the scroll handlers
   // before submitting a frame.
   bool enable_synchronized_scrolling = true;
@@ -216,9 +209,6 @@ class CC_EXPORT LayerTreeSettings {
   // to find the link to the Fluent Scrollbar spec and related CLs.
   bool enable_fluent_scrollbar = false;
 
-  // This corresponds to the ScrollUpdateOptimizations feature.
-  bool enable_scroll_update_optimizations = false;
-
   // Whether to disable the frame rate limit in the scheduler.
   bool disable_frame_rate_limit = false;
 
@@ -230,6 +220,11 @@ class CC_EXPORT LayerTreeSettings {
   // Enables shared image cache for gpu.
   // TODO(crbug.com/1378251): not ready to be used by renderer cc instance yet.
   bool enable_shared_image_cache_for_gpu = false;
+
+  // Maximum size for buffers allocated for rendering when GPU compositing is
+  // disabled. This size is equivalent to the max texture size in GPU mode.
+  // This is an arbitrary limit here similar to what hardware might have.
+  int max_render_buffer_bounds_for_sw = 16 * 1024;
 };
 
 class CC_EXPORT LayerListSettings : public LayerTreeSettings {
