@@ -10,7 +10,7 @@
 #include <utility>
 #include <vector>
 
-#include "base/bind.h"
+#include "base/functional/bind.h"
 #include "base/notreached.h"
 #include "base/synchronization/waitable_event.h"
 #include "base/trace_event/trace_event.h"
@@ -94,9 +94,14 @@ void ProxyMain::BeginMainFrameNotExpectedUntil(base::TimeTicks time) {
   layer_tree_host_->BeginMainFrameNotExpectedUntil(time);
 }
 
-void ProxyMain::DidCommitAndDrawFrame() {
+void ProxyMain::DidCommitAndDrawFrame(int source_frame_number) {
   DCHECK(IsMainThread());
   layer_tree_host_->DidCommitAndDrawFrame();
+  if (synchronous_composite_for_test_callback_ &&
+      source_frame_number == synchronous_composite_source_frame_number_) {
+    synchronous_composite_source_frame_number_ = -1;
+    std::move(synchronous_composite_for_test_callback_).Run();
+  }
 }
 
 void ProxyMain::DidLoseLayerTreeFrameSink() {
@@ -217,6 +222,14 @@ void ProxyMain::BeginMainFrame(
     return;
   }
 
+  // This call winds through to the LocalFrameView to mark the beginning
+  // of a main frame for metrics purposes. Some metrics are only gathered
+  // between calls to RecordStartOfFrameMetrics and RecordEndOfFrameMetrics.
+  // This is not wrapped into layer_tree_host_->WillBeginMainFrame because
+  // it should only be called from the multi-threaded proxy (we do not want
+  // metrics gathering in tests).
+  layer_tree_host_->RecordStartOfFrameMetrics();
+
   final_pipeline_stage_ =
       std::max(final_pipeline_stage_, deferred_final_pipeline_stage_);
   deferred_final_pipeline_stage_ = NO_PIPELINE_STAGE;
@@ -248,14 +261,6 @@ void ProxyMain::BeginMainFrame(
 
   layer_tree_host_->WillBeginMainFrame();
 
-  // This call winds through to the LocalFrameView to mark the beginning
-  // of a main frame for metrics purposes. Some metrics are only gathered
-  // between calls to RecordStartOfFrameMetrics and RecordEndOfFrameMetrics.
-  // This is not wrapped into layer_tree_host_->WillBeginMainFrame because
-  // it should only be called from the multi-threaded proxy (we do not want
-  // metrics gathering in tests).
-  layer_tree_host_->RecordStartOfFrameMetrics();
-
   // See LayerTreeHostClient::BeginMainFrame for more documentation on
   // what this does.
   layer_tree_host_->BeginMainFrame(frame_args);
@@ -326,6 +331,16 @@ void ProxyMain::BeginMainFrame(
     return;
   }
 
+  // The devtools "Commit" step includes the update layers pipeline stage
+  // through to the actual commit to the impl thread. This is done for
+  // simplicity and it follows
+  // https://developer.chrome.com/articles/renderingng-architecture.
+  //
+  // TODO(paint-dev): It is not clear how to best show the interlacing of main
+  // thread tasks with commit (non-blocking commit) (crbug.com/1277952).
+  commit_trace_ = std::make_unique<devtools_instrumentation::ScopedCommitTrace>(
+      layer_tree_host_->GetId(), frame_args.frame_id.sequence_number);
+
   // If UI resources were evicted on the impl thread, we need a commit.
   if (begin_main_frame_state->evicted_ui_resources)
     final_pipeline_stage_ = COMMIT_PIPELINE_STAGE;
@@ -343,14 +358,14 @@ void ProxyMain::BeginMainFrame(
   // to corresponding  cc display list. An exception is for painted scrollbars,
   // which paint eagerly during layer update.
   bool updated = should_update_layers && layer_tree_host_->UpdateLayers();
+  if (synchronous_composite_for_test_callback_) {
+    updated = true;
+  }
 
   // If updating the layers resulted in a content update, we need a commit.
   if (updated)
     final_pipeline_stage_ = COMMIT_PIPELINE_STAGE;
 
-  commit_trace_ = std::make_unique<devtools_instrumentation::ScopedCommitTrace>(
-      layer_tree_host_->GetId(), frame_args.frame_id.sequence_number);
-
   auto completion_event_ptr = std::make_unique<CompletionEvent>(
       base::WaitableEvent::ResetPolicy::MANUAL);
   auto* completion_event = completion_event_ptr.get();
@@ -359,6 +374,7 @@ void ProxyMain::BeginMainFrame(
   auto& unsafe_state = layer_tree_host_->GetUnsafeStateForCommit();
   std::unique_ptr<CommitState> commit_state = layer_tree_host_->WillCommit(
       std::move(completion_event_ptr), has_updates);
+
   DCHECK_EQ(has_updates, (bool)commit_state.get());
   if (commit_state.get()) {
     commit_state->trace_id =
@@ -408,6 +424,12 @@ void ProxyMain::BeginMainFrame(
     return;
   }
 
+  if (synchronous_composite_for_test_callback_ &&
+      synchronous_composite_source_frame_number_ == -1) {
+    synchronous_composite_source_frame_number_ =
+        commit_state->source_frame_number;
+  }
+
   current_pipeline_stage_ = NO_PIPELINE_STAGE;
 
   // Notify the impl thread that the main thread is ready to commit. This will
@@ -612,8 +634,6 @@ void ProxyMain::SetPauseRendering(bool pause_rendering) {
                                     TRACE_ID_LOCAL(this));
   }
 
-  layer_tree_host_->OnPauseRenderingChanged(pause_rendering_);
-
   // The impl thread needs to know that it should not issue BeginFrames.
   ImplThreadTaskRunner()->PostTask(
       FROM_HERE,
@@ -721,7 +741,7 @@ void ProxyMain::Stop() {
 }
 
 void ProxyMain::SetMutator(std::unique_ptr<LayerTreeMutator> mutator) {
-  TRACE_EVENT0("cc", "ThreadProxy::SetMutator");
+  TRACE_EVENT0("cc", "ProxyMain::SetMutator");
   ImplThreadTaskRunner()->PostTask(
       FROM_HERE,
       base::BindOnce(&ProxyImpl::InitializeMutatorOnImpl,
@@ -730,7 +750,7 @@ void ProxyMain::SetMutator(std::unique_ptr<LayerTreeMutator> mutator) {
 
 void ProxyMain::SetPaintWorkletLayerPainter(
     std::unique_ptr<PaintWorkletLayerPainter> painter) {
-  TRACE_EVENT0("cc", "ThreadProxy::SetPaintWorkletLayerPainter");
+  TRACE_EVENT0("cc", "ProxyMain::SetPaintWorkletLayerPainter");
   ImplThreadTaskRunner()->PostTask(
       FROM_HERE,
       base::BindOnce(&ProxyImpl::InitializePaintWorkletLayerPainterOnImpl,
@@ -794,6 +814,7 @@ bool ProxyMain::SendCommitRequestToImplThreadIfNeeded(
   ImplThreadTaskRunner()->PostTask(
       FROM_HERE, base::BindOnce(&ProxyImpl::SetNeedsCommitOnImpl,
                                 base::Unretained(proxy_impl_.get())));
+  layer_tree_host_->OnCommitRequested();
   return true;
 }
 
@@ -834,6 +855,13 @@ void ProxyMain::SetRenderFrameObserver(
                      base::Unretained(proxy_impl_.get()), std::move(observer)));
 }
 
+void ProxyMain::CompositeImmediatelyForTest(base::TimeTicks frame_begin_time,
+                                            bool raster,
+                                            base::OnceClosure callback) {
+  synchronous_composite_for_test_callback_ = std::move(callback);
+  SetNeedsCommit();
+}
+
 double ProxyMain::GetPercentDroppedFrames() const {
   NOTIMPLEMENTED();
   return 0.0;
