@@ -9,7 +9,7 @@
 #include <vector>
 
 #include "base/auto_reset.h"
-#include "base/bind.h"
+#include "base/functional/bind.h"
 #include "base/memory/ptr_util.h"
 #include "base/notreached.h"
 #include "base/synchronization/waitable_event.h"
@@ -192,6 +192,7 @@ void SingleThreadProxy::SetNeedsAnimate() {
   DebugScopedSetImplThread impl(task_runner_provider_);
   if (scheduler_on_impl_thread_)
     scheduler_on_impl_thread_->SetNeedsBeginMainFrame();
+  layer_tree_host_->OnCommitRequested();
 }
 
 void SingleThreadProxy::SetNeedsUpdateLayers() {
@@ -362,8 +363,6 @@ void SingleThreadProxy::SetPauseRendering(bool pause_rendering) {
         "cc", "SingleThreadProxy::SetPauseRendering", TRACE_ID_LOCAL(this));
   }
 
-  layer_tree_host_->OnPauseRenderingChanged(pause_rendering_);
-
   // The scheduler needs to know that it should not issue BeginFrame.
   DebugScopedSetImplThread impl(task_runner_provider_);
   scheduler_on_impl_thread_->SetPauseRendering(pause_rendering_);
@@ -734,7 +733,8 @@ void SingleThreadProxy::RequestBeginMainFrameNotExpected(bool new_state) {
 
 void SingleThreadProxy::CompositeImmediatelyForTest(
     base::TimeTicks frame_begin_time,
-    bool raster) {
+    bool raster,
+    base::OnceClosure callback) {
   TRACE_EVENT0("cc,benchmark",
                "SingleThreadProxy::CompositeImmediatelyForTest");
   DCHECK(task_runner_provider_->IsMainThread());
@@ -748,8 +748,12 @@ void SingleThreadProxy::CompositeImmediatelyForTest(
     RequestNewLayerTreeFrameSink();
     // RequestNewLayerTreeFrameSink could have synchronously created an output
     // surface, so check again before returning.
-    if (layer_tree_frame_sink_lost_)
+    if (layer_tree_frame_sink_lost_) {
+      if (callback) {
+        std::move(callback).Run();
+      }
       return;
+    }
   }
 
   viz::BeginFrameArgs begin_frame_args(viz::BeginFrameArgs::Create(
@@ -775,9 +779,12 @@ void SingleThreadProxy::CompositeImmediatelyForTest(
     // a commit here.
     commit_requested_ = true;
     StopDeferringCommits(PaintHoldingCommitTrigger::kFeatureDisabled);
+    layer_tree_host_->RecordStartOfFrameMetrics();
     DoBeginMainFrame(begin_frame_args);
     commit_requested_ = false;
     DoPainting(begin_frame_args);
+    layer_tree_host_->RecordEndOfFrameMetrics(frame_begin_time,
+                                              /* trackers */ 0u);
     DoCommit(begin_frame_args);
     DoPostCommit();
 
@@ -812,6 +819,9 @@ void SingleThreadProxy::CompositeImmediatelyForTest(
 
     DidFinishImplFrame(begin_frame_args);
   }
+  if (callback) {
+    std::move(callback).Run();
+  }
 }
 
 bool SingleThreadProxy::ShouldComposite() const {
@@ -1006,9 +1016,10 @@ void SingleThreadProxy::BeginMainFrame(
   ScopedAbortRemainingSwapPromises swap_promise_checker(
       layer_tree_host_->GetSwapPromiseManager());
 
+  base::TimeTicks frame_start_time = base::TimeTicks::Now();
+
   if (scheduler_on_impl_thread_) {
-    scheduler_on_impl_thread_->NotifyBeginMainFrameStarted(
-        base::TimeTicks::Now());
+    scheduler_on_impl_thread_->NotifyBeginMainFrameStarted(frame_start_time);
   }
 
   commit_requested_ = false;
@@ -1046,9 +1057,10 @@ void SingleThreadProxy::BeginMainFrame(
   // Check now if we should stop deferring commits. Do this before
   // DoBeginMainFrame because the latter updates scroll offsets, which
   // we should avoid if deferring commits.
-  if (IsDeferringCommits() && base::TimeTicks::Now() > commits_restart_time_)
+  if (IsDeferringCommits() && frame_start_time > commits_restart_time_)
     StopDeferringCommits(ReasonToTimeoutTrigger(*paint_holding_reason_));
 
+  layer_tree_host_->RecordStartOfFrameMetrics();
   DoBeginMainFrame(begin_frame_args);
 
   // New commits requested inside UpdateLayers should be respected.
@@ -1062,11 +1074,15 @@ void SingleThreadProxy::BeginMainFrame(
                          TRACE_EVENT_SCOPE_THREAD);
     BeginMainFrameAbortedOnImplThread(
         CommitEarlyOutReason::ABORTED_DEFERRED_COMMIT);
+    layer_tree_host_->RecordEndOfFrameMetrics(frame_start_time,
+                                              /* trackers */ 0u);
     layer_tree_host_->DidBeginMainFrame();
     return;
   }
 
   DoPainting(begin_frame_args);
+  layer_tree_host_->RecordEndOfFrameMetrics(frame_start_time,
+                                            /* trackers */ 0u);
 }
 
 void SingleThreadProxy::DoBeginMainFrame(
