@@ -1,14 +1,14 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 #include "cc/trees/ukm_manager.h"
 
-#include <algorithm>
 #include <utility>
 #include <vector>
 
 #include "base/memory/raw_ptr.h"
+#include "base/ranges/algorithm.h"
 #include "base/test/simple_test_tick_clock.h"
 #include "base/time/time.h"
 #include "cc/metrics/begin_main_frame_metrics.h"
@@ -25,15 +25,6 @@ namespace {
 
 const char kTestUrl[] = "https://example.com/foo";
 const int64_t kTestSourceId1 = 100;
-const int64_t kTestSourceId2 = 200;
-
-const char kUserInteraction[] = "Compositor.UserInteraction";
-const char kRendering[] = "Compositor.Rendering";
-
-const char kCheckerboardArea[] = "CheckerboardedContentArea";
-const char kCheckerboardAreaRatio[] = "CheckerboardedContentAreaRatio";
-const char kMissingTiles[] = "NumMissingTiles";
-const char kCheckerboardedImagesCount[] = "CheckerboardedImagesCount";
 
 // Names of compositor/event latency UKM events.
 const char kCompositorLatency[] = "Graphics.Smoothness.Latency";
@@ -67,8 +58,6 @@ const char kBlinkBreakdownLayoutUpdate[] =
 const char kBlinkBreakdownPrepaint[] = "SendBeginMainFrameToCommit.Prepaint";
 const char kBlinkBreakdownCompositingInputs[] =
     "SendBeginMainFrameToCommit.CompositingInputs";
-const char kBlinkBreakdownCompositingAssignments[] =
-    "SendBeginMainFrameToCommit.CompositingAssignments";
 const char kBlinkBreakdownPaint[] = "SendBeginMainFrameToCommit.Paint";
 const char kBlinkBreakdownCompositeCommit[] =
     "SendBeginMainFrameToCommit.CompositeCommit";
@@ -106,7 +95,6 @@ const char kVizBreakdownLatchToSwapEnd[] =
 const char kVizBreakdownSwapEndToPresentationCompositorFrame[] =
     "SubmitCompositorFrameToPresentationCompositorFrame."
     "SwapEndToPresentationCompositorFrame";
-const char kTotalLatencyToSwapBegin[] = "TotalLatencyToSwapBegin";
 const char kTotalLatency[] = "TotalLatency";
 
 // Names of frame sequence types use in compositor latency UKM metrics (see
@@ -141,13 +129,8 @@ class UkmManagerTest : public testing::Test {
     return test_tick_clock_.NowTicks();
   }
 
-  std::unique_ptr<EventMetrics> CreateEventMetrics(
-      ui::EventType type,
-      absl::optional<EventMetrics::GestureParams> gesture_params) {
-    base::TimeTicks event_time = AdvanceNowByMs(10);
-    AdvanceNowByMs(10);
-    std::unique_ptr<EventMetrics> metrics = EventMetrics::CreateForTesting(
-        type, gesture_params, event_time, &test_tick_clock_);
+  std::unique_ptr<EventMetrics> SetupEventMetrics(
+      std::unique_ptr<EventMetrics> metrics) {
     if (metrics) {
       AdvanceNowByMs(10);
       metrics->SetDispatchStageTimestamp(
@@ -165,6 +148,28 @@ class UkmManagerTest : public testing::Test {
     return metrics;
   }
 
+  std::unique_ptr<EventMetrics> CreateScrollBeginEventMetrics() {
+    base::TimeTicks event_time = AdvanceNowByMs(10);
+    base::TimeTicks arrived_in_browser_main_timestamp = AdvanceNowByMs(5);
+    AdvanceNowByMs(10);
+    return SetupEventMetrics(ScrollEventMetrics::CreateForTesting(
+        ui::ET_GESTURE_SCROLL_BEGIN, ui::ScrollInputType::kWheel,
+        /*is_inertial=*/false, event_time, arrived_in_browser_main_timestamp,
+        &test_tick_clock_));
+  }
+
+  std::unique_ptr<EventMetrics> CreateScrollUpdateEventMetrics(
+      bool is_inertial,
+      ScrollUpdateEventMetrics::ScrollUpdateType scroll_update_type) {
+    base::TimeTicks event_time = AdvanceNowByMs(10);
+    base::TimeTicks arrived_in_browser_main_timestamp = AdvanceNowByMs(5);
+    AdvanceNowByMs(10);
+    return SetupEventMetrics(ScrollUpdateEventMetrics::CreateForTesting(
+        ui::ET_GESTURE_SCROLL_UPDATE, ui::ScrollInputType::kWheel, is_inertial,
+        scroll_update_type, /*delta=*/10.0f, event_time,
+        arrived_in_browser_main_timestamp, &test_tick_clock_));
+  }
+
   struct DispatchTimestamps {
     base::TimeTicks generated;
     base::TimeTicks arrived_in_renderer;
@@ -177,9 +182,9 @@ class UkmManagerTest : public testing::Test {
       const EventMetrics::List& events_metrics) {
     std::vector<DispatchTimestamps> event_times;
     event_times.reserve(events_metrics.size());
-    std::transform(
-        events_metrics.cbegin(), events_metrics.cend(),
-        std::back_inserter(event_times), [](const auto& event_metrics) {
+    base::ranges::transform(
+        events_metrics, std::back_inserter(event_times),
+        [](const auto& event_metrics) {
           return DispatchTimestamps{
               event_metrics->GetDispatchStageTimestamp(
                   EventMetrics::DispatchStage::kGenerated),
@@ -206,13 +211,12 @@ class UkmManagerTest : public testing::Test {
     breakdown.layout_update = base::Microseconds(7);
     breakdown.compositing_inputs = base::Microseconds(6);
     breakdown.prepaint = base::Microseconds(5);
-    breakdown.compositing_assignments = base::Microseconds(4);
     breakdown.paint = base::Microseconds(3);
     breakdown.composite_commit = base::Microseconds(2);
     breakdown.update_layers = base::Microseconds(1);
 
     // Advance now by the sum of the breakdowns.
-    AdvanceNowByMs(10 + 9 + 8 + 7 + 6 + 5 + 4 + 3 + 2 + 1);
+    AdvanceNowByMs(10 + 9 + 8 + 7 + 6 + 5 + 3 + 2 + 1);
 
     return breakdown;
   }
@@ -235,64 +239,6 @@ class UkmManagerTest : public testing::Test {
   base::SimpleTestTickClock test_tick_clock_;
 };
 
-TEST_F(UkmManagerTest, Basic) {
-  manager_->SetUserInteractionInProgress(true);
-  manager_->AddCheckerboardStatsForFrame(5, 1, 10);
-  manager_->AddCheckerboardStatsForFrame(15, 3, 30);
-  manager_->AddCheckerboardedImages(6);
-  manager_->SetUserInteractionInProgress(false);
-
-  // We should see a single entry for the interaction above.
-  const auto& entries = test_ukm_recorder_->GetEntriesByName(kUserInteraction);
-  ukm::SourceId original_id = ukm::kInvalidSourceId;
-  EXPECT_EQ(1u, entries.size());
-  for (const auto* entry : entries) {
-    original_id = entry->source_id;
-    EXPECT_NE(ukm::kInvalidSourceId, entry->source_id);
-    test_ukm_recorder_->ExpectEntrySourceHasUrl(entry, GURL(kTestUrl));
-    test_ukm_recorder_->ExpectEntryMetric(entry, kCheckerboardArea, 10);
-    test_ukm_recorder_->ExpectEntryMetric(entry, kMissingTiles, 2);
-    test_ukm_recorder_->ExpectEntryMetric(entry, kCheckerboardAreaRatio, 50);
-    test_ukm_recorder_->ExpectEntryMetric(entry, kCheckerboardedImagesCount, 6);
-  }
-  test_ukm_recorder_->Purge();
-
-  // Try pushing some stats while no user interaction is happening. No entries
-  // should be pushed.
-  manager_->AddCheckerboardStatsForFrame(6, 1, 10);
-  manager_->AddCheckerboardStatsForFrame(99, 3, 100);
-  EXPECT_EQ(0u, test_ukm_recorder_->entries_count());
-  manager_->SetUserInteractionInProgress(true);
-  EXPECT_EQ(0u, test_ukm_recorder_->entries_count());
-
-  // Record a few entries and change the source before the interaction ends. The
-  // stats collected up till this point should be recorded before the source is
-  // swapped.
-  manager_->AddCheckerboardStatsForFrame(10, 1, 100);
-  manager_->AddCheckerboardStatsForFrame(30, 5, 100);
-
-  manager_->SetSourceId(kTestSourceId2);
-
-  const auto& entries2 = test_ukm_recorder_->GetEntriesByName(kUserInteraction);
-  EXPECT_EQ(1u, entries2.size());
-  for (const auto* entry : entries2) {
-    EXPECT_EQ(original_id, entry->source_id);
-    test_ukm_recorder_->ExpectEntryMetric(entry, kCheckerboardArea, 20);
-    test_ukm_recorder_->ExpectEntryMetric(entry, kMissingTiles, 3);
-    test_ukm_recorder_->ExpectEntryMetric(entry, kCheckerboardAreaRatio, 20);
-    test_ukm_recorder_->ExpectEntryMetric(entry, kCheckerboardedImagesCount, 0);
-  }
-
-  // An entry for rendering is emitted when the URL changes.
-  const auto& entries_rendering =
-      test_ukm_recorder_->GetEntriesByName(kRendering);
-  EXPECT_EQ(1u, entries_rendering.size());
-  for (const auto* entry : entries_rendering) {
-    EXPECT_EQ(original_id, entry->source_id);
-    test_ukm_recorder_->ExpectEntryMetric(entry, kCheckerboardedImagesCount, 6);
-  }
-}
-
 class UkmManagerCompositorLatencyTest
     : public UkmManagerTest,
       public testing::WithParamInterface<
@@ -444,9 +390,6 @@ TEST_P(UkmManagerCompositorLatencyTest, CompositorLatency) {
   test_ukm_recorder_->ExpectEntryMetric(
       entry, kBlinkBreakdownCompositingInputs,
       blink_breakdown.compositing_inputs.InMicroseconds());
-  test_ukm_recorder_->ExpectEntryMetric(
-      entry, kBlinkBreakdownCompositingAssignments,
-      blink_breakdown.compositing_assignments.InMicroseconds());
   test_ukm_recorder_->ExpectEntryMetric(entry, kBlinkBreakdownPaint,
                                         blink_breakdown.paint.InMicroseconds());
   test_ukm_recorder_->ExpectEntryMetric(
@@ -535,22 +478,16 @@ TEST_F(UkmManagerTest, EventLatency) {
   const bool kScrollIsInertial = true;
   const bool kScrollIsNotInertial = false;
   std::unique_ptr<EventMetrics> event_metrics_ptrs[] = {
-      CreateEventMetrics(
-          ui::ET_GESTURE_SCROLL_BEGIN,
-          EventMetrics::GestureParams(ui::ScrollInputType::kWheel,
-                                      kScrollIsNotInertial)),
-      CreateEventMetrics(ui::ET_GESTURE_SCROLL_UPDATE,
-                         EventMetrics::GestureParams(
-                             ui::ScrollInputType::kWheel, kScrollIsNotInertial,
-                             EventMetrics::ScrollUpdateType::kStarted)),
-      CreateEventMetrics(ui::ET_GESTURE_SCROLL_UPDATE,
-                         EventMetrics::GestureParams(
-                             ui::ScrollInputType::kWheel, kScrollIsNotInertial,
-                             EventMetrics::ScrollUpdateType::kContinued)),
-      CreateEventMetrics(ui::ET_GESTURE_SCROLL_UPDATE,
-                         EventMetrics::GestureParams(
-                             ui::ScrollInputType::kWheel, kScrollIsInertial,
-                             EventMetrics::ScrollUpdateType::kContinued)),
+      CreateScrollBeginEventMetrics(),
+      CreateScrollUpdateEventMetrics(
+          kScrollIsNotInertial,
+          ScrollUpdateEventMetrics::ScrollUpdateType::kStarted),
+      CreateScrollUpdateEventMetrics(
+          kScrollIsNotInertial,
+          ScrollUpdateEventMetrics::ScrollUpdateType::kContinued),
+      CreateScrollUpdateEventMetrics(
+          kScrollIsInertial,
+          ScrollUpdateEventMetrics::ScrollUpdateType::kContinued),
   };
   EXPECT_THAT(event_metrics_ptrs, ::testing::Each(::testing::NotNull()));
   EventMetrics::List events_metrics(
@@ -640,7 +577,7 @@ TEST_F(UkmManagerTest, EventLatency) {
         entry, kEventType, static_cast<int64_t>(event_metrics->type()));
     test_ukm_recorder_->ExpectEntryMetric(
         entry, kScrollInputType,
-        static_cast<int64_t>(*event_metrics->scroll_type()));
+        static_cast<int64_t>(event_metrics->AsScroll()->scroll_type()));
 
     test_ukm_recorder_->ExpectEntryMetric(
         entry, kGenerationToRendererCompositor,
@@ -695,9 +632,6 @@ TEST_F(UkmManagerTest, EventLatency) {
     test_ukm_recorder_->ExpectEntryMetric(
         entry, kBlinkBreakdownCompositingInputs,
         blink_breakdown.compositing_inputs.InMicroseconds());
-    test_ukm_recorder_->ExpectEntryMetric(
-        entry, kBlinkBreakdownCompositingAssignments,
-        blink_breakdown.compositing_assignments.InMicroseconds());
     test_ukm_recorder_->ExpectEntryMetric(
         entry, kBlinkBreakdownPaint, blink_breakdown.paint.InMicroseconds());
     test_ukm_recorder_->ExpectEntryMetric(
@@ -812,11 +746,6 @@ TEST_F(UkmManagerTest, EventLatency) {
         (viz_breakdown.presentation_feedback.timestamp -
          viz_breakdown.swap_timings.swap_end)
             .InMicroseconds());
-    test_ukm_recorder_->ExpectEntryMetric(
-        entry, kTotalLatencyToSwapBegin,
-        (viz_breakdown.swap_timings.swap_start -
-         event_dispatch_times[i].generated)
-            .InMicroseconds());
     test_ukm_recorder_->ExpectEntryMetric(
         entry, kTotalLatency,
         (viz_breakdown.presentation_feedback.timestamp -
