@@ -1,58 +1,49 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser;
 
-import android.app.Notification;
-import android.content.Intent;
-import android.os.Build;
-import android.os.Handler;
-import android.os.Looper;
-import android.support.annotation.Nullable;
+import androidx.annotation.Nullable;
+import androidx.annotation.VisibleForTesting;
+
+import com.google.android.gms.common.ConnectionResult;
+import com.google.android.gms.common.GoogleApiAvailability;
 
-import org.chromium.base.Callback;
 import org.chromium.base.ContextUtils;
-import org.chromium.base.VisibleForTesting;
+import org.chromium.base.PackageUtils;
 import org.chromium.base.annotations.CalledByNative;
-import org.chromium.chrome.browser.banners.AppDetailsDelegate;
 import org.chromium.chrome.browser.customtabs.CustomTabsConnection;
-import org.chromium.chrome.browser.datausage.ExternalDataUseObserver;
-import org.chromium.chrome.browser.externalauth.ExternalAuthUtils;
-import org.chromium.chrome.browser.feedback.AsyncFeedbackSource;
-import org.chromium.chrome.browser.feedback.FeedbackCollector;
+import org.chromium.chrome.browser.directactions.DirectActionCoordinator;
 import org.chromium.chrome.browser.feedback.FeedbackReporter;
-import org.chromium.chrome.browser.feedback.FeedbackSource;
-import org.chromium.chrome.browser.feedback.FeedbackSourceProvider;
+import org.chromium.chrome.browser.feedback.HelpAndFeedbackLauncher;
+import org.chromium.chrome.browser.feedback.HelpAndFeedbackLauncherImpl;
 import org.chromium.chrome.browser.gsa.GSAHelper;
-import org.chromium.chrome.browser.help.HelpAndFeedback;
 import org.chromium.chrome.browser.historyreport.AppIndexingReporter;
+import org.chromium.chrome.browser.init.ChromeStartupDelegate;
 import org.chromium.chrome.browser.init.ProcessInitializationHandler;
 import org.chromium.chrome.browser.instantapps.InstantAppsHandler;
-import org.chromium.chrome.browser.locale.LocaleManager;
 import org.chromium.chrome.browser.metrics.VariationsSession;
-import org.chromium.chrome.browser.multiwindow.MultiWindowUtils;
-import org.chromium.chrome.browser.offlinepages.CCTRequestStatus;
+import org.chromium.chrome.browser.notifications.chime.ChimeDelegate;
 import org.chromium.chrome.browser.omaha.RequestGenerator;
 import org.chromium.chrome.browser.partnerbookmarks.PartnerBookmark;
 import org.chromium.chrome.browser.partnerbookmarks.PartnerBookmarksProviderIterator;
-import org.chromium.chrome.browser.partnercustomizations.PartnerBrowserCustomizations;
-import org.chromium.chrome.browser.physicalweb.PhysicalWebBleClient;
+import org.chromium.chrome.browser.password_manager.GooglePasswordManagerUIProvider;
 import org.chromium.chrome.browser.policy.PolicyAuditor;
-import org.chromium.chrome.browser.preferences.LocationSettings;
 import org.chromium.chrome.browser.rlz.RevenueStats;
-import org.chromium.chrome.browser.services.AndroidEduOwnerCheckCallback;
-import org.chromium.chrome.browser.signin.GoogleActivityController;
 import org.chromium.chrome.browser.survey.SurveyController;
-import org.chromium.chrome.browser.sync.GmsCoreSyncListener;
-import org.chromium.chrome.browser.tab.AuthenticatorNavigationInterceptor;
-import org.chromium.chrome.browser.tab.Tab;
+import org.chromium.chrome.browser.sync.TrustedVaultClient;
+import org.chromium.chrome.browser.ui.signin.GoogleActivityController;
+import org.chromium.chrome.browser.usage_stats.DigitalWellbeingClient;
 import org.chromium.chrome.browser.webapps.GooglePlayWebApkInstallDelegate;
-import org.chromium.chrome.browser.webauth.U2fApiHandler;
+import org.chromium.chrome.browser.xsurface.ProcessScope;
+import org.chromium.chrome.browser.xsurface.ProcessScopeDependencyProvider;
+import org.chromium.chrome.modules.image_editor.ImageEditorModuleProvider;
+import org.chromium.components.policy.AppRestrictionsProvider;
+import org.chromium.components.policy.CombinedPolicyProvider;
 import org.chromium.components.signin.AccountManagerDelegate;
 import org.chromium.components.signin.SystemAccountManagerDelegate;
-import org.chromium.policy.AppRestrictionsProvider;
-import org.chromium.policy.CombinedPolicyProvider;
+import org.chromium.components.webapps.AppDetailsDelegate;
 
 import java.util.Collections;
 import java.util.List;
@@ -61,6 +52,9 @@ import java.util.List;
  * Base class for defining methods where different behavior is required by downstream targets.
  * The correct version of {@link AppHooksImpl} will be determined at compile time via build rules.
  * See http://crbug/560466.
+ *
+ * Note that new functionality should not be added to AppHooks. Instead the delegate pattern in
+ * go/apphooks-migration should be followed to solve this class of problems.
  */
 public abstract class AppHooks {
     private static AppHooksImpl sInstance;
@@ -75,20 +69,10 @@ public abstract class AppHooks {
 
     @CalledByNative
     public static AppHooks get() {
-        if (sInstance == null) {
-            sInstance = new AppHooksImpl();
-        }
+        if (sInstance == null) sInstance = new AppHooksImpl();
         return sInstance;
     }
 
-    /**
-     * Initiate AndroidEdu device check.
-     * @param callback Callback that should receive the results of the AndroidEdu device check.
-     */
-    public void checkIsAndroidEduDevice(final AndroidEduOwnerCheckCallback callback) {
-        new Handler(Looper.getMainLooper()).post(() -> callback.onSchoolCheckDone(false));
-    }
-
     /**
      * Creates a new {@link AccountManagerDelegate}.
      * @return the created {@link AccountManagerDelegate}.
@@ -113,14 +97,6 @@ public abstract class AppHooks {
         return new AppIndexingReporter();
     }
 
-    /**
-     * Return a {@link AuthenticatorNavigationInterceptor} for the given {@link Tab}.
-     * This can be null if there are no applicable interceptor to be built.
-     */
-    public AuthenticatorNavigationInterceptor createAuthenticatorNavigationInterceptor(Tab tab) {
-        return null;
-    }
-
     /**
      * @return An instance of {@link CustomTabsConnection}. Should not be called
      * outside of {@link CustomTabsConnection#getInstance()}.
@@ -129,6 +105,14 @@ public abstract class AppHooks {
         return new CustomTabsConnection();
     }
 
+    /**
+     * Returns a new {@link DirectActionCoordinator} instance, if available.
+     */
+    @Nullable
+    public DirectActionCoordinator createDirectActionCoordinator() {
+        return null;
+    }
+
     /**
      * Creates a new {@link SurveyController}.
      * @return The created {@link SurveyController}.
@@ -137,21 +121,6 @@ public abstract class AppHooks {
         return new SurveyController();
     }
 
-    /**
-     * @return An instance of ExternalAuthUtils to be installed as a singleton.
-     */
-    public ExternalAuthUtils createExternalAuthUtils() {
-        return new ExternalAuthUtils();
-    }
-
-    /**
-     * @return An external observer of data use.
-     * @param nativePtr Pointer to the native ExternalDataUseObserver object.
-     */
-    public ExternalDataUseObserver createExternalDataUseObserver(long nativePtr) {
-        return new ExternalDataUseObserver(nativePtr);
-    }
-
     /**
      * @return An instance of {@link FeedbackReporter} to report feedback.
      */
@@ -159,14 +128,6 @@ public abstract class AppHooks {
         return new FeedbackReporter() {};
     }
 
-    /**
-     * @return An instance of GmsCoreSyncListener to notify GmsCore of sync encryption key changes.
-     *         Will be null if one is unavailable.
-     */
-    public GmsCoreSyncListener createGmsCoreSyncListener() {
-        return null;
-    }
-
     /**
      * @return An instance of GoogleActivityController.
      */
@@ -183,10 +144,10 @@ public abstract class AppHooks {
     }
 
     /**
-     * Returns a new instance of HelpAndFeedback.
+     * Returns a new instance of HelpAndFeedbackLauncher.
      */
-    public HelpAndFeedback createHelpAndFeedback() {
-        return new HelpAndFeedback();
+    public HelpAndFeedbackLauncher createHelpAndFeedbackLauncher() {
+        return new HelpAndFeedbackLauncherImpl();
     }
 
     public InstantAppsHandler createInstantAppsHandler() {
@@ -194,27 +155,11 @@ public abstract class AppHooks {
     }
 
     /**
-     * @return An instance of {@link LocaleManager} that handles customized locale related logic.
+     * @return An instance of {@link GooglePasswordManagerUIProvider}. Will be null if one is not
+     *         available.
      */
-    public LocaleManager createLocaleManager() {
-        return new LocaleManager();
-    }
-
-    /**
-     * Returns an instance of LocationSettings to be installed as a singleton.
-     */
-    public LocationSettings createLocationSettings() {
-        // Using an anonymous subclass as the constructor is protected.
-        // This is done to deter instantiation of LocationSettings elsewhere without using the
-        // getInstance() helper method.
-        return new LocationSettings() {};
-    }
-
-    /**
-     * @return An instance of MultiWindowUtils to be installed as a singleton.
-     */
-    public MultiWindowUtils createMultiWindowUtils() {
-        return new MultiWindowUtils();
+    public GooglePasswordManagerUIProvider createGooglePasswordManagerUIProvider() {
+        return null;
     }
 
     /**
@@ -225,13 +170,6 @@ public abstract class AppHooks {
         return null;
     }
 
-    /**
-     * @return A new {@link PhysicalWebBleClient} instance.
-     */
-    public PhysicalWebBleClient createPhysicalWebBleClient() {
-        return new PhysicalWebBleClient();
-    }
-
     /**
      * @return a new {@link ProcessInitializationHandler} instance.
      */
@@ -263,8 +201,7 @@ public abstract class AppHooks {
      * Only applicable when the user has a policy active, that is tracking the activity.
      */
     public PolicyAuditor getPolicyAuditor() {
-        // This class has a protected constructor to prevent accidental instantiation.
-        return new PolicyAuditor() {};
+        return null;
     }
 
     public void registerPolicyProviders(CombinedPolicyProvider combinedProvider) {
@@ -273,47 +210,7 @@ public abstract class AppHooks {
     }
 
     /**
-     * Starts a service from {@code intent} with the expectation that it will make itself a
-     * foreground service with {@link android.app.Service#startForeground(int, Notification)}.
-     *
-     * @param intent The {@link Intent} to fire to start the service.
-     */
-    public void startForegroundService(Intent intent) {
-        // TODO(crbug.com/758280): Remove this whole method once the downstream override is gone and
-        // all overrides have been ported over.
-        ContextUtils.startForegroundService(ContextUtils.getApplicationContext(), intent);
-    }
-
-    /**
-     * @return Whether the renderer should detect whether video elements are in fullscreen. The
-     * detection results can be retrieved through
-     * {@link WebContents.hasActiveEffectivelyFullscreenVideo()}.
-     */
-    @CalledByNative
-    public boolean shouldDetectVideoFullscreen() {
-        return Build.VERSION.SDK_INT >= Build.VERSION_CODES.O;
-    }
-
-    /**
-     * @return A callback that will be run each time an offline page is saved in the custom tabs
-     * namespace.
-     */
-    @CalledByNative
-    public Callback<CCTRequestStatus> getOfflinePagesCCTRequestDoneCallback() {
-        return null;
-    }
-
-    /**
-     * @return A list of whitelisted apps that are allowed to receive notification when the
-     * set of offlined pages downloaded on their behalf has changed. Apps are listed by their
-     * package name.
-     */
-    public List<String> getOfflinePagesCctWhitelist() {
-        return Collections.emptyList();
-    }
-
-    /**
-     * @return A list of whitelisted app package names whose completed notifications
+     * @return A list of allowlisted app package names whose completed notifications
      * we should suppress.
      */
     public List<String> getOfflinePagesSuppressNotificationPackages() {
@@ -329,25 +226,76 @@ public abstract class AppHooks {
     }
 
     /**
-     * @return An instance of PartnerBrowserCustomizations.Provider that provides customizations
-     * specified by partners.
+     * @return A new {@link DigitalWellbeingClient} instance.
      */
-    public PartnerBrowserCustomizations.Provider getCustomizationProvider() {
-        return new PartnerBrowserCustomizations.ProviderPackage();
+    public DigitalWellbeingClient createDigitalWellbeingClient() {
+        return new DigitalWellbeingClient();
     }
 
     /**
-     * @return A {@link FeedbackSourceProvider} that can provide additional {@link FeedbackSource}s
-     * and {@link AsyncFeedbackSource}s to be used by a {@link FeedbackCollector}.
+     * Checks the Google Play services availability on the this device.
+     *
+     * This is a workaround for the
+     * versioned API of {@link GoogleApiAvailability#isGooglePlayServicesAvailable()}. The current
+     * Google Play services SDK version doesn't have this API yet.
+     *
+     * TODO(zqzhang): Remove this method after the SDK is updated.
+     *
+     * @return status code indicating whether there was an error. The possible return values are the
+     * same as {@link GoogleApiAvailability#isGooglePlayServicesAvailable()}.
      */
-    public FeedbackSourceProvider getAdditionalFeedbackSources() {
-        return new FeedbackSourceProvider() {};
+    public int isGoogleApiAvailableWithMinApkVersion(int minApkVersion) {
+        int apkVersion =
+                PackageUtils.getPackageVersion(GoogleApiAvailability.GOOGLE_PLAY_SERVICES_PACKAGE);
+        return apkVersion < 0                ? ConnectionResult.SERVICE_MISSING
+                : apkVersion < minApkVersion ? ConnectionResult.SERVICE_VERSION_UPDATE_REQUIRED
+                                             : ConnectionResult.SUCCESS;
     }
 
     /**
-     * @return a new {@link U2fApiHandler} instance.
+     * Returns a new {@link TrustedVaultClient.Backend} instance.
      */
-    public U2fApiHandler createU2fApiHandler() {
-        return new U2fApiHandler();
+    public TrustedVaultClient.Backend createSyncTrustedVaultClientBackend() {
+        return new TrustedVaultClient.EmptyBackend();
     }
+
+    /**
+     * This is deprecated, and should not be called. Use FeedHooks instead.
+     */
+    public @Nullable ProcessScope getExternalSurfaceProcessScope(
+            ProcessScopeDependencyProvider dependencies) {
+        return null;
+    }
+
+    /**
+     * Returns the URL to the WebAPK creation/update server.
+     */
+    public String getWebApkServerUrl() {
+        return "";
+    }
+
+    /**
+     * Returns a Chime Delegate if the chime module is defined.
+     */
+    public ChimeDelegate getChimeDelegate() {
+        return new ChimeDelegate();
+    }
+
+    public @Nullable ImageEditorModuleProvider getImageEditorModuleProvider() {
+        return null;
+    }
+
+    public ChromeStartupDelegate createChromeStartupDelegate() {
+        return new ChromeStartupDelegate();
+    }
+
+    public boolean canStartForegroundServiceWhileInvisible() {
+        return true;
+    }
+
+    public String getDefaultQueryTilesServerUrl() {
+        return "";
+    }
+
+    // Stop! Do not add new methods to AppHooks anymore. Follow go/apphooks-migration instead.
 }
