@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,12 +6,12 @@ package org.chromium.chrome.browser;
 
 import android.annotation.SuppressLint;
 import android.app.Activity;
-import android.app.Application;
-import android.content.SharedPreferences;
 import android.provider.Settings;
-import android.support.annotation.Nullable;
 import android.text.TextUtils;
 
+import androidx.annotation.Nullable;
+import androidx.annotation.VisibleForTesting;
+
 import org.chromium.base.ApplicationState;
 import org.chromium.base.ApplicationStatus;
 import org.chromium.base.ApplicationStatus.ApplicationStateListener;
@@ -19,44 +19,52 @@ import org.chromium.base.Callback;
 import org.chromium.base.ContextUtils;
 import org.chromium.base.LocaleUtils;
 import org.chromium.base.ThreadUtils;
-import org.chromium.base.VisibleForTesting;
+import org.chromium.base.TraceEvent;
 import org.chromium.base.metrics.RecordHistogram;
-import org.chromium.chrome.browser.accessibility.FontSizePrefs;
+import org.chromium.base.supplier.Supplier;
+import org.chromium.chrome.browser.browsing_data.BrowsingDataBridge;
 import org.chromium.chrome.browser.browsing_data.BrowsingDataType;
 import org.chromium.chrome.browser.browsing_data.TimePeriod;
+import org.chromium.chrome.browser.feature_engagement.TrackerFactory;
 import org.chromium.chrome.browser.metrics.UmaUtils;
 import org.chromium.chrome.browser.metrics.VariationsSession;
 import org.chromium.chrome.browser.notifications.NotificationPlatformBridge;
 import org.chromium.chrome.browser.partnercustomizations.PartnerBrowserCustomizations;
-import org.chromium.chrome.browser.preferences.PrefServiceBridge;
-import org.chromium.chrome.browser.preferences.privacy.BrowsingDataBridge;
+import org.chromium.chrome.browser.password_manager.PasswordManagerLifecycleHelper;
+import org.chromium.chrome.browser.preferences.ChromePreferenceKeys;
+import org.chromium.chrome.browser.preferences.Pref;
+import org.chromium.chrome.browser.preferences.SharedPreferencesManager;
+import org.chromium.chrome.browser.profiles.Profile;
 import org.chromium.chrome.browser.profiles.ProfileManagerUtils;
-import org.chromium.chrome.browser.share.ShareHelper;
+import org.chromium.chrome.browser.read_later.ReadingListBridge;
 import org.chromium.chrome.browser.tabmodel.TabModelSelector;
-import org.chromium.chrome.browser.util.FeatureUtilities;
-import org.chromium.content.browser.ChildProcessLauncherHelper;
+import org.chromium.chrome.browser.translate.TranslateBridge;
+import org.chromium.components.browser_ui.accessibility.FontSizePrefs;
+import org.chromium.components.browser_ui.share.ShareImageFileUtils;
+import org.chromium.components.feature_engagement.EventConstants;
+import org.chromium.components.feature_engagement.Tracker;
+import org.chromium.components.user_prefs.UserPrefs;
 
-import java.lang.ref.WeakReference;
+import java.util.HashMap;
+import java.util.Map;
 
 /**
  * Tracks the foreground session state for the Chrome activities.
  */
 public class ChromeActivitySessionTracker {
 
-    private static final String PREF_LOCALE = "locale";
-
     @SuppressLint("StaticFieldLeak")
     private static ChromeActivitySessionTracker sInstance;
 
     private final PowerBroadcastReceiver mPowerBroadcastReceiver = new PowerBroadcastReceiver();
+    private final Map<Activity, Supplier<TabModelSelector>> mTabModelSelectorSuppliers =
+            new HashMap<>();
 
     // Used to trigger variation changes (such as seed fetches) upon application foregrounding.
-    private VariationsSession mVariationsSession;
+    private final VariationsSession mVariationsSession;
 
-    private Application mApplication;
     private boolean mIsInitialized;
     private boolean mIsStarted;
-    private boolean mIsFinishedCachingNativeFlags;
 
     /**
      * @return The activity session tracker for Chrome.
@@ -73,17 +81,34 @@ public class ChromeActivitySessionTracker {
      * @see #getInstance()
      */
     protected ChromeActivitySessionTracker() {
-        mApplication = (Application) ContextUtils.getApplicationContext();
         mVariationsSession = AppHooks.get().createVariationsSession();
     }
 
+    /**
+     * Register a supplier which returns the total tab count for the given application.
+     * @param activity The activity associated with the given tab count supplier.
+     * @param tabCountSupplier Supplies the current tab count for the given activity.
+     */
+    public void registerTabModelSelectorSupplier(
+            Activity activity, Supplier<TabModelSelector> tabCountSupplier) {
+        mTabModelSelectorSuppliers.put(activity, tabCountSupplier);
+    }
+
+    /**
+     * Unregisters the supplier associated with the given activity.
+     * @param activity Tha activity to unregister.
+     */
+    public void unregisterTabModelSelectorSupplier(Activity activity) {
+        mTabModelSelectorSuppliers.remove(activity);
+    }
+
     /**
      * Asynchronously returns the value of the "restrict" URL param that the variations service
      * should use for variation seed requests.
      * @param callback Callback that will be called with the param value when available.
      */
     public void getVariationsRestrictModeValue(Callback<String> callback) {
-        mVariationsSession.getRestrictModeValue(mApplication, callback);
+        mVariationsSession.getRestrictModeValue(callback);
     }
 
     /**
@@ -104,6 +129,7 @@ public class ChromeActivitySessionTracker {
         mIsInitialized = true;
         assert !mIsStarted;
 
+        mVariationsSession.initializeWithNative();
         ApplicationStatus.registerApplicationStateListener(createApplicationStateListener());
     }
 
@@ -123,29 +149,34 @@ public class ChromeActivitySessionTracker {
         assert mIsInitialized;
 
         onForegroundSessionStart();
-        cacheNativeFlags();
     }
 
     /**
-     * Called when a top-level Chrome activity (ChromeTabbedActivity, FullscreenActivity) is
+     * Called when a top-level Chrome activity (ChromeTabbedActivity, CustomTabActivity) is
      * started in foreground. It will not be called again when other Chrome activities take over
      * (see onStart()), that is, when correct activity calls startActivity() for another Chrome
      * activity.
      */
     private void onForegroundSessionStart() {
-        UmaUtils.recordForegroundStartTime();
-        ChildProcessLauncherHelper.onBroughtToForeground();
-        updatePasswordEchoState();
-        FontSizePrefs.getInstance(mApplication).onSystemFontScaleChanged();
-        updateAcceptLanguages();
-        mVariationsSession.start(mApplication);
-        mPowerBroadcastReceiver.onForegroundSessionStart();
+        try (TraceEvent te = TraceEvent.scoped(
+                     "ChromeActivitySessionTracker.onForegroundSessionStart")) {
+            UmaUtils.recordForegroundStartTimeWithNative();
+            updatePasswordEchoState();
+            FontSizePrefs.getInstance(Profile.getLastUsedRegularProfile())
+                    .onSystemFontScaleChanged();
+            ChromeLocalizationUtils.recordUiLanguageStatus();
+            updateAcceptLanguages();
+            mVariationsSession.start();
+            mPowerBroadcastReceiver.onForegroundSessionStart();
+            AppHooks.get().getChimeDelegate().startSession();
+            ReadingListBridge.onStartChromeForeground();
+            PasswordManagerLifecycleHelper.getInstance().onStartForegroundSession();
 
-        // Track the ratio of Chrome startups that are caused by notification clicks.
-        // TODO(johnme): Add other reasons (and switch to recordEnumeratedHistogram).
-        RecordHistogram.recordBooleanHistogram(
-                "Startup.BringToForegroundReason",
-                NotificationPlatformBridge.wasNotificationRecentlyClicked());
+            // Track the ratio of Chrome startups that are caused by notification clicks.
+            // TODO(johnme): Add other reasons (and switch to recordEnumeratedHistogram).
+            RecordHistogram.recordBooleanHistogram("Startup.BringToForegroundReason",
+                    NotificationPlatformBridge.wasNotificationRecentlyClicked());
+        }
     }
 
     /**
@@ -156,35 +187,32 @@ public class ChromeActivitySessionTracker {
      */
     private void onForegroundSessionEnd() {
         if (!mIsStarted) return;
-        UmaUtils.recordBackgroundTime();
+        UmaUtils.recordBackgroundTimeWithNative();
         ProfileManagerUtils.flushPersistentDataForAllProfiles();
         mIsStarted = false;
         mPowerBroadcastReceiver.onForegroundSessionEnd();
 
-        ChildProcessLauncherHelper.onSentToBackground();
         IntentHandler.clearPendingReferrer();
         IntentHandler.clearPendingIncognitoUrl();
 
         int totalTabCount = 0;
-        for (WeakReference<Activity> reference : ApplicationStatus.getRunningActivities()) {
-            Activity activity = reference.get();
-            if (activity instanceof ChromeActivity) {
-                TabModelSelector tabModelSelector =
-                        ((ChromeActivity) activity).getTabModelSelector();
-                if (tabModelSelector != null) {
-                    totalTabCount += tabModelSelector.getTotalTabCount();
-                }
-            }
+        for (Activity activity : ApplicationStatus.getRunningActivities()) {
+            Supplier<TabModelSelector> tabModelSelectorSupplier =
+                    mTabModelSelectorSuppliers.get(activity);
+            if (tabModelSelectorSupplier == null || !tabModelSelectorSupplier.hasValue()) continue;
+            totalTabCount += tabModelSelectorSupplier.get().getTotalTabCount();
         }
-        RecordHistogram.recordCountHistogram(
-                "Tab.TotalTabCount.BeforeLeavingApp", totalTabCount);
+        RecordHistogram.recordCount1MHistogram("Tab.TotalTabCount.BeforeLeavingApp", totalTabCount);
+
+        Tracker tracker = TrackerFactory.getTrackerForProfile(Profile.getLastUsedRegularProfile());
+        tracker.notifyEvent(EventConstants.FOREGROUND_SESSION_DESTROYED);
     }
 
     private void onForegroundActivityDestroyed() {
         if (ApplicationStatus.isEveryActivityDestroyed()) {
             // These will all be re-initialized when a new Activity starts / upon next use.
             PartnerBrowserCustomizations.destroy();
-            ShareHelper.clearSharedImages();
+            ShareImageFileUtils.clearSharedImages();
         }
     }
 
@@ -204,53 +232,43 @@ public class ChromeActivitySessionTracker {
      * {@link #onStart} instead of {@link #initialize}.
      */
     private void updateAcceptLanguages() {
-        String localeString = LocaleUtils.getDefaultLocaleListString();
-        if (hasLocaleChanged(localeString)) {
-            PrefServiceBridge.getInstance().resetAcceptLanguages(localeString);
-            // Clear cache so that accept-languages change can be applied immediately.
-            // TODO(changwan): The underlying BrowsingDataRemover::Remove() is an asynchronous call.
-            // So cache-clearing may not be effective if URL rendering can happen before
-            // OnBrowsingDataRemoverDone() is called, in which case we may have to reload as well.
-            // Check if it can happen.
-            BrowsingDataBridge.getInstance().clearBrowsingData(
-                    null, new int[] {BrowsingDataType.CACHE}, TimePeriod.ALL_TIME);
+        String currentLocale = LocaleUtils.getDefaultLocaleListString();
+        String previousLocale = SharedPreferencesManager.getInstance().readString(
+                ChromePreferenceKeys.APP_LOCALE, null);
+        ChromeLocalizationUtils.recordLocaleUpdateStatus(previousLocale, currentLocale);
+        if (!TextUtils.equals(previousLocale, currentLocale)) {
+            SharedPreferencesManager.getInstance().writeString(
+                    ChromePreferenceKeys.APP_LOCALE, currentLocale);
+            TranslateBridge.resetAcceptLanguages(currentLocale);
+            if (previousLocale != null) {
+                // Clear cache so that accept-languages change can be applied immediately.
+                // TODO(changwan): The underlying BrowsingDataRemover::Remove() is an asynchronous
+                // call. So cache-clearing may not be effective if URL rendering can happen before
+                // OnBrowsingDataRemoverDone() is called, in which case we may have to reload as
+                // well. Check if it can happen.
+                BrowsingDataBridge.getInstance().clearBrowsingData(
+                        null, new int[] {BrowsingDataType.CACHE}, TimePeriod.ALL_TIME);
+            }
         }
     }
 
-    private boolean hasLocaleChanged(String newLocale) {
-        String previousLocale = ContextUtils.getAppSharedPreferences().getString(PREF_LOCALE, null);
-        if (!TextUtils.equals(previousLocale, newLocale)) {
-            SharedPreferences prefs = ContextUtils.getAppSharedPreferences();
-            SharedPreferences.Editor editor = prefs.edit();
-            editor.putString(PREF_LOCALE, newLocale);
-            editor.apply();
-            // Consider writing the initial value to prefs as _not_ changing the locale.
-            return previousLocale != null;
-        }
-        return false;
-    }
-
     /**
      * Honor the Android system setting about showing the last character of a password for a short
      * period of time.
      */
     private void updatePasswordEchoState() {
-        boolean systemEnabled = Settings.System.getInt(mApplication.getContentResolver(),
-                Settings.System.TEXT_SHOW_PASSWORD, 1) == 1;
-        if (PrefServiceBridge.getInstance().getPasswordEchoEnabled() == systemEnabled) return;
+        boolean systemEnabled =
+                Settings.System.getInt(ContextUtils.getApplicationContext().getContentResolver(),
+                        Settings.System.TEXT_SHOW_PASSWORD, 1)
+                == 1;
+        if (UserPrefs.get(Profile.getLastUsedRegularProfile())
+                        .getBoolean(Pref.WEB_KIT_PASSWORD_ECHO_ENABLED)
+                == systemEnabled) {
+            return;
+        }
 
-        PrefServiceBridge.getInstance().setPasswordEchoEnabled(systemEnabled);
-    }
-
-    /**
-     * Caches flags that are needed by Activities that launch before the native library is loaded
-     * and stores them in SharedPreferences. Because this function is called during launch after the
-     * library has loaded, they won't affect the next launch until Chrome is restarted.
-     */
-    private void cacheNativeFlags() {
-        if (mIsFinishedCachingNativeFlags) return;
-        FeatureUtilities.cacheNativeFlags();
-        mIsFinishedCachingNativeFlags = true;
+        UserPrefs.get(Profile.getLastUsedRegularProfile())
+                .setBoolean(Pref.WEB_KIT_PASSWORD_ECHO_ENABLED, systemEnabled);
     }
 
     /**
