@@ -1,22 +1,24 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser;
 
-import android.annotation.TargetApi;
 import android.content.Context;
-import android.os.Build;
 import android.view.KeyEvent;
 import android.view.KeyboardShortcutGroup;
 import android.view.KeyboardShortcutInfo;
 
-import org.chromium.base.annotations.SuppressFBWarnings;
 import org.chromium.chrome.R;
+import org.chromium.chrome.browser.fullscreen.FullscreenManager;
 import org.chromium.chrome.browser.tab.Tab;
 import org.chromium.chrome.browser.tabmodel.TabModel;
+import org.chromium.chrome.browser.tabmodel.TabModelSelector;
 import org.chromium.chrome.browser.tabmodel.TabModelUtils;
-import org.chromium.content.browser.ContentViewCore;
+import org.chromium.chrome.browser.toolbar.ToolbarManager;
+import org.chromium.components.browser_ui.widget.MenuOrKeyboardActionController;
+import org.chromium.content_public.browser.WebContents;
+import org.chromium.device.gamepad.GamepadList;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -38,11 +40,6 @@ public class KeyboardShortcuts {
                 | (event.isShiftPressed() ? SHIFT : 0);
     }
 
-    private static boolean isGamepadAPIActive(ChromeActivity activity) {
-        ContentViewCore cvc = activity.getCurrentContentViewCore();
-        return (cvc != null) ? cvc.isGamepadAPIActive() : false;
-    }
-
     /**
      * This should be called from the Activity's dispatchKeyEvent() to handle keyboard shortcuts.
      *
@@ -50,15 +47,16 @@ public class KeyboardShortcuts {
      * the key event. So the keys handled here cannot be overridden by any view or web page.
      *
      * @param event The KeyEvent to handle.
-     * @param activity The ChromeActivity in which the key was pressed.
      * @param uiInitialized Whether the UI has been initialized. If this is false, most keys will
      *                      not be handled.
+     * @param fullscreenManager Manages fullscreen state.
+     * @param menuOrKeyboardActionController Controls keyboard actions.
      * @return True if the event was handled. False if the event was ignored. Null if the event
      *         should be handled by the activity's parent class.
      */
-    @SuppressFBWarnings("NP_BOOLEAN_RETURN_NULL")
-    public static Boolean dispatchKeyEvent(KeyEvent event, ChromeActivity activity,
-            boolean uiInitialized) {
+    public static Boolean dispatchKeyEvent(KeyEvent event, boolean uiInitialized,
+            FullscreenManager fullscreenManager,
+            MenuOrKeyboardActionController menuOrKeyboardActionController) {
         int keyCode = event.getKeyCode();
         if (!uiInitialized) {
             if (keyCode == KeyEvent.KEYCODE_SEARCH || keyCode == KeyEvent.KEYCODE_MENU) return true;
@@ -68,19 +66,23 @@ public class KeyboardShortcuts {
         switch (keyCode) {
             case KeyEvent.KEYCODE_SEARCH:
                 if (event.getAction() == KeyEvent.ACTION_DOWN && event.getRepeatCount() == 0) {
-                    activity.onMenuOrKeyboardAction(R.id.focus_url_bar, false);
+                    menuOrKeyboardActionController.onMenuOrKeyboardAction(
+                            R.id.focus_url_bar, false);
                 }
                 // Always consume the SEARCH key events to prevent android from showing
                 // the default app search UI, which locks up Chrome.
                 return true;
             case KeyEvent.KEYCODE_MENU:
                 if (event.getAction() == KeyEvent.ACTION_DOWN && event.getRepeatCount() == 0) {
-                    activity.onMenuOrKeyboardAction(R.id.show_menu, false);
+                    menuOrKeyboardActionController.onMenuOrKeyboardAction(R.id.show_menu, false);
                 }
                 return true;
             case KeyEvent.KEYCODE_ESCAPE:
                 if (event.getAction() == KeyEvent.ACTION_DOWN && event.getRepeatCount() == 0) {
-                    if (activity.exitFullscreenIfShowing()) return true;
+                    if (fullscreenManager.getPersistentFullscreenMode()) {
+                        fullscreenManager.exitPersistentFullscreenMode();
+                        return true;
+                    }
                 }
                 break;
             case KeyEvent.KEYCODE_TV:
@@ -109,13 +111,14 @@ public class KeyboardShortcuts {
      * appropriate group in this method so the user can see it when this method
      * is called.
      *
+     * Preventing inlining since this uses APIs only available on Android N, and this causes dex
+     * validation failures on earlier versions if inlined.
+     *
      * @param context We need an activity so we can call the strings from our
      *            resource.
      * @return a list of shortcuts organized into groups.
      */
-    @TargetApi(Build.VERSION_CODES.N)
     public static List<KeyboardShortcutGroup> createShortcutGroup(Context context) {
-
         final int ctrlShift = KeyEvent.META_CTRL_ON | KeyEvent.META_SHIFT_ON;
 
         List<KeyboardShortcutGroup> shortcutGroups = new ArrayList<>();
@@ -173,9 +176,8 @@ public class KeyboardShortcuts {
         return shortcutGroups;
     }
 
-    @TargetApi(Build.VERSION_CODES.N)
-    private static void addShortcut(Context context,
-            KeyboardShortcutGroup shortcutGroup, int resId, int keyCode, int keyModifier) {
+    private static void addShortcut(Context context, KeyboardShortcutGroup shortcutGroup, int resId,
+            int keyCode, int keyModifier) {
         shortcutGroup.addItem(new KeyboardShortcutInfo(context.getString(resId), keyCode,
                 keyModifier));
     }
@@ -187,19 +189,23 @@ public class KeyboardShortcuts {
      * the key event. So the keys handled here *can* be overridden by any view or web page.
      *
      * @param event The KeyEvent to handle.
-     * @param activity The ChromeActivity in which the key was pressed.
-     * @param isCurrentTabVisible Whether page-related actions are valid, e.g. reload, zoom in.
-     *                            This should be false when in the tab switcher.
+     * @param isCurrentTabVisible Whether page-related actions are valid, e.g. reload, zoom in. This
+     *         should be false when in the tab switcher.
      * @param tabSwitchingEnabled Whether shortcuts that switch between tabs are enabled (e.g.
-     *                            Ctrl+Tab, Ctrl+3).
+     *         Ctrl+Tab, Ctrl+3).
+     * @param tabModelSelector The current tab modelSelector.
+     * @param menuOrKeyboardActionController Controls keyboard actions.
+     * @param toolbarManager Manages the toolbar.
      * @return Whether the key event was handled.
      */
-    public static boolean onKeyDown(KeyEvent event, ChromeActivity activity,
-            boolean isCurrentTabVisible, boolean tabSwitchingEnabled) {
+    public static boolean onKeyDown(KeyEvent event, boolean isCurrentTabVisible,
+            boolean tabSwitchingEnabled, TabModelSelector tabModelSelector,
+            MenuOrKeyboardActionController menuOrKeyboardActionController,
+            ToolbarManager toolbarManager) {
         int keyCode = event.getKeyCode();
         if (event.getRepeatCount() != 0 || KeyEvent.isModifierKey(keyCode)) return false;
         if (KeyEvent.isGamepadButton(keyCode)) {
-            if (isGamepadAPIActive(activity)) return false;
+            if (GamepadList.isGamepadAPIActive()) return false;
         } else if (!event.isCtrlPressed() && !event.isAltPressed()
                 && keyCode != KeyEvent.KEYCODE_F3
                 && keyCode != KeyEvent.KEYCODE_F5
@@ -208,26 +214,31 @@ public class KeyboardShortcuts {
             return false;
         }
 
-        TabModel curModel = activity.getCurrentTabModel();
-        int count = curModel.getCount();
+        TabModel currentTabModel = tabModelSelector.getCurrentModel();
+        Tab currentTab = tabModelSelector.getCurrentTab();
+        WebContents currentWebContents = currentTab == null ? null : currentTab.getWebContents();
 
+        int tabCount = currentTabModel.getCount();
         int metaState = getMetaState(event);
         int keyCodeAndMeta = keyCode | metaState;
 
         switch (keyCodeAndMeta) {
             case CTRL | SHIFT | KeyEvent.KEYCODE_T:
-                activity.onMenuOrKeyboardAction(R.id.open_recently_closed_tab, false);
+                menuOrKeyboardActionController.onMenuOrKeyboardAction(
+                        R.id.open_recently_closed_tab, false);
                 return true;
             case CTRL | KeyEvent.KEYCODE_T:
-                activity.onMenuOrKeyboardAction(curModel.isIncognito()
-                        ? R.id.new_incognito_tab_menu_id
-                        : R.id.new_tab_menu_id, false);
+                menuOrKeyboardActionController.onMenuOrKeyboardAction(currentTabModel.isIncognito()
+                                ? R.id.new_incognito_tab_menu_id
+                                : R.id.new_tab_menu_id,
+                        false);
                 return true;
             case CTRL | KeyEvent.KEYCODE_N:
-                activity.onMenuOrKeyboardAction(R.id.new_tab_menu_id, false);
+                menuOrKeyboardActionController.onMenuOrKeyboardAction(R.id.new_tab_menu_id, false);
                 return true;
             case CTRL | SHIFT | KeyEvent.KEYCODE_N:
-                activity.onMenuOrKeyboardAction(R.id.new_incognito_tab_menu_id, false);
+                menuOrKeyboardActionController.onMenuOrKeyboardAction(
+                        R.id.new_incognito_tab_menu_id, false);
                 return true;
             // Alt+E represents a special character ´ (latin code: &#180) in Android.
             // If an EditText or ContentView has focus, Alt+E will be swallowed by
@@ -236,20 +247,20 @@ public class KeyboardShortcuts {
             case ALT | KeyEvent.KEYCODE_F:
             case KeyEvent.KEYCODE_F10:
             case KeyEvent.KEYCODE_BUTTON_Y:
-                activity.onMenuOrKeyboardAction(R.id.show_menu, false);
+                menuOrKeyboardActionController.onMenuOrKeyboardAction(R.id.show_menu, false);
                 return true;
         }
 
         if (isCurrentTabVisible) {
             if (tabSwitchingEnabled && (metaState == CTRL || metaState == ALT)) {
                 int numCode = keyCode - KeyEvent.KEYCODE_0;
-                if (numCode > 0 && numCode <= Math.min(count, 8)) {
+                if (numCode > 0 && numCode <= Math.min(tabCount, 8)) {
                     // Ctrl+1 to Ctrl+8: select tab by index
-                    TabModelUtils.setIndex(curModel, numCode - 1);
+                    TabModelUtils.setIndex(currentTabModel, numCode - 1, false);
                     return true;
-                } else if (numCode == 9 && count != 0) {
+                } else if (numCode == 9 && tabCount != 0) {
                     // Ctrl+9: select last tab
-                    TabModelUtils.setIndex(curModel, count - 1);
+                    TabModelUtils.setIndex(currentTabModel, tabCount - 1, false);
                     return true;
                 }
             }
@@ -258,97 +269,97 @@ public class KeyboardShortcuts {
                 case CTRL | KeyEvent.KEYCODE_TAB:
                 case CTRL | KeyEvent.KEYCODE_PAGE_DOWN:
                 case KeyEvent.KEYCODE_BUTTON_R1:
-                    if (tabSwitchingEnabled && count > 1) {
-                        TabModelUtils.setIndex(curModel, (curModel.index() + 1) % count);
+                    if (tabSwitchingEnabled && tabCount > 1) {
+                        TabModelUtils.setIndex(
+                                currentTabModel, (currentTabModel.index() + 1) % tabCount, false);
                     }
                     return true;
                 case CTRL | SHIFT | KeyEvent.KEYCODE_TAB:
                 case CTRL | KeyEvent.KEYCODE_PAGE_UP:
                 case KeyEvent.KEYCODE_BUTTON_L1:
-                    if (tabSwitchingEnabled && count > 1) {
-                        TabModelUtils.setIndex(curModel, (curModel.index() + count - 1) % count);
+                    if (tabSwitchingEnabled && tabCount > 1) {
+                        TabModelUtils.setIndex(currentTabModel,
+                                (currentTabModel.index() + tabCount - 1) % tabCount, false);
                     }
                     return true;
                 case CTRL | KeyEvent.KEYCODE_W:
                 case CTRL | KeyEvent.KEYCODE_F4:
                 case KeyEvent.KEYCODE_BUTTON_B:
-                    TabModelUtils.closeCurrentTab(curModel);
+                    TabModelUtils.closeCurrentTab(currentTabModel);
                     return true;
                 case CTRL | KeyEvent.KEYCODE_F:
                 case CTRL | KeyEvent.KEYCODE_G:
                 case CTRL | SHIFT | KeyEvent.KEYCODE_G:
                 case KeyEvent.KEYCODE_F3:
                 case SHIFT | KeyEvent.KEYCODE_F3:
-                    activity.onMenuOrKeyboardAction(R.id.find_in_page_id, false);
+                    menuOrKeyboardActionController.onMenuOrKeyboardAction(
+                            R.id.find_in_page_id, false);
                     return true;
                 case CTRL | KeyEvent.KEYCODE_L:
                 case ALT | KeyEvent.KEYCODE_D:
                 case KeyEvent.KEYCODE_BUTTON_X:
-                    activity.onMenuOrKeyboardAction(R.id.focus_url_bar, false);
+                    menuOrKeyboardActionController.onMenuOrKeyboardAction(
+                            R.id.focus_url_bar, false);
                     return true;
                 case CTRL | SHIFT | KeyEvent.KEYCODE_B:
-                    activity.onMenuOrKeyboardAction(R.id.all_bookmarks_menu_id, false);
+                    menuOrKeyboardActionController.onMenuOrKeyboardAction(
+                            R.id.all_bookmarks_menu_id, false);
                     return true;
                 case KeyEvent.KEYCODE_BOOKMARK:
                 case CTRL | KeyEvent.KEYCODE_D:
-                    activity.onMenuOrKeyboardAction(R.id.bookmark_this_page_id, false);
+                    menuOrKeyboardActionController.onMenuOrKeyboardAction(
+                            R.id.bookmark_this_page_id, false);
                     return true;
                 case CTRL | KeyEvent.KEYCODE_H:
-                    activity.onMenuOrKeyboardAction(R.id.open_history_menu_id, false);
+                    menuOrKeyboardActionController.onMenuOrKeyboardAction(
+                            R.id.open_history_menu_id, false);
                     return true;
                 case CTRL | KeyEvent.KEYCODE_P:
-                    activity.onMenuOrKeyboardAction(R.id.print_id, false);
+                    menuOrKeyboardActionController.onMenuOrKeyboardAction(R.id.print_id, false);
                     return true;
                 case CTRL | KeyEvent.KEYCODE_PLUS:
                 case CTRL | KeyEvent.KEYCODE_EQUALS:
                 case CTRL | SHIFT | KeyEvent.KEYCODE_PLUS:
                 case CTRL | SHIFT | KeyEvent.KEYCODE_EQUALS:
                 case KeyEvent.KEYCODE_ZOOM_IN:
-                    ContentViewCore cvc = activity.getCurrentContentViewCore();
-                    if (cvc != null) cvc.zoomIn();
+                    ZoomController.zoomIn(currentWebContents);
                     return true;
                 case CTRL | KeyEvent.KEYCODE_MINUS:
                 case KeyEvent.KEYCODE_ZOOM_OUT:
-                    cvc = activity.getCurrentContentViewCore();
-                    if (cvc != null) cvc.zoomOut();
+                    ZoomController.zoomOut(currentWebContents);
                     return true;
                 case CTRL | KeyEvent.KEYCODE_0:
-                    cvc = activity.getCurrentContentViewCore();
-                    if (cvc != null) cvc.zoomReset();
+                    ZoomController.zoomReset(currentWebContents);
                     return true;
                 case SHIFT | CTRL | KeyEvent.KEYCODE_R:
                 case CTRL | KeyEvent.KEYCODE_R:
                 case SHIFT | KeyEvent.KEYCODE_F5:
                 case KeyEvent.KEYCODE_F5:
-                    Tab tab = activity.getActivityTab();
-                    if (tab != null) {
+                    if (currentTab != null) {
                         if ((keyCodeAndMeta & SHIFT) == SHIFT) {
-                            tab.reloadIgnoringCache();
+                            currentTab.reloadIgnoringCache();
                         } else {
-                            tab.reload();
+                            currentTab.reload();
                         }
 
-                        if (activity.getToolbarManager() != null
-                                && tab.getWebContents() != null
-                                && tab.getWebContents().focusLocationBarByDefault()) {
-                            activity.getToolbarManager().revertLocationBarChanges();
-                        } else {
-                            tab.requestFocus();
+                        if (toolbarManager != null && currentWebContents != null
+                                && currentWebContents.focusLocationBarByDefault()) {
+                            toolbarManager.revertLocationBarChanges();
+                        } else if (currentTab.getView() != null) {
+                            currentTab.getView().requestFocus();
                         }
                     }
                     return true;
                 case ALT | KeyEvent.KEYCODE_DPAD_LEFT:
-                    tab = activity.getActivityTab();
-                    if (tab != null && tab.canGoBack()) tab.goBack();
+                    if (currentTab != null && currentTab.canGoBack()) currentTab.goBack();
                     return true;
                 case ALT | KeyEvent.KEYCODE_DPAD_RIGHT:
                 case KeyEvent.KEYCODE_FORWARD:
                 case KeyEvent.KEYCODE_BUTTON_START:
-                    tab = activity.getActivityTab();
-                    if (tab != null && tab.canGoForward()) tab.goForward();
+                    if (currentTab != null && currentTab.canGoForward()) currentTab.goForward();
                     return true;
                 case CTRL | SHIFT | KeyEvent.KEYCODE_SLASH:  // i.e. Ctrl+?
-                    activity.onMenuOrKeyboardAction(R.id.help_id, false);
+                    menuOrKeyboardActionController.onMenuOrKeyboardAction(R.id.help_id, false);
                     return true;
             }
         }
