@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -10,15 +10,18 @@ import android.content.Intent;
 import android.content.IntentFilter;
 import android.os.Handler;
 import android.os.Looper;
+import android.os.PowerManager;
+
+import androidx.annotation.IntDef;
+import androidx.annotation.VisibleForTesting;
 
-import org.chromium.base.ApiCompatibilityUtils;
 import org.chromium.base.ApplicationStatus;
 import org.chromium.base.ContextUtils;
 import org.chromium.base.ThreadUtils;
-import org.chromium.base.VisibleForTesting;
-import org.chromium.chrome.browser.invalidation.DelayedInvalidationsController;
 import org.chromium.chrome.browser.omaha.OmahaBase;
 
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 /**
@@ -31,29 +34,21 @@ import java.util.concurrent.atomic.AtomicBoolean;
 public class PowerBroadcastReceiver extends BroadcastReceiver {
     private final AtomicBoolean mIsRegistered = new AtomicBoolean(false);
 
-    private PowerManagerHelper mPowerManagerHelper;
-    private ServiceRunnable mServiceRunnable;
-
-    /**
-     * Stubs out interaction with the PowerManager.
-     */
-    @VisibleForTesting
-    static class PowerManagerHelper {
-        /** @return whether the screen is on or not. */
-        public boolean isScreenOn(Context context) {
-            return ApiCompatibilityUtils.isInteractive(context);
-        }
-    }
+    private ServiceRunnable mServiceRunnable = new ServiceRunnable();
 
     /**
      * Defines a set of actions to perform when the conditions are met.
      */
     @VisibleForTesting
     public static class ServiceRunnable implements Runnable {
-        static final int STATE_UNINITIALIZED = 0;
-        static final int STATE_POSTED = 1;
-        static final int STATE_CANCELED = 2;
-        static final int STATE_COMPLETED = 3;
+        @IntDef({State.UNINITIALIZED, State.POSTED, State.CANCELED, State.COMPLETED})
+        @Retention(RetentionPolicy.SOURCE)
+        public @interface State {
+            int UNINITIALIZED = 0;
+            int POSTED = 1;
+            int CANCELED = 2;
+            int COMPLETED = 3;
+        }
 
         /**
          * ANRs are triggered if the app fails to respond to a touch event within 5 seconds. Posting
@@ -63,33 +58,33 @@ public class PowerBroadcastReceiver extends BroadcastReceiver {
         private static final long MS_DELAY_TO_RUN = 5000;
         private final Handler mHandler = new Handler(Looper.getMainLooper());
 
-        private int mState = STATE_UNINITIALIZED;
+        private @State int mState = State.UNINITIALIZED;
 
         public int getState() {
             return mState;
         }
 
         public void post() {
-            if (mState == STATE_POSTED) return;
-            setState(STATE_POSTED);
-            mHandler.postDelayed(this, getDelayToRun());
+            if (mState == State.POSTED) return;
+            setState(State.POSTED);
+            mHandler.postDelayed(this, MS_DELAY_TO_RUN);
         }
 
         public void cancel() {
-            if (mState != STATE_POSTED) return;
-            setState(STATE_CANCELED);
+            if (mState != State.POSTED) return;
+            setState(State.CANCELED);
             mHandler.removeCallbacks(this);
         }
 
         /** Unless testing, do not override this function. */
         @Override
         public void run() {
-            if (mState != STATE_POSTED) return;
-            setState(STATE_COMPLETED);
+            if (mState != State.POSTED) return;
+            setState(State.COMPLETED);
             runActions();
         }
 
-        public void setState(int state) {
+        public void setState(@State int state) {
             mState = state;
         }
 
@@ -97,19 +92,9 @@ public class PowerBroadcastReceiver extends BroadcastReceiver {
          * Executed when all of the system conditions are met.
          */
         public void runActions() {
-            Context context = ContextUtils.getApplicationContext();
-            OmahaBase.onForegroundSessionStart(context);
-            DelayedInvalidationsController.getInstance().notifyPendingInvalidations(context);
+            OmahaBase.onForegroundSessionStart();
         }
 
-        public long getDelayToRun() {
-            return MS_DELAY_TO_RUN;
-        }
-    }
-
-    public PowerBroadcastReceiver() {
-        mServiceRunnable = new ServiceRunnable();
-        mPowerManagerHelper = new PowerManagerHelper();
     }
 
     /** See {@link ChromeApplication#onForegroundSessionStart()}. */
@@ -117,10 +102,13 @@ public class PowerBroadcastReceiver extends BroadcastReceiver {
         ThreadUtils.assertOnUiThread();
         assert Looper.getMainLooper() == Looper.myLooper();
 
-        if (mPowerManagerHelper.isScreenOn(ContextUtils.getApplicationContext())) {
+        PowerManager powerManager =
+                (PowerManager) ContextUtils.getApplicationContext().getSystemService(
+                        Context.POWER_SERVICE);
+        if (powerManager.isInteractive()) {
             mServiceRunnable.post();
         } else {
-            registerReceiver();
+            registerBroadcastReceiver();
         }
     }
 
@@ -129,7 +117,7 @@ public class PowerBroadcastReceiver extends BroadcastReceiver {
         assert Looper.getMainLooper() == Looper.myLooper();
 
         mServiceRunnable.cancel();
-        unregisterReceiver();
+        unregisterBroadcastReceiver();
     }
 
     @Override
@@ -137,7 +125,7 @@ public class PowerBroadcastReceiver extends BroadcastReceiver {
         if (Intent.ACTION_SCREEN_ON.equals(intent.getAction())
                 && ApplicationStatus.hasVisibleActivities()) {
             mServiceRunnable.post();
-            unregisterReceiver();
+            unregisterBroadcastReceiver();
         }
     }
 
@@ -153,7 +141,7 @@ public class PowerBroadcastReceiver extends BroadcastReceiver {
      * Unregisters this broadcast receiver so it no longer receives Intents.
      * Also cancels any Runnables waiting to be executed.
      */
-    private void unregisterReceiver() {
+    private void unregisterBroadcastReceiver() {
         if (mIsRegistered.getAndSet(false)) {
             ContextUtils.getApplicationContext().unregisterReceiver(this);
         }
@@ -162,11 +150,11 @@ public class PowerBroadcastReceiver extends BroadcastReceiver {
     /**
      * Registers this broadcast receiver so it receives Intents.
      */
-    private void registerReceiver() {
+    private void registerBroadcastReceiver() {
         assert Looper.getMainLooper() == Looper.myLooper();
         if (mIsRegistered.getAndSet(true)) return;
-        ContextUtils.getApplicationContext().registerReceiver(
-                this, new IntentFilter(Intent.ACTION_SCREEN_ON));
+        ContextUtils.registerProtectedBroadcastReceiver(ContextUtils.getApplicationContext(), this,
+                new IntentFilter(Intent.ACTION_SCREEN_ON));
     }
 
     /**
@@ -178,12 +166,4 @@ public class PowerBroadcastReceiver extends BroadcastReceiver {
         mServiceRunnable.cancel();
         mServiceRunnable = runnable;
     }
-
-    /**
-     * Sets the PowerManagerHelper that will be used to check if the screen is on.
-     */
-    @VisibleForTesting
-    void setPowerManagerHelperForTests(PowerManagerHelper helper) {
-        mPowerManagerHelper = helper;
-    }
 }
