@@ -1,14 +1,15 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser;
 
+import android.os.Build;
 import android.os.Bundle;
 import android.view.WindowManager;
 
-import org.chromium.chrome.browser.snackbar.SnackbarManager;
-import org.chromium.chrome.browser.snackbar.SnackbarManager.SnackbarManageable;
+import org.chromium.chrome.browser.ui.messages.snackbar.SnackbarManager;
+import org.chromium.chrome.browser.ui.messages.snackbar.SnackbarManager.SnackbarManageable;
 
 /**
  * Base Activity class that is used for lighter-weight standalone Activities that rely on the native
@@ -25,20 +26,11 @@ public abstract class SnackbarActivity extends SynchronousInitializationActivity
     @Override
     protected void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
-        getWindow().clearFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS);
-        mSnackbarManager = new SnackbarManager(this, null);
-    }
 
-    @Override
-    protected void onStart() {
-        super.onStart();
-        mSnackbarManager.onStart();
-    }
-
-    @Override
-    protected void onStop() {
-        super.onStop();
-        mSnackbarManager.onStop();
+        if (Build.VERSION.SDK_INT <= Build.VERSION_CODES.O) {
+            getWindow().clearFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS);
+        }
+        mSnackbarManager = new SnackbarManager(this, findViewById(android.R.id.content), null);
     }
 
     @Override
