@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,82 +7,138 @@ package org.chromium.chrome.browser.compositor.bottombar;
 import android.app.Activity;
 import android.content.Context;
 import android.graphics.RectF;
+import android.os.Handler;
+import android.view.MotionEvent;
+import android.view.View;
+import android.view.ViewGroup;
+
+import androidx.annotation.IntDef;
+import androidx.annotation.NonNull;
+import androidx.annotation.VisibleForTesting;
 
 import org.chromium.base.ActivityState;
 import org.chromium.base.ApplicationStatus;
 import org.chromium.base.ApplicationStatus.ActivityStateListener;
-import org.chromium.base.VisibleForTesting;
-import org.chromium.chrome.browser.ChromeActivity;
-import org.chromium.chrome.browser.compositor.LayerTitleCache;
+import org.chromium.base.supplier.ObservableSupplier;
+import org.chromium.base.supplier.Supplier;
+import org.chromium.cc.input.BrowserControlsState;
+import org.chromium.chrome.browser.browser_controls.BrowserControlsStateProvider;
 import org.chromium.chrome.browser.compositor.bottombar.OverlayPanelManager.PanelPriority;
-import org.chromium.chrome.browser.compositor.layouts.LayoutUpdateHost;
-import org.chromium.chrome.browser.compositor.layouts.components.VirtualView;
-import org.chromium.chrome.browser.compositor.layouts.eventfilter.EdgeSwipeHandler;
-import org.chromium.chrome.browser.compositor.layouts.eventfilter.EventFilter;
+import org.chromium.chrome.browser.compositor.layouts.Layout;
+import org.chromium.chrome.browser.compositor.layouts.LayoutManagerImpl;
+import org.chromium.chrome.browser.compositor.layouts.SceneChangeObserver;
 import org.chromium.chrome.browser.compositor.layouts.eventfilter.GestureHandler;
 import org.chromium.chrome.browser.compositor.layouts.eventfilter.OverlayPanelEventFilter;
-import org.chromium.chrome.browser.compositor.layouts.eventfilter.ScrollDirection;
-import org.chromium.chrome.browser.compositor.overlays.SceneOverlay;
-import org.chromium.chrome.browser.compositor.scene_layer.SceneOverlayLayer;
+import org.chromium.chrome.browser.layouts.EventFilter;
+import org.chromium.chrome.browser.layouts.SceneOverlay;
+import org.chromium.chrome.browser.layouts.components.VirtualView;
+import org.chromium.chrome.browser.layouts.scene_layer.SceneOverlayLayer;
 import org.chromium.chrome.browser.multiwindow.MultiWindowUtils;
 import org.chromium.chrome.browser.tab.Tab;
-import org.chromium.content_public.browser.ContentViewCore;
+import org.chromium.chrome.browser.tab.TabBrowserControlsConstraintsHelper;
+import org.chromium.components.browser_ui.widget.gesture.SwipeGestureListener.ScrollDirection;
+import org.chromium.components.browser_ui.widget.gesture.SwipeGestureListener.SwipeHandler;
 import org.chromium.content_public.browser.SelectionPopupController;
 import org.chromium.content_public.browser.WebContents;
-import org.chromium.content_public.common.BrowserControlsState;
 import org.chromium.ui.base.LocalizationUtils;
+import org.chromium.ui.base.WindowAndroid;
 import org.chromium.ui.resources.ResourceManager;
 
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
 import java.util.List;
 
 /**
  * Controls the Overlay Panel.
  */
-public class OverlayPanel extends OverlayPanelAnimation implements ActivityStateListener,
-        EdgeSwipeHandler, GestureHandler, OverlayPanelContentFactory, SceneOverlay {
-
-    /** The extra dp added around the close button touch target. */
-    private static final int CLOSE_BUTTON_TOUCH_SLOP_DP = 5;
+public class OverlayPanel extends OverlayPanelAnimation
+        implements ActivityStateListener, SwipeHandler, GestureHandler, OverlayPanelContentFactory,
+                   SceneOverlay {
+    /** The delay after which the hide progress will be hidden. */
+    private static final long HIDE_PROGRESS_BAR_DELAY_MS = 1000 / 60 * 4;
 
     /** State of the Overlay Panel. */
-    public static enum PanelState {
+    @IntDef({PanelState.UNDEFINED, PanelState.CLOSED, PanelState.PEEKED, PanelState.EXPANDED,
+            PanelState.MAXIMIZED})
+    @Retention(RetentionPolicy.SOURCE)
+    public @interface PanelState {
+        // Values can't have gaps and should be numerated from 0.
+        // Values CLOSED - MAXIMIZED are sorted and show next states.
         // TODO(pedrosimonetti): consider removing the UNDEFINED state
-        UNDEFINED,
-        CLOSED,
-        PEEKED,
-        EXPANDED,
-        MAXIMIZED
+        int UNDEFINED = 0;
+        int CLOSED = 1;
+        int PEEKED = 2;
+        int EXPANDED = 3;
+        int MAXIMIZED = 4;
+        int NUM_ENTRIES = 5;
     }
 
     /**
      * The reason for a change in the Overlay Panel's state.
      */
-    public enum StateChangeReason {
-        UNKNOWN,
-        RESET,
-        BACK_PRESS,
-        TEXT_SELECT_TAP,
-        TEXT_SELECT_LONG_PRESS,
-        INVALID_SELECTION,
-        CLEARED_SELECTION,
-        BASE_PAGE_TAP,
-        BASE_PAGE_SCROLL,
-        SEARCH_BAR_TAP,
-        SERP_NAVIGATION,
-        TAB_PROMOTION,
-        CLICK,
-        SWIPE,
-        FLING,
-        OPTIN,
-        OPTOUT,
-        CLOSE_BUTTON,
-        PANEL_SUPPRESS,
-        PANEL_UNSUPPRESS,
-        TAP_SUPPRESS
+    @IntDef({StateChangeReason.UNKNOWN, StateChangeReason.RESET, StateChangeReason.BACK_PRESS,
+            StateChangeReason.TEXT_SELECT_TAP, StateChangeReason.TEXT_SELECT_LONG_PRESS,
+            StateChangeReason.INVALID_SELECTION, StateChangeReason.CLEARED_SELECTION,
+            StateChangeReason.BASE_PAGE_TAP, StateChangeReason.BASE_PAGE_SCROLL,
+            StateChangeReason.SEARCH_BAR_TAP, StateChangeReason.SERP_NAVIGATION,
+            StateChangeReason.TAB_PROMOTION, StateChangeReason.CLICK, StateChangeReason.SWIPE,
+            StateChangeReason.FLING, StateChangeReason.OPTIN, StateChangeReason.OPTOUT,
+            StateChangeReason.CLOSE_BUTTON, StateChangeReason.PANEL_SUPPRESS,
+            StateChangeReason.PANEL_UNSUPPRESS, StateChangeReason.TAP_SUPPRESS,
+            StateChangeReason.NAVIGATION})
+    @Retention(RetentionPolicy.SOURCE)
+    public @interface StateChangeReason {
+        int UNKNOWN = 0;
+        int RESET = 1;
+        int BACK_PRESS = 2;
+        int TEXT_SELECT_TAP = 3;
+        int TEXT_SELECT_LONG_PRESS = 4;
+        int INVALID_SELECTION = 5;
+        int CLEARED_SELECTION = 6;
+        int BASE_PAGE_TAP = 7;
+        int BASE_PAGE_SCROLL = 8;
+        int SEARCH_BAR_TAP = 9;
+        int SERP_NAVIGATION = 10;
+        int TAB_PROMOTION = 11;
+        int CLICK = 12;
+        int SWIPE = 13;
+        int FLING = 14;
+        int OPTIN = 15;
+        int OPTOUT = 16;
+        int CLOSE_BUTTON = 17;
+        int PANEL_SUPPRESS = 18;
+        int PANEL_UNSUPPRESS = 19;
+        int TAP_SUPPRESS = 20;
+        int NAVIGATION = 21;
+        // Always update MAX_VALUE to match the last StateChangeReason in the list.
+        int MAX_VALUE = 21;
     }
 
+    /** A layout manager for tracking changes in the active layout. */
+    private final LayoutManagerImpl mLayoutManager;
+
+    /** The observer that reacts to scene-change events. */
+    private final SceneChangeObserver mSceneChangeObserver;
+
+    /** Used to measure the browser controls. */
+    private final BrowserControlsStateProvider mBrowserControlsStateProvider;
+
+    /** The {@link WindowAndroid} for the current activity.  */
+    private final WindowAndroid mWindowAndroid;
+
+    /**
+     * The {@link CompositorViewHolder}, used as an anchor view. Also injected into other classes.
+     */
+    private final ViewGroup mCompositorViewHolder;
+
+    /** Supplies the current activity {@link Tab}. */
+    private final Supplier<Tab> mCurrentTabSupplier;
+
+    /** OverlayPanel manager handle for notifications of opening and closing. */
+    protected final OverlayPanelManager mPanelManager;
+
     /** The activity this panel is in. */
-    protected ChromeActivity mActivity;
+    protected Activity mActivity;
 
     /** The initial height of the Overlay Panel. */
     private float mInitialPanelHeight;
@@ -102,9 +158,6 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     /** Container for content the panel will show. */
     private OverlayPanelContent mContent;
 
-    /** OverlayPanel manager handle for notifications of opening and closing. */
-    protected OverlayPanelManager mPanelManager;
-
     /** If the base page text controls have been cleared. */
     private boolean mDidClearTextControls;
 
@@ -127,18 +180,43 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
 
     /**
      * @param context The current Android {@link Context}.
-     * @param updateHost The {@link LayoutUpdateHost} used to request updates in the Layout.
-     * @param eventHost The {@link EventFilterHost} used to propagate events.
+     * @param layoutManager A {@link LayoutManagerImpl} for observing changes in the active layout.
      * @param panelManager The {@link OverlayPanelManager} responsible for showing panels.
+     * @param browserControlsStateProvider The {@link BrowserControlsStateProvider} for measuring
+     *         controls.
+     * @param windowAndroid The {@link WindowAndroid} for the current activity.
+     * @param compositorViewHolder The {@link CompositorViewHolder}
+     * @param toolbarHeightDp The height of the toolbar in dp.
+     * @param currentTabSupplier Supplies the current {@link Tab}.
      */
-    public OverlayPanel(
-            Context context, LayoutUpdateHost updateHost, OverlayPanelManager panelManager) {
-        super(context, updateHost);
+    public OverlayPanel(@NonNull Context context, @NonNull LayoutManagerImpl layoutManager,
+            @NonNull OverlayPanelManager panelManager,
+            @NonNull BrowserControlsStateProvider browserControlsStateProvider,
+            @NonNull WindowAndroid windowAndroid, @NonNull ViewGroup compositorViewHolder,
+            float toolbarHeightDp, @NonNull Supplier<Tab> currentTabSupplier) {
+        super(context, layoutManager, toolbarHeightDp);
+        mLayoutManager = layoutManager;
         mContentFactory = this;
+        mBrowserControlsStateProvider = browserControlsStateProvider;
+        mWindowAndroid = windowAndroid;
+        mCompositorViewHolder = compositorViewHolder;
+        mCurrentTabSupplier = currentTabSupplier;
 
         mPanelManager = panelManager;
         mPanelManager.registerPanel(this);
         mEventFilter = new OverlayPanelEventFilter(mContext, this);
+
+        mSceneChangeObserver = new SceneChangeObserver() {
+            @Override
+            public void onTabSelectionHinted(int tabId) {}
+
+            @Override
+            public void onSceneChange(Layout layout) {
+                closePanel(StateChangeReason.UNKNOWN, false);
+            }
+        };
+
+        mLayoutManager.addSceneChangeObserver(mSceneChangeObserver);
     }
 
     /**
@@ -146,6 +224,7 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
      */
     public void destroy() {
         closePanel(StateChangeReason.UNKNOWN, false);
+        mLayoutManager.removeSceneChangeObserver(mSceneChangeObserver);
         ApplicationStatus.unregisterActivityStateListener(this);
     }
 
@@ -158,7 +237,7 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     }
 
     @Override
-    protected void onClosed(StateChangeReason reason) {
+    protected void onClosed(@StateChangeReason int reason) {
         mPanelShown = false;
         setBasePageTextControlsVisibility(true);
         destroyComponents();
@@ -184,7 +263,7 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     }
 
     @Override
-    public void closePanel(StateChangeReason reason, boolean animate) {
+    public void closePanel(@StateChangeReason int reason, boolean animate) {
         // If the panel hasn't peeked, then it shouldn't need to close.
         if (!mPanelShown) return;
 
@@ -195,7 +274,7 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
      * Request that this panel be shown.
      * @param reason The reason the panel is being shown.
      */
-    public void requestPanelShow(StateChangeReason reason) {
+    public void requestPanelShow(@StateChangeReason int reason) {
         if (mPanelShown) return;
 
         if (mPanelManager != null) {
@@ -204,7 +283,7 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     }
 
     @Override
-    public void peekPanel(StateChangeReason reason) {
+    public void peekPanel(@StateChangeReason int reason) {
         // TODO(mdjones): This is making a protected API public and should be removed. Animation
         // should only be controlled by the OverlayPanelManager.
 
@@ -231,22 +310,22 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     }
 
     /**
-     * @return True if a URL has been loaded in the panel's current ContentViewCore.
+     * @return True if a URL has been loaded in the panel's current WebContents.
      */
     public boolean isProcessingPendingNavigation() {
         return mContent != null && mContent.isProcessingPendingNavigation();
     }
 
     /**
-     * @param activity The ChromeActivity associated with the panel.
+     * @param activity The {@link Activity} associated with the panel.
      */
-    public void setChromeActivity(ChromeActivity activity) {
+    public void setActivity(Activity activity) {
         mActivity = activity;
         if (mActivity != null) {
             ApplicationStatus.registerStateListenerForActivity(this, mActivity);
+        } else {
+            throw new RuntimeException("Activity provided to OverlayPanel cannot be null!");
         }
-
-        initializeUiState();
     }
 
     /**
@@ -272,7 +351,7 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
      * child classes.
      * @return The panel's display priority.
      */
-    public PanelPriority getPriority() {
+    public @PanelPriority int getPriority() {
         return PanelPriority.MEDIUM;
     }
 
@@ -287,20 +366,20 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
      * @return The absolute amount in DP that the browser controls have shifted off screen.
      */
     protected float getBrowserControlsOffsetDp() {
-        if (mActivity == null || mActivity.getFullscreenManager() == null) return 0.0f;
-        return -mActivity.getFullscreenManager().getTopControlOffset() * mPxToDp;
+        if (mActivity == null) return 0.0f;
+        return -mBrowserControlsStateProvider.getTopControlOffset() * mPxToDp;
     }
 
     /**
      * Set the visibility of the base page text selection controls. This will also attempt to
      * remove focus from the base page to clear any open controls.
-     * TODO(mdjones): This should be replaced with focusing the panel's ContentViewCore.
      * @param visible If the text controls are visible.
      */
     protected void setBasePageTextControlsVisibility(boolean visible) {
-        if (mActivity == null || mActivity.getActivityTab() == null) return;
+        if (mActivity == null) return;
+        if (!mCurrentTabSupplier.hasValue()) return;
 
-        WebContents baseWebContents = mActivity.getActivityTab().getWebContents();
+        WebContents baseWebContents = mCurrentTabSupplier.get().getWebContents();
         if (baseWebContents == null) return;
 
         // If the panel does not have focus or isn't open, return.
@@ -310,22 +389,44 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
         mDidClearTextControls = !visible;
 
         SelectionPopupController spc = SelectionPopupController.fromWebContents(baseWebContents);
-        if (!visible) {
-            spc.setPreserveSelectionOnNextLossOfFocus(true);
-            ContentViewCore.fromWebContents(baseWebContents).getContainerView().clearFocus();
-        }
+        if (!visible) spc.setPreserveSelectionOnNextLossOfFocus(true);
+        updateFocus(baseWebContents, visible);
 
         spc.updateTextSelectionUI(visible);
     }
 
+    // Claim or lose focus of the content view of the base WebContents. This keeps
+    // the state of the text selected for overlay in consistent way.
+    private static void updateFocus(WebContents baseWebContents, boolean focusBaseView) {
+        View baseContentView = baseWebContents.getViewAndroidDelegate() != null
+                ? baseWebContents.getViewAndroidDelegate().getContainerView()
+                : null;
+        if (baseContentView == null) return;
+
+        if (focusBaseView) {
+            baseContentView.requestFocus();
+        } else {
+            baseContentView.clearFocus();
+        }
+    }
+
+    /**
+     * Returns whether the panel has been activated -- asked to show.  It may not yet be physically
+     * showing due animation.  Use {@link #isShowing} instead to determine if the panel is
+     * physically visible.
+     * @return Whether the panel is showing or about to show.
+     */
+    public boolean isActive() {
+        return mPanelShown;
+    }
+
     // ============================================================================================
     // ActivityStateListener
     // ============================================================================================
 
     @Override
     public void onActivityStateChange(Activity activity, int newState) {
-        boolean isMultiWindowMode = MultiWindowUtils.getInstance().isLegacyMultiWindow(mActivity)
-                || MultiWindowUtils.getInstance().isInMultiWindowMode(mActivity);
+        boolean isMultiWindowMode = MultiWindowUtils.getInstance().isInMultiWindowMode(mActivity);
 
         // In multi-window mode the activity that was interacted with last is resumed and
         // all others are paused. We should not close Contextual Search in this case,
@@ -354,11 +455,17 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     }
 
     /**
-     * @return The ContentViewCore that this panel currently holds.
+     * @return The WebContents that this panel currently holds.
      */
-    public ContentViewCore getContentViewCore() {
-        // Expose OverlayPanelContent method.
-        return mContent != null ? mContent.getContentViewCore() : null;
+    public WebContents getWebContents() {
+        return mContent != null ? mContent.getWebContents() : null;
+    }
+
+    /**
+     * @return The container view that this panel currently holds.
+     */
+    public ViewGroup getContainerView() {
+        return mContent != null ? mContent.getContainerView() : null;
     }
 
     /**
@@ -369,6 +476,37 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
         if (mContent != null) mContent.onLoadUrlFailed();
     }
 
+    /**
+     * Progress observer progress indicator animation for a panel.
+     */
+    public class PanelProgressObserver extends OverlayContentProgressObserver {
+        @Override
+        public void onProgressBarStarted() {
+            setProgressBarCompletion(0);
+            setProgressBarVisible(true);
+            requestUpdate();
+        }
+
+        @Override
+        public void onProgressBarUpdated(float progress) {
+            setProgressBarCompletion(progress);
+            requestUpdate();
+        }
+
+        @Override
+        public void onProgressBarFinished() {
+            // Hides the Progress Bar after a delay to make sure it is rendered for at least
+            // a few frames, otherwise its completion won't be visually noticeable.
+            new Handler().postDelayed(new Runnable() {
+                @Override
+                public void run() {
+                    setProgressBarVisible(false);
+                    requestUpdate();
+                }
+            }, HIDE_PROGRESS_BAR_DELAY_MS);
+        }
+    }
+
     /**
      * Create a new OverlayPanelContent object. This can be overridden for tests.
      * @return A new OverlayPanelContent object.
@@ -376,7 +514,8 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     @Override
     public OverlayPanelContent createNewOverlayPanelContent() {
         return new OverlayPanelContent(new OverlayContentDelegate(),
-                new OverlayContentProgressObserver(), mActivity, getBarHeight());
+                new OverlayContentProgressObserver(), mActivity, /* isIncognito= */ false,
+                getBarHeight(), mCompositorViewHolder, mWindowAndroid, mCurrentTabSupplier);
     }
 
     /**
@@ -414,17 +553,14 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     /**
      * Updates the browser controls state for the base tab.  As these values are set at the renderer
      * level, there is potential for this impacting other tabs that might share the same
-     * process. See {@link Tab#updateBrowserControlsState(int current, boolean animate)}
+     * process. See {@link BrowserControlsState.update(Tab, tab, int current, boolean animate)}
      * @param current The desired current state for the controls.  Pass
      *                {@link BrowserControlsState#BOTH} to preserve the current position.
      * @param animate Whether the controls should animate to the specified ending condition or
      *                should jump immediately.
      */
     public void updateBrowserControlsState(int current, boolean animate) {
-        Tab currentTab = mActivity.getActivityTab();
-        if (currentTab != null) {
-            currentTab.updateBrowserControlsState(current, animate);
-        }
+        TabBrowserControlsConstraintsHelper.update(mCurrentTabSupplier.get(), current, animate);
     }
 
     /**
@@ -474,13 +610,9 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
         } else {
             setBasePageTextControlsVisibility(false);
         }
-    }
-
-    @Override
-    protected int getControlContainerHeightResource() {
-        // TODO(mdjones): Investigate passing this in to the constructor instead.
-        assert mActivity != null;
-        return mActivity.getControlContainerHeightResource();
+        if (mContent != null) {
+            mContent.setPanelTopOffset((int) ((mViewportHeight - getHeight()) / mPxToDp));
+        }
     }
 
     // ============================================================================================
@@ -556,12 +688,22 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
      */
     protected boolean isCoordinateInsideCloseButton(float x) {
         if (LocalizationUtils.isLayoutRtl()) {
-            return x <= (getCloseIconX() + getCloseIconDimension() + CLOSE_BUTTON_TOUCH_SLOP_DP);
+            return x <= (getCloseIconX() + getCloseIconDimension() + mButtonPaddingDps);
         } else {
-            return x >= (getCloseIconX() - CLOSE_BUTTON_TOUCH_SLOP_DP);
+            return x >= (getCloseIconX() - mButtonPaddingDps);
         }
     }
 
+    /**
+     * @param x The x coordinate in dp.
+     * @return Whether the given |x| coordinate is inside the open-in-new-tab button.
+     */
+    protected boolean isCoordinateInsideOpenTabButton(float x) {
+        // Calculation is the same for RTL: within the button plus padding.
+        return getOpenTabIconX() - mButtonPaddingDps <= x
+                && x <= getOpenTabIconX() + getOpenTabIconDimension() + mButtonPaddingDps;
+    }
+
     /**
      * Handles the click gesture.
      *
@@ -669,7 +811,7 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     }
 
     // ============================================================================================
-    // GestureHandler and EdgeSwipeHandler implementation.
+    // GestureHandler and SwipeHandler implementation.
     // ============================================================================================
 
     @Override
@@ -704,10 +846,10 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     @Override
     public void onPinch(float x0, float y0, float x1, float y1, boolean firstEvent) {}
 
-    // EdgeSwipeHandler implementation.
+    // SwipeHandler implementation.
 
     @Override
-    public void swipeStarted(ScrollDirection direction, float x, float y) {
+    public void onSwipeStarted(@ScrollDirection int direction, MotionEvent ev) {
         if (onInterceptBarSwipe()) {
             mIgnoreSwipeEvents = true;
             return;
@@ -716,13 +858,13 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     }
 
     @Override
-    public void swipeUpdated(float x, float y, float dx, float dy, float tx, float ty) {
+    public void onSwipeUpdated(MotionEvent current, float tx, float ty, float dx, float dy) {
         if (mIgnoreSwipeEvents) return;
-        handleSwipeMove(ty);
+        handleSwipeMove(ty * mPxToDp);
     }
 
     @Override
-    public void swipeFinished() {
+    public void onSwipeFinished() {
         if (mIgnoreSwipeEvents) {
             mIgnoreSwipeEvents = false;
             return;
@@ -731,13 +873,14 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     }
 
     @Override
-    public void swipeFlingOccurred(float x, float y, float tx, float ty, float vx, float vy) {
+    public void onFling(@ScrollDirection int direction, MotionEvent current, float tx, float ty,
+            float vx, float vy) {
         if (mIgnoreSwipeEvents) return;
-        handleFling(vy);
+        handleFling(vy * mPxToDp);
     }
 
     @Override
-    public boolean isSwipeEnabled(ScrollDirection direction) {
+    public boolean isSwipeEnabled(@ScrollDirection int direction) {
         return direction == ScrollDirection.UP && isShowing();
     }
 
@@ -758,8 +901,8 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
     // ============================================================================================
 
     @Override
-    public SceneOverlayLayer getUpdatedSceneOverlayTree(RectF viewport, RectF visibleViewport,
-            LayerTitleCache layerTitleCache, ResourceManager resourceManager, float yOffset) {
+    public SceneOverlayLayer getUpdatedSceneOverlayTree(
+            RectF viewport, RectF visibleViewport, ResourceManager resourceManager, float yOffset) {
         return null;
     }
 
@@ -778,34 +921,28 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
             int orientation) {
         // Filter events that don't change the viewport width or height.
         if (height != mViewportHeight || width != mViewportWidth) {
-          // We only care if the orientation is changing or we're shifting in/out of multi-window.
-          // In either case the screen's viewport width or height will certainly change.
+            // We only care if the orientation is changing or we're shifting in/out of multi-window.
+            // In either case the screen's viewport width or height will certainly change.
             mViewportWidth = width;
             mViewportHeight = height;
-            resizePanelContentViewCore(width, height);
+
             onLayoutChanged(width, height, visibleViewportOffsetY);
+            resizePanelContentView();
         }
     }
 
     /**
-     * Resize the panel's ContentViewCore manually since it is not attached to the view hierarchy.
-     * TODO(mdjones): Remove the need for this method by supporting multiple ContentViewCores
-     * existing simultaneously in the view hierarchy.
-     * @param width The new width in dp.
-     * @param height The new height in dp.
+     * Resize the panel's ContentView. Apply adjusted bar size to the height.
      */
-    protected void resizePanelContentViewCore(float width, float height) {
+    protected void resizePanelContentView() {
         if (!isShowing()) return;
+
         OverlayPanelContent panelContent = getOverlayPanelContent();
-        int widthPx = (int) (width / mPxToDp);
-        int heightPx = (int) (height / mPxToDp);
 
         // Device could have been rotated before panel webcontent creation. Update content size.
-        panelContent.setContentViewSize(widthPx, heightPx, isFullWidthSizePanel());
-
-        if (isFullWidthSizePanel()) heightPx = (int) ((height - getBarHeight()) / mPxToDp);
-        panelContent.onSizeChanged(widthPx, heightPx);
-        panelContent.onPhysicalBackingSizeChanged(widthPx, heightPx);
+        panelContent.setContentViewSize(
+                getContentViewWidthPx(), getContentViewHeightPx(), isFullWidthSizePanel());
+        panelContent.resizePanelContentView();
     }
 
     @Override
@@ -828,7 +965,7 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
 
     @Override
     public boolean shouldHideAndroidBrowserControls() {
-        return isPanelOpened();
+        return isPanelOpened() && mCanHideAndroidBrowserControls;
     }
 
     @Override
@@ -837,52 +974,20 @@ public class OverlayPanel extends OverlayPanelAnimation implements ActivityState
         return true;
     }
 
-    @Override
-    public void onHideLayout() {
-        if (!isShowing()) return;
-        closePanel(StateChangeReason.UNKNOWN, false);
-    }
-
     @Override
     public boolean onBackPressed() {
-        if (!isPanelOpened()) return false;
+        if (!isShowing()) return false;
         closePanel(StateChangeReason.BACK_PRESS, true);
         return true;
     }
 
     @Override
-    public void tabTitleChanged(int tabId, String title) {}
+    public ObservableSupplier<Boolean> getHandleBackPressChangedSupplier() {
+        return isShowingSupplier();
+    }
 
     @Override
-    public void tabStateInitialized() {}
-
-    @Override
-    public void tabModelSwitched(boolean incognito) {}
-
-    @Override
-    public void tabSelected(long time, boolean incognito, int id, int prevId) {}
-
-    @Override
-    public void tabMoved(long time, boolean incognito, int id, int oldIndex, int newIndex) {}
-
-    @Override
-    public void tabClosed(long time, boolean incognito, int id) {}
-
-    @Override
-    public void tabClosureCancelled(long time, boolean incognito, int id) {}
-
-    @Override
-    public void tabCreated(long time, boolean incognito, int id, int prevId, boolean selected) {}
-
-    @Override
-    public void tabPageLoadStarted(int id, boolean incognito) {}
-
-    @Override
-    public void tabPageLoadFinished(int id, boolean incognito) {}
-
-    @Override
-    public void tabLoadStarted(int id, boolean incognito) {}
-
-    @Override
-    public void tabLoadFinished(int id, boolean incognito) {}
+    public @BackPressResult int handleBackPress() {
+        return onBackPressed() ? BackPressResult.SUCCESS : BackPressResult.FAILURE;
+    }
 }
