@@ -1,54 +1,75 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.compositor.bottombar;
 
+import android.app.Activity;
 import android.text.TextUtils;
 import android.view.View;
 import android.view.View.MeasureSpec;
 import android.view.ViewGroup;
+import android.view.ViewGroup.MarginLayoutParams;
+
+import androidx.annotation.NonNull;
+import androidx.annotation.VisibleForTesting;
 
-import org.chromium.base.VisibleForTesting;
 import org.chromium.base.annotations.CalledByNative;
-import org.chromium.chrome.browser.ChromeActivity;
-import org.chromium.chrome.browser.ChromeVersionInfo;
+import org.chromium.base.annotations.NativeMethods;
+import org.chromium.base.supplier.Supplier;
 import org.chromium.chrome.browser.WebContentsFactory;
+import org.chromium.chrome.browser.content.ContentUtils;
 import org.chromium.chrome.browser.contextualsearch.ContextualSearchManager;
-import org.chromium.chrome.browser.externalnav.ExternalNavigationHandler;
+import org.chromium.chrome.browser.externalnav.ExternalNavigationDelegateImpl;
+import org.chromium.chrome.browser.incognito.IncognitoUtils;
+import org.chromium.chrome.browser.profiles.Profile;
 import org.chromium.chrome.browser.tab.Tab;
-import org.chromium.components.content_view.ContentView;
+import org.chromium.components.embedder_support.delegate.WebContentsDelegateAndroid;
+import org.chromium.components.embedder_support.view.ContentView;
+import org.chromium.components.external_intents.ExternalNavigationHandler;
 import org.chromium.components.navigation_interception.InterceptNavigationDelegate;
-import org.chromium.components.navigation_interception.NavigationParams;
-import org.chromium.components.web_contents_delegate_android.WebContentsDelegateAndroid;
-import org.chromium.content.browser.ContentVideoViewEmbedder;
-import org.chromium.content_public.browser.ContentViewCore;
+import org.chromium.components.version_info.VersionInfo;
+import org.chromium.content_public.browser.LoadCommittedDetails;
 import org.chromium.content_public.browser.LoadUrlParams;
+import org.chromium.content_public.browser.NavigationHandle;
+import org.chromium.content_public.browser.RenderCoordinates;
 import org.chromium.content_public.browser.WebContents;
 import org.chromium.content_public.browser.WebContentsObserver;
+import org.chromium.ui.base.PageTransition;
 import org.chromium.ui.base.ViewAndroidDelegate;
+import org.chromium.ui.base.WindowAndroid;
+import org.chromium.url.GURL;
+import org.chromium.url.Origin;
 
 /**
  * Content container for an OverlayPanel. This class is responsible for the management of the
- * ContentViewCore displayed inside of a panel and exposes a simple API relevant to actions a
+ * WebContents displayed inside of a panel and exposes a simple API relevant to actions a
  * panel has.
  */
 public class OverlayPanelContent {
+    /** The {@link CompositorViewHolder} for the current activity, used to add/remove views. */
+    private final ViewGroup mCompositorViewHolder;
 
-    /** The ContentViewCore that this panel will display. */
-    private ContentViewCore mContentViewCore;
+    /** The {@link WindowAndroid} for the current activity. */
+    private final WindowAndroid mWindowAndroid;
 
-    /** The WebContents that this panel will display. */
-    private WebContents mWebContents;
-
-    /** The pointer to the native version of this class. */
-    private long mNativeOverlayPanelContentPtr;
+    /** Supplies the current activity {@link Tab}. */
+    private final Supplier<Tab> mCurrentTabSupplier;
 
     /** Used for progress bar events. */
     private final WebContentsDelegateAndroid mWebContentsDelegate;
 
+    /** The WebContents that this panel will display. */
+    private WebContents mWebContents;
+
+    /** The container view that this panel uses. */
+    private ViewGroup mContainerView;
+
+    /** The pointer to the native version of this class. */
+    private long mNativeOverlayPanelContentPtr;
+
     /** The activity that this content is contained in. */
-    private ChromeActivity mActivity;
+    private Activity mActivity;
 
     /** Observer used for tracking loading and navigation. */
     private WebContentsObserver mWebContentsObserver;
@@ -56,7 +77,7 @@ public class OverlayPanelContent {
     /** The URL that was directly loaded using the {@link #loadUrl(String)} method. */
     private String mLoadedUrl;
 
-    /** Whether the ContentViewCore has started loading a URL. */
+    /** Whether the content has started loading a URL. */
     private boolean mDidStartLoadingUrl;
 
     /**
@@ -66,7 +87,7 @@ public class OverlayPanelContent {
     private boolean mShouldReuseWebContents;
 
     /**
-     * Whether the ContentViewCore is processing a pending navigation.
+     * Whether the WebContents is processing a pending navigation.
      * NOTE(pedrosimonetti): This is being used to prevent redirections on the SERP to be
      * interpreted as a regular navigation, which should cause the Contextual Search Panel
      * to be promoted as a Tab. This was added to work around a server bug that has been fixed.
@@ -94,39 +115,74 @@ public class OverlayPanelContent {
     // java layer. Otherwise, the instance could be garbage-collected unexpectedly.
     private InterceptNavigationDelegate mInterceptNavigationDelegate;
 
+    /** Set to {@code True} if opened for an incognito tab. */
+    private boolean mIsIncognito;
+
     /** The desired size of the {@link ContentView} associated with this panel content. */
     private int mContentViewWidth;
     private int mContentViewHeight;
     private boolean mSubtractBarHeight;
 
     /** The height of the bar at the top of the OverlayPanel in pixels. */
-    private int mBarHeightPx;
+    private final int mBarHeightPx;
+
+    /** Sets the top offset of the overlay panel in pixel. 0 when fully expanded. */
+    private int mPanelTopOffsetPx;
+
+    private class OverlayViewDelegate extends ViewAndroidDelegate {
+        public OverlayViewDelegate(ViewGroup v) {
+            super(v);
+        }
+
+        @Override
+        public void setViewPosition(View view, float x, float y, float width, float height,
+                int leftMargin, int topMargin) {
+            super.setViewPosition(view, x, y, width, height, leftMargin, topMargin);
+
+            // Applies top offset depending on the overlay panel state.
+            MarginLayoutParams lp = (MarginLayoutParams) view.getLayoutParams();
+            lp.topMargin += mPanelTopOffsetPx + mBarHeightPx;
+        }
+    }
 
     // ============================================================================================
     // InterceptNavigationDelegateImpl
     // ============================================================================================
 
     // Used to intercept intent navigations.
-    // TODO(jeremycho): Consider creating a Tab with the Panel's ContentViewCore,
+    // TODO(jeremycho): Consider creating a Tab with the Panel's WebContents.
     // which would also handle functionality like long-press-to-paste.
-    private class InterceptNavigationDelegateImpl implements InterceptNavigationDelegate {
+    private class InterceptNavigationDelegateImpl extends InterceptNavigationDelegate {
         final ExternalNavigationHandler mExternalNavHandler;
 
         public InterceptNavigationDelegateImpl() {
-            Tab tab = mActivity.getActivityTab();
-            mExternalNavHandler = (tab != null && tab.getContentViewCore() != null)
-                    ? new ExternalNavigationHandler(tab) : null;
+            Tab tab = mCurrentTabSupplier.get();
+            mExternalNavHandler = (tab != null && tab.getWebContents() != null)
+                    ? new ExternalNavigationHandler(new ExternalNavigationDelegateImpl(tab))
+                    : null;
         }
 
         @Override
-        public boolean shouldIgnoreNavigation(NavigationParams navigationParams) {
+        public boolean shouldIgnoreNavigation(NavigationHandle navigationHandle, GURL escapedUrl,
+                boolean crossFrame, boolean isSandboxedFrame) {
             // If either of the required params for the delegate are null, do not call the
             // delegate and ignore the navigation.
-            if (mExternalNavHandler == null || navigationParams == null) return true;
-            // TODO(mdjones): Rather than passing the two navigation params, instead consider
-            // passing a boolean to make this API simpler.
-            return !mContentDelegate.shouldInterceptNavigation(mExternalNavHandler,
-                    navigationParams);
+            if (mExternalNavHandler == null || navigationHandle == null) return true;
+            return !mContentDelegate.shouldInterceptNavigation(mExternalNavHandler, escapedUrl,
+                    navigationHandle.pageTransition(), navigationHandle.isRedirect(),
+                    navigationHandle.hasUserGesture(), navigationHandle.isRendererInitiated(),
+                    navigationHandle.getReferrerUrl(), navigationHandle.isInPrimaryMainFrame(),
+                    navigationHandle.isExternalProtocol());
+        }
+
+        @Override
+        public GURL handleSubframeExternalProtocol(GURL escapedUrl, @PageTransition int transition,
+                boolean hasUserGesture, Origin initiatorOrigin) {
+            mContentDelegate.shouldInterceptNavigation(mExternalNavHandler, escapedUrl, transition,
+                    false /* isRedirect */, hasUserGesture, true /* isRendererInitiated */,
+                    GURL.emptyGURL() /* referrerUrl */, false /* isInPrimaryMainFrame */,
+                    true /* isExternalProtocol */);
+            return null;
         }
     }
 
@@ -138,23 +194,32 @@ public class OverlayPanelContent {
      * @param contentDelegate An observer for events that occur on this content. If null is passed
      *                        for this parameter, the default one will be used.
      * @param progressObserver An observer for progress related events.
-     * @param activity The ChromeActivity that contains this object.
+     * @param activity The {@link Activity} that contains this object.
+     * @param isIncognito {@True} if opened for an incognito tab
      * @param barHeight The height of the bar at the top of the OverlayPanel in dp.
+     * @param compositorViewHolder The {@link CompositorViewHolder} for the current activity.
+     * @param windowAndroid The {@link WindowAndroid} for the current activity.
+     * @param currentTabSupplier Supplies the current activity {@link Tab}.
      */
-    public OverlayPanelContent(OverlayContentDelegate contentDelegate,
-            OverlayContentProgressObserver progressObserver, ChromeActivity activity,
-            float barHeight) {
-        mNativeOverlayPanelContentPtr = nativeInit();
+    public OverlayPanelContent(@NonNull OverlayContentDelegate contentDelegate,
+            @NonNull OverlayContentProgressObserver progressObserver, @NonNull Activity activity,
+            boolean isIncognito, float barHeight, @NonNull ViewGroup compositorViewHolder,
+            @NonNull WindowAndroid windowAndroid, @NonNull Supplier<Tab> currentTabSupplier) {
+        mNativeOverlayPanelContentPtr = OverlayPanelContentJni.get().init(OverlayPanelContent.this);
         mContentDelegate = contentDelegate;
         mProgressObserver = progressObserver;
         mActivity = activity;
+        mIsIncognito = isIncognito;
         mBarHeightPx = (int) (barHeight * mActivity.getResources().getDisplayMetrics().density);
+        mCompositorViewHolder = compositorViewHolder;
+        mWindowAndroid = windowAndroid;
+        mCurrentTabSupplier = currentTabSupplier;
 
         mWebContentsDelegate = new WebContentsDelegateAndroid() {
             private boolean mIsFullscreen;
 
             @Override
-            public void loadingStateChanged(boolean toDifferentDocument) {
+            public void loadingStateChanged(boolean shouldShowLoadingUI) {
                 boolean isLoading = mWebContents != null && mWebContents.isLoading();
                 if (isLoading) {
                     mProgressObserver.onProgressBarStarted();
@@ -164,13 +229,19 @@ public class OverlayPanelContent {
             }
 
             @Override
-            public void onLoadProgressChanged(int progress) {
-                mProgressObserver.onProgressBarUpdated(progress);
+            public void visibleSSLStateChanged() {
+                mContentDelegate.onSSLStateUpdated();
             }
 
             @Override
-            public void toggleFullscreenModeForTab(boolean enterFullscreen) {
-                mIsFullscreen = enterFullscreen;
+            public void enterFullscreenModeForTab(
+                    boolean prefersNavigationBar, boolean prefersStatusBar) {
+                mIsFullscreen = true;
+            }
+
+            @Override
+            public void exitFullscreenModeForTab() {
+                mIsFullscreen = false;
             }
 
             @Override
@@ -179,34 +250,28 @@ public class OverlayPanelContent {
             }
 
             @Override
-            public ContentVideoViewEmbedder getContentVideoViewEmbedder() {
-                return null;  // Have a no-op embedder be used.
+            public boolean shouldCreateWebContents(GURL targetUrl) {
+                return false;
             }
 
             @Override
             public int getTopControlsHeight() {
-                return (int) (mBarHeightPx
-                        / mActivity.getWindowAndroid().getDisplay().getDipScale());
+                return (int) (mBarHeightPx / mWindowAndroid.getDisplay().getDipScale());
             }
 
             @Override
             public int getBottomControlsHeight() {
                 return 0;
             }
-
-            @Override
-            public boolean controlsResizeView() {
-                return false;
-            }
         };
     }
 
     // ============================================================================================
-    // ContentViewCore related
+    // WebContents related
     // ============================================================================================
 
     /**
-     * Load a URL; this will trigger creation of a new ContentViewCore if being loaded immediately,
+     * Load a URL; this will trigger creation of a new WebContents if being loaded immediately,
      * otherwise one is created when the panel's content becomes visible.
      * @param url The URL that should be loaded.
      * @param shouldLoadImmediately If a URL should be loaded immediately or wait until visibility
@@ -218,22 +283,28 @@ public class OverlayPanelContent {
         if (!shouldLoadImmediately) {
             mPendingUrl = url;
         } else {
-            createNewContentView();
+            createNewWebContents();
             mLoadedUrl = url;
             mDidStartLoadingUrl = true;
             mIsProcessingPendingNavigation = true;
-            if (!mContentDelegate.handleInterceptLoadUrl(mContentViewCore, url)) {
-                mWebContents.getNavigationController().loadUrl(new LoadUrlParams(url));
-            }
+            mWebContents.getNavigationController().loadUrl(new LoadUrlParams(url));
         }
     }
 
+    /**
+     * Whether we should reuse any existing WebContents instead of deleting and recreating.
+     * @param reuse {@code true} if we want to reuse the WebContents.
+     */
+    public void setReuseWebContents(boolean reuse) {
+        mShouldReuseWebContents = reuse;
+    }
+
     /**
      * Call this when a loadUrl request has failed to notify the panel that the WebContents can
      * be reused.  See crbug.com/682953 for details.
      */
     void onLoadUrlFailed() {
-        mShouldReuseWebContents = true;
+        setReuseWebContents(true);
     }
 
     /**
@@ -257,21 +328,31 @@ public class OverlayPanelContent {
     }
 
     /**
-     * Create a new ContentViewCore that will be managed by this panel.
+     * Sets the top offset of the overlay panel that varies as the panel state changes.
+     * @param offset Top offset in pixel.
      */
-    private void createNewContentView() {
-        if (mContentViewCore != null) {
-            // If the ContentViewCore has already been created, but never used,
+    public void setPanelTopOffset(int offset) {
+        mPanelTopOffsetPx = offset;
+    }
+
+    /**
+     * Create a new WebContents that will be managed by this panel.
+     */
+    private void createNewWebContents() {
+        if (mWebContents != null) {
+            // If the WebContents has already been created, but never used,
             // then there's no need to create a new one.
             if (!mDidStartLoadingUrl || mShouldReuseWebContents) return;
 
-            destroyContentView();
+            destroyWebContents();
         }
 
+        Profile profile = IncognitoUtils.getProfileFromWindowAndroid(mWindowAndroid, mIsIncognito);
         // Creates an initially hidden WebContents which gets shown when the panel is opened.
-        mWebContents = WebContentsFactory.createWebContents(false, true);
+        mWebContents = WebContentsFactory.createWebContents(profile, true);
 
-        ContentView cv = ContentView.createContentView(mActivity, mWebContents);
+        ContentView cv = ContentView.createContentView(
+                mActivity, null /* eventOffsetHandler */, mWebContents);
         if (mContentViewWidth != 0 || mContentViewHeight != 0) {
             int width = mContentViewWidth == 0 ? ContentView.DEFAULT_MEASURE_SPEC
                     : MeasureSpec.makeMeasureSpec(mContentViewWidth, MeasureSpec.EXACTLY);
@@ -280,94 +361,83 @@ public class OverlayPanelContent {
             cv.setDesiredMeasureSpec(width, height);
         }
 
-        // Dummny ViewAndroidDelegate since the container view for overlay panel is
-        // never added to the view hierarchy.
-        ViewAndroidDelegate delegate =
-                new ViewAndroidDelegate() {
-                    private ViewGroup mContainerView;
-
-                    private ViewAndroidDelegate init(ViewGroup containerView) {
-                        mContainerView = containerView;
-                        return this;
-                    }
-
-                    @Override
-                    public View acquireView() {
-                        return null;
-                    }
-
-                    @Override
-                    public void setViewPosition(View anchorView, float x, float y, float width,
-                            float height, int leftMargin, int topMargin) {}
-
-                    @Override
-                    public void removeView(View anchorView) { }
-
-                    @Override
-                    public ViewGroup getContainerView() {
-                        return mContainerView;
-                    }
-                }.init(cv);
-        mContentViewCore = ContentViewCore.create(mActivity, ChromeVersionInfo.getProductVersion(),
-                mWebContents, delegate, cv, mActivity.getWindowAndroid());
+        OverlayViewDelegate delegate = new OverlayViewDelegate(cv);
+        mWebContents.initialize(VersionInfo.getProductVersion(), delegate, cv, mWindowAndroid,
+                WebContents.createDefaultInternalsHolder());
+        ContentUtils.setUserAgentOverride(mWebContents, /* overrideInNewTabs= */ false);
 
         // Transfers the ownership of the WebContents to the native OverlayPanelContent.
-        nativeSetWebContents(mNativeOverlayPanelContentPtr, mWebContents, mWebContentsDelegate);
+        OverlayPanelContentJni.get().setWebContents(mNativeOverlayPanelContentPtr,
+                OverlayPanelContent.this, mWebContents, mWebContentsDelegate);
 
         mWebContentsObserver =
                 new WebContentsObserver(mWebContents) {
                     @Override
-                    public void didStartLoading(String url) {
-                        mContentDelegate.onContentLoadStarted(url);
+                    public void didStartLoading(GURL url) {
+                        mContentDelegate.onContentLoadStarted();
                     }
 
                     @Override
-                    public void navigationEntryCommitted() {
+                    public void loadProgressChanged(float progress) {
+                        mProgressObserver.onProgressBarUpdated(progress);
+                    }
+
+                    @Override
+                    public void navigationEntryCommitted(LoadCommittedDetails details) {
                         mContentDelegate.onNavigationEntryCommitted();
                     }
 
                     @Override
-                    public void didStartNavigation(String url, boolean isInMainFrame,
-                            boolean isSameDocument, boolean isErrorPage) {
-                        if (isInMainFrame && !isSameDocument) {
+                    public void didStartNavigationInPrimaryMainFrame(NavigationHandle navigation) {
+                        if (!navigation.isSameDocument()) {
+                            String url = navigation.getUrl().getSpec();
                             mContentDelegate.onMainFrameLoadStarted(
                                     url, !TextUtils.equals(url, mLoadedUrl));
                         }
                     }
 
                     @Override
-                    public void didFinishNavigation(String url, boolean isInMainFrame,
-                            boolean isErrorPage, boolean hasCommitted, boolean isSameDocument,
-                            boolean isFragmentNavigation, Integer pageTransition, int errorCode,
-                            String errorDescription, int httpStatusCode) {
-                        if (hasCommitted && isInMainFrame) {
+                    public void titleWasSet(String title) {
+                        mContentDelegate.onTitleUpdated(title);
+                    }
+
+                    @Override
+                    public void didFinishNavigationInPrimaryMainFrame(NavigationHandle navigation) {
+                        if (navigation.hasCommitted()) {
                             mIsProcessingPendingNavigation = false;
-                            mContentDelegate.onMainFrameNavigation(url,
-                                    !TextUtils.equals(url, mLoadedUrl),
-                                    isHttpFailureCode(httpStatusCode));
+                            mContentDelegate.onMainFrameNavigation(navigation.getUrl().getSpec(),
+                                    !TextUtils.equals(navigation.getUrl().getSpec(), mLoadedUrl),
+                                    isHttpFailureCode(navigation.httpStatusCode()),
+                                    navigation.isErrorPage());
                         }
                     }
+
+                    @Override
+                    public void didFirstVisuallyNonEmptyPaint() {
+                        mContentDelegate.onFirstNonEmptyPaint();
+                    }
                 };
 
+        mContainerView = cv;
         mInterceptNavigationDelegate = new InterceptNavigationDelegateImpl();
-        nativeSetInterceptNavigationDelegate(
-                mNativeOverlayPanelContentPtr, mInterceptNavigationDelegate, mWebContents);
+        OverlayPanelContentJni.get().setInterceptNavigationDelegate(mNativeOverlayPanelContentPtr,
+                OverlayPanelContent.this, mInterceptNavigationDelegate, mWebContents);
 
         mContentDelegate.onContentViewCreated();
-        int viewHeight = mContentViewHeight - (mSubtractBarHeight ? mBarHeightPx : 0);
-        onPhysicalBackingSizeChanged(mContentViewWidth, viewHeight);
-        mWebContents.setSize(mContentViewWidth, viewHeight);
+        resizePanelContentView();
+        mCompositorViewHolder.addView(mContainerView, 1);
     }
 
     /**
-     * Destroy this panel's ContentViewCore.
+     * Destroy this panel's WebContents.
      */
-    private void destroyContentView() {
-        if (mContentViewCore != null) {
+    private void destroyWebContents() {
+        if (mWebContents != null) {
+            mCompositorViewHolder.removeView(mContainerView);
+
             // Native destroy will call up to destroy the Java WebContents.
-            nativeDestroyWebContents(mNativeOverlayPanelContentPtr);
-            mContentViewCore.destroy();
-            mContentViewCore = null;
+            OverlayPanelContentJni.get().destroyWebContents(
+                    mNativeOverlayPanelContentPtr, OverlayPanelContent.this);
             mWebContents = null;
             if (mWebContentsObserver != null) {
                 mWebContentsObserver.destroy();
@@ -377,11 +447,6 @@ public class OverlayPanelContent {
             mDidStartLoadingUrl = false;
             mIsProcessingPendingNavigation = false;
             mShouldReuseWebContents = false;
-
-            setVisibility(false);
-
-            // After everything has been disposed, notify the observer.
-            mContentDelegate.onContentViewDestroyed();
         }
     }
 
@@ -390,13 +455,14 @@ public class OverlayPanelContent {
     // ============================================================================================
 
     /**
-     * Calls updateBrowserControlsState on the ContentViewCore.
+     * Calls updateBrowserControlsState on the WebContents.
      * @param areControlsHidden Whether the browser controls are hidden for the web contents. If
      *                          false, the web contents viewport always accounts for the controls.
      *                          Otherwise the web contents never accounts for them.
      */
     public void updateBrowserControlsState(boolean areControlsHidden) {
-        nativeUpdateBrowserControlsState(mNativeOverlayPanelContentPtr, areControlsHidden);
+        OverlayPanelContentJni.get().updateBrowserControlsState(
+                mNativeOverlayPanelContentPtr, OverlayPanelContent.this, areControlsHidden);
     }
 
     /**
@@ -407,11 +473,11 @@ public class OverlayPanelContent {
     }
 
     /**
-     * Reset the ContentViewCore's scroll position to (0, 0).
+     * Reset the content's scroll position to (0, 0).
      */
     public void resetContentViewScroll() {
-        if (mContentViewCore != null) {
-            mContentViewCore.scrollTo(0, 0);
+        if (mWebContents != null) {
+            mWebContents.getEventForwarder().scrollTo(0, 0);
         }
     }
 
@@ -419,8 +485,9 @@ public class OverlayPanelContent {
      * @return The Y scroll position.
      */
     public float getContentVerticalScroll() {
-        return mContentViewCore != null
-                ? mContentViewCore.computeVerticalScrollOffset() : -1.f;
+        return mWebContents != null
+                ? RenderCoordinates.fromWebContents(mWebContents).getScrollYPixInt()
+                : -1.f;
     }
 
     /**
@@ -436,11 +503,11 @@ public class OverlayPanelContent {
             // If the last call to loadUrl was specified to be delayed, load it now.
             if (!TextUtils.isEmpty(mPendingUrl)) loadUrl(mPendingUrl, true);
 
-            // The CVC is created with the search request, but if none was made we'll need
+            // The WebContents is created with the search request, but if none was made we'll need
             // one in order to display an empty panel.
-            if (mContentViewCore == null) createNewContentView();
+            if (mWebContents == null) createNewWebContents();
 
-            // NOTE(pedrosimonetti): Calling onShow() on the ContentViewCore will cause the page
+            // NOTE(pedrosimonetti): Calling onShow() on the WebContents will cause the page
             // to be rendered. This has a side effect of causing the page to be included in
             // your Web History (if enabled). For this reason, onShow() should only be called
             // when we know for sure the page will be seen by the user.
@@ -457,19 +524,19 @@ public class OverlayPanelContent {
     /**
      * @return Whether the given HTTP result code represents a failure or not.
      */
-    private boolean isHttpFailureCode(int httpResultCode) {
+    private static boolean isHttpFailureCode(int httpResultCode) {
         return httpResultCode <= 0 || httpResultCode >= 400;
     }
 
     /**
-     * @return true if the ContentViewCore is visible on the page.
+     * @return true if the content is visible on the page.
      */
     public boolean isContentShowing() {
         return mIsContentViewShowing;
     }
 
     // ============================================================================================
-    // Methods for managing this panel's ContentViewCore.
+    // Methods for managing this panel's WebContents.
     // ============================================================================================
 
     /**
@@ -482,28 +549,26 @@ public class OverlayPanelContent {
     }
 
     /**
-     * @return This panel's ContentViewCore.
+     * @return The associated {@link WebContents}.
      */
-    @VisibleForTesting
-    public ContentViewCore getContentViewCore() {
-        return mContentViewCore;
-    }
-
-    private WebContents getWebContents() {
+    public WebContents getWebContents() {
         return mWebContents;
     }
 
-    void onSizeChanged(int width, int height) {
-        if (getWebContents() == null) return;
-        getWebContents().setSize(width, height);
+    /**
+     * @return The associated {@link ContentView}.
+     */
+    public ViewGroup getContainerView() {
+        return mContainerView;
     }
 
-    void onPhysicalBackingSizeChanged(int width, int height) {
+    void resizePanelContentView() {
         WebContents webContents = getWebContents();
-        if (webContents != null) {
-            nativeOnPhysicalBackingSizeChanged(
-                    mNativeOverlayPanelContentPtr, webContents, width, height);
-        }
+        if (webContents == null) return;
+        int viewHeight = mContentViewHeight - (mSubtractBarHeight ? mBarHeightPx : 0);
+        OverlayPanelContentJni.get().onPhysicalBackingSizeChanged(mNativeOverlayPanelContentPtr,
+                OverlayPanelContent.this, webContents, mContentViewWidth, viewHeight);
+        mWebContents.setSize(mContentViewWidth, viewHeight);
     }
 
     /**
@@ -512,7 +577,8 @@ public class OverlayPanelContent {
      * @param urlTimeMs The time the URL was navigated to.
      */
     public void removeLastHistoryEntry(String historyUrl, long urlTimeMs) {
-        nativeRemoveLastHistoryEntry(mNativeOverlayPanelContentPtr, historyUrl, urlTimeMs);
+        OverlayPanelContentJni.get().removeLastHistoryEntry(
+                mNativeOverlayPanelContentPtr, OverlayPanelContent.this, historyUrl, urlTimeMs);
     }
 
     /**
@@ -520,29 +586,37 @@ public class OverlayPanelContent {
      */
     @VisibleForTesting
     public void destroy() {
-        if (mContentViewCore != null) {
-            destroyContentView();
-        }
+        if (mWebContents != null) destroyWebContents();
 
         // Tests will not create the native pointer, so we need to check if it's not zero
-        // otherwise calling nativeDestroy with zero will make Chrome crash.
+        // otherwise calling OverlayPanelContentJni.get().destroy with zero will make Chrome crash.
         if (mNativeOverlayPanelContentPtr != 0L) {
-            nativeDestroy(mNativeOverlayPanelContentPtr);
+            OverlayPanelContentJni.get().destroy(
+                    mNativeOverlayPanelContentPtr, OverlayPanelContent.this);
         }
     }
 
-    // Native calls.
-    private native long nativeInit();
-    private native void nativeDestroy(long nativeOverlayPanelContent);
-    private native void nativeRemoveLastHistoryEntry(
-            long nativeOverlayPanelContent, String historyUrl, long urlTimeMs);
-    private native void nativeOnPhysicalBackingSizeChanged(
-            long nativeOverlayPanelContent, WebContents webContents, int width, int height);
-    private native void nativeSetWebContents(long nativeOverlayPanelContent,
-            WebContents webContents, WebContentsDelegateAndroid delegate);
-    private native void nativeDestroyWebContents(long nativeOverlayPanelContent);
-    private native void nativeSetInterceptNavigationDelegate(long nativeOverlayPanelContent,
-            InterceptNavigationDelegate delegate, WebContents webContents);
-    private native void nativeUpdateBrowserControlsState(
-            long nativeOverlayPanelContent, boolean areControlsHidden);
+    public InterceptNavigationDelegate getInterceptNavigationDelegateForTesting() {
+        return mInterceptNavigationDelegate;
+    }
+
+    @NativeMethods
+    interface Natives {
+        // Native calls.
+        long init(OverlayPanelContent caller);
+
+        void destroy(long nativeOverlayPanelContent, OverlayPanelContent caller);
+        void removeLastHistoryEntry(long nativeOverlayPanelContent, OverlayPanelContent caller,
+                String historyUrl, long urlTimeMs);
+        void onPhysicalBackingSizeChanged(long nativeOverlayPanelContent,
+                OverlayPanelContent caller, WebContents webContents, int width, int height);
+        void setWebContents(long nativeOverlayPanelContent, OverlayPanelContent caller,
+                WebContents webContents, WebContentsDelegateAndroid delegate);
+        void destroyWebContents(long nativeOverlayPanelContent, OverlayPanelContent caller);
+        void setInterceptNavigationDelegate(long nativeOverlayPanelContent,
+                OverlayPanelContent caller, InterceptNavigationDelegate delegate,
+                WebContents webContents);
+        void updateBrowserControlsState(long nativeOverlayPanelContent, OverlayPanelContent caller,
+                boolean areControlsHidden);
+    }
 }
