@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,10 +6,15 @@ package org.chromium.chrome.browser.compositor.bottombar;
 
 import android.view.ViewGroup;
 
-import org.chromium.base.VisibleForTesting;
+import androidx.annotation.IntDef;
+import androidx.annotation.VisibleForTesting;
+
+import org.chromium.base.ObserverList;
 import org.chromium.chrome.browser.compositor.bottombar.OverlayPanel.StateChangeReason;
 import org.chromium.ui.resources.dynamics.DynamicResourceLoader;
 
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
 import java.util.Comparator;
 import java.util.HashSet;
 import java.util.PriorityQueue;
@@ -20,15 +25,29 @@ import java.util.Set;
  * Used to decide which panel should be showing on screen at any moment.
  */
 public class OverlayPanelManager {
+    /** An observer of panel visibility. */
+    public interface OverlayPanelManagerObserver {
+        /**
+         * A notification that an {@link OverlayPanel} has been shown.
+         */
+        void onOverlayPanelShown();
+
+        /**
+         * A notification that an {@link OverlayPanel} has been hidden.
+         */
+        void onOverlayPanelHidden();
+    }
 
     /**
      * Priority of an OverlayPanel; used for deciding which panel will be shown when there are
-     * multiple candidates.
+     * multiple candidates. Values should be numbered from 0 and can't have gaps.
      */
-    public static enum PanelPriority {
-        LOW,
-        MEDIUM,
-        HIGH;
+    @IntDef({PanelPriority.LOW, PanelPriority.MEDIUM, PanelPriority.HIGH})
+    @Retention(RetentionPolicy.SOURCE)
+    public @interface PanelPriority {
+        int LOW = 0;
+        int MEDIUM = 1;
+        int HIGH = 2;
     }
 
     /** The initial size of the priority queue for suppressed panels. */
@@ -37,6 +56,9 @@ public class OverlayPanelManager {
     /** A map of panels that this class is managing. */
     private final Set<OverlayPanel> mPanelSet;
 
+    /** A list of observers for this manager. */
+    private final ObserverList<OverlayPanelManagerObserver> mObservers;
+
     /** The panel that is currently being displayed. */
     private OverlayPanel mActivePanel;
 
@@ -50,7 +72,7 @@ public class OverlayPanelManager {
     private OverlayPanel mPendingPanel;
 
     /** When a panel is suppressed, this the reason the pending panel is to be shown. */
-    private StateChangeReason mPendingReason;
+    private @StateChangeReason int mPendingReason;
 
     /** This handles resource loading for each panels. */
     private DynamicResourceLoader mDynamicResourceLoader;
@@ -68,10 +90,11 @@ public class OverlayPanelManager {
                     public int compare(OverlayPanel p1, OverlayPanel p2) {
                         // The head of the queue is the smallest element, so subtract p1's priority
                         // from p2's priority.
-                        return p2.getPriority().ordinal() - p1.getPriority().ordinal();
+                        return p2.getPriority() - p1.getPriority();
                     }
                 });
         mPanelSet = new HashSet<>();
+        mObservers = new ObserverList<>();
     }
 
     /**
@@ -80,23 +103,21 @@ public class OverlayPanelManager {
      * @param panel The panel to show.
      * @param reason The reason the panel is going to be shown.
      */
-    public void requestPanelShow(OverlayPanel panel, StateChangeReason reason) {
+    public void requestPanelShow(OverlayPanel panel, @StateChangeReason int reason) {
         if (panel == null || panel == mActivePanel) return;
 
         if (mActivePanel == null) {
             // If no panel is currently showing, simply show the requesting panel.
             mActivePanel = panel;
-            // TODO(mdjones): peekPanel should not be exposed publicly since the manager
-            // controls if a panel should show or not.
-            mActivePanel.peekPanel(reason);
+            peekPanel(mActivePanel, reason);
 
-        } else if (panel.getPriority().ordinal() > mActivePanel.getPriority().ordinal()) {
+        } else if (panel.getPriority() > mActivePanel.getPriority()) {
             // If a panel with higher priority than the active one requests to be shown, suppress
             // the active panel and show the requesting one. closePanel will trigger
             // notifyPanelClosed.
             mPendingPanel = panel;
             mPendingReason = reason;
-            mActivePanel.closePanel(StateChangeReason.SUPPRESS, true);
+            mActivePanel.closePanel(StateChangeReason.PANEL_SUPPRESS, true);
 
         } else if (panel.canBeSuppressed()) {
             // If a panel was showing and the requesting panel has a lower priority, suppress it
@@ -110,20 +131,20 @@ public class OverlayPanelManager {
      * NOTE(mdjones): It is possible that a panel other than the one currently showing was hidden.
      * @param panel The panel that was closed.
      */
-    public void notifyPanelClosed(OverlayPanel panel, StateChangeReason reason) {
+    public void notifyPanelClosed(OverlayPanel panel, @StateChangeReason int reason) {
         // TODO(mdjones): Close should behave like "requestShowPanel". The reason it currently does
         // not is because closing will cancel animation for that panel. This method waits for the
         // panel's "onClosed" event to fire, thus preserving the animation.
         if (panel == null) return;
 
         // If the reason to close was to suppress, only suppress the panel.
-        if (reason == StateChangeReason.SUPPRESS) {
+        if (reason == StateChangeReason.PANEL_SUPPRESS) {
             if (mActivePanel == panel) {
                 if (mActivePanel.canBeSuppressed()) {
                     mSuppressedPanels.add(mActivePanel);
                 }
                 mActivePanel = mPendingPanel;
-                mActivePanel.peekPanel(mPendingReason);
+                peekPanel(mActivePanel, mPendingReason);
                 mPendingPanel = null;
                 mPendingReason = StateChangeReason.UNKNOWN;
             }
@@ -133,12 +154,25 @@ public class OverlayPanelManager {
                 mActivePanel = null;
                 if (!mSuppressedPanels.isEmpty()) {
                     mActivePanel = mSuppressedPanels.poll();
-                    mActivePanel.peekPanel(StateChangeReason.UNSUPPRESS);
+                    peekPanel(mActivePanel, StateChangeReason.PANEL_UNSUPPRESS);
                 }
             } else {
                 mSuppressedPanels.remove(panel);
             }
         }
+        for (OverlayPanelManagerObserver o : mObservers) o.onOverlayPanelHidden();
+    }
+
+    /**
+     * Peek an {@link OverlayPanel} and trigger the observer event.
+     * @param overlayPanel The panel to peek.
+     * @param reason The reason the panel was peeked.
+     */
+    private void peekPanel(OverlayPanel overlayPanel, @StateChangeReason int reason) {
+        // TODO(mdjones): peekPanel should not be exposed publicly since the manager
+        // controls if a panel should show or not.
+        overlayPanel.peekPanel(reason);
+        for (OverlayPanelManagerObserver o : mObservers) o.onOverlayPanelShown();
     }
 
     /**
@@ -213,4 +247,18 @@ public class OverlayPanelManager {
 
         mPanelSet.add(panel);
     }
+
+    /**
+     * @param observer The observer to add to this manager.
+     */
+    public void addObserver(OverlayPanelManagerObserver observer) {
+        mObservers.addObserver(observer);
+    }
+
+    /**
+     * @param observer The observer to remove from this manager.
+     */
+    public void removeObserver(OverlayPanelManagerObserver observer) {
+        mObservers.removeObserver(observer);
+    }
 }
