@@ -1,42 +1,58 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.compositor.bottombar.contextualsearch;
 
 import android.content.Context;
+import android.text.TextUtils;
 import android.view.View;
 import android.view.ViewGroup;
 import android.widget.TextView;
 
 import org.chromium.chrome.R;
-import org.chromium.chrome.browser.compositor.bottombar.OverlayPanel;
 import org.chromium.chrome.browser.compositor.bottombar.OverlayPanelAnimation;
 import org.chromium.chrome.browser.compositor.bottombar.OverlayPanelTextViewInflater;
-import org.chromium.chrome.browser.compositor.layouts.ChromeAnimation;
+import org.chromium.chrome.browser.layouts.animation.CompositorAnimator;
+import org.chromium.components.browser_ui.widget.animation.Interpolators;
 import org.chromium.ui.resources.dynamics.DynamicResourceLoader;
 
 /**
- * Controls the Caption View that is shown at the bottom of the control and used
- * as a dynamic resource.
+ * Controls the Caption View that is shown at the bottom of the {@link ContextualSearchBarControl}
+ * and used as a dynamic resource.
  */
-public class ContextualSearchCaptionControl extends OverlayPanelTextViewInflater
-        implements ChromeAnimation.Animatable<ContextualSearchCaptionControl.AnimationType> {
+public class ContextualSearchCaptionControl extends OverlayPanelTextViewInflater {
     private static final float ANIMATION_PERCENTAGE_ZERO = 0.f;
     private static final float ANIMATION_PERCENTAGE_COMPLETE = 1.f;
 
-    /**
-     * Animation properties.
-     */
-    protected enum AnimationType {
-        APPEARANCE
-    }
-
     /**
      * The caption View.
      */
     private TextView mCaption;
 
+    /**
+     * The text for the caption when the Bar is peeking.
+     */
+    private String mPeekingCaptionText;
+
+    /**
+     * Whether there is a caption when the Bar is peeking.
+     */
+    private boolean mHasPeekingCaption;
+
+    /**
+     * Whether the caption for the expanded Bar is showing.
+     */
+    private boolean mShowingExpandedCaption;
+
+    /**
+     * Whether the expanded caption should be shown.
+     */
+    private final boolean mShouldShowExpandedCaption;
+
+    /** The {@link ContextualSearchPanel} that this class belongs to. */
+    private final ContextualSearchPanel mPanel;
+
     /**
      * The caption visibility.
      */
@@ -49,6 +65,9 @@ public class ContextualSearchCaptionControl extends OverlayPanelTextViewInflater
      */
     private float mAnimationPercentage = ANIMATION_PERCENTAGE_ZERO;
 
+    /** The animator responsible for transitioning the caption. */
+    private CompositorAnimator mTransitionAnimator;
+
     /**
      * Whether a new snapshot has been captured by the system yet - this is false when we have
      * something to show, but cannot yet show it.
@@ -56,15 +75,21 @@ public class ContextualSearchCaptionControl extends OverlayPanelTextViewInflater
     private boolean mDidCapture;
 
     /**
-     * @param panel             The panel.
-     * @param context           The Android Context used to inflate the View.
-     * @param container         The container View used to inflate the View.
-     * @param resourceLoader    The resource loader that will handle the snapshot capturing.
+     * @param panel                     The panel.
+     * @param context                   The Android Context used to inflate the View.
+     * @param container                 The container View used to inflate the View.
+     * @param resourceLoader            The resource loader that will handle the snapshot capturing.
+     * @param shouldShowExpandedCaption Whether the "Open in new tab" caption should be shown
+     *                                  when the panel is expanded.
      */
-    public ContextualSearchCaptionControl(OverlayPanel panel, Context context, ViewGroup container,
-            DynamicResourceLoader resourceLoader) {
+    public ContextualSearchCaptionControl(ContextualSearchPanel panel, Context context,
+            ViewGroup container, DynamicResourceLoader resourceLoader,
+            boolean shouldShowExpandedCaption) {
         super(panel, R.layout.contextual_search_caption_view, R.id.contextual_search_caption_view,
-                context, container, resourceLoader);
+                context, container, resourceLoader, R.dimen.contextual_search_end_padding,
+                R.dimen.contextual_search_padded_button_width);
+        mShouldShowExpandedCaption = shouldShowExpandedCaption;
+        mPanel = panel;
     }
 
     /**
@@ -73,8 +98,10 @@ public class ContextualSearchCaptionControl extends OverlayPanelTextViewInflater
      *        e.g. a Quick Answer.
      */
     public void setCaption(String caption) {
-        // If the caption is visible it has already been set. Return early rather than changing it.
-        if (mIsVisible) return;
+        mPeekingCaptionText = sanitizeText(caption);
+        mHasPeekingCaption = true;
+
+        if (mShowingExpandedCaption) return;
 
         mDidCapture = false;
 
@@ -86,12 +113,26 @@ public class ContextualSearchCaptionControl extends OverlayPanelTextViewInflater
         show();
     }
 
+    /**
+     * Updates the caption when in transition between peeked to expanded states.
+     * @param percentage The percentage to the more opened state.
+     */
+    @Override
+    public void onUpdateFromPeekToExpand(float percentage) {
+        super.onUpdateFromPeekToExpand(percentage);
+        if (mHasPeekingCaption) {
+            if (mTransitionAnimator != null) mTransitionAnimator.cancel();
+            mAnimationPercentage = 1.f - percentage;
+        }
+    }
+
     /**
      * Hides the caption.
      */
     public void hide() {
         mIsVisible = false;
         mAnimationPercentage = ANIMATION_PERCENTAGE_ZERO;
+        mHasPeekingCaption = false;
     }
 
     /**
@@ -131,6 +172,11 @@ public class ContextualSearchCaptionControl extends OverlayPanelTextViewInflater
         return mCaption.getText();
     }
 
+    /** Returns whether there's already a visible caption. */
+    boolean hasCaption() {
+        return getIsVisible() && !TextUtils.isEmpty(getCaptionText());
+    }
+
     //========================================================================================
     // OverlayPanelTextViewInflater overrides
     //========================================================================================
@@ -155,8 +201,9 @@ public class ContextualSearchCaptionControl extends OverlayPanelTextViewInflater
     @Override
     protected void onCaptureEnd() {
         super.onCaptureEnd();
-        mDidCapture = true;
+        if (mDidCapture) return;
 
+        mDidCapture = true;
         animateTransitionIn();
     }
 
@@ -165,18 +212,13 @@ public class ContextualSearchCaptionControl extends OverlayPanelTextViewInflater
     // ============================================================================================
 
     private void animateTransitionIn() {
-        mOverlayPanel.addToAnimation(this, AnimationType.APPEARANCE, ANIMATION_PERCENTAGE_ZERO,
-                ANIMATION_PERCENTAGE_COMPLETE, OverlayPanelAnimation.MAXIMUM_ANIMATION_DURATION_MS,
-                0);
-    }
+        mTransitionAnimator = CompositorAnimator.ofFloat(mOverlayPanel.getAnimationHandler(),
+                ANIMATION_PERCENTAGE_ZERO, ANIMATION_PERCENTAGE_COMPLETE,
+                OverlayPanelAnimation.BASE_ANIMATION_DURATION_MS, null);
+        mTransitionAnimator.addUpdateListener(
+                animator -> mAnimationPercentage = animator.getAnimatedValue());
+        mTransitionAnimator.setInterpolator(Interpolators.FAST_OUT_SLOW_IN_INTERPOLATOR);
 
-    @Override
-    public void setProperty(AnimationType type, float value) {
-        if (type == AnimationType.APPEARANCE) {
-            mAnimationPercentage = value;
-        }
+        mTransitionAnimator.start();
     }
-
-    @Override
-    public void onPropertyAnimationFinished(AnimationType prop) {}
 }
