@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -9,15 +9,15 @@ import android.content.Intent;
 import android.content.pm.ActivityInfo;
 import android.content.pm.PackageManager;
 import android.content.pm.ResolveInfo;
-import android.content.res.Resources;
 import android.graphics.drawable.Drawable;
-import android.os.StrictMode;
 import android.provider.Browser;
-import android.support.v4.graphics.drawable.DrawableCompat;
 import android.text.TextUtils;
 import android.widget.ImageView;
 
-import org.chromium.base.ApiCompatibilityUtils;
+import androidx.core.graphics.drawable.DrawableCompat;
+
+import org.chromium.base.IntentUtils;
+import org.chromium.base.PackageManagerUtils;
 import org.chromium.chrome.R;
 import org.chromium.chrome.browser.ChromeTabbedActivity;
 import org.chromium.chrome.browser.ChromeTabbedActivity2;
@@ -25,66 +25,21 @@ import org.chromium.chrome.browser.IntentHandler;
 import org.chromium.chrome.browser.contextualsearch.ContextualSearchUma;
 import org.chromium.chrome.browser.contextualsearch.QuickActionCategory;
 import org.chromium.chrome.browser.tab.Tab;
-import org.chromium.chrome.browser.util.ColorUtils;
-import org.chromium.chrome.browser.util.FeatureUtilities;
-import org.chromium.chrome.browser.util.IntentUtils;
+import org.chromium.chrome.browser.theme.ThemeUtils;
 import org.chromium.content_public.browser.LoadUrlParams;
 import org.chromium.ui.resources.dynamics.DynamicResourceLoader;
 import org.chromium.ui.resources.dynamics.ViewResourceInflater;
+import org.chromium.ui.util.ColorUtils;
 
 import java.net.URISyntaxException;
-import java.util.Collections;
-import java.util.HashMap;
 import java.util.List;
-import java.util.Map;
 
 /**
  * Stores information related to a Contextual Search "quick action."
+ * Actions can be activated through a tap on the Bar and include intents like calling a phone
+ * number or launching Maps for a street address.
  */
 public class ContextualSearchQuickActionControl extends ViewResourceInflater {
-    private static final Map<Integer, Integer> ICON_MAP;
-    static {
-        Map<Integer, Integer> icons = new HashMap<>();
-        icons.put(QuickActionCategory.ADDRESS, R.drawable.ic_place_googblue_36dp);
-        icons.put(QuickActionCategory.EMAIL, R.drawable.ic_email_googblue_36dp);
-        icons.put(QuickActionCategory.EVENT, R.drawable.ic_event_googblue_36dp);
-        icons.put(QuickActionCategory.PHONE, R.drawable.ic_phone_googblue_36dp);
-        icons.put(QuickActionCategory.WEBSITE, R.drawable.ic_link_grey600_36dp);
-        ICON_MAP = Collections.unmodifiableMap(icons);
-    }
-
-    private static final Map<Integer, Integer> DEFAULT_APP_CAPTION_MAP;
-    static {
-        Map<Integer, Integer> captions = new HashMap<>();
-        captions.put(
-                QuickActionCategory.ADDRESS, R.string.contextual_search_quick_action_caption_open);
-        captions.put(
-                QuickActionCategory.EMAIL, R.string.contextual_search_quick_action_caption_email);
-        captions.put(
-                QuickActionCategory.EVENT, R.string.contextual_search_quick_action_caption_event);
-        captions.put(
-                QuickActionCategory.PHONE, R.string.contextual_search_quick_action_caption_phone);
-        captions.put(
-                QuickActionCategory.WEBSITE, R.string.contextual_search_quick_action_caption_open);
-        DEFAULT_APP_CAPTION_MAP = Collections.unmodifiableMap(captions);
-    }
-
-    private static final Map<Integer, Integer> FALLBACK_CAPTION_MAP;
-    static {
-        Map<Integer, Integer> captions = new HashMap<>();
-        captions.put(QuickActionCategory.ADDRESS,
-                R.string.contextual_search_quick_action_caption_generic_map);
-        captions.put(QuickActionCategory.EMAIL,
-                R.string.contextual_search_quick_action_caption_generic_email);
-        captions.put(QuickActionCategory.EVENT,
-                R.string.contextual_search_quick_action_caption_generic_event);
-        captions.put(QuickActionCategory.PHONE,
-                R.string.contextual_search_quick_action_caption_phone);
-        captions.put(QuickActionCategory.WEBSITE,
-                R.string.contextual_search_quick_action_caption_generic_website);
-        FALLBACK_CAPTION_MAP = Collections.unmodifiableMap(captions);
-    }
-
     private Context mContext;
     private String mQuickActionUri;
     private int mQuickActionCategory;
@@ -107,11 +62,78 @@ public class ContextualSearchQuickActionControl extends ViewResourceInflater {
     }
 
     /**
-     * @param quickActionUri The URI for the intent associated with the quick action. If the URI is
-     *                       the empty string or cannot be parsed no quick action will be available.
-     * @param quickActionCategory The {@link QuickActionCategory} for the quick action.
-     * @param toolbarBackgroundColor The current toolbar background color. This may be used for
-     *                               icon tinting.
+     * Gets the resource ID of the icon for the given category.
+     * @param category Which application category the icon should be for.
+     * @return         The resource ID or {@code null} if an unsupported category is supplied.
+     */
+    private static Integer getIconResId(@QuickActionCategory int category) {
+        switch (category) {
+            case QuickActionCategory.ADDRESS:
+                return R.drawable.ic_place_googblue_36dp;
+            case QuickActionCategory.EMAIL:
+                return R.drawable.ic_email_googblue_36dp;
+            case QuickActionCategory.EVENT:
+                return R.drawable.ic_event_googblue_36dp;
+            case QuickActionCategory.PHONE:
+                return R.drawable.ic_phone_googblue_36dp;
+            case QuickActionCategory.WEBSITE:
+                return R.drawable.ic_link_grey600_36dp;
+            default:
+                return null;
+        }
+    }
+
+    /**
+     * Gets the caption string to show for the default app for the given category.
+     * @param  category Which application category the string should be for.
+     * @return          A string ID or {@code null} if an unsupported category is supplied.
+     */
+    private static Integer getDefaultAppCaptionId(@QuickActionCategory int category) {
+        switch (category) {
+            case QuickActionCategory.ADDRESS:
+                return R.string.contextual_search_quick_action_caption_open;
+            case QuickActionCategory.EMAIL:
+                return R.string.contextual_search_quick_action_caption_email;
+            case QuickActionCategory.EVENT:
+                return R.string.contextual_search_quick_action_caption_event;
+            case QuickActionCategory.PHONE:
+                return R.string.contextual_search_quick_action_caption_phone;
+            case QuickActionCategory.WEBSITE:
+                return R.string.contextual_search_quick_action_caption_open;
+            default:
+                return null;
+        }
+    }
+
+    /**
+     * Gets the caption string to show for a generic app of the given category.
+     * @param  category Which application category the string should be for.
+     * @return          A string ID or {@code null} if an unsupported category is supplied.
+     */
+    private static Integer getFallbackCaptionId(@QuickActionCategory int category) {
+        switch (category) {
+            case QuickActionCategory.ADDRESS:
+                return R.string.contextual_search_quick_action_caption_generic_map;
+            case QuickActionCategory.EMAIL:
+                return R.string.contextual_search_quick_action_caption_generic_email;
+            case QuickActionCategory.EVENT:
+                return R.string.contextual_search_quick_action_caption_generic_event;
+            case QuickActionCategory.PHONE:
+                return R.string.contextual_search_quick_action_caption_phone;
+            case QuickActionCategory.WEBSITE:
+                return R.string.contextual_search_quick_action_caption_generic_website;
+            default:
+                return null;
+        }
+    }
+
+    /**
+     * @param quickActionUri         The URI for the intent associated with the quick action.
+     *                               If the URI is the empty string or cannot be parsed no quick
+     *                               action will be available.
+     * @param quickActionCategory    The {@link QuickActionCategory} for the quick action.
+     * @param toolbarBackgroundColor The current toolbar background color. This may be
+     *                               used for icon tinting.
      */
     public void setQuickAction(
             String quickActionUri, int quickActionCategory, int toolbarBackgroundColor) {
@@ -130,8 +152,8 @@ public class ContextualSearchQuickActionControl extends ViewResourceInflater {
 
     /**
      * Sends the intent associated with the quick action if one is available.
-     * @param tab The current tab, used to load a URL if the quick action should open inside
-     *            Chrome.
+     * @param tab The current tab, used to load a URL if the quick action should open
+     *            inside Chrome.
      */
     public void sendIntent(Tab tab) {
         if (mOpenQuickActionInChrome) {
@@ -158,16 +180,16 @@ public class ContextualSearchQuickActionControl extends ViewResourceInflater {
     }
 
     /**
-     * @return The caption associated with the quick action or null if no quick action is
-     *         available.
+     * @return The caption associated with the quick action or null if no quick action
+     *         is available.
      */
     public String getCaption() {
         return mCaption;
     }
 
     /**
-     * @return The resource id for the icon associated with the quick action or 0 if no quick
-     *         action is available.
+     * @return The resource id for the icon associated with the quick action or 0 if no
+     *         quick action is available.
      */
     public int getIconResId() {
         return mHasQuickAction ? getViewId() : 0;
@@ -210,39 +232,30 @@ public class ContextualSearchQuickActionControl extends ViewResourceInflater {
 
         PackageManager packageManager = mContext.getPackageManager();
 
-        // If a default is set, PackageManager#resolveActivity() will return the ResolveInfo
-        // for the default activity.
-        ResolveInfo possibleDefaultActivity = null;
+        // If a default is set, PackageManager#resolveActivity() will return the
+        // ResolveInfo for the default activity.
+        ResolveInfo possibleDefaultActivity = PackageManagerUtils.resolveActivity(mIntent, 0);
 
-        // On KitKat, calling PackageManager#resolveActivity() causes disk reads and writes.
-        // Temporarily allow this while resolving the intent.
-        StrictMode.ThreadPolicy oldPolicy = StrictMode.allowThreadDiskWrites();
-        try {
-            possibleDefaultActivity = packageManager.resolveActivity(mIntent, 0);
-        } finally {
-            StrictMode.setThreadPolicy(oldPolicy);
-        }
-
-        // PackageManager#queryIntentActivities() will return a list of activities that can handle
-        // the intent, sorted from best to worst. If there are no matching activities, an empty
-        // list is returned.
-        List<ResolveInfo> resolveInfoList = packageManager.queryIntentActivities(
-                mIntent, 0);
+        // PackageManager#queryIntentActivities() will return a list of activities that
+        // can handle the intent, sorted from best to worst. If there are no matching
+        // activities, an empty list is returned.
+        List<ResolveInfo> resolveInfoList = PackageManagerUtils.queryIntentActivities(mIntent, 0);
 
         int numMatchingActivities = 0;
         ResolveInfo defaultActivityResolveInfo = null;
         for (ResolveInfo resolveInfo : resolveInfoList) {
             if (resolveInfo.activityInfo != null && resolveInfo.activityInfo.exported) {
                 numMatchingActivities++;
+                if (possibleDefaultActivity == null
+                        || possibleDefaultActivity.activityInfo == null) {
+                    continue;
+                }
 
                 // Return early if this resolveInfo matches the possibleDefaultActivity.
                 ActivityInfo possibleDefaultActivityInfo = possibleDefaultActivity.activityInfo;
-                if (possibleDefaultActivityInfo == null) continue;
-
                 ActivityInfo resolveActivityInfo = resolveInfo.activityInfo;
                 boolean matchesPossibleDefaultActivity =
-                        TextUtils.equals(resolveActivityInfo.name,
-                                possibleDefaultActivityInfo.name)
+                        TextUtils.equals(resolveActivityInfo.name, possibleDefaultActivityInfo.name)
                         && TextUtils.equals(resolveActivityInfo.packageName,
                                 possibleDefaultActivityInfo.packageName);
 
@@ -253,8 +266,8 @@ public class ContextualSearchQuickActionControl extends ViewResourceInflater {
             }
         }
 
-        ContextualSearchUma.logQuickActionIntentResolution(mQuickActionCategory,
-                numMatchingActivities);
+        ContextualSearchUma.logQuickActionIntentResolution(
+                mQuickActionCategory, numMatchingActivities);
 
         if (numMatchingActivities == 0) {
             reset();
@@ -270,16 +283,16 @@ public class ContextualSearchQuickActionControl extends ViewResourceInflater {
             if (mQuickActionCategory != QuickActionCategory.PHONE) {
                 // Use the default app's name to construct the caption.
                 mCaption = mContext.getResources().getString(
-                        DEFAULT_APP_CAPTION_MAP.get(mQuickActionCategory),
+                        getDefaultAppCaptionId(mQuickActionCategory),
                         defaultActivityResolveInfo.loadLabel(packageManager));
             } else {
                 // The caption for phone numbers does not use the app's name.
                 mCaption = mContext.getResources().getString(
-                        DEFAULT_APP_CAPTION_MAP.get(mQuickActionCategory));
+                        getDefaultAppCaptionId(mQuickActionCategory));
             }
         } else if (mQuickActionCategory == QuickActionCategory.WEBSITE) {
-            // If there is not a default app handler for a URL, open the quick action inside
-            // of Chrome.
+            // If there is not a default app handler for a URL, open the quick action
+            // inside of Chrome.
             mOpenQuickActionInChrome = true;
 
             if (mContext instanceof ChromeTabbedActivity) {
@@ -287,27 +300,25 @@ public class ContextualSearchQuickActionControl extends ViewResourceInflater {
                 iconResId = R.mipmap.app_icon;
             } else {
                 // Otherwise use the link icon.
-                iconResId = ICON_MAP.get(mQuickActionCategory);
+                iconResId = getIconResId(mQuickActionCategory);
 
-                Resources res = mContext.getResources();
                 if (mToolbarBackgroundColor != 0
-                        && !ColorUtils.isUsingDefaultToolbarColor(res,
-                                   FeatureUtilities.isChromeModernDesignEnabled(), false,
-                                   mToolbarBackgroundColor)
+                        && !ThemeUtils.isUsingDefaultToolbarColor(
+                                mContext, false, mToolbarBackgroundColor)
                         && ColorUtils.shouldUseLightForegroundOnBackground(
-                                   mToolbarBackgroundColor)) {
+                                mToolbarBackgroundColor)) {
                     // Tint the link icon to match the custom tab toolbar.
-                    iconDrawable = ApiCompatibilityUtils.getDrawable(res, iconResId);
+                    iconDrawable = mContext.getDrawable(iconResId);
                     iconDrawable.mutate();
                     DrawableCompat.setTint(iconDrawable, mToolbarBackgroundColor);
                 }
             }
-            mCaption = mContext.getResources().getString(
-                    FALLBACK_CAPTION_MAP.get(mQuickActionCategory));
+            mCaption =
+                    mContext.getResources().getString(getFallbackCaptionId(mQuickActionCategory));
         } else {
-            iconResId = ICON_MAP.get(mQuickActionCategory);
-            mCaption = mContext.getResources().getString(
-                    FALLBACK_CAPTION_MAP.get(mQuickActionCategory));
+            iconResId = getIconResId(mQuickActionCategory);
+            mCaption =
+                    mContext.getResources().getString(getFallbackCaptionId(mQuickActionCategory));
         }
 
         inflate();
