@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -8,8 +8,8 @@ import android.content.Context;
 import android.graphics.RectF;
 import android.view.View;
 
-import org.chromium.chrome.browser.compositor.TitleCache;
-import org.chromium.chrome.browser.fullscreen.ChromeFullscreenManager;
+import org.chromium.chrome.browser.fullscreen.BrowserControlsManager;
+import org.chromium.chrome.browser.fullscreen.FullscreenManager;
 
 /**
  * This is the minimal interface of the host view from the layout side.
@@ -27,6 +27,15 @@ public interface LayoutManagerHost {
      */
     void requestRender();
 
+    /**
+     * Requests a refresh of the visuals.
+     * @param onUpdateEffective Callback that will be called when there is a buffer swap for the
+     *                          requested update. The rendered frame for this request won't be
+     *                          visible until a buffer swap occurs. Note that there is no guarantee
+     *                          the updated buffer is the one currently being displayed for pre-Q.
+     */
+    default void requestRender(Runnable onUpdateEffective) {}
+
     /**
      * @return The Android context of the host view.
      */
@@ -62,12 +71,6 @@ public interface LayoutManagerHost {
      */
     void getViewportFullControls(RectF outRect);
 
-    /**
-     * @return The height of the screen minus the height of the top and bottom browser controls
-     *         when not hidden.
-     */
-    float getHeightMinusBrowserControls();
-
     /**
      * @return The height of the top browser controls in pixels.
      */
@@ -86,18 +89,19 @@ public interface LayoutManagerHost {
     /**
      * Sets the visibility of the content overlays.
      * @param show True if the content overlays should be shown.
+     * @param canBeFocusable Whether the host view can make itself focusable e.g. for accessibility.
      */
-    void setContentOverlayVisibility(boolean show);
+    void setContentOverlayVisibility(boolean show, boolean canBeFocusable);
 
     /**
-     * @return The {@link TitleCache} to use to store title bitmaps.
+     * @return The manager providing browser control state.
      */
-    TitleCache getTitleCache();
+    BrowserControlsManager getBrowserControlsManager();
 
     /**
      * @return The manager in charge of handling fullscreen changes.
      */
-    ChromeFullscreenManager getFullscreenManager();
+    FullscreenManager getFullscreenManager();
 
     /**
      * Called when the currently visible content has been changed.
