@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,23 +7,46 @@ package org.chromium.chrome.browser.compositor.layouts.components;
 import android.content.Context;
 import android.content.res.Resources;
 import android.graphics.RectF;
+import android.util.FloatProperty;
 
 import org.chromium.chrome.R;
-import org.chromium.chrome.browser.compositor.layouts.ChromeAnimation;
+import org.chromium.chrome.browser.layouts.components.VirtualView;
 
 /**
  * {@link CompositorButton} keeps track of state for buttons that are rendered
  * in the compositor.
  */
-public class CompositorButton
-        implements ChromeAnimation.Animatable<CompositorButton.Property>, VirtualView {
+public class CompositorButton implements VirtualView {
     /**
-     * Animatable properties that can be used with a {@link ChromeAnimation.Animatable} on a
-     * {@link CompositorButton}.
+     * A property that can be used with a
+     * {@link org.chromium.chrome.browser.compositor.animation.CompositorAnimator}.
      */
-    public enum Property {
-        OPACITY,
-    }
+    public static final FloatProperty<CompositorButton> OPACITY =
+            new FloatProperty<CompositorButton>("opacity") {
+                @Override
+                public void setValue(CompositorButton object, float value) {
+                    object.setOpacity(value);
+                }
+
+                @Override
+                public Float get(CompositorButton object) {
+                    return object.getOpacity();
+                }
+            };
+
+    /** A property for animations to use for changing the drawX of the button. */
+    public static final FloatProperty<CompositorButton> DRAW_X =
+            new FloatProperty<CompositorButton>("drawX") {
+                @Override
+                public void setValue(CompositorButton object, float value) {
+                    object.setX(value);
+                }
+
+                @Override
+                public Float get(CompositorButton object) {
+                    return object.getX();
+                }
+            };
 
     /** Handler for click actions on VirtualViews. */
     public interface CompositorOnClickHandler {
@@ -40,7 +63,9 @@ public class CompositorButton
 
     private final CompositorOnClickHandler mClickHandler;
 
-    private int mResource;
+    protected int mResource;
+    protected int mBackgroundResource;
+
     private int mPressedResource;
     private int mIncognitoResource;
     private int mIncognitoPressedResource;
@@ -78,17 +103,6 @@ public class CompositorButton
         mClickHandler = clickHandler;
     }
 
-    /**
-     * Secondary constructor for {@link CompositorButton}
-     * @param context      An Android context for fetching dimens.
-     * @param bounds       A RectF that bounds the button.
-     * @param clickHandler The action to be performed on click.
-     */
-    public CompositorButton(Context context, RectF bounds, CompositorOnClickHandler clickHandler) {
-        this(context, bounds.width(), bounds.height(), clickHandler);
-        mBounds.set(bounds);
-    }
-
     /**
      * A set of Android resources to supply to the compositor.
      * @param resource                  The default Android resource.
@@ -96,10 +110,10 @@ public class CompositorButton
      * @param incognitoResource         The incognito Android resource.
      * @param incognitoPressedResource  The incognito pressed resource.
      */
-    public void setResources(int resource, int presssedResource, int incognitoResource,
+    public void setResources(int resource, int pressedResource, int incognitoResource,
             int incognitoPressedResource) {
         mResource = resource;
-        mPressedResource = presssedResource;
+        mPressedResource = pressedResource;
         mIncognitoResource = incognitoResource;
         mIncognitoPressedResource = incognitoPressedResource;
     }
@@ -125,7 +139,7 @@ public class CompositorButton
     }
 
     /**
-     * @return The the x offset of the button.
+     * @return The x offset of the button.
      */
     public float getX() {
         return mBounds.left;
@@ -183,7 +197,7 @@ public class CompositorButton
     }
 
     /**
-     * @param bounds A {@link Rect} representing the location of the button.
+     * @param bounds A {@link RectF} representing the location of the button.
      */
     public void setBounds(RectF bounds) {
         mBounds.set(bounds);
@@ -253,7 +267,7 @@ public class CompositorButton
     }
 
     /**
-     * @param state Whether or not the button can be interacted with.
+     * @param enabled Whether or not the button can be interacted with.
      */
     public void setEnabled(boolean enabled) {
         mIsEnabled = enabled;
@@ -346,25 +360,4 @@ public class CompositorButton
         setPressed(false);
         return state;
     }
-
-    /**
-     * Callback for {@link org.chromium.chrome.browser.compositor.layouts.ChromeAnimation
-     * .Animatable}
-     *
-     * @param prop The property to set
-     * @param val The value to set it to
-     */
-    @Override
-    public void setProperty(Property prop, float val) {
-        switch (prop) {
-            case OPACITY:
-                setOpacity(val);
-                break;
-            default:
-                // Do nothing.
-        }
-    }
-
-    @Override
-    public void onPropertyAnimationFinished(Property prop) {}
 }
