@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -10,16 +10,17 @@ import android.graphics.Bitmap;
 import android.graphics.Canvas;
 import android.graphics.Paint;
 import android.graphics.Paint.FontMetrics;
-import android.graphics.drawable.BitmapDrawable;
-import android.graphics.drawable.Drawable;
+import android.graphics.Typeface;
 import android.text.Layout;
 import android.text.TextPaint;
 import android.text.TextUtils;
 import android.util.Log;
 import android.view.InflateException;
 
-import org.chromium.base.ApiCompatibilityUtils;
+import androidx.appcompat.content.res.AppCompatResources;
+
 import org.chromium.chrome.R;
+import org.chromium.ui.UiUtils;
 
 /**
  * A factory that creates text and favicon bitmaps.
@@ -33,7 +34,6 @@ public class TitleBitmapFactory {
     private static final int MAX_NUM_TITLE_CHAR = 1000;
 
     private final int mMaxWidth;
-    private final int mNullFaviconResourceId;
 
     private final TextPaint mTextPaint;
     private int mFaviconDimension;
@@ -44,33 +44,21 @@ public class TitleBitmapFactory {
     /**
      * @param context   The current Android's context.
      * @param incognito Whether the title are for incognito mode.
-     * @param nullFaviconResourceId A drawable resource id of a default favicon.
      */
-    public TitleBitmapFactory(Context context, boolean incognito, int nullFaviconResourceId) {
-        mNullFaviconResourceId = nullFaviconResourceId;
-
+    public TitleBitmapFactory(Context context, boolean incognito) {
         Resources res = context.getResources();
-        int textColor = ApiCompatibilityUtils.getColor(res, incognito
-                ? R.color.compositor_tab_title_bar_text_incognito
-                : R.color.compositor_tab_title_bar_text);
-        int shadowColor = ApiCompatibilityUtils.getColor(res, incognito
-                ? R.color.compositor_tab_title_bar_shadow_incognito
-                : R.color.compositor_tab_title_bar_shadow);
-        int shadowXOffset = res.getDimensionPixelOffset(incognito
-                ? R.dimen.compositor_tab_title_bar_shadow_x_offset_incognito
-                : R.dimen.compositor_tab_title_bar_shadow_x_offset);
-        int shadowYOffset = res.getDimensionPixelOffset(incognito
-                ? R.dimen.compositor_tab_title_bar_shadow_y_offset_incognito
-                : R.dimen.compositor_tab_title_bar_shadow_y_offset);
+        int textColor = AppCompatResources
+                                .getColorStateList(context,
+                                        incognito ? R.color.compositor_tab_title_bar_text_incognito
+                                                  : R.color.compositor_tab_title_bar_text)
+                                .getDefaultColor();
         float textSize = res.getDimension(R.dimen.compositor_tab_title_text_size);
 
         boolean fakeBoldText = res.getBoolean(R.bool.compositor_tab_title_fake_bold_text);
 
         mTextPaint = new TextPaint(Paint.ANTI_ALIAS_FLAG);
         mTextPaint.setColor(textColor);
-        if (shadowXOffset != 0 && shadowYOffset != 0) {
-            mTextPaint.setShadowLayer(0.001f, shadowXOffset, shadowYOffset, shadowColor);
-        }
+
         mTextPaint.setTextSize(textSize);
         mTextPaint.setFakeBoldText(fakeBoldText);
         mTextPaint.density = res.getDisplayMetrics().density;
@@ -93,29 +81,27 @@ public class TitleBitmapFactory {
     /**
      * Generates the favicon bitmap.
      *
-     * @param context   Android's UI context.
      * @param favicon   The favicon of the tab.
      * @return          The Bitmap with the favicon.
      */
-    public Bitmap getFaviconBitmap(Context context, Bitmap favicon) {
+    public Bitmap getFaviconBitmap(Bitmap favicon) {
+        assert favicon != null;
         try {
             Bitmap b = Bitmap.createBitmap(
                     mFaviconDimension, mFaviconDimension, Bitmap.Config.ARGB_8888);
             Canvas c = new Canvas(b);
-            if (favicon == null) {
-                Drawable drawable = ApiCompatibilityUtils.getDrawable(
-                        context.getResources(), mNullFaviconResourceId);
-                if (drawable instanceof BitmapDrawable) {
-                    favicon = ((BitmapDrawable) drawable).getBitmap();
-                }
-            }
-            if (favicon != null) {
-                c.drawBitmap(favicon, Math.round((mFaviconDimension - favicon.getWidth()) / 2.0f),
-                        Math.round((mFaviconDimension - favicon.getHeight()) / 2.0f), null);
+            if (favicon.getWidth() > mFaviconDimension || favicon.getHeight() > mFaviconDimension) {
+                float scale = (float) mFaviconDimension
+                        / Math.max(favicon.getWidth(), favicon.getHeight());
+                c.scale(scale, scale);
+            } else {
+                c.translate(Math.round((mFaviconDimension - favicon.getWidth()) / 2.0f),
+                        Math.round((mFaviconDimension - favicon.getHeight()) / 2.0f));
             }
+            c.drawBitmap(favicon, 0, 0, null);
             return b;
         } catch (OutOfMemoryError ex) {
-            Log.w(TAG, "OutOfMemoryError while building favicon texture.");
+            Log.e(TAG, "OutOfMemoryError while building favicon texture.");
         } catch (InflateException ex) {
             Log.w(TAG, "InflateException while building favicon texture.");
         }
@@ -128,13 +114,22 @@ public class TitleBitmapFactory {
      *
      * @param context   Android's UI context.
      * @param title     The title of the tab.
+     * @param useRobotoMediumStyle    Whether the tab title text style should be TextMediumThick /
+     *         RobotoMedium.
      * @return          The Bitmap with the title.
      */
-    public Bitmap getTitleBitmap(Context context, String title) {
+    public Bitmap getTitleBitmap(Context context, String title, boolean useRobotoMediumStyle) {
         try {
             boolean drawText = !TextUtils.isEmpty(title);
             int textWidth =
                     drawText ? (int) Math.ceil(Layout.getDesiredWidth(title, mTextPaint)) : 0;
+
+            // Use TextMediumThick / RobotoMediumStyle for tab title text style.
+            if (useRobotoMediumStyle) {
+                Typeface RobotoMediumStyle = UiUtils.createRobotoMediumTypeface();
+                mTextPaint.setTypeface(RobotoMediumStyle);
+            }
+
             // Minimum 1 width bitmap to avoid createBitmap function's IllegalArgumentException,
             // when textWidth == 0.
             Bitmap b = Bitmap.createBitmap(Math.max(Math.min(mMaxWidth, textWidth), 1), mViewHeight,
@@ -144,9 +139,13 @@ public class TitleBitmapFactory {
                 c.drawText(title, 0, Math.min(MAX_NUM_TITLE_CHAR, title.length()), 0,
                         Math.round((mViewHeight - mTextHeight) / 2.0f + mTextYOffset), mTextPaint);
             }
+
+            // Set bolded tab title text back to normal.
+            mTextPaint.setTypeface(Typeface.create(Typeface.DEFAULT, Typeface.NORMAL));
+
             return b;
         } catch (OutOfMemoryError ex) {
-            Log.w(TAG, "OutOfMemoryError while building title texture.");
+            Log.e(TAG, "OutOfMemoryError while building title texture.");
         } catch (InflateException ex) {
             Log.w(TAG, "InflateException while building title texture.");
         }
