@@ -1,4 +1,4 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,11 +6,13 @@ package org.chromium.chrome.browser.contextualsearch;
 
 import android.text.TextUtils;
 
-import org.chromium.base.VisibleForTesting;
-import org.chromium.base.annotations.CalledByNative;
-import org.chromium.content_public.browser.WebContents;
+import androidx.annotation.NonNull;
+import androidx.annotation.Nullable;
+import androidx.annotation.VisibleForTesting;
 
-import javax.annotation.Nullable;
+import org.chromium.base.annotations.CalledByNative;
+import org.chromium.base.annotations.NativeClassQualifiedName;
+import org.chromium.base.annotations.NativeMethods;
 
 /**
  * Provides a context in which to search, and links to the native ContextualSearchContext.
@@ -38,9 +40,6 @@ public abstract class ContextualSearchContext {
     private int mSelectionStartOffset = INVALID_OFFSET;
     private int mSelectionEndOffset = INVALID_OFFSET;
 
-    // The home country, or an empty string if not set.
-    private String mHomeCountry = "";
-
     // The detected language of the context, or {@code null} if not yet detected, and empty if
     // it cannot be reliably determined.
     private String mDetectedLanguage;
@@ -48,8 +47,8 @@ public abstract class ContextualSearchContext {
     // The offset of an initial Tap gesture within the text content.
     private int mTapOffset = INVALID_OFFSET;
 
-    // The initial word selected by a Tap, or null.
-    private String mInitialSelectedWord;
+    // The selection being resolved, or null if no resolve has started.
+    private String mSelectionBeingResolved;
 
     // The original encoding of the base page.
     private String mEncoding;
@@ -65,17 +64,20 @@ public abstract class ContextualSearchContext {
     // The offset of the tap within the tapped word, or {@code INVALID_OFFSET} if not yet analyzed.
     private int mTapWithinWordOffset = INVALID_OFFSET;
 
-    // The words before and after the tapped word, and their offsets.
-    private String mWordPreviousToTap;
-    private int mWordPreviousToTapOffset = INVALID_OFFSET;
-    private String mWordFollowingTap;
-    private int mWordFollowingTapOffset = INVALID_OFFSET;
+    // Translation members.
+    @NonNull
+    private String mTargetLanguage = "";
+    @NonNull
+    private String mFluentLanguages = "";
+
+    // The Related Searches stamp - non-empty when Related Searches are being requested.
+    private String mRelatedSearchesStamp;
 
     /**
      * Constructs a context that tracks the selection and some amount of page content.
      */
     ContextualSearchContext() {
-        mNativePointer = nativeInit();
+        mNativePointer = ContextualSearchContextJni.get().init(this);
         mHasSetResolveProperties = false;
     }
 
@@ -84,27 +86,47 @@ public abstract class ContextualSearchContext {
      * page content.
      * @param homeCountry The country where the user usually resides, or an empty string if not
      *        known.
-     * @param maySendBasePageUrl Whether policy allows sending the base-page URL to the server.
+     * @param doSendBasePageUrl Whether the base-page URL should be sent to the server.
+     * @param targetLanguage The language to translate into, in case translation might be needed.
+     * @param fluentLanguages An ordered comma-separated list of ISO 639 language codes that
+     *        the user can read fluently, or an empty string.
      */
-    void setResolveProperties(String homeCountry, boolean maySendBasePageUrl) {
+    void setResolveProperties(@NonNull String homeCountry, boolean doSendBasePageUrl,
+            @NonNull String targetLanguage, @NonNull String fluentLanguages) {
+        // TODO(donnd): consider making this a constructor variation.
         mHasSetResolveProperties = true;
-        mHomeCountry = homeCountry;
-        nativeSetResolveProperties(getNativePointer(), homeCountry, maySendBasePageUrl);
+        ContextualSearchContextJni.get().setResolveProperties(
+                getNativePointer(), this, homeCountry, doSendBasePageUrl);
+        mTargetLanguage = targetLanguage;
+        mFluentLanguages = fluentLanguages;
     }
 
     /**
      * This method should be called to clean up storage when an instance of this class is
-     * no longer in use.  The nativeDestroy will call the destructor on the native instance.
+     * no longer in use.  The ContextualSearchContextJni.get().destroy will call the destructor on
+     * the native instance.
      */
     void destroy() {
         assert mNativePointer != 0;
-        nativeDestroy(mNativePointer);
+        ContextualSearchContextJni.get().destroy(mNativePointer, this);
         mNativePointer = 0;
 
         // Also zero out private data that may be sizable.
         mSurroundingText = null;
     }
 
+    /**
+     * Sets the surrounding text and selection offsets assuming UTF-8 and no insertion-point
+     * support.
+     * @param surroundingText The text from the base page surrounding the selection.
+     * @param startOffset The offset of start the selection.
+     * @param endOffset The offset of the end of the selection
+     */
+    @VisibleForTesting
+    void setSurroundingText(String surroundingText, int startOffset, int endOffset) {
+        setSurroundingText("UTF-8", surroundingText, startOffset, endOffset);
+    }
+
     /**
      * Sets the surrounding text and selection offsets.
      * @param encoding The original encoding of the base page.
@@ -112,6 +134,7 @@ public abstract class ContextualSearchContext {
      * @param startOffset The offset of start the selection.
      * @param endOffset The offset of the end of the selection
      */
+    @VisibleForTesting
     void setSurroundingText(
             String encoding, String surroundingText, int startOffset, int endOffset) {
         assert startOffset <= endOffset;
@@ -123,17 +146,12 @@ public abstract class ContextualSearchContext {
                 && !hasAnalyzedTap()) {
             analyzeTap(startOffset);
         }
-        // Notify of an initial selection if it's not empty.
-        if (endOffset > startOffset) onSelectionChanged();
-    }
-
-    /**
-     * Sets the surrounding text to just identify the current selection.
-     * @param selection The current selection on the base page.
-     */
-    void setSurroundingText(WebContents basePageWebContents, String selection) {
-        String encoding = basePageWebContents != null ? basePageWebContents.getEncoding() : null;
-        setSurroundingText(encoding, selection, 0, selection.length());
+        // Notify of a changed selection if it's not empty.
+        if (endOffset > startOffset) {
+            onSelectionChanged();
+        }
+        // Detect the language of the surroundings or the selection.
+        setTranslationLanguages(getDetectedLanguage(), mTargetLanguage, mFluentLanguages);
     }
 
     /**
@@ -168,17 +186,12 @@ public abstract class ContextualSearchContext {
     }
 
     /**
-     * @return The home country, or an empty string if none set.
+     * @return The selection being resolved, or {@code null} if no resolve has been
+     * requested.
      */
-    String getHomeCountry() {
-        return mHomeCountry;
-    }
-
-    /**
-     * @return The initial word selected by a Tap.
-     */
-    String getInitialSelectedWord() {
-        return mInitialSelectedWord;
+    @Nullable
+    String getSelectionBeingResolved() {
+        return mSelectionBeingResolved;
     }
 
     /**
@@ -200,6 +213,23 @@ public abstract class ContextualSearchContext {
         return mHasSetResolveProperties && hasValidSelection();
     }
 
+    /**
+     * Prepares the Context to be used in a Resolve request by supplying last minute parameters.
+     * If this call is not made before a Resolve then defaults are used (not exact and not a
+     * Related Search).
+     * @param isExactSearch Specifies whether this search must be exact -- meaning the resolve must
+     *        return a non-expanding result that matches the selection exactly.
+     * @param relatedSearchesStamp Information to be attached to the Resolve request that is needed
+     *        for Related Searches. If this string is empty then no Related Searches results will
+     *        be requested.
+     */
+    void prepareToResolve(boolean isExactSearch, String relatedSearchesStamp) {
+        mSelectionBeingResolved = getCurrentSelection();
+        mRelatedSearchesStamp = relatedSearchesStamp;
+        ContextualSearchContextJni.get().prepareToResolve(
+                mNativePointer, this, isExactSearch, relatedSearchesStamp);
+    }
+
     /**
      * Notifies of an adjustment that has been applied to the start and end of the selection.
      * @param startAdjust A signed value indicating the direction of the adjustment to the start of
@@ -211,22 +241,30 @@ public abstract class ContextualSearchContext {
         // Fully track the selection as it changes.
         mSelectionStartOffset += startAdjust;
         mSelectionEndOffset += endAdjust;
-        if (TextUtils.isEmpty(mInitialSelectedWord) && !TextUtils.isEmpty(mSurroundingText)) {
-            // TODO(donnd): investigate the root cause of crbug.com/725027 that requires this
-            // additional validation to prevent this substring call from crashing!
-            if (mSelectionEndOffset < mSelectionStartOffset || mSelectionStartOffset < 0
-                    || mSelectionEndOffset > mSurroundingText.length()) {
-                return;
-            }
-
-            mInitialSelectedWord =
-                    mSurroundingText.substring(mSelectionStartOffset, mSelectionEndOffset);
-        }
-        nativeAdjustSelection(getNativePointer(), startAdjust, endAdjust);
+        ContextualSearchContextJni.get().adjustSelection(
+                getNativePointer(), this, startAdjust, endAdjust);
         // Notify of changes.
         onSelectionChanged();
     }
 
+    /** Returns the current selection, or an empty string if there is no valid selection. */
+    private String getCurrentSelection() {
+        if (TextUtils.isEmpty(mSurroundingText) || mSelectionEndOffset < mSelectionStartOffset
+                || mSelectionStartOffset < 0 || mSelectionEndOffset > mSurroundingText.length()) {
+            return "";
+        }
+        return mSurroundingText.substring(mSelectionStartOffset, mSelectionEndOffset);
+    }
+
+    /** @return the current selection, or an empty string if data is invalid or nothing selected. */
+    String getSelection() {
+        if (TextUtils.isEmpty(mSurroundingText) || mSelectionEndOffset < mSelectionStartOffset
+                || mSelectionStartOffset < 0 || mSelectionEndOffset > mSurroundingText.length()) {
+            return "";
+        }
+        return mSurroundingText.substring(mSelectionStartOffset, mSelectionEndOffset);
+    }
+
     /**
      * Notifies this instance that the selection has been changed.
      */
@@ -238,14 +276,35 @@ public abstract class ContextualSearchContext {
      * @return An ISO 639 language code string, or an empty string if the language cannot be
      *         reliably determined.
      */
+    @NonNull
     String getDetectedLanguage() {
         assert mSurroundingText != null;
         if (mDetectedLanguage == null) {
-            mDetectedLanguage = nativeDetectLanguage(mNativePointer);
+            mDetectedLanguage =
+                    ContextualSearchContextJni.get().detectLanguage(mNativePointer, this);
         }
         return mDetectedLanguage;
     }
 
+    /**
+     * Pushes the given languages down to the native ContextualSearchContext.
+     * @param detectedLanguage An ISO 639 language code string for the language to translate from.
+     * @param targetLanguage An ISO 639 language code string to translation into.
+     * @param fluentLanguages An ordered comma-separated list of ISO 639 language codes that
+     *        the user can read fluently, or an empty string.
+     */
+    @VisibleForTesting
+    void setTranslationLanguages(@NonNull String detectedLanguage, @NonNull String targetLanguage,
+            @NonNull String fluentLanguages) {
+        // Set redundant languages to empty strings.
+        fluentLanguages = targetLanguage.equals(fluentLanguages) ? "" : fluentLanguages;
+        // The target language is essential in order to provide results the user can read, and if
+        // not specified the server may fallback onto a guess based on location, which isn't
+        // always a good experience.
+        ContextualSearchContextJni.get().setTranslationLanguages(
+                mNativePointer, this, detectedLanguage, targetLanguage, fluentLanguages);
+    }
+
     // ============================================================================================
     // Content Analysis.
     // ============================================================================================
@@ -260,7 +319,7 @@ public abstract class ContextualSearchContext {
     }
 
     /**
-     * @return Whether this context has a valid selection.
+     * @return Whether this context has a valid selection, which may be an insertion point.
      */
     @VisibleForTesting
     boolean hasValidSelection() {
@@ -287,15 +346,6 @@ public abstract class ContextualSearchContext {
         return mWordTapped;
     }
 
-    /**
-     * @return The offset of the start of the tapped word, or {@code INVALID_OFFSET} if the tapped
-     *         word cannot be identified by the current parsing capability.
-     * @see #analyzeTap(int)
-     */
-    int getWordTappedOffset() {
-        return mWordTappedStartOffset;
-    }
-
     /**
      * @return The offset of the tap within the tapped word, or {@code INVALID_OFFSET} if the tapped
      *         word cannot be identified by the current parsing capability.
@@ -305,36 +355,6 @@ public abstract class ContextualSearchContext {
         return mTapWithinWordOffset;
     }
 
-    /**
-     * @return The word previous to the word that was tapped, or {@code null} if not available.
-     */
-    String getWordPreviousToTap() {
-        return mWordPreviousToTap;
-    }
-
-    /**
-     * @return The offset of the first character of the word previous to the word that was tapped,
-     *         or {@code INVALID_OFFSET} if not available.
-     */
-    int getWordPreviousToTapOffset() {
-        return mWordPreviousToTapOffset;
-    }
-
-    /**
-     * @return The word following the word that was tapped, or {@code null} if not available.
-     */
-    String getWordFollowingTap() {
-        return mWordFollowingTap;
-    }
-
-    /**
-     * @return The offset of the first character of the word following the word that was tapped,
-     *         or {@code INVALID_OFFSET} if not available.
-     */
-    int getWordFollowingTapOffset() {
-        return mWordFollowingTapOffset;
-    }
-
     /**
      * Finds the words around the initial Tap offset by expanding and looking for word-breaks.
      * This mimics the Blink word-segmentation invoked by SelectWordAroundCaret and similar
@@ -353,50 +373,8 @@ public abstract class ContextualSearchContext {
         int wordEndOffset = findWordEndOffset(mTapOffset);
         if (wordStartOffset == INVALID_OFFSET || wordEndOffset == INVALID_OFFSET) return;
 
-        mWordTappedStartOffset = wordStartOffset;
         mWordTapped = mSurroundingText.substring(wordStartOffset, wordEndOffset);
         mTapWithinWordOffset = mTapOffset - wordStartOffset;
-
-        findPreviousWord();
-        findFollowingWord();
-    }
-
-    /**
-     * Finds the word previous to the word tapped.
-     */
-    void findPreviousWord() {
-        // Scan past word-break characters preceding the tapped word.
-        int previousWordEndOffset = mWordTappedStartOffset;
-        while (previousWordEndOffset >= 1 && isWordBreakAtIndex(previousWordEndOffset - 1)) {
-            --previousWordEndOffset;
-        }
-        if (previousWordEndOffset == 0) return;
-
-        mWordPreviousToTapOffset = findWordStartOffset(previousWordEndOffset);
-        if (mWordPreviousToTapOffset == INVALID_OFFSET) return;
-
-        mWordPreviousToTap =
-                mSurroundingText.substring(mWordPreviousToTapOffset, previousWordEndOffset);
-    }
-
-    /**
-     * Finds the word following the word tapped.
-     */
-    void findFollowingWord() {
-        int tappedWordOffset = getWordTappedOffset();
-        int followingWordStartOffset = tappedWordOffset + mWordTapped.length() + 1;
-        while (followingWordStartOffset < mSurroundingText.length()
-                && isWordBreakAtIndex(followingWordStartOffset)) {
-            ++followingWordStartOffset;
-        }
-        if (followingWordStartOffset == mSurroundingText.length()) return;
-
-        int wordFollowingTapEndOffset = findWordEndOffset(followingWordStartOffset);
-        if (wordFollowingTapEndOffset == INVALID_OFFSET) return;
-
-        mWordFollowingTapOffset = followingWordStartOffset;
-        mWordFollowingTap =
-                mSurroundingText.substring(mWordFollowingTapOffset, wordFollowingTapEndOffset);
     }
 
     /**
@@ -444,6 +422,15 @@ public abstract class ContextualSearchContext {
                 && mSurroundingText.charAt(index) != SOFT_HYPHEN_CHAR;
     }
 
+    // ============================================================================================
+    // Test support.
+    // ============================================================================================
+
+    @VisibleForTesting
+    String getRelatedSearchesStamp() {
+        return mRelatedSearchesStamp;
+    }
+
     // ============================================================================================
     // Native callback support.
     // ============================================================================================
@@ -454,19 +441,26 @@ public abstract class ContextualSearchContext {
         return mNativePointer;
     }
 
-    // ============================================================================================
-    // Native methods.
-    // ============================================================================================
-    @VisibleForTesting
-    protected native long nativeInit();
-    @VisibleForTesting
-    protected native void nativeDestroy(long nativeContextualSearchContext);
-    @VisibleForTesting
-    protected native void nativeSetResolveProperties(
-            long nativeContextualSearchContext, String homeCountry, boolean maySendBasePageUrl);
-    @VisibleForTesting
-    protected native void nativeAdjustSelection(
-            long nativeContextualSearchContext, int startAdjust, int endAdjust);
-    @VisibleForTesting
-    protected native String nativeDetectLanguage(long nativeContextualSearchContext);
+    @NativeMethods
+    interface Natives {
+        @NativeClassQualifiedName("NativeContextualSearchContext")
+        long init(ContextualSearchContext caller);
+        @NativeClassQualifiedName("NativeContextualSearchContext")
+        void destroy(long nativeContextualSearchContext, ContextualSearchContext caller);
+        @NativeClassQualifiedName("NativeContextualSearchContext")
+        void setResolveProperties(long nativeContextualSearchContext,
+                ContextualSearchContext caller, String homeCountry, boolean doSendBasePageUrl);
+        @NativeClassQualifiedName("NativeContextualSearchContext")
+        void adjustSelection(long nativeContextualSearchContext, ContextualSearchContext caller,
+                int startAdjust, int endAdjust);
+        @NativeClassQualifiedName("NativeContextualSearchContext")
+        String detectLanguage(long nativeContextualSearchContext, ContextualSearchContext caller);
+        @NativeClassQualifiedName("NativeContextualSearchContext")
+        void setTranslationLanguages(long nativeContextualSearchContext,
+                ContextualSearchContext caller, String detectedLanguage, String targetLanguage,
+                String fluentLanguages);
+        @NativeClassQualifiedName("NativeContextualSearchContext")
+        void prepareToResolve(long nativeContextualSearchContext, ContextualSearchContext caller,
+                boolean isExactSearch, String relatedSearchesStamp);
+    }
 }
