@@ -1,15 +1,15 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.contextualsearch;
 
-import android.support.annotation.Nullable;
+import androidx.annotation.Nullable;
 
 /**
- * Implements the policy that a Tap relatively far away from an existing Contextual Search
- * selection should just dismiss our UX.  When a Tap is close by, we assume the user must have
- * missed the original intended target so we reselect based on the new Tap location.
+ * Implements a {@link ContextualSearchHeuristic} that a Tap relatively far away from an existing
+ * Contextual Search selection should just dismiss our UX.  When a Tap is close by, we assume the
+ * user must have missed the original intended target so we reselect based on the new Tap location.
  */
 class TapFarFromPreviousSuppression extends ContextualSearchHeuristic {
     private static final double RETAP_DISTANCE_SQUARED_DP = Math.pow(75, 2);
