@@ -1,16 +1,16 @@
-// Copyright 2014 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.dom_distiller;
 
-import org.chromium.base.JNINamespace;
 import org.chromium.base.ThreadUtils;
+import org.chromium.base.annotations.JNINamespace;
+import org.chromium.base.annotations.NativeMethods;
 import org.chromium.chrome.browser.profiles.Profile;
+import org.chromium.chrome.browser.profiles.ProfileKeyedMap;
 import org.chromium.components.dom_distiller.core.DomDistillerService;
 
-import java.util.HashMap;
-
 /**
  * DomDistillerServiceFactory maps Profiles to instances of
  * {@link DomDistillerService} instances. Each {@link Profile} will at most
@@ -19,22 +19,20 @@ import java.util.HashMap;
  */
 @JNINamespace("dom_distiller::android")
 public class DomDistillerServiceFactory {
-
-    private static final HashMap<Profile, DomDistillerService> sServiceMap =
-            new HashMap<Profile, DomDistillerService>();
+    private static final ProfileKeyedMap<DomDistillerService> sServiceMap =
+            new ProfileKeyedMap<>(ProfileKeyedMap.NO_REQUIRED_CLEANUP_ACTION);
 
     /**
      * Returns Java DomDistillerService for given Profile.
      */
     public static DomDistillerService getForProfile(Profile profile) {
         ThreadUtils.assertOnUiThread();
-        DomDistillerService service = sServiceMap.get(profile);
-        if (service == null) {
-            service = (DomDistillerService) nativeGetForProfile(profile);
-            sServiceMap.put(profile, service);
-        }
-        return service;
+        return sServiceMap.getForProfile(
+                profile, () -> DomDistillerServiceFactoryJni.get().getForProfile(profile));
     }
 
-    private static native DomDistillerService nativeGetForProfile(Profile profile);
+    @NativeMethods
+    interface Natives {
+        DomDistillerService getForProfile(Profile profile);
+    }
 }
