@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,28 +6,26 @@ package org.chromium.chrome.browser.download;
 
 import android.Manifest.permission;
 import android.app.DownloadManager;
-import android.content.Context;
 import android.content.pm.PackageManager;
-import android.net.Uri;
-import android.os.AsyncTask;
 import android.os.Environment;
 import android.text.TextUtils;
 import android.util.Pair;
-import android.webkit.MimeTypeMap;
 import android.webkit.URLUtil;
 
+import androidx.annotation.VisibleForTesting;
+
 import org.chromium.base.Log;
 import org.chromium.base.ThreadUtils;
-import org.chromium.base.annotations.CalledByNative;
-import org.chromium.chrome.browser.UrlConstants;
-import org.chromium.chrome.browser.tab.EmptyTabObserver;
+import org.chromium.base.UserData;
+import org.chromium.base.UserDataHost;
+import org.chromium.base.task.AsyncTask;
 import org.chromium.chrome.browser.tab.Tab;
-import org.chromium.ui.base.PermissionCallback;
+import org.chromium.components.embedder_support.util.UrlUtilities;
 import org.chromium.ui.base.WindowAndroid;
+import org.chromium.ui.permissions.PermissionCallback;
+import org.chromium.url.GURL;
 
 import java.io.File;
-import java.util.Arrays;
-import java.util.HashSet;
 
 /**
  * Chrome implementation of the ContentViewDownloadDelegate interface.
@@ -38,33 +36,31 @@ import java.util.HashSet;
  *
  * Prompts the user when a dangerous file is downloaded. Auto-opens PDFs after downloading.
  */
-public class ChromeDownloadDelegate {
+public class ChromeDownloadDelegate implements UserData {
     private static final String TAG = "Download";
 
-    // Mime types that Android can't handle when tries to open the file. Chrome may deduct a better
-    // mime type based on file extension.
-    private static final HashSet<String> GENERIC_MIME_TYPES = new HashSet<String>(Arrays.asList(
-            "text/plain", "application/octet-stream", "binary/octet-stream", "octet/stream",
-            "application/download", "application/force-download", "application/unknown"));
-
-    // The application context.
-    private final Context mContext;
+    private static final Class<ChromeDownloadDelegate> USER_DATA_KEY = ChromeDownloadDelegate.class;
     private Tab mTab;
 
+    public static ChromeDownloadDelegate from(Tab tab) {
+        UserDataHost host = tab.getUserDataHost();
+        ChromeDownloadDelegate controller = host.getUserData(USER_DATA_KEY);
+        return controller == null ? host.setUserData(USER_DATA_KEY, new ChromeDownloadDelegate(tab))
+                                  : controller;
+    }
+
     /**
      * Creates ChromeDownloadDelegate.
-     * @param context The application context.
      * @param tab The corresponding tab instance.
      */
-    public ChromeDownloadDelegate(Context context, Tab tab) {
-        mContext = context;
+    @VisibleForTesting
+    ChromeDownloadDelegate(Tab tab) {
         mTab = tab;
-        mTab.addObserver(new EmptyTabObserver() {
-            @Override
-            public void onDestroyed(Tab tab) {
-                mTab = null;
-            }
-        });
+    }
+
+    @Override
+    public void destroy() {
+        mTab = null;
     }
 
     /**
@@ -76,11 +72,11 @@ public class ChromeDownloadDelegate {
     protected void onDownloadStartNoStream(final DownloadInfo downloadInfo) {
         final String fileName = downloadInfo.getFileName();
         assert !TextUtils.isEmpty(fileName);
-        final String newMimeType =
-                remapGenericMimeType(downloadInfo.getMimeType(), downloadInfo.getUrl(), fileName);
-        new AsyncTask<Void, Void, Pair<String, File>>() {
+        final String newMimeType = MimeUtils.remapGenericMimeType(
+                downloadInfo.getMimeType(), downloadInfo.getUrl().getSpec(), fileName);
+        new AsyncTask<Pair<String, File>>() {
             @Override
-            protected Pair<String, File> doInBackground(Void... params) {
+            protected Pair<String, File> doInBackground() {
                 // Check to see if we have an SDCard.
                 String status = Environment.getExternalStorageState();
                 File fullDirPath = getDownloadDirectoryFullPath();
@@ -92,22 +88,23 @@ public class ChromeDownloadDelegate {
                 String externalStorageState = result.first;
                 File fullDirPath = result.second;
                 if (!checkExternalStorageAndNotify(
-                        fileName, fullDirPath, externalStorageState)) {
+                            downloadInfo, fullDirPath, externalStorageState)) {
                     return;
                 }
-                String url = sanitizeDownloadUrl(downloadInfo);
+                GURL url = sanitizeDownloadUrl(downloadInfo);
                 if (url == null) return;
                 DownloadInfo newInfo = DownloadInfo.Builder.fromDownloadInfo(downloadInfo)
                                                .setUrl(url)
                                                .setMimeType(newMimeType)
-                                               .setDescription(url)
+                                               .setDescription(url.getSpec())
                                                .setFileName(fileName)
                                                .setIsGETRequest(true)
                                                .build();
                 DownloadController.enqueueDownloadManagerRequest(newInfo);
-                DownloadController.closeTabIfBlank(mTab);
+                // TODO(shaktisahu): Verify if we still need to close an empty tab for OMA download.
             }
-        }.execute();
+        }
+                .executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR);
     }
 
     /**
@@ -115,7 +112,7 @@ public class ChromeDownloadDelegate {
      *
      * @param downloadInfo Information about the download.
      */
-    protected String sanitizeDownloadUrl(DownloadInfo downloadInfo) {
+    protected GURL sanitizeDownloadUrl(DownloadInfo downloadInfo) {
         return downloadInfo.getUrl();
     }
 
@@ -147,38 +144,6 @@ public class ChromeDownloadDelegate {
         }
     }
 
-    /**
-     * Enqueue download manager request, only from native side. Note that at this point
-     * we don't need to show an infobar even when the file already exists.
-     *
-     * @param overwrite Whether or not we will overwrite the file.
-     * @param downloadInfo The download info.
-     * @return true iff this request resulted in the tab creating the download to close.
-     */
-    @CalledByNative
-    private boolean enqueueDownloadManagerRequestFromNative(
-            final boolean overwrite, final DownloadInfo downloadInfo) {
-        if (overwrite) {
-            // Android DownloadManager does not have an overwriting option.
-            // We remove the file here instead.
-            new AsyncTask<Void, Void, Void>() {
-                @Override
-                public Void doInBackground(Void... params) {
-                    deleteFileForOverwrite(downloadInfo);
-                    return null;
-                }
-
-                @Override
-                public void onPostExecute(Void args) {
-                    DownloadController.enqueueDownloadManagerRequest(downloadInfo);
-                }
-            }.execute();
-        } else {
-            DownloadController.enqueueDownloadManagerRequest(downloadInfo);
-        }
-        return DownloadController.closeTabIfBlank(mTab);
-    }
-
     /**
      * Check the external storage and notify user on error.
      *
@@ -187,11 +152,10 @@ public class ChromeDownloadDelegate {
      * @return Whether external storage is ok for downloading.
      */
     private boolean checkExternalStorageAndNotify(
-            String filename, File fullDirPath, String externalStorageStatus) {
+            DownloadInfo downloadInfo, File fullDirPath, String externalStorageStatus) {
         if (fullDirPath == null) {
             Log.e(TAG, "Download failed: no SD card");
-            alertDownloadFailure(
-                    filename, DownloadManager.ERROR_DEVICE_NOT_FOUND);
+            alertDownloadFailure(downloadInfo, DownloadManager.ERROR_DEVICE_NOT_FOUND);
             return false;
         }
         if (!externalStorageStatus.equals(Environment.MEDIA_MOUNTED)) {
@@ -203,7 +167,7 @@ public class ChromeDownloadDelegate {
             } else {
                 Log.e(TAG, "Download failed: no SD card");
             }
-            alertDownloadFailure(filename, reason);
+            alertDownloadFailure(downloadInfo, reason);
             return false;
         }
         return true;
@@ -212,58 +176,12 @@ public class ChromeDownloadDelegate {
     /**
      * Alerts user of download failure.
      *
-     * @param fileName Name of the download file.
+     * @param downloadInfo The associated download.
      * @param reason Reason of failure defined in {@link DownloadManager}
      */
-    private void alertDownloadFailure(String fileName, int reason) {
-        DownloadManagerService.getDownloadManagerService().onDownloadFailed(fileName, reason);
-    }
-
-    /**
-     * If the given MIME type is null, or one of the "generic" types (text/plain
-     * or application/octet-stream) map it to a type that Android can deal with.
-     * If the given type is not generic, return it unchanged.
-     *
-     * We have to implement this ourselves as
-     * MimeTypeMap.remapGenericMimeType() is not public.
-     * See http://crbug.com/407829.
-     *
-     * @param mimeType MIME type provided by the server.
-     * @param url URL of the data being loaded.
-     * @param filename file name obtained from content disposition header
-     * @return The MIME type that should be used for this data.
-     */
-    static String remapGenericMimeType(String mimeType, String url, String filename) {
-        // If we have one of "generic" MIME types, try to deduce
-        // the right MIME type from the file extension (if any):
-        if (mimeType == null || mimeType.isEmpty() || GENERIC_MIME_TYPES.contains(mimeType)) {
-            String extension = getFileExtension(url, filename);
-            String newMimeType = MimeTypeMap.getSingleton().getMimeTypeFromExtension(extension);
-            if (newMimeType != null) {
-                mimeType = newMimeType;
-            } else if (extension.equals("dm")) {
-                mimeType = OMADownloadHandler.OMA_DRM_MESSAGE_MIME;
-            } else if (extension.equals("dd")) {
-                mimeType = OMADownloadHandler.OMA_DOWNLOAD_DESCRIPTOR_MIME;
-            }
-        }
-        return mimeType;
-    }
-
-    /**
-     * Retrieve the file extension from a given file name or url.
-     *
-     * @param url URL to extract the extension.
-     * @param filename File name to extract the extension.
-     * @return If extension can be extracted from file name, use that. Or otherwise, use the
-     *         extension extracted from the url.
-     */
-    static String getFileExtension(String url, String filename) {
-        if (!TextUtils.isEmpty(filename)) {
-            int index = filename.lastIndexOf(".");
-            if (index > 0) return filename.substring(index + 1);
-        }
-        return MimeTypeMap.getFileExtensionFromUrl(url);
+    private void alertDownloadFailure(DownloadInfo downloadInfo, int reason) {
+        DownloadItem downloadItem = new DownloadItem(false, downloadInfo);
+        DownloadManagerService.getDownloadManagerService().onDownloadFailed(downloadItem, reason);
     }
 
     /**
@@ -273,17 +191,13 @@ public class ChromeDownloadDelegate {
      * @param url URL to be downloaded.
      * @return whether the DownloadManager should intercept the download.
      */
-    public boolean shouldInterceptContextMenuDownload(String url) {
-        Uri uri = Uri.parse(url);
-        String scheme = uri.normalizeScheme().getScheme();
-        if (!UrlConstants.HTTP_SCHEME.equals(scheme) && !UrlConstants.HTTPS_SCHEME.equals(scheme)) {
-            return false;
-        }
-        String path = uri.getPath();
+    public boolean shouldInterceptContextMenuDownload(GURL url) {
+        if (!UrlUtilities.isHttpOrHttps(url)) return false;
+        String path = url.getPath();
         if (!OMADownloadHandler.isOMAFile(path)) return false;
         if (mTab == null) return true;
-        String fileName = URLUtil.guessFileName(
-                url, null, OMADownloadHandler.OMA_DRM_MESSAGE_MIME);
+        String fileName =
+                URLUtil.guessFileName(url.getSpec(), null, MimeUtils.OMA_DRM_MESSAGE_MIME);
         final DownloadInfo downloadInfo =
                 new DownloadInfo.Builder().setUrl(url).setFileName(fileName).build();
         WindowAndroid window = mTab.getWindowAndroid();
@@ -301,8 +215,4 @@ public class ChromeDownloadDelegate {
         }
         return true;
     }
-
-    protected Context getContext() {
-        return mContext;
-    }
 }
