@@ -1,4 +1,4 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -11,37 +11,41 @@ import android.content.ComponentName;
 import android.content.Context;
 import android.content.Intent;
 import android.content.ServiceConnection;
-import android.os.Build;
+import android.os.Build.VERSION;
+import android.os.Build.VERSION_CODES;
 import android.os.Handler;
 import android.os.IBinder;
 
-import com.google.ipc.invalidation.util.Preconditions;
+import androidx.annotation.Nullable;
+import androidx.annotation.VisibleForTesting;
 
+import org.chromium.base.ApplicationStatus;
 import org.chromium.base.ContextUtils;
 import org.chromium.base.Log;
-import org.chromium.base.VisibleForTesting;
+import org.chromium.chrome.browser.download.DownloadNotificationService.DownloadStatus;
+import org.chromium.chrome.browser.notifications.NotificationUmaTracker;
+import org.chromium.chrome.browser.notifications.NotificationWrapperBuilderFactory;
+import org.chromium.chrome.browser.notifications.channels.ChromeChannelDefinitions;
+import org.chromium.components.browser_ui.notifications.NotificationMetadata;
+import org.chromium.components.browser_ui.notifications.NotificationWrapperBuilder;
 
-import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.Iterator;
-import java.util.List;
 import java.util.Map;
 
-import javax.annotation.Nullable;
-
 /**
  * Manager to stop and start the foreground service associated with downloads.
  */
 public class DownloadForegroundServiceManager {
-    public enum DownloadStatus { PAUSE, CANCEL, COMPLETE, IN_PROGRESS, FAIL }
-    private static class DownloadUpdate {
+    protected static class DownloadUpdate {
         int mNotificationId;
         Notification mNotification;
-        DownloadStatus mDownloadStatus;
+        @DownloadNotificationService.DownloadStatus
+        int mDownloadStatus;
         Context mContext;
 
-        DownloadUpdate(int notificationId, Notification notification, DownloadStatus downloadStatus,
-                Context context) {
+        DownloadUpdate(int notificationId, @Nullable Notification notification,
+                @DownloadNotificationService.DownloadStatus int downloadStatus, Context context) {
             mNotificationId = notificationId;
             mNotification = notification;
             mDownloadStatus = downloadStatus;
@@ -51,53 +55,65 @@ public class DownloadForegroundServiceManager {
 
     private static final String TAG = "DownloadFg";
     // Delay to ensure start/stop foreground doesn't happen too quickly (b/74236718).
-    private static final int WAIT_TIME_MS = 100;
-
-    // Used to track existing notifications for UMA stats.
-    private final List<Integer> mExistingNotifications = new ArrayList<>();
+    private static final int WAIT_TIME_MS = 200;
 
     // Variables used to ensure start/stop foreground doesn't happen too quickly (b/74236718).
     private final Handler mHandler = new Handler();
     private final Runnable mMaybeStopServiceRunnable = new Runnable() {
         @Override
         public void run() {
+            Log.w(TAG, "Checking if delayed stopAndUnbindService needs to be resolved.");
             mStopServiceDelayed = false;
             processDownloadUpdateQueue(false /* not isProcessingPending */);
             mHandler.removeCallbacks(mMaybeStopServiceRunnable);
+            Log.w(TAG, "Done checking if delayed stopAndUnbindService needs to be resolved.");
         }
     };
-    private boolean mStopServiceDelayed = false;
+    private boolean mStopServiceDelayed;
 
     private int mPinnedNotificationId = INVALID_NOTIFICATION_ID;
 
     // This is true when context.bindService has been called and before context.unbindService.
     private boolean mIsServiceBound;
+
+    // Whether startForeground() is called. startForeground() must be called in 5 seconds after the
+    // service is started.
+    private boolean mStartForegroundCalled;
+
     // This is non-null when onServiceConnected has been called (aka service is active).
-    private DownloadForegroundService mBoundService;
+    private DownloadForegroundServiceImpl mBoundService;
 
     @VisibleForTesting
     final Map<Integer, DownloadUpdate> mDownloadUpdateQueue = new HashMap<>();
 
+    private static <T> void checkNotNull(T reference) {
+        if (reference == null) {
+            throw new NullPointerException();
+        }
+    }
+
     public DownloadForegroundServiceManager() {}
 
-    public void updateDownloadStatus(Context context, DownloadStatus downloadStatus,
-            int notificationId, Notification notification) {
-        if (downloadStatus != DownloadStatus.IN_PROGRESS) {
+    /**
+     * Updates download notification status. In progress notification will have a foreground service
+     * associated. If all notifications are not in progress, foreground service will stop.
+     * @param context Android {@link Context}.
+     * @param downloadStatus Download status. In progress notification will have a foreground
+     *         service.
+     * @param notificationId The notification id.
+     * @param notification The notification associated with the id. Can be null if {@link
+     *         DownloadNotificationService} tries to cancel a notification.
+     */
+    public void updateDownloadStatus(Context context,
+            @DownloadNotificationService.DownloadStatus int downloadStatus, int notificationId,
+            @Nullable Notification notification) {
+        if (downloadStatus != DownloadNotificationService.DownloadStatus.IN_PROGRESS) {
             Log.w(TAG,
                     "updateDownloadStatus status: " + downloadStatus + ", id: " + notificationId);
         }
         mDownloadUpdateQueue.put(notificationId,
                 new DownloadUpdate(notificationId, notification, downloadStatus, context));
         processDownloadUpdateQueue(false /* not isProcessingPending */);
-
-        // Record instance where notification is being launched for the first time.
-        if (!mExistingNotifications.contains(notificationId)) {
-            mExistingNotifications.add(notificationId);
-            if (Build.VERSION.SDK_INT < 24) {
-                DownloadNotificationUmaHelper.recordNotificationFlickerCountHistogram(
-                        DownloadNotificationUmaHelper.LaunchType.LAUNCH);
-            }
-        }
     }
 
     /**
@@ -112,6 +128,9 @@ public class DownloadForegroundServiceManager {
     void processDownloadUpdateQueue(boolean isProcessingPending) {
         DownloadUpdate downloadUpdate = findInterestingDownloadUpdate();
         if (downloadUpdate == null) return;
+        // If foreground service is disallowed, don't handle active download updates. Only stopping
+        // the foreground service is allowed.
+        if (isActive(downloadUpdate.mDownloadStatus) && !canStartForeground()) return;
 
         // When nothing has been initialized, just bind the service.
         if (!mIsServiceBound) {
@@ -129,8 +148,8 @@ public class DownloadForegroundServiceManager {
 
         // In the pending case, start foreground with specific notificationId and notification.
         if (isProcessingPending) {
-            startOrUpdateForegroundService(
-                    downloadUpdate.mNotificationId, downloadUpdate.mNotification);
+            Log.w(TAG, "Starting service with type " + downloadUpdate.mDownloadStatus);
+            startOrUpdateForegroundService(downloadUpdate);
 
             // Post a delayed task to eventually check to see if service needs to be stopped.
             postMaybeStopServiceRunnable();
@@ -144,6 +163,8 @@ public class DownloadForegroundServiceManager {
             if (!mStopServiceDelayed) {
                 stopAndUnbindService(downloadUpdate.mDownloadStatus);
                 cleanDownloadUpdateQueue();
+            } else {
+                Log.w(TAG, "Delaying call to stopAndUnbindService.");
             }
             return;
         }
@@ -151,8 +172,7 @@ public class DownloadForegroundServiceManager {
         // Make sure the pinned notification is still active, if not, update.
         if (mDownloadUpdateQueue.get(mPinnedNotificationId) == null
                 || !isActive(mDownloadUpdateQueue.get(mPinnedNotificationId).mDownloadStatus)) {
-            startOrUpdateForegroundService(
-                    downloadUpdate.mNotificationId, downloadUpdate.mNotification);
+            startOrUpdateForegroundService(downloadUpdate);
         }
 
         // Clear out inactive download updates in queue if there is at least one active download.
@@ -176,8 +196,8 @@ public class DownloadForegroundServiceManager {
         return null;
     }
 
-    private boolean isActive(DownloadStatus downloadStatus) {
-        return downloadStatus == DownloadStatus.IN_PROGRESS;
+    private boolean isActive(@DownloadNotificationService.DownloadStatus int downloadStatus) {
+        return downloadStatus == DownloadNotificationService.DownloadStatus.IN_PROGRESS;
     }
 
     private void cleanDownloadUpdateQueue() {
@@ -199,12 +219,13 @@ public class DownloadForegroundServiceManager {
     void startAndBindService(Context context) {
         Log.w(TAG, "startAndBindService");
         mIsServiceBound = true;
+        mStartForegroundCalled = false;
         startAndBindServiceInternal(context);
     }
 
     @VisibleForTesting
     void startAndBindServiceInternal(Context context) {
-        DownloadForegroundService.startDownloadForegroundService(context);
+        DownloadForegroundServiceImpl.startDownloadForegroundService(context);
         context.bindService(new Intent(context, DownloadForegroundService.class), mConnection,
                 Context.BIND_AUTO_CREATE);
     }
@@ -213,13 +234,13 @@ public class DownloadForegroundServiceManager {
         @Override
         public void onServiceConnected(ComponentName className, IBinder service) {
             Log.w(TAG, "onServiceConnected");
-            if (!(service instanceof DownloadForegroundService.LocalBinder)) {
+            if (!(service instanceof DownloadForegroundServiceImpl.LocalBinder)) {
                 Log.w(TAG,
                         "Not from DownloadNotificationService, do not connect."
                                 + " Component name: " + className);
                 return;
             }
-            mBoundService = ((DownloadForegroundService.LocalBinder) service).getService();
+            mBoundService = ((DownloadForegroundServiceImpl.LocalBinder) service).getService();
             DownloadForegroundServiceObservers.addObserver(
                     DownloadNotificationServiceObserver.class);
             processDownloadUpdateQueue(true /* isProcessingPending */);
@@ -235,8 +256,23 @@ public class DownloadForegroundServiceManager {
     /** Helper code to start or update foreground service. */
 
     @VisibleForTesting
-    void startOrUpdateForegroundService(int notificationId, Notification notification) {
-        Log.w(TAG, "startOrUpdateForegroundService id: " + notificationId);
+    void startOrUpdateForegroundService(DownloadUpdate update) {
+        Log.w(TAG,
+                "startOrUpdateForegroundService id: " + update.mNotificationId
+                        + ", startForeground() Called: " + mStartForegroundCalled);
+
+        int notificationId = update.mNotificationId;
+        Notification notification = update.mNotification;
+
+        // On O+, we must call startForeground or Android will crash. If the last update
+        // is DownloadStatus.CANCELLED, then create an empty notification. See crbug.com/1121096.
+        // Notices the empty notification will be cancelled immediately in
+        // DownloadNotificationService afterward.
+        if (VERSION.SDK_INT >= VERSION_CODES.O && notification == null && !mStartForegroundCalled) {
+            assert update.mDownloadStatus == DownloadStatus.CANCELLED;
+            notification = createEmptyNotification(notificationId, update.mContext);
+        }
+
         if (mBoundService != null && notificationId != INVALID_NOTIFICATION_ID
                 && notification != null) {
             // If there was an originally pinned notification, get its id and notification.
@@ -244,68 +280,77 @@ public class DownloadForegroundServiceManager {
             Notification oldNotification =
                     (downloadUpdate == null) ? null : downloadUpdate.mNotification;
 
+            boolean killOldNotification = downloadUpdate != null
+                    && downloadUpdate.mDownloadStatus == DownloadStatus.CANCELLED;
+
             // Start service and handle notifications.
-            mBoundService.startOrUpdateForegroundService(
-                    notificationId, notification, mPinnedNotificationId, oldNotification);
+            mBoundService.startOrUpdateForegroundService(notificationId, notification,
+                    mPinnedNotificationId, oldNotification, killOldNotification);
+            mStartForegroundCalled = true;
 
             // After the service has been started and the notification handled, change stored id.
             mPinnedNotificationId = notificationId;
         }
     }
 
+    // Creates an empty notification to feed to startForeground().
+    private Notification createEmptyNotification(int notificationId, Context context) {
+        NotificationWrapperBuilder builder =
+                NotificationWrapperBuilderFactory.createNotificationWrapperBuilder(
+                        ChromeChannelDefinitions.ChannelId.DOWNLOADS,
+                        new NotificationMetadata(
+                                NotificationUmaTracker.SystemNotificationType.DOWNLOAD_FILES, null,
+                                notificationId));
+        return builder.build();
+    }
+
     /** Helper code to stop and unbind service. */
 
     @VisibleForTesting
-    void stopAndUnbindService(DownloadStatus downloadStatus) {
+    void stopAndUnbindService(@DownloadNotificationService.DownloadStatus int downloadStatus) {
         Log.w(TAG, "stopAndUnbindService status: " + downloadStatus);
-        Preconditions.checkNotNull(mBoundService);
+        checkNotNull(mBoundService);
         mIsServiceBound = false;
 
-        @DownloadForegroundService.StopForegroundNotification
+        @DownloadForegroundServiceImpl.StopForegroundNotification
         int stopForegroundNotification;
-        if (downloadStatus == DownloadStatus.CANCEL) {
-            stopForegroundNotification = DownloadForegroundService.StopForegroundNotification.KILL;
-        } else if (downloadStatus == DownloadStatus.PAUSE) {
+        if (downloadStatus == DownloadNotificationService.DownloadStatus.CANCELLED) {
             stopForegroundNotification =
-                    DownloadForegroundService.StopForegroundNotification.DETACH_OR_PERSIST;
+                    DownloadForegroundServiceImpl.StopForegroundNotification.KILL;
         } else {
             stopForegroundNotification =
-                    DownloadForegroundService.StopForegroundNotification.DETACH_OR_ADJUST;
+                    DownloadForegroundServiceImpl.StopForegroundNotification.DETACH;
         }
 
         DownloadUpdate downloadUpdate = mDownloadUpdateQueue.get(mPinnedNotificationId);
         Notification oldNotification =
                 (downloadUpdate == null) ? null : downloadUpdate.mNotification;
 
-        boolean notificationHandledProperly = stopAndUnbindServiceInternal(
+        stopAndUnbindServiceInternal(
                 stopForegroundNotification, mPinnedNotificationId, oldNotification);
 
         mBoundService = null;
+        mStartForegroundCalled = false;
 
-        // Only if the notification was handled properly (ie. detached or killed), reset stored ID.
-        if (notificationHandledProperly) mPinnedNotificationId = INVALID_NOTIFICATION_ID;
+        mPinnedNotificationId = INVALID_NOTIFICATION_ID;
     }
 
     @VisibleForTesting
-    boolean stopAndUnbindServiceInternal(
-            @DownloadForegroundService.StopForegroundNotification int stopForegroundStatus,
+    void stopAndUnbindServiceInternal(
+            @DownloadForegroundServiceImpl.StopForegroundNotification int stopForegroundStatus,
             int pinnedNotificationId, Notification pinnedNotification) {
-        boolean notificationHandledProperly = mBoundService.stopDownloadForegroundService(
+        mBoundService.stopDownloadForegroundService(
                 stopForegroundStatus, pinnedNotificationId, pinnedNotification);
         ContextUtils.getApplicationContext().unbindService(mConnection);
 
-        if (notificationHandledProperly) {
-            DownloadForegroundServiceObservers.removeObserver(
-                    DownloadNotificationServiceObserver.class);
-        }
-
-        return notificationHandledProperly;
+        DownloadForegroundServiceObservers.removeObserver(
+                DownloadNotificationServiceObserver.class);
     }
 
     /** Helper code for testing. */
 
     @VisibleForTesting
-    void setBoundService(DownloadForegroundService service) {
+    void setBoundService(DownloadForegroundServiceImpl service) {
         mBoundService = service;
     }
 
@@ -316,4 +361,14 @@ public class DownloadForegroundServiceManager {
         mHandler.postDelayed(mMaybeStopServiceRunnable, WAIT_TIME_MS);
         mStopServiceDelayed = true;
     }
+
+    /**
+     * @return Whether startForeground() is allowed to be called.
+     */
+    private boolean canStartForeground() {
+        if (VERSION.SDK_INT < VERSION_CODES.S) return true;
+        // If foreground service is started, startForeground() must be called.
+        return ApplicationStatus.hasVisibleActivities()
+                || (mIsServiceBound && !mStartForegroundCalled);
+    }
 }
