@@ -1,11 +1,10 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.download;
 
 import org.chromium.components.offline_items_collection.ContentId;
-import org.chromium.components.offline_items_collection.FailState;
 import org.chromium.components.offline_items_collection.PendingState;
 
 /**
@@ -25,9 +24,8 @@ public interface DownloadNotifier {
     /**
      * Add a download failed notification.
      * @param downloadInfo info about the failed download.
-     * @param failState The reason the download failed.
      */
-    void notifyDownloadFailed(DownloadInfo downloadInfo, @FailState int failState);
+    void notifyDownloadFailed(DownloadInfo downloadInfo);
 
     /**
      * Update the download progress notification.
@@ -67,9 +65,4 @@ public interface DownloadNotifier {
      * @param downloadInfo   Info about the removed download.
      */
     void removeDownloadNotification(int notificationId, DownloadInfo downloadInfo);
-
-    /**
-     * Called to resume all the pending download entries in SharedPreferences.
-     */
-    void resumePendingDownloads();
 }
