@@ -1,4 +1,4 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,14 +6,19 @@ package org.chromium.chrome.browser.download;
 
 import android.graphics.Bitmap;
 
+import androidx.annotation.Nullable;
+import androidx.annotation.NonNull;
+
+import org.chromium.chrome.browser.profiles.OTRProfileID;
 import org.chromium.components.offline_items_collection.ContentId;
 import org.chromium.components.offline_items_collection.FailState;
 import org.chromium.components.offline_items_collection.OfflineItem.Progress;
 import org.chromium.components.offline_items_collection.PendingState;
+import org.chromium.url.GURL;
 
 /**
  * Class representing information relating to an update in download status.
- * TODO(jming): Consolidate with other downloads-related objects (http://crbug.com/746692).
+ * TODO(crbug.com/691805): Consolidate with other downloads-related objects.
  */
 public final class DownloadUpdate {
     private final ContentId mContentId;
@@ -22,16 +27,19 @@ public final class DownloadUpdate {
     private final Bitmap mIcon;
     private final int mIconId;
     private final boolean mIsOffTheRecord;
+    private final @Nullable OTRProfileID mOTRProfileID;
     private final boolean mIsOpenable;
     private final boolean mIsSupportedMimeType;
     private final boolean mIsTransient;
     private final int mNotificationId;
-    private final String mOriginalUrl;
+    private final @NonNull GURL mOriginalUrl;
+    private final boolean mShouldPromoteOrigin;
     private final Progress mProgress;
-    private final String mReferrer;
+    private final @NonNull GURL mReferrer;
     private final long mStartTime;
     private final long mSystemDownloadId;
     private final long mTimeRemainingInMillis;
+    private final long mTotalBytes;
     private final @FailState int mFailState;
     private final @PendingState int mPendingState;
 
@@ -42,16 +50,19 @@ public final class DownloadUpdate {
         this.mIcon = builder.mIcon;
         this.mIconId = builder.mIconId;
         this.mIsOffTheRecord = builder.mIsOffTheRecord;
+        this.mOTRProfileID = builder.mOTRProfileID;
         this.mIsOpenable = builder.mIsOpenable;
         this.mIsSupportedMimeType = builder.mIsSupportedMimeType;
         this.mIsTransient = builder.mIsTransient;
         this.mNotificationId = builder.mNotificationId;
-        this.mOriginalUrl = builder.mOriginalUrl;
+        this.mOriginalUrl = builder.mOriginalUrl == null ? GURL.emptyGURL() : builder.mOriginalUrl;
+        this.mShouldPromoteOrigin = builder.mShouldPromoteOrigin;
         this.mProgress = builder.mProgress;
-        this.mReferrer = builder.mReferrer;
+        this.mReferrer = builder.mReferrer == null ? GURL.emptyGURL() : builder.mReferrer;
         this.mStartTime = builder.mStartTime;
         this.mSystemDownloadId = builder.mSystemDownloadId;
         this.mTimeRemainingInMillis = builder.mTimeRemainingInMillis;
+        this.mTotalBytes = builder.mTotalBytes;
         this.mFailState = builder.mFailState;
         this.mPendingState = builder.mPendingState;
     }
@@ -84,6 +95,11 @@ public final class DownloadUpdate {
         return mIsOffTheRecord;
     }
 
+    @Nullable
+    public OTRProfileID getOTRProfileID() {
+        return mOTRProfileID;
+    }
+
     public boolean getIsOpenable() {
         return mIsOpenable;
     }
@@ -100,15 +116,21 @@ public final class DownloadUpdate {
         return mNotificationId;
     }
 
-    public String getOriginalUrl() {
+    @NonNull
+    public GURL getOriginalUrl() {
         return mOriginalUrl;
     }
 
+    public boolean getShouldPromoteOrigin() {
+        return mShouldPromoteOrigin;
+    }
+
     public Progress getProgress() {
         return mProgress;
     }
 
-    public String getReferrer() {
+    @NonNull
+    public GURL getReferrer() {
         return mReferrer;
     }
 
@@ -124,6 +146,10 @@ public final class DownloadUpdate {
         return mTimeRemainingInMillis;
     }
 
+    public long getTotalBytes() {
+        return mTotalBytes;
+    }
+
     public @FailState int getFailState() {
         return mFailState;
     }
@@ -142,16 +168,19 @@ public final class DownloadUpdate {
         private Bitmap mIcon;
         private int mIconId = -1;
         private boolean mIsOffTheRecord;
+        private @Nullable OTRProfileID mOTRProfileID;
         private boolean mIsOpenable;
         private boolean mIsSupportedMimeType;
         private boolean mIsTransient;
         private int mNotificationId = -1;
-        private String mOriginalUrl;
+        private GURL mOriginalUrl;
+        private boolean mShouldPromoteOrigin;
         private Progress mProgress;
-        private String mReferrer;
+        private GURL mReferrer;
         private long mStartTime;
         private long mSystemDownloadId = -1;
         private long mTimeRemainingInMillis;
+        private long mTotalBytes;
         private @FailState int mFailState;
         private @PendingState int mPendingState;
 
@@ -180,8 +209,11 @@ public final class DownloadUpdate {
             return this;
         }
 
-        public Builder setIsOffTheRecord(boolean isOffTheRecord) {
-            this.mIsOffTheRecord = isOffTheRecord;
+        public Builder setOTRProfileID(@Nullable OTRProfileID otrProfileID) {
+            this.mOTRProfileID = otrProfileID;
+            // TODO(crbug.com/1161132): Remove this after replacing |DownloadUpdate#isOffTheRecord|
+            // usages with |DownloadUpdate#getOTRProfileID|.
+            this.mIsOffTheRecord = OTRProfileID.isOffTheRecord(otrProfileID);
             return this;
         }
 
@@ -205,17 +237,22 @@ public final class DownloadUpdate {
             return this;
         }
 
-        public Builder setOriginalUrl(String originalUrl) {
+        public Builder setOriginalUrl(GURL originalUrl) {
             this.mOriginalUrl = originalUrl;
             return this;
         }
 
+        public Builder setShouldPromoteOrigin(boolean shouldPromoteOrigin) {
+            this.mShouldPromoteOrigin = shouldPromoteOrigin;
+            return this;
+        }
+
         public Builder setProgress(Progress progress) {
             this.mProgress = progress;
             return this;
         }
 
-        public Builder setReferrer(String referrer) {
+        public Builder setReferrer(GURL referrer) {
             this.mReferrer = referrer;
             return this;
         }
@@ -235,6 +272,11 @@ public final class DownloadUpdate {
             return this;
         }
 
+        public Builder setTotalBytes(long totalBytes) {
+            this.mTotalBytes = totalBytes;
+            return this;
+        }
+
         public Builder setFailState(@FailState int failState) {
             this.mFailState = failState;
             return this;
