@@ -1,4 +1,4 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -8,16 +8,20 @@ import org.chromium.chrome.browser.download.DownloadInfo;
 import org.chromium.chrome.browser.download.DownloadItem;
 import org.chromium.chrome.browser.download.DownloadNotifier;
 import org.chromium.chrome.browser.download.DownloadServiceDelegate;
+import org.chromium.chrome.browser.profiles.OTRProfileID;
 import org.chromium.components.offline_items_collection.ContentId;
 import org.chromium.components.offline_items_collection.LegacyHelpers;
 import org.chromium.components.offline_items_collection.OfflineContentProvider;
 import org.chromium.components.offline_items_collection.OfflineItem;
 import org.chromium.components.offline_items_collection.OfflineItemState;
 import org.chromium.components.offline_items_collection.OfflineItemVisuals;
+import org.chromium.components.offline_items_collection.OpenParams;
+import org.chromium.components.offline_items_collection.UpdateDelta;
 import org.chromium.components.offline_items_collection.VisualsCallback;
+import org.chromium.ui.permissions.ContextualNotificationPermissionRequester;
 
-import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 
 /**
  * A glue class that bridges the Profile-attached OfflineContentProvider with the
@@ -64,18 +68,15 @@ public class OfflineContentAggregatorNotificationBridgeUi
         destroyServiceDelegate();
     }
 
-    /** @see OfflineContentProvider#openItem(ContentId) */
-    public void openItem(ContentId id) {
-        mProvider.openItem(id);
+    /** @see OfflineContentProvider#openItem(OpenParams, ContentId) */
+    public void openItem(OpenParams openParams, ContentId id) {
+        mProvider.openItem(openParams, id);
     }
 
     // OfflineContentProvider.Observer implementation.
     @Override
-    public void onItemsAdded(ArrayList<OfflineItem> items) {
-        for (int i = 0; i < items.size(); i++) {
-            OfflineItem item = items.get(i);
-            if (shouldPushNewItemToUi(item)) getVisualsAndUpdateItem(item);
-        }
+    public void onItemsAdded(List<OfflineItem> items) {
+        for (int i = 0; i < items.size(); ++i) getVisualsAndUpdateItem(items.get(i), null);
     }
 
     @Override
@@ -86,9 +87,8 @@ public class OfflineContentAggregatorNotificationBridgeUi
     }
 
     @Override
-    public void onItemUpdated(OfflineItem item) {
-        // Assume that any item sending updates should have them reflected in the UI.
-        getVisualsAndUpdateItem(item);
+    public void onItemUpdated(OfflineItem item, UpdateDelta updateDelta) {
+        getVisualsAndUpdateItem(item, updateDelta);
     }
 
     // OfflineContentProvider.VisualsCallback implementation.
@@ -107,12 +107,12 @@ public class OfflineContentAggregatorNotificationBridgeUi
 
     // DownloadServiceDelegate implementation.
     @Override
-    public void cancelDownload(ContentId id, boolean isOffTheRecord) {
+    public void cancelDownload(ContentId id, OTRProfileID otrProfileID) {
         mProvider.cancelDownload(id);
     }
 
     @Override
-    public void pauseDownload(ContentId id, boolean isOffTheRecord) {
+    public void pauseDownload(ContentId id, OTRProfileID otrProfileID) {
         mProvider.pauseDownload(id);
     }
 
@@ -124,7 +124,9 @@ public class OfflineContentAggregatorNotificationBridgeUi
     @Override
     public void destroyServiceDelegate() {}
 
-    private void getVisualsAndUpdateItem(OfflineItem item) {
+    private void getVisualsAndUpdateItem(OfflineItem item, UpdateDelta updateDelta) {
+        if (shouldIgnoreUpdate(item, updateDelta)) return;
+        if (updateDelta != null && updateDelta.visualsChanged) mVisualsCache.remove(item.id);
         if (needsVisualsForUi(item)) {
             if (!mVisualsCache.containsKey(item.id)) {
                 // We don't have any visuals for this item yet.  Stash the current OfflineItem and,
@@ -148,7 +150,20 @@ public class OfflineContentAggregatorNotificationBridgeUi
     }
 
     private void pushItemToUi(OfflineItem item, OfflineItemVisuals visuals) {
-        if (!shouldShowNotification(item)) return;
+        // TODO(http://crbug.com/855141): Find a cleaner way to hide unimportant UI updates.
+        // If it's a suggested page, or the user choose to download later. Do not add it to the
+        // notification UI.
+        if (item.isSuggested) return;
+
+        // If the download is cancelled, no need to DownloadInfo object and it is enough to notify
+        // that the download is canceled.
+        if (item.state == OfflineItemState.CANCELLED) {
+            mUi.notifyDownloadCanceled(item.id);
+            return;
+        }
+
+        // Request notification permission if needed.
+        ContextualNotificationPermissionRequester.getInstance().requestPermissionIfNeeded();
 
         DownloadInfo info = DownloadInfo.fromOfflineItem(item, visuals);
         switch (item.state) {
@@ -156,23 +171,20 @@ public class OfflineContentAggregatorNotificationBridgeUi
                 mUi.notifyDownloadProgress(info, item.creationTimeMs, item.allowMetered);
                 break;
             case OfflineItemState.COMPLETE:
-                mUi.notifyDownloadSuccessful(info, -1L, false, false);
-                break;
-            case OfflineItemState.CANCELLED:
-                mUi.notifyDownloadCanceled(item.id);
+                mUi.notifyDownloadSuccessful(info, -1L, false, item.isOpenable);
                 break;
             case OfflineItemState.INTERRUPTED:
-                // TODO(dtrainor): Push the correct value for auto resume.
-                mUi.notifyDownloadInterrupted(info, true, item.pendingState);
+                mUi.notifyDownloadInterrupted(info,
+                        LegacyHelpers.isLegacyDownload(item.id) ? false : true, item.pendingState);
                 break;
             case OfflineItemState.PAUSED:
                 mUi.notifyDownloadPaused(info);
                 break;
             case OfflineItemState.FAILED:
-                mUi.notifyDownloadFailed(info, item.failState);
+                mUi.notifyDownloadFailed(info);
                 break;
             case OfflineItemState.PENDING:
-                // Not Implemented.
+                mUi.notifyDownloadPaused(info);
                 break;
             default:
                 assert false : "Unexpected OfflineItem state.";
@@ -180,6 +192,7 @@ public class OfflineContentAggregatorNotificationBridgeUi
     }
 
     private boolean needsVisualsForUi(OfflineItem item) {
+        if (item.ignoreVisuals) return false;
         switch (item.state) {
             case OfflineItemState.IN_PROGRESS:
             case OfflineItemState.PENDING:
@@ -188,45 +201,34 @@ public class OfflineContentAggregatorNotificationBridgeUi
             case OfflineItemState.FAILED:
             case OfflineItemState.PAUSED:
                 return true;
-            case OfflineItemState.CANCELLED:
-            default:
-                return false;
-        }
-    }
-
-    private boolean shouldPushNewItemToUi(OfflineItem item) {
-        switch (item.state) {
-            case OfflineItemState.IN_PROGRESS:
-                return true;
-            case OfflineItemState.PENDING:
-            case OfflineItemState.COMPLETE:
-            case OfflineItemState.INTERRUPTED:
-            case OfflineItemState.FAILED:
-            case OfflineItemState.PAUSED:
-            case OfflineItemState.CANCELLED:
+            // OfflineItemState.CANCELLED
             default:
                 return false;
         }
     }
 
     private boolean shouldCacheVisuals(OfflineItem item) {
+        if (item.ignoreVisuals) return false;
         switch (item.state) {
             case OfflineItemState.IN_PROGRESS:
             case OfflineItemState.PENDING:
             case OfflineItemState.INTERRUPTED:
             case OfflineItemState.PAUSED:
-                return true;
-            case OfflineItemState.FAILED:
             case OfflineItemState.COMPLETE:
-            case OfflineItemState.CANCELLED:
+                return true;
+            // OfflineItemState.FAILED,
+            // OfflineItemState.CANCELLED
             default:
                 return false;
         }
     }
 
-    private boolean shouldShowNotification(OfflineItem item) {
-        // Temporarily return immediately to prevent unnecessary notifications for offline pages
-        // until https://crbug.com/831083 and https://crbug.com/832282 are fixed.
-        return !item.isTransient && !LegacyHelpers.isLegacyOfflinePage(item.id);
+    private boolean shouldIgnoreUpdate(OfflineItem item, UpdateDelta updateDelta) {
+        // We only ignore updates for completed items, if there is no significant state change
+        // update.
+        if (item.state != OfflineItemState.COMPLETE) return false;
+        if (updateDelta == null) return false;
+        if (updateDelta.stateChanged || updateDelta.visualsChanged) return false;
+        return true;
     }
 }
