@@ -1,4 +1,4 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,7 +7,7 @@ package org.chromium.chrome.browser.download.items;
 import org.chromium.base.ThreadUtils;
 import org.chromium.chrome.browser.download.DownloadManagerService;
 import org.chromium.chrome.browser.download.DownloadNotifier;
-import org.chromium.chrome.browser.profiles.Profile;
+import org.chromium.chrome.browser.offlinepages.downloads.OfflinePageDownloadBridge;
 import org.chromium.components.offline_items_collection.OfflineContentProvider;
 
 /**
@@ -24,11 +24,10 @@ public class OfflineContentAggregatorNotificationBridgeUiFactory {
     public static OfflineContentAggregatorNotificationBridgeUi instance() {
         ThreadUtils.assertOnUiThread();
         if (sBridgeUi == null) {
-            Profile profile = Profile.getLastUsedProfile();
-            OfflineContentProvider provider = OfflineContentAggregatorFactory.forProfile(profile);
+            OfflineContentProvider provider = OfflineContentAggregatorFactory.get();
             DownloadNotifier ui =
                     DownloadManagerService.getDownloadManagerService().getDownloadNotifier();
-
+            OfflinePageDownloadBridge.getInstance();
             sBridgeUi = new OfflineContentAggregatorNotificationBridgeUi(provider, ui);
         }
 
