@@ -1,37 +1,33 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.firstrun;
 
 import android.os.Bundle;
-import android.support.v4.app.Fragment;
 import android.view.LayoutInflater;
 import android.view.View;
 import android.view.ViewGroup;
+import android.view.accessibility.AccessibilityEvent;
 import android.widget.Button;
 
-import org.chromium.base.ThreadUtils;
+import androidx.fragment.app.Fragment;
+
 import org.chromium.base.metrics.RecordUserAction;
+import org.chromium.base.task.PostTask;
+import org.chromium.base.task.TaskTraits;
 import org.chromium.chrome.R;
-import org.chromium.chrome.browser.locale.DefaultSearchEngineDialogHelper;
 import org.chromium.chrome.browser.locale.LocaleManager;
-import org.chromium.chrome.browser.locale.LocaleManager.SearchEnginePromoType;
-import org.chromium.chrome.browser.search_engines.TemplateUrlService;
-import org.chromium.chrome.browser.widget.RadioButtonLayout;
+import org.chromium.chrome.browser.profiles.Profile;
+import org.chromium.chrome.browser.search_engines.DefaultSearchEngineDialogHelper;
+import org.chromium.chrome.browser.search_engines.SearchEnginePromoType;
+import org.chromium.chrome.browser.search_engines.TemplateUrlServiceFactory;
+import org.chromium.components.browser_ui.widget.RadioButtonLayout;
 
 /** A {@link Fragment} that presents a set of search engines for the user to choose from. */
 public class DefaultSearchEngineFirstRunFragment extends Fragment implements FirstRunFragment {
-    /** FRE page that instantiates this fragment. */
-    public static class Page implements FirstRunPage<DefaultSearchEngineFirstRunFragment> {
-        @Override
-        public DefaultSearchEngineFirstRunFragment instantiateFragment() {
-            return new DefaultSearchEngineFirstRunFragment();
-        }
-    }
-
     @SearchEnginePromoType
-    private int mSearchEnginePromoDialoType;
+    private int mSearchEnginePromoDialogType;
     private boolean mShownRecorded;
 
     /** Layout that displays the available search engines to the user. */
@@ -50,29 +46,34 @@ public class DefaultSearchEngineFirstRunFragment extends Fragment implements Fir
         mButton = (Button) rootView.findViewById(R.id.button_primary);
         mButton.setEnabled(false);
 
-        assert TemplateUrlService.getInstance().isLoaded();
-        mSearchEnginePromoDialoType = LocaleManager.getInstance().getSearchEnginePromoShowType();
-        if (mSearchEnginePromoDialoType != LocaleManager.SEARCH_ENGINE_PROMO_DONT_SHOW) {
-            Runnable dismissRunnable = new Runnable() {
-                @Override
-                public void run() {
-                    getPageDelegate().advanceToNextPage();
-                }
-            };
-            new DefaultSearchEngineDialogHelper(
-                    mSearchEnginePromoDialoType, mEngineLayout, mButton, dismissRunnable);
+        assert TemplateUrlServiceFactory.getForProfile(Profile.getLastUsedRegularProfile())
+                .isLoaded();
+        mSearchEnginePromoDialogType = LocaleManager.getInstance().getSearchEnginePromoShowType();
+        if (mSearchEnginePromoDialogType != SearchEnginePromoType.DONT_SHOW) {
+            new DefaultSearchEngineDialogHelper(mSearchEnginePromoDialogType,
+                    LocaleManager.getInstance(), mEngineLayout, mButton,
+                    getPageDelegate()::advanceToNextPage);
         }
 
         return rootView;
     }
 
+    @Override
+    public void setInitialA11yFocus() {
+        // Ignore calls before view is created.
+        if (getView() == null) return;
+
+        final View title = getView().findViewById(R.id.chooser_title);
+        title.sendAccessibilityEvent(AccessibilityEvent.TYPE_VIEW_FOCUSED);
+    }
+
     @Override
     public void setUserVisibleHint(boolean isVisibleToUser) {
         super.setUserVisibleHint(isVisibleToUser);
 
         if (isVisibleToUser) {
-            if (mSearchEnginePromoDialoType == LocaleManager.SEARCH_ENGINE_PROMO_DONT_SHOW) {
-                ThreadUtils.postOnUiThread(new Runnable() {
+            if (mSearchEnginePromoDialogType == SearchEnginePromoType.DONT_SHOW) {
+                PostTask.postTask(TaskTraits.UI_DEFAULT, new Runnable() {
                     @Override
                     public void run() {
                         getPageDelegate().advanceToNextPage();
@@ -87,9 +88,9 @@ public class DefaultSearchEngineFirstRunFragment extends Fragment implements Fir
     private void recordShown() {
         if (mShownRecorded) return;
 
-        if (mSearchEnginePromoDialoType == LocaleManager.SEARCH_ENGINE_PROMO_SHOW_NEW) {
+        if (mSearchEnginePromoDialogType == SearchEnginePromoType.SHOW_NEW) {
             RecordUserAction.record("SearchEnginePromo.NewDevice.Shown.FirstRun");
-        } else if (mSearchEnginePromoDialoType == LocaleManager.SEARCH_ENGINE_PROMO_SHOW_EXISTING) {
+        } else if (mSearchEnginePromoDialogType == SearchEnginePromoType.SHOW_EXISTING) {
             RecordUserAction.record("SearchEnginePromo.ExistingDevice.Shown.FirstRun");
         }
 
