@@ -1,18 +1,23 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.infobar;
 
 import android.net.Uri;
-import android.support.annotation.StringRes;
 import android.view.LayoutInflater;
 import android.view.ViewGroup;
 import android.widget.TextView;
 
-import org.chromium.base.VisibleForTesting;
+import androidx.annotation.StringRes;
+import androidx.annotation.VisibleForTesting;
+
 import org.chromium.base.annotations.CalledByNative;
 import org.chromium.chrome.R;
+import org.chromium.components.infobars.InfoBar;
+import org.chromium.components.infobars.InfoBarCompactLayout;
+import org.chromium.components.infobars.InfoBarControlLayout;
+import org.chromium.components.infobars.InfoBarLayout;
 import org.chromium.components.url_formatter.UrlFormatter;
 
 /**
@@ -20,6 +25,7 @@ import org.chromium.components.url_formatter.UrlFormatter;
  * continue the redirection by tapping on a link.
  */
 public class FramebustBlockInfoBar extends InfoBar {
+
     private final String mBlockedUrl;
 
     /** Whether the infobar should be shown as a mini-infobar or a classic expanded one. */
@@ -27,7 +33,7 @@ public class FramebustBlockInfoBar extends InfoBar {
 
     @VisibleForTesting
     public FramebustBlockInfoBar(String blockedUrl) {
-        super(R.drawable.infobar_redirect_blocked, null, null);
+        super(R.drawable.infobar_chrome, R.color.infobar_icon_drawable_color, null, null);
         mBlockedUrl = blockedUrl;
     }
 
@@ -49,19 +55,32 @@ public class FramebustBlockInfoBar extends InfoBar {
         // Formatting the URL and requesting to omit the scheme might still include it for some of
         // them (e.g. file, filesystem). We split the output of the formatting to make sure we don't
         // end up duplicating it.
-        String formattedUrl = UrlFormatter.formatUrlForSecurityDisplay(mBlockedUrl, true);
-        String scheme = Uri.parse(mBlockedUrl).getScheme() + "://";
+        final String schemeSeparator = "://";
+        String scheme = Uri.parse(mBlockedUrl).getScheme();
+
+        // In case mBlockedUrl does not specify a scheme, formatUrlForSecurityDisplay returns an
+        // empty string. Temporarily adding scheme separator allows it to parse the URL correctly.
+        String urlWithScheme = mBlockedUrl;
+        if (scheme == null) {
+            scheme = "";
+            urlWithScheme = schemeSeparator + mBlockedUrl;
+        }
+
+        String textToEllipsize = UrlFormatter
+                    .formatUrlForSecurityDisplay(urlWithScheme)
+                    .substring(scheme.length() + schemeSeparator.length());
 
         TextView schemeView = ellipsizerView.findViewById(R.id.url_scheme);
         schemeView.setText(scheme);
 
         TextView urlView = ellipsizerView.findViewById(R.id.url_minus_scheme);
-        urlView.setText(formattedUrl.substring(scheme.length()));
+        urlView.setText(textToEllipsize);
 
         ellipsizerView.setOnClickListener(view -> onLinkClicked());
 
         control.addView(ellipsizerView);
-        layout.setButtons(getContext().getResources().getString(R.string.ok), null);
+        layout.setButtons(
+                getContext().getResources().getString(R.string.always_allow_redirects), null);
     }
 
     @Override
@@ -88,6 +107,11 @@ public class FramebustBlockInfoBar extends InfoBar {
         super.onLinkClicked();
     }
 
+    @VisibleForTesting
+    public String getBlockedUrl() {
+        return mBlockedUrl;
+    }
+
     private String getString(@StringRes int stringResId) {
         return getContext().getString(stringResId);
     }
