@@ -1,22 +1,24 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.init;
 
-import android.os.AsyncTask;
+import androidx.annotation.VisibleForTesting;
 
 import org.chromium.base.Callback;
 import org.chromium.base.ContextUtils;
 import org.chromium.base.ThreadUtils;
-import org.chromium.base.VisibleForTesting;
 import org.chromium.base.library_loader.LibraryLoader;
-import org.chromium.base.library_loader.LibraryProcessType;
+import org.chromium.base.library_loader.LibraryPrefetcher;
 import org.chromium.base.library_loader.ProcessInitException;
+import org.chromium.base.task.PostTask;
+import org.chromium.base.task.TaskTraits;
 import org.chromium.chrome.browser.ChromeActivitySessionTracker;
-import org.chromium.chrome.browser.ChromeVersionInfo;
+import org.chromium.chrome.browser.flags.CachedFeatureFlags;
 import org.chromium.components.variations.firstrun.VariationsSeedFetcher;
-import org.chromium.content.browser.ChildProcessLauncherHelper;
+import org.chromium.components.version_info.VersionInfo;
+import org.chromium.content_public.browser.ChildProcessLauncherHelper;
 
 import java.util.concurrent.Executor;
 
@@ -27,51 +29,57 @@ import java.util.concurrent.Executor;
  * - Fetching the variations seed on first run
  */
 public abstract class AsyncInitTaskRunner {
-    private boolean mFetchingVariations;
-    private boolean mLibraryLoaded;
     private boolean mAllocateChildConnection;
 
     private FetchSeedTask mFetchSeedTask;
 
+    // Barrier counter to determine when all tasks have completed and are
+    // successful. -1 indicates "terminal state".
+    private int mNumPendingSuccesses;
+
     @VisibleForTesting
     boolean shouldFetchVariationsSeedDuringFirstRun() {
-        return ChromeVersionInfo.isOfficialBuild();
+        return VersionInfo.isOfficialBuild();
     }
 
-    private class FetchSeedTask extends AsyncTask<Void, Void, Void> {
+    @VisibleForTesting
+    void prefetchLibrary() {
+        LibraryPrefetcher.asyncPrefetchLibrariesToMemory();
+    }
+
+    private class FetchSeedTask implements Runnable {
         private final String mRestrictMode;
         private final String mMilestone;
         private final String mChannel;
 
         public FetchSeedTask(String restrictMode) {
             mRestrictMode = restrictMode;
-            mMilestone = Integer.toString(ChromeVersionInfo.getProductMajorVersion());
+            mMilestone = Integer.toString(VersionInfo.getProductMajorVersion());
             mChannel = getChannelString();
         }
 
         @Override
-        protected Void doInBackground(Void... params) {
+        public void run() {
             VariationsSeedFetcher.get().fetchSeed(mRestrictMode, mMilestone, mChannel);
-            return null;
-        }
-
-        @Override
-        protected void onPostExecute(Void result) {
-            mFetchingVariations = false;
-            tasksPossiblyComplete(true);
+            PostTask.postTask(TaskTraits.UI_DEFAULT, new Runnable() {
+                @Override
+                public void run() {
+                    tasksPossiblyComplete(null);
+                }
+            });
         }
 
         private String getChannelString() {
-            if (ChromeVersionInfo.isCanaryBuild()) {
+            if (VersionInfo.isCanaryBuild()) {
                 return "canary";
             }
-            if (ChromeVersionInfo.isDevBuild()) {
+            if (VersionInfo.isDevBuild()) {
                 return "dev";
             }
-            if (ChromeVersionInfo.isBetaBuild()) {
+            if (VersionInfo.isBetaBuild()) {
                 return "beta";
             }
-            if (ChromeVersionInfo.isStableBuild()) {
+            if (VersionInfo.isStableBuild()) {
                 return "stable";
             }
             return "";
@@ -88,7 +96,7 @@ public abstract class AsyncInitTaskRunner {
     public void startBackgroundTasks(boolean allocateChildConnection, boolean fetchVariationSeed) {
         ThreadUtils.assertOnUiThread();
         if (fetchVariationSeed && shouldFetchVariationsSeedDuringFirstRun()) {
-            mFetchingVariations = true;
+            ++mNumPendingSuccesses;
 
             // Fetching variations restrict mode requires AccountManagerFacade to be initialized.
             ProcessInitializationHandler.getInstance().initializePreNative();
@@ -99,7 +107,7 @@ public abstract class AsyncInitTaskRunner {
                 @Override
                 public void onResult(String restrictMode) {
                     mFetchSeedTask = new FetchSeedTask(restrictMode);
-                    mFetchSeedTask.executeOnExecutor(getFetchSeedExecutor());
+                    PostTask.postTask(TaskTraits.USER_BLOCKING, mFetchSeedTask);
                 }
             });
         }
@@ -112,24 +120,22 @@ public abstract class AsyncInitTaskRunner {
         // Load the library on a background thread. Using a plain Thread instead of AsyncTask
         // because the latter would be throttled, and this task is on the critical path of the
         // browser initialization.
+        ++mNumPendingSuccesses;
         getTaskPerThreadExecutor().execute(() -> {
-            final boolean libraryLoaded = loadNativeLibrary();
-            ThreadUtils.postOnUiThread(() -> {
-                mLibraryLoaded = libraryLoaded;
-                tasksPossiblyComplete(mLibraryLoaded);
-            });
+            final ProcessInitException libraryLoadException = loadNativeLibrary();
+            ThreadUtils.postOnUiThread(() -> { tasksPossiblyComplete(libraryLoadException); });
         });
     }
 
     /**
      * Loads the native library. Can be run on any thread.
      *
-     * @return true iff loading succeeded.
+     * @return null if loading succeeds, or ProcessInitException if loading fails.
      */
-    private static boolean loadNativeLibrary() {
+    private ProcessInitException loadNativeLibrary() {
         try {
-            LibraryLoader libraryLoader = LibraryLoader.get(LibraryProcessType.PROCESS_BROWSER);
-            libraryLoader.ensureInitialized();
+            LibraryLoader.getInstance().getMediator().ensureInitializedInMainProcess();
+            LibraryLoader.getInstance().ensureInitialized();
             // The prefetch is done after the library load for two reasons:
             // - It is easier to know the library location after it has
             // been loaded.
@@ -140,32 +146,42 @@ public abstract class AsyncInitTaskRunner {
             // generally startup on some devices, most likely by
             // competing for IO.
             // For experimental results, see http://crbug.com/460438.
-            libraryLoader.asyncPrefetchLibrariesToMemory();
+            prefetchLibrary();
         } catch (ProcessInitException e) {
-            return false;
+            return e;
         }
-        return true;
+        return null;
     }
 
-    private void tasksPossiblyComplete(boolean result) {
+    private void tasksPossiblyComplete(Exception failureCause) {
         ThreadUtils.assertOnUiThread();
 
-        if (!result) {
-            if (mFetchSeedTask != null) mFetchSeedTask.cancel(true);
-            onFailure();
+        if (mNumPendingSuccesses < 0) {
+            // Terminal state: Have called onSuccess() or onFailure(). Tasks that complete after
+            // onFailure() was triggered by a previous failure would arrive here for no-op.
+            return;
         }
 
-        if (mLibraryLoaded && !mFetchingVariations) {
-            if (mAllocateChildConnection) {
-                ChildProcessLauncherHelper.warmUp(ContextUtils.getApplicationContext());
+        if (failureCause == null) {
+            // Task succeeded.
+            --mNumPendingSuccesses;
+            if (mNumPendingSuccesses == 0) {
+                // All tasks succeeded: Finish tasks, call onSuccess(), and reach terminal state.
+                if (CachedFeatureFlags.isNetworkServiceWarmUpEnabled()) {
+                    ChildProcessLauncherHelper.warmUp(ContextUtils.getApplicationContext(), false);
+                }
+                if (mAllocateChildConnection) {
+                    ChildProcessLauncherHelper.warmUp(ContextUtils.getApplicationContext(), true);
+                }
+                onSuccess();
+                mNumPendingSuccesses = -1;
             }
-            onSuccess();
-        }
-    }
 
-    @VisibleForTesting
-    protected Executor getFetchSeedExecutor() {
-        return AsyncTask.THREAD_POOL_EXECUTOR;
+        } else {
+            // Task failed: Call onFailure(), and reach terminal state.
+            onFailure(failureCause);
+            mNumPendingSuccesses = -1;
+        }
     }
 
     @VisibleForTesting
@@ -180,6 +196,7 @@ public abstract class AsyncInitTaskRunner {
 
     /**
      * Handle failed completion of the Async initialization tasks.
+     * @param failureCause The Exception from the original failure.
      */
-    protected abstract void onFailure();
+    protected abstract void onFailure(Exception failureCause);
 }
