@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -14,8 +14,8 @@ import android.widget.RelativeLayout;
 import android.widget.TextView;
 
 import org.chromium.chrome.R;
-import org.chromium.chrome.browser.ntp.ForeignSessionHelper.ForeignSession;
-import org.chromium.chrome.browser.widget.TintedDrawable;
+import org.chromium.chrome.browser.recent_tabs.ForeignSessionHelper.ForeignSession;
+import org.chromium.components.browser_ui.widget.TintedDrawable;
 
 /**
  * Header view shown above each group of items on the Recent Tabs page. Shows the name of the
@@ -55,9 +55,9 @@ public class RecentTabsGroupView extends RelativeLayout {
         LevelListDrawable collapseIcon = new LevelListDrawable();
         collapseIcon.addLevel(DRAWABLE_LEVEL_COLLAPSED, DRAWABLE_LEVEL_COLLAPSED,
                 TintedDrawable.constructTintedDrawable(
-                        getResources(), R.drawable.ic_expand_more_black_24dp));
+                        getContext(), R.drawable.ic_expand_more_black_24dp));
         TintedDrawable collapse = TintedDrawable.constructTintedDrawable(
-                getResources(), R.drawable.ic_expand_less_black_24dp);
+                getContext(), R.drawable.ic_expand_less_black_24dp);
         collapseIcon.addLevel(DRAWABLE_LEVEL_EXPANDED, DRAWABLE_LEVEL_EXPANDED, collapse);
         mExpandCollapseIcon.setImageDrawable(collapseIcon);
     }
@@ -111,9 +111,9 @@ public class RecentTabsGroupView extends RelativeLayout {
     }
 
     private void setGroupViewHeight(boolean isTimeLabelVisible) {
-        mRow.getLayoutParams().height = getResources().getDimensionPixelOffset(isTimeLabelVisible
+        mRow.setMinimumHeight(getResources().getDimensionPixelOffset(isTimeLabelVisible
                         ? R.dimen.recent_tabs_foreign_session_group_item_height
-                        : R.dimen.recent_tabs_default_group_item_height);
+                        : R.dimen.recent_tabs_default_group_item_height));
     }
 
     private CharSequence getTimeString(ForeignSession session) {
