@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -8,7 +8,6 @@ import android.app.Activity;
 import android.content.res.Resources;
 import android.graphics.Canvas;
 import android.graphics.Color;
-import android.os.SystemClock;
 import android.view.ContextMenu;
 import android.view.ContextMenu.ContextMenuInfo;
 import android.view.LayoutInflater;
@@ -16,40 +15,34 @@ import android.view.View;
 import android.view.ViewGroup;
 import android.widget.ExpandableListView;
 
-import org.chromium.base.ActivityState;
-import org.chromium.base.ApiCompatibilityUtils;
-import org.chromium.base.ApplicationStatus;
-import org.chromium.base.metrics.RecordHistogram;
 import org.chromium.chrome.R;
-import org.chromium.chrome.browser.ChromeActivity;
-import org.chromium.chrome.browser.NativePage;
-import org.chromium.chrome.browser.UrlConstants;
+import org.chromium.chrome.browser.browser_controls.BrowserControlsStateProvider;
 import org.chromium.chrome.browser.compositor.layouts.content.InvalidationAwareThumbnailProvider;
-import org.chromium.chrome.browser.metrics.StartupMetrics;
-import org.chromium.chrome.browser.util.ColorUtils;
-import org.chromium.chrome.browser.util.FeatureUtilities;
-import org.chromium.chrome.browser.util.ViewUtils;
-
-import java.util.concurrent.TimeUnit;
+import org.chromium.chrome.browser.ui.native_page.NativePage;
+import org.chromium.chrome.browser.ui.native_page.NativePageHost;
+import org.chromium.components.embedder_support.util.UrlConstants;
+import org.chromium.ui.base.DeviceFormFactor;
+import org.chromium.ui.base.ViewUtils;
 
 /**
  * The native recent tabs page. Lists recently closed tabs, open windows and tabs from the user's
  * synced devices, and snapshot documents sent from Chrome to Mobile in an expandable list view.
  */
 public class RecentTabsPage
-        implements NativePage, ApplicationStatus.ActivityStateListener,
-                   ExpandableListView.OnChildClickListener,
+        implements NativePage, ExpandableListView.OnChildClickListener,
                    ExpandableListView.OnGroupCollapseListener,
                    ExpandableListView.OnGroupExpandListener, RecentTabsManager.UpdatedCallback,
                    View.OnAttachStateChangeListener, View.OnCreateContextMenuListener,
-                   InvalidationAwareThumbnailProvider {
+                   InvalidationAwareThumbnailProvider, BrowserControlsStateProvider.Observer {
     private final Activity mActivity;
+    private final BrowserControlsStateProvider mBrowserControlsStateProvider;
     private final ExpandableListView mListView;
     private final String mTitle;
     private final ViewGroup mView;
 
     private RecentTabsManager mRecentTabsManager;
     private RecentTabsRowAdapter mAdapter;
+    private NativePageHost mPageHost;
 
     private boolean mSnapshotContentChanged;
     private int mSnapshotListPosition;
@@ -57,32 +50,24 @@ public class RecentTabsPage
     private int mSnapshotWidth;
     private int mSnapshotHeight;
 
-    /**
-     * Whether the page is in the foreground and is visible.
-     */
-    private boolean mInForeground;
-
     /**
      * Whether {@link #mView} is attached to the application window.
      */
     private boolean mIsAttachedToWindow;
 
-    /**
-     * The time, whichever is most recent, that the page:
-     * - Moved to the foreground
-     * - Became visible
-     */
-    private long mForegroundTimeMs;
-
     /**
      * Constructor returns an instance of RecentTabsPage.
      *
      * @param activity The activity this view belongs to.
      * @param recentTabsManager The RecentTabsManager which provides the model data.
+     * @param pageHost The NativePageHost used to provide a history navigation delegate object.
+     * @param browserControlsManager The BrowserControlsManager used to provide offset values.
      */
-    public RecentTabsPage(ChromeActivity activity, RecentTabsManager recentTabsManager) {
+    public RecentTabsPage(Activity activity, RecentTabsManager recentTabsManager,
+            NativePageHost pageHost, BrowserControlsStateProvider browserControlsStateProvider) {
         mActivity = activity;
         mRecentTabsManager = recentTabsManager;
+        mPageHost = pageHost;
         Resources resources = activity.getResources();
 
         mTitle = resources.getString(R.string.recent_tabs);
@@ -99,43 +84,19 @@ public class RecentTabsPage
         mListView.setOnCreateContextMenuListener(this);
 
         mView.addOnAttachStateChangeListener(this);
-        ApplicationStatus.registerStateListenerForActivity(this, activity);
-        // {@link #mInForeground} will be updated once the view is attached to the window.
 
-        View recentTabsRoot = mView.findViewById(R.id.recent_tabs_root);
-        if (activity.getFullscreenManager().getBottomControlsHeight() != 0) {
-            ApiCompatibilityUtils.setPaddingRelative(recentTabsRoot,
-                    ApiCompatibilityUtils.getPaddingStart(recentTabsRoot), 0,
-                    ApiCompatibilityUtils.getPaddingEnd(recentTabsRoot),
-                    activity.getFullscreenManager().getBottomControlsHeight());
+        if (!DeviceFormFactor.isNonMultiDisplayContextOnTablet(mActivity)) {
+            mBrowserControlsStateProvider = browserControlsStateProvider;
+            mBrowserControlsStateProvider.addObserver(this);
+            onBottomControlsHeightChanged(mBrowserControlsStateProvider.getBottomControlsHeight(),
+                    mBrowserControlsStateProvider.getBottomControlsMinHeight());
+        } else {
+            mBrowserControlsStateProvider = null;
         }
 
         onUpdated();
     }
 
-    /**
-     * Updates whether the page is in the foreground based on whether the application is in the
-     * foreground and whether {@link #mView} is attached to the application window. If the page is
-     * no longer in the foreground, records the time that the page spent in the foreground to UMA.
-     */
-    private void updateForegroundState() {
-        boolean inForeground = mIsAttachedToWindow
-                && ApplicationStatus.getStateForActivity(mActivity) == ActivityState.RESUMED;
-        if (mInForeground == inForeground) {
-            return;
-        }
-
-        mInForeground = inForeground;
-        if (mInForeground) {
-            mForegroundTimeMs = SystemClock.elapsedRealtime();
-            StartupMetrics.getInstance().recordOpenedRecents();
-            mRecentTabsManager.recordRecentTabMetrics();
-        } else {
-            RecordHistogram.recordLongTimesHistogram("NewTabPage.RecentTabsPage.TimeVisibleAndroid",
-                    SystemClock.elapsedRealtime() - mForegroundTimeMs, TimeUnit.MILLISECONDS);
-        }
-    }
-
     // NativePage overrides
 
     @Override
@@ -153,12 +114,6 @@ public class RecentTabsPage
         return Color.WHITE;
     }
 
-    @Override
-    public int getThemeColor() {
-        return ColorUtils.getDefaultThemeColor(
-                mActivity.getResources(), FeatureUtilities.isChromeModernDesignEnabled(), false);
-    }
-
     @Override
     public boolean needsToolbarShadow() {
         return true;
@@ -179,45 +134,38 @@ public class RecentTabsPage
         assert !mIsAttachedToWindow : "Destroy called before removed from window";
         mRecentTabsManager.destroy();
         mRecentTabsManager = null;
+        mPageHost = null;
         mAdapter.notifyDataSetInvalidated();
         mAdapter = null;
         mListView.setAdapter((RecentTabsRowAdapter) null);
 
         mView.removeOnAttachStateChangeListener(this);
-        ApplicationStatus.unregisterActivityStateListener(this);
+        if (mBrowserControlsStateProvider != null) {
+            mBrowserControlsStateProvider.removeObserver(this);
+        }
     }
 
     @Override
     public void updateForUrl(String url) {
     }
 
-    // ApplicationStatus.ActivityStateListener
-    @Override
-    public void onActivityStateChange(Activity activity, int state) {
-        // Called when the user locks the screen or moves Chrome to the background via the task
-        // switcher.
-        updateForegroundState();
-    }
-
     // View.OnAttachStateChangeListener
     @Override
     public void onViewAttachedToWindow(View view) {
         // Called when the user opens the RecentTabsPage or switches back to the RecentTabsPage from
         // another tab.
         mIsAttachedToWindow = true;
-        updateForegroundState();
 
         // Work around a bug on Samsung devices where the recent tabs page does not appear after
         // toggling the Sync quick setting.  For some reason, the layout is being dropped on the
         // flow and we need to force a root level layout to get the UI to appear.
-        view.getRootView().requestLayout();
+        ViewUtils.requestLayout(view.getRootView(), "RecentTabsPage.onViewAttachedToWindow");
     }
 
     @Override
     public void onViewDetachedFromWindow(View view) {
         // Called when the user navigates from the RecentTabsPage or switches to another tab.
         mIsAttachedToWindow = false;
-        updateForegroundState();
     }
 
     // ExpandableListView.OnChildClickedListener
@@ -299,4 +247,49 @@ public class RecentTabsPage
         mSnapshotWidth = mView.getWidth();
         mSnapshotHeight = mView.getHeight();
     }
+
+    @Override
+    public void onBottomControlsHeightChanged(
+            int bottomControlsHeight, int bottomControlsMinHeight) {
+        updateMargins();
+    }
+
+    @Override
+    public void onTopControlsHeightChanged(int topControlsHeight, int topControlsMinHeight) {
+        updateMargins();
+    }
+
+    @Override
+    public void onControlsOffsetChanged(int topOffset, int topControlsMinHeightOffset,
+            int bottomOffset, int bottomControlsMinHeightOffset, boolean needsAnimate) {
+        updateMargins();
+    }
+
+    private void updateMargins() {
+        final View recentTabsRoot = mView.findViewById(R.id.recent_tabs_root);
+        final int topControlsHeight = mBrowserControlsStateProvider.getTopControlsHeight();
+        final int contentOffset = mBrowserControlsStateProvider.getContentOffset();
+        ViewGroup.MarginLayoutParams layoutParams =
+                (ViewGroup.MarginLayoutParams) recentTabsRoot.getLayoutParams();
+        int topMargin = layoutParams.topMargin;
+
+        // If the top controls are at the resting position or their height is decreasing, we want to
+        // update the margin. We don't do this if the controls height is increasing because changing
+        // the margin shrinks the view height to its final value, leaving a gap at the bottom until
+        // the animation finishes.
+        if (contentOffset >= topControlsHeight) {
+            topMargin = topControlsHeight;
+        }
+
+        // If the content offset is different from the margin, we use translationY to position the
+        // view in line with the content offset.
+        recentTabsRoot.setTranslationY(contentOffset - topMargin);
+
+        final int bottomMargin = mBrowserControlsStateProvider.getBottomControlsHeight();
+        if (topMargin != layoutParams.topMargin || bottomMargin != layoutParams.bottomMargin) {
+            layoutParams.topMargin = topMargin;
+            layoutParams.bottomMargin = bottomMargin;
+            recentTabsRoot.setLayoutParams(layoutParams);
+        }
+    }
 }
