@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -8,11 +8,10 @@ import android.app.Activity;
 import android.content.res.Resources;
 import android.graphics.Bitmap;
 import android.graphics.BitmapFactory;
-import android.graphics.drawable.BitmapDrawable;
+import android.graphics.PorterDuff;
 import android.graphics.drawable.Drawable;
-import android.support.v4.graphics.drawable.RoundedBitmapDrawable;
-import android.support.v4.graphics.drawable.RoundedBitmapDrawableFactory;
 import android.text.TextUtils;
+import android.util.ArrayMap;
 import android.util.LruCache;
 import android.view.ContextMenu;
 import android.view.LayoutInflater;
@@ -23,64 +22,107 @@ import android.widget.BaseExpandableListAdapter;
 import android.widget.ImageView;
 import android.widget.TextView;
 
-import org.chromium.base.ApiCompatibilityUtils;
+import androidx.annotation.IntDef;
+
 import org.chromium.base.metrics.RecordHistogram;
 import org.chromium.chrome.R;
-import org.chromium.chrome.browser.favicon.FaviconHelper.FaviconImageCallback;
-import org.chromium.chrome.browser.ntp.ForeignSessionHelper.ForeignSession;
-import org.chromium.chrome.browser.ntp.ForeignSessionHelper.ForeignSessionTab;
-import org.chromium.chrome.browser.ntp.ForeignSessionHelper.ForeignSessionWindow;
-import org.chromium.chrome.browser.signin.PersonalizedSigninPromoView;
-import org.chromium.chrome.browser.signin.SigninAccessPoint;
-import org.chromium.chrome.browser.signin.SyncPromoView;
-import org.chromium.chrome.browser.util.FeatureUtilities;
-import org.chromium.chrome.browser.util.UrlUtilities;
-import org.chromium.chrome.browser.widget.RoundedIconGenerator;
+import org.chromium.chrome.browser.recent_tabs.ForeignSessionHelper.ForeignSession;
+import org.chromium.chrome.browser.recent_tabs.ForeignSessionHelper.ForeignSessionTab;
+import org.chromium.chrome.browser.recent_tabs.ForeignSessionHelper.ForeignSessionWindow;
+import org.chromium.chrome.browser.signin.LegacySyncPromoView;
+import org.chromium.chrome.browser.ui.favicon.FaviconHelper.DefaultFaviconHelper;
+import org.chromium.chrome.browser.ui.favicon.FaviconHelper.FaviconImageCallback;
+import org.chromium.chrome.browser.ui.favicon.FaviconUtils;
+import org.chromium.chrome.browser.ui.signin.SyncPromoController.SyncPromoState;
+import org.chromium.components.browser_ui.styles.SemanticColorUtils;
+import org.chromium.components.browser_ui.widget.RoundedIconGenerator;
+import org.chromium.components.embedder_support.util.UrlUtilities;
+import org.chromium.components.signin.metrics.SigninAccessPoint;
 import org.chromium.ui.base.DeviceFormFactor;
 import org.chromium.ui.mojom.WindowOpenDisposition;
+import org.chromium.url.GURL;
 
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
+import java.text.DateFormat;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Locale;
+import java.util.Map;
 
 /**
  * Row adapter for presenting recently closed tabs, synced tabs from other devices, the sync or
  * sign in promo, and currently open tabs (only in document mode) in a grouped list view.
  */
 public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
-    private static final int MAX_NUM_FAVICONS_TO_CACHE = 256;
+    private static final int MAX_NUM_FAVICONS_TO_CACHE = 128;
 
-    private enum ChildType {
-        NONE,
-        DEFAULT_CONTENT,
-        PERSONALIZED_SIGNIN_PROMO,
-        SYNC_PROMO
+    @IntDef({ChildType.NONE, ChildType.DEFAULT_CONTENT, ChildType.PERSONALIZED_SIGNIN_PROMO,
+            ChildType.PERSONALIZED_SYNC_PROMO, ChildType.SYNC_PROMO})
+    @Retention(RetentionPolicy.SOURCE)
+    private @interface ChildType {
+        // Values should be enumerated from 0 and can't have gaps.
+        int NONE = 0;
+        int DEFAULT_CONTENT = 1;
+        int PERSONALIZED_SIGNIN_PROMO = 2;
+        int PERSONALIZED_SYNC_PROMO = 3;
+        int SYNC_PROMO = 4;
+        /**
+         * Number of entries.
+         */
+        int NUM_ENTRIES = 5;
     }
 
-    private enum GroupType {
-        CONTENT, VISIBLE_SEPARATOR, INVISIBLE_SEPARATOR
+    @IntDef({GroupType.CONTENT, GroupType.VISIBLE_SEPARATOR, GroupType.INVISIBLE_SEPARATOR})
+    @Retention(RetentionPolicy.SOURCE)
+    private @interface GroupType {
+        // Values should be enumerated from 0 and can't have gaps.
+        int CONTENT = 0;
+        int VISIBLE_SEPARATOR = 1;
+        int INVISIBLE_SEPARATOR = 2;
+        /**
+         * Number of entries.
+         */
+        int NUM_ENTRIES = 3;
     }
 
     // Values from the OtherSessionsActions enum in histograms.xml; do not change these values or
     // histograms will be broken.
-    private static class OtherSessionsActions {
-        static final int MENU_INITIALIZED = 0;
-        static final int LINK_CLICKED = 2;
-        static final int COLLAPSE_SESSION = 6;
-        static final int EXPAND_SESSION = 7;
-        static final int OPEN_ALL = 8;
-        static final int HAS_FOREIGN_DATA = 9;
-        static final int HIDE_FOR_NOW = 10;
-        static final int LIMIT = 11;
+    @IntDef({OtherSessionsActions.MENU_INITIALIZED, OtherSessionsActions.LINK_CLICKED,
+            OtherSessionsActions.COLLAPSE_SESSION, OtherSessionsActions.EXPAND_SESSION,
+            OtherSessionsActions.OPEN_ALL, OtherSessionsActions.HAS_FOREIGN_DATA,
+            OtherSessionsActions.HIDE_FOR_NOW})
+    @Retention(RetentionPolicy.SOURCE)
+    private @interface OtherSessionsActions {
+        int MENU_INITIALIZED = 0;
+        int LINK_CLICKED = 2;
+        int COLLAPSE_SESSION = 6;
+        int EXPAND_SESSION = 7;
+        int OPEN_ALL = 8;
+        int HAS_FOREIGN_DATA = 9;
+        int HIDE_FOR_NOW = 10;
+
+        int NUM_ENTRIES = 11;
+    }
+
+    @IntDef({FaviconLocality.LOCAL, FaviconLocality.FOREIGN})
+    @Retention(RetentionPolicy.SOURCE)
+    private @interface FaviconLocality {
+        int LOCAL = 0;
+        int FOREIGN = 1;
+
+        int NUM_ENTRIES = 2;
     }
 
     private final Activity mActivity;
     private final List<Group> mGroups;
-    private final Drawable mDefaultFavicon;
+    private final DefaultFaviconHelper mDefaultFaviconHelper;
     private final RecentTabsManager mRecentTabsManager;
     private final RecentlyClosedTabsGroup mRecentlyClosedTabsGroup = new RecentlyClosedTabsGroup();
     private final SeparatorGroup mVisibleSeparatorGroup = new SeparatorGroup(true);
     private final SeparatorGroup mInvisibleSeparatorGroup = new SeparatorGroup(false);
-    private final FaviconCache mFaviconCache;
+    private final Map<Integer, FaviconCache> mFaviconCaches =
+            new ArrayMap<>(FaviconLocality.NUM_ENTRIES);
     private final int mFaviconSize;
     private boolean mHasForeignDataRecorded;
     private RoundedIconGenerator mIconGenerator;
@@ -93,7 +135,7 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         /**
          * @return The type of group: GroupType.CONTENT or GroupType.SEPARATOR.
          */
-        abstract GroupType getGroupType();
+        abstract @GroupType int getGroupType();
 
         /**
          * @return The number of children in this group.
@@ -103,7 +145,7 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         /**
          * @return The child type.
          */
-        abstract ChildType getChildType();
+        abstract @ChildType int getChildType();
 
         /**
          * @param childPosition The position for which to return the child.
@@ -135,9 +177,6 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
                 viewHolder.domainView = (TextView) childView.findViewById(R.id.domain_row);
                 viewHolder.imageView = (ImageView) childView.findViewById(R.id.recent_tabs_favicon);
                 viewHolder.imageView.setBackgroundResource(R.drawable.list_item_icon_modern_bg);
-                if (!FeatureUtilities.isChromeModernDesignEnabled()) {
-                    viewHolder.imageView.getBackground().setAlpha(0);
-                }
                 viewHolder.itemLayout = childView.findViewById(R.id.recent_tabs_list_item_layout);
                 childView.setTag(viewHolder);
             }
@@ -232,7 +271,7 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         }
 
         @Override
-        public GroupType getGroupType() {
+        public @GroupType int getGroupType() {
             return GroupType.CONTENT;
         }
 
@@ -246,7 +285,7 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         }
 
         @Override
-        public ChildType getChildType() {
+        public @ChildType int getChildType() {
             return ChildType.DEFAULT_CONTENT;
         }
 
@@ -265,9 +304,10 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         @Override
         public void configureChildView(int childPosition, ViewHolder viewHolder) {
             ForeignSessionTab sessionTab = getChild(childPosition);
-            String text = TextUtils.isEmpty(sessionTab.title) ? sessionTab.url : sessionTab.title;
+            String url = sessionTab.url.getSpec();
+            String text = TextUtils.isEmpty(sessionTab.title) ? url : sessionTab.title;
             viewHolder.textView.setText(text);
-            String domain = UrlUtilities.getDomainAndRegistry(sessionTab.url, false);
+            String domain = UrlUtilities.getDomainAndRegistry(url, false);
             if (!TextUtils.isEmpty(domain)) {
                 viewHolder.domainView.setText(domain);
                 viewHolder.domainView.setVisibility(View.VISIBLE);
@@ -275,7 +315,7 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
                 viewHolder.domainView.setText("");
                 viewHolder.domainView.setVisibility(View.GONE);
             }
-            loadSyncedFavicon(viewHolder, sessionTab.url);
+            loadFavicon(viewHolder, sessionTab.url, FaviconLocality.FOREIGN);
         }
 
         @Override
@@ -287,10 +327,10 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         public void setCollapsed(boolean isCollapsed) {
             if (isCollapsed) {
                 RecordHistogram.recordEnumeratedHistogram("HistoryPage.OtherDevicesMenu",
-                        OtherSessionsActions.COLLAPSE_SESSION, OtherSessionsActions.LIMIT);
+                        OtherSessionsActions.COLLAPSE_SESSION, OtherSessionsActions.NUM_ENTRIES);
             } else {
                 RecordHistogram.recordEnumeratedHistogram("HistoryPage.OtherDevicesMenu",
-                        OtherSessionsActions.EXPAND_SESSION, OtherSessionsActions.LIMIT);
+                        OtherSessionsActions.EXPAND_SESSION, OtherSessionsActions.NUM_ENTRIES);
             }
             mRecentTabsManager.setForeignSessionCollapsed(mForeignSession, isCollapsed);
         }
@@ -303,7 +343,7 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         @Override
         public boolean onChildClick(int childPosition) {
             RecordHistogram.recordEnumeratedHistogram("HistoryPage.OtherDevicesMenu",
-                    OtherSessionsActions.LINK_CLICKED, OtherSessionsActions.LIMIT);
+                    OtherSessionsActions.LINK_CLICKED, OtherSessionsActions.NUM_ENTRIES);
             ForeignSessionTab foreignSessionTab = getChild(childPosition);
             mRecentTabsManager.openForeignSessionTab(mForeignSession, foreignSessionTab,
                     WindowOpenDisposition.CURRENT_TAB);
@@ -314,13 +354,13 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         public void onCreateContextMenuForGroup(ContextMenu menu, Activity activity) {
             menu.add(R.string.recent_tabs_open_all_menu_option).setOnMenuItemClickListener(item -> {
                 RecordHistogram.recordEnumeratedHistogram("HistoryPage.OtherDevicesMenu",
-                        OtherSessionsActions.OPEN_ALL, OtherSessionsActions.LIMIT);
+                        OtherSessionsActions.OPEN_ALL, OtherSessionsActions.NUM_ENTRIES);
                 openAllTabs();
                 return true;
             });
             menu.add(R.string.recent_tabs_hide_menu_option).setOnMenuItemClickListener(item -> {
                 RecordHistogram.recordEnumeratedHistogram("HistoryPage.OtherDevicesMenu",
-                        OtherSessionsActions.HIDE_FOR_NOW, OtherSessionsActions.LIMIT);
+                        OtherSessionsActions.HIDE_FOR_NOW, OtherSessionsActions.NUM_ENTRIES);
                 mRecentTabsManager.deleteForeignSession(mForeignSession);
                 return true;
             });
@@ -364,7 +404,8 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
      */
     private abstract class PromoGroup extends Group {
         @Override
-        GroupType getGroupType() {
+        @GroupType
+        int getGroupType() {
             return GroupType.CONTENT;
         }
 
@@ -389,13 +430,22 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         }
     }
 
-    /**
-     * A group containing the personalized signin promo.
-     */
-    class PersonalizedSigninPromoGroup extends PromoGroup {
+    /** A group containing the personalized sync promo. */
+    class PersonalizedSyncPromoGroup extends PromoGroup {
+        private final @ChildType int mChildType;
+
+        PersonalizedSyncPromoGroup(@ChildType int childType) {
+            assert childType == ChildType.PERSONALIZED_SIGNIN_PROMO
+                    || childType
+                            == ChildType.PERSONALIZED_SYNC_PROMO : "Unsupported child type:"
+                                    + childType;
+            mChildType = childType;
+        }
+
         @Override
-        ChildType getChildType() {
-            return ChildType.PERSONALIZED_SIGNIN_PROMO;
+        @ChildType
+        int getChildType() {
+            return mChildType;
         }
 
         @Override
@@ -403,11 +453,11 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
                 int childPosition, boolean isLastChild, View convertView, ViewGroup parent) {
             if (convertView == null) {
                 LayoutInflater layoutInflater = LayoutInflater.from(parent.getContext());
-                convertView = layoutInflater.inflate(
-                        R.layout.personalized_signin_promo_view_recent_tabs, parent, false);
+                convertView =
+                        layoutInflater.inflate(R.layout.sync_promo_view_recent_tabs, parent, false);
             }
-            mRecentTabsManager.setupPersonalizedSigninPromo(
-                    (PersonalizedSigninPromoView) convertView);
+            mRecentTabsManager.setUpSyncPromoView(
+                    convertView.findViewById(R.id.signin_promo_view_container));
             return convertView;
         }
     }
@@ -417,7 +467,7 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
      */
     class SyncPromoGroup extends PromoGroup {
         @Override
-        public ChildType getChildType() {
+        public @ChildType int getChildType() {
             return ChildType.SYNC_PROMO;
         }
 
@@ -425,7 +475,7 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         View getChildView(
                 int childPosition, boolean isLastChild, View convertView, ViewGroup parent) {
             if (convertView == null) {
-                convertView = SyncPromoView.create(parent, SigninAccessPoint.RECENT_TABS);
+                convertView = LegacySyncPromoView.create(parent, SigninAccessPoint.RECENT_TABS);
             }
             return convertView;
         }
@@ -440,7 +490,7 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         static final int ID_REMOVE_ALL = 2;
 
         @Override
-        public GroupType getGroupType() {
+        public @GroupType int getGroupType() {
             return GroupType.CONTENT;
         }
 
@@ -448,11 +498,11 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         public int getChildrenCount() {
             // The number of children is the number of recently closed tabs, plus one for the "Show
             // full history" item.
-            return 1 + mRecentTabsManager.getRecentlyClosedTabs().size();
+            return 1 + mRecentTabsManager.getRecentlyClosedEntries().size();
         }
 
         @Override
-        public ChildType getChildType() {
+        public @ChildType int getChildType() {
             return ChildType.DEFAULT_CONTENT;
         }
 
@@ -461,15 +511,13 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
          * @return Whether the item at childPosition is the link to the history page.
          */
         private boolean isHistoryLink(int childPosition) {
-            return childPosition == mRecentTabsManager.getRecentlyClosedTabs().size();
+            return childPosition == mRecentTabsManager.getRecentlyClosedEntries().size();
         }
 
         @Override
-        public RecentlyClosedTab getChild(int childPosition) {
-            if (isHistoryLink(childPosition)) {
-                return null;
-            }
-            return mRecentTabsManager.getRecentlyClosedTabs().get(childPosition);
+        public RecentlyClosedEntry getChild(int childPosition) {
+            if (isHistoryLink(childPosition)) return null;
+            return mRecentTabsManager.getRecentlyClosedEntries().get(childPosition);
         }
 
         @Override
@@ -478,32 +526,85 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
             // lead to wrong pairings of domain & title texts.
             viewHolder.domainView.setText("");
             viewHolder.domainView.setVisibility(View.GONE);
+            // Reset content description.
+            viewHolder.textView.setContentDescription(null);
             if (isHistoryLink(childPosition)) {
                 viewHolder.textView.setText(R.string.show_full_history);
                 Bitmap historyIcon = BitmapFactory.decodeResource(
                         mActivity.getResources(), R.drawable.ic_watch_later_24dp);
-                Drawable drawable = getRoundedFavicon(historyIcon,
-                        mActivity.getResources().getDimensionPixelSize(
-                                R.dimen.tile_view_icon_size_modern));
+                int size = mActivity.getResources().getDimensionPixelSize(
+                        R.dimen.tile_view_icon_size_modern);
+                Drawable drawable =
+                        FaviconUtils.createRoundedBitmapDrawable(mActivity.getResources(),
+                                Bitmap.createScaledBitmap(historyIcon, size, size, true));
+                drawable.setColorFilter(
+                        SemanticColorUtils.getDefaultIconColor(mActivity), PorterDuff.Mode.SRC_IN);
                 viewHolder.imageView.setImageDrawable(drawable);
-                viewHolder.itemLayout.getLayoutParams().height =
+                viewHolder.itemLayout.setMinimumHeight(
                         mActivity.getResources().getDimensionPixelSize(
-                                R.dimen.recent_tabs_show_history_item_size);
+                                R.dimen.recent_tabs_show_history_item_size));
                 return;
             }
-            viewHolder.itemLayout.getLayoutParams().height =
-                    mActivity.getResources().getDimensionPixelSize(
-                            R.dimen.recent_tabs_foreign_session_group_item_height);
-            RecentlyClosedTab tab = getChild(childPosition);
-            String title = TitleUtil.getTitleForDisplay(tab.title, tab.url);
-            viewHolder.textView.setText(title);
+            viewHolder.itemLayout.setMinimumHeight(mActivity.getResources().getDimensionPixelSize(
+                    R.dimen.recent_tabs_foreign_session_group_item_height));
+            RecentlyClosedEntry entry = getChild(childPosition);
+            if (!(entry instanceof RecentlyClosedTab)) {
+                int tabCount = 0;
+                if (entry instanceof RecentlyClosedGroup) {
+                    RecentlyClosedGroup recentlyClosedGroup = (RecentlyClosedGroup) entry;
+                    tabCount = recentlyClosedGroup.getTabs().size();
 
-            String domain = UrlUtilities.getDomainAndRegistry(tab.url, false);
-            if (!TextUtils.isEmpty(domain)) {
-                viewHolder.domainView.setText(domain);
-                viewHolder.domainView.setVisibility(View.VISIBLE);
+                    String groupTitle = recentlyClosedGroup.getTitle();
+                    if (TextUtils.isEmpty(groupTitle)) {
+                        viewHolder.textView.setText(mActivity.getResources().getString(
+                                R.string.recent_tabs_group_closure_without_title, tabCount));
+                        String contentDescription = mActivity.getResources().getString(
+                                R.string.recent_tabs_group_closure_without_title_accessibility,
+                                tabCount);
+                        viewHolder.textView.setContentDescription(contentDescription);
+                    } else {
+                        viewHolder.textView.setText(mActivity.getResources().getString(
+                                R.string.recent_tabs_group_closure_with_title, groupTitle));
+                        viewHolder.textView.setContentDescription(
+                                mActivity.getResources().getString(
+                                        R.string.recent_tabs_group_closure_with_title_accessibility,
+                                        groupTitle));
+                    }
+                }
+                if (entry instanceof RecentlyClosedBulkEvent) {
+                    RecentlyClosedBulkEvent recentlyClosedBulkEvent =
+                            (RecentlyClosedBulkEvent) entry;
+                    tabCount = recentlyClosedBulkEvent.getTabs().size();
+
+                    viewHolder.textView.setText(mActivity.getResources().getString(
+                            R.string.recent_tabs_bulk_closure, tabCount));
+                    viewHolder.textView.setContentDescription(mActivity.getResources().getString(
+                            R.string.recent_tabs_bulk_closure_accessibility, tabCount));
+                }
+
+                // Entries without dates have a time of 0. TabRestoreService may not save timestamps
+                // between restarts.
+                if (entry.getDate().getTime() != 0L) {
+                    String dateString =
+                            DateFormat.getDateInstance(DateFormat.LONG, getPreferredLocale())
+                                    .format(entry.getDate());
+                    viewHolder.domainView.setText(dateString);
+                    viewHolder.domainView.setVisibility(View.VISIBLE);
+                }
+                loadTabCount(viewHolder, tabCount);
+            } else {
+                RecentlyClosedTab tab = (RecentlyClosedTab) entry;
+
+                String title = TitleUtil.getTitleForDisplay(tab.getTitle(), tab.getUrl());
+                viewHolder.textView.setText(title);
+
+                String domain = UrlUtilities.getDomainAndRegistry(tab.getUrl().getSpec(), false);
+                if (!TextUtils.isEmpty(domain)) {
+                    viewHolder.domainView.setText(domain);
+                    viewHolder.domainView.setVisibility(View.VISIBLE);
+                }
+                loadFavicon(viewHolder, tab.getUrl(), FaviconLocality.LOCAL);
             }
-            loadLocalFavicon(viewHolder, tab.url);
         }
 
         @Override
@@ -525,10 +626,15 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         public boolean onChildClick(int childPosition) {
             if (isHistoryLink(childPosition)) {
                 mRecentTabsManager.openHistoryPage();
-            } else {
-                mRecentTabsManager.openRecentlyClosedTab(getChild(childPosition),
-                        WindowOpenDisposition.CURRENT_TAB);
+                return true;
             }
+            RecentlyClosedEntry entry = getChild(childPosition);
+            if (entry instanceof RecentlyClosedTab) {
+                mRecentTabsManager.openRecentlyClosedTab(
+                        (RecentlyClosedTab) entry, WindowOpenDisposition.CURRENT_TAB);
+                return true;
+            }
+            mRecentTabsManager.openRecentlyClosedEntry(entry);
             return true;
         }
 
@@ -539,24 +645,28 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         @Override
         public void onCreateContextMenuForChild(final int childPosition, ContextMenu menu,
                 Activity activity) {
-            final RecentlyClosedTab recentlyClosedTab = getChild(childPosition);
-            if (recentlyClosedTab == null) return;
+            final RecentlyClosedEntry recentlyClosedEntry = getChild(childPosition);
+            if (recentlyClosedEntry == null) return;
             OnMenuItemClickListener listener = item -> {
                 switch (item.getItemId()) {
                     case ID_REMOVE_ALL:
-                        mRecentTabsManager.clearRecentlyClosedTabs();
+                        mRecentTabsManager.clearRecentlyClosedEntries();
                         break;
                     case ID_OPEN_IN_NEW_TAB:
                         mRecentTabsManager.openRecentlyClosedTab(
-                                recentlyClosedTab, WindowOpenDisposition.NEW_BACKGROUND_TAB);
+                                (RecentlyClosedTab) recentlyClosedEntry,
+                                WindowOpenDisposition.NEW_BACKGROUND_TAB);
                         break;
                     default:
                         assert false;
                 }
                 return true;
             };
-            menu.add(ContextMenu.NONE, ID_OPEN_IN_NEW_TAB, ContextMenu.NONE,
-                    R.string.contextmenu_open_in_new_tab).setOnMenuItemClickListener(listener);
+            if (recentlyClosedEntry instanceof RecentlyClosedTab) {
+                menu.add(ContextMenu.NONE, ID_OPEN_IN_NEW_TAB, ContextMenu.NONE,
+                            R.string.contextmenu_open_in_new_tab)
+                        .setOnMenuItemClickListener(listener);
+            }
             menu.add(ContextMenu.NONE, ID_REMOVE_ALL, ContextMenu.NONE,
                     R.string.remove_all).setOnMenuItemClickListener(listener);
         }
@@ -573,12 +683,12 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         }
 
         @Override
-        public GroupType getGroupType() {
+        public @GroupType int getGroupType() {
             return mIsVisible ? GroupType.VISIBLE_SEPARATOR : GroupType.INVISIBLE_SEPARATOR;
         }
 
         @Override
-        public ChildType getChildType() {
+        public @ChildType int getChildType() {
             return ChildType.NONE;
         }
 
@@ -613,34 +723,23 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
     }
 
     private static class FaviconCache {
-        private static final String SYNCED_FAVICON_PREFIX = "Synced";
-        private static final String LOCAL_FAVICON_PREFIX = "Local";
-
-        private final LruCache<String, Drawable> mMemoryCache;
+        private final LruCache<GURL, Drawable> mMemoryCache;
 
         public FaviconCache(int size) {
-            mMemoryCache = new LruCache<String, Drawable>(size);
+            mMemoryCache = new LruCache<>(size);
         }
 
-        public Drawable getSyncedFaviconImage(String url) {
-            return mMemoryCache.get(SYNCED_FAVICON_PREFIX + url);
+        Drawable getFaviconImage(GURL url) {
+            return mMemoryCache.get(url);
         }
 
-        public void putSyncedFaviconImage(String url, Drawable image) {
-            mMemoryCache.put(SYNCED_FAVICON_PREFIX + url, image);
-        }
-
-        public Drawable getLocalFaviconImage(String url) {
-            return mMemoryCache.get(LOCAL_FAVICON_PREFIX + url);
-        }
-
-        public void putLocalFaviconImage(String url, Drawable image) {
-            mMemoryCache.put(LOCAL_FAVICON_PREFIX + url, image);
+        public void putFaviconImage(GURL url, Drawable image) {
+            mMemoryCache.put(url, image);
         }
     }
 
     /**
-     * Creates an RecentTabsRowAdapter used to populate an ExpandableList with other
+     * Creates a RecentTabsRowAdapter used to populate an ExpandableList with other
      * devices and foreign tab cells.
      *
      * @param activity The Android activity this adapter will work in.
@@ -650,22 +749,17 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         mActivity = activity;
         mRecentTabsManager = recentTabsManager;
         mGroups = new ArrayList<>();
-        mFaviconCache = new FaviconCache(MAX_NUM_FAVICONS_TO_CACHE);
+        mFaviconCaches.put(FaviconLocality.LOCAL, new FaviconCache(MAX_NUM_FAVICONS_TO_CACHE));
+        mFaviconCaches.put(FaviconLocality.FOREIGN, new FaviconCache(MAX_NUM_FAVICONS_TO_CACHE));
 
         Resources resources = activity.getResources();
-        mDefaultFavicon = ApiCompatibilityUtils.getDrawable(resources, R.drawable.default_favicon);
+        mDefaultFaviconHelper = new DefaultFaviconHelper();
         mFaviconSize = resources.getDimensionPixelSize(R.dimen.default_favicon_size);
 
-        int cornerRadius = resources.getDimensionPixelSize(R.dimen.default_favicon_corner_radius);
-        int textSize = resources.getDimensionPixelSize(R.dimen.default_favicon_icon_text_size);
-        int iconColor =
-                ApiCompatibilityUtils.getColor(resources, R.color.default_favicon_background_color);
-        mIconGenerator = new RoundedIconGenerator(mFaviconSize, mFaviconSize,
-                FeatureUtilities.isChromeModernDesignEnabled() ? mFaviconSize / 2 : cornerRadius,
-                iconColor, textSize);
+        mIconGenerator = FaviconUtils.createCircularIconGenerator(activity);
 
         RecordHistogram.recordEnumeratedHistogram("HistoryPage.OtherDevicesMenu",
-                OtherSessionsActions.MENU_INITIALIZED, OtherSessionsActions.LIMIT);
+                OtherSessionsActions.MENU_INITIALIZED, OtherSessionsActions.NUM_ENTRIES);
     }
 
     /**
@@ -681,57 +775,46 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         public FaviconImageCallback imageCallback;
     }
 
-    private Drawable faviconDrawable(Bitmap image, String url) {
-        if (url == null) return null;
-        if (image == null) {
-            image = mIconGenerator.generateIconForUrl(url);
-            return new BitmapDrawable(mActivity.getResources(),
-                    Bitmap.createScaledBitmap(image, mFaviconSize, mFaviconSize, true));
-        }
-        return getRoundedFavicon(image, mFaviconSize);
-    }
-
-    private Drawable getRoundedFavicon(Bitmap image, int size) {
-        // TODO(injae): Move shared code between Bookmarks/History/Downloads/here to ViewUtils.java.
-        // Also applies to RoundedIconGenerator. crbug.com/829550
-        RoundedBitmapDrawable roundedIcon = RoundedBitmapDrawableFactory.create(
-                mActivity.getResources(), Bitmap.createScaledBitmap(image, size, size, true));
-        roundedIcon.setCornerRadius(mActivity.getResources().getDimensionPixelSize(
-                R.dimen.default_favicon_corner_radius));
-        return roundedIcon;
-    }
-
-    private void loadSyncedFavicon(final ViewHolder viewHolder, final String url) {
-        Drawable image = mFaviconCache.getSyncedFaviconImage(url);
-        if (image == null) {
-            image = faviconDrawable(mRecentTabsManager.getSyncedFaviconImageForURL(url), url);
-            image = (image == null) ? mDefaultFavicon : image;
-            mFaviconCache.putSyncedFaviconImage(url, image);
-        }
+    private void loadTabCount(final ViewHolder viewHolder, int tabCount) {
+        RecentTabCountDrawable image = new RecentTabCountDrawable(mActivity);
+        image.updateTabCount(tabCount);
         viewHolder.imageView.setImageDrawable(image);
     }
 
-    private void loadLocalFavicon(final ViewHolder viewHolder, final String url) {
+    private void loadFavicon(
+            final ViewHolder viewHolder, final GURL url, @FaviconLocality int locality) {
         Drawable image;
         if (url == null) {
             // URL is null for print jobs, for example.
-            image = mDefaultFavicon;
+            image = mDefaultFaviconHelper.getDefaultFaviconDrawable(
+                    mActivity.getResources(), url, true);
         } else {
-            image = mFaviconCache.getLocalFaviconImage(url);
+            image = mFaviconCaches.get(locality).getFaviconImage(url);
             if (image == null) {
                 FaviconImageCallback imageCallback = new FaviconImageCallback() {
                     @Override
-                    public void onFaviconAvailable(Bitmap bitmap, String iconUrl) {
+                    public void onFaviconAvailable(Bitmap bitmap, GURL iconUrl) {
                         if (this != viewHolder.imageCallback) return;
-                        Drawable image = faviconDrawable(bitmap, url);
-                        image = (image == null) ? mDefaultFavicon : image;
-                        mFaviconCache.putLocalFaviconImage(url, image);
-                        viewHolder.imageView.setImageDrawable(image);
+                        Drawable faviconDrawable = FaviconUtils.getIconDrawableWithFilter(bitmap,
+                                url, mIconGenerator, mDefaultFaviconHelper,
+                                mActivity.getResources(), mFaviconSize);
+                        mFaviconCaches.get(locality).putFaviconImage(url, faviconDrawable);
+                        viewHolder.imageView.setImageDrawable(faviconDrawable);
                     }
                 };
                 viewHolder.imageCallback = imageCallback;
-                mRecentTabsManager.getLocalFaviconForUrl(url, mFaviconSize, imageCallback);
-                image = mDefaultFavicon;
+                switch (locality) {
+                    case FaviconLocality.LOCAL:
+                        mRecentTabsManager.getLocalFaviconForUrl(url, mFaviconSize, imageCallback);
+                        break;
+                    case FaviconLocality.FOREIGN:
+                        mRecentTabsManager.getForeignFaviconForUrl(
+                                url, mFaviconSize, imageCallback);
+                        break;
+                }
+
+                image = mDefaultFaviconHelper.getDefaultFaviconDrawable(
+                        mActivity.getResources(), url, true);
             }
         }
         viewHolder.imageView.setImageDrawable(image);
@@ -795,12 +878,12 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
 
     @Override
     public int getGroupType(int groupPosition) {
-        return getGroup(groupPosition).getGroupType().ordinal();
+        return getGroup(groupPosition).getGroupType();
     }
 
     @Override
     public int getGroupTypeCount() {
-        return GroupType.values().length;
+        return GroupType.NUM_ENTRIES;
     }
 
     private void addGroup(Group group) {
@@ -822,19 +905,22 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
         for (ForeignSession session : mRecentTabsManager.getForeignSessions()) {
             if (!mHasForeignDataRecorded) {
                 RecordHistogram.recordEnumeratedHistogram("HistoryPage.OtherDevicesMenu",
-                        OtherSessionsActions.HAS_FOREIGN_DATA, OtherSessionsActions.LIMIT);
+                        OtherSessionsActions.HAS_FOREIGN_DATA, OtherSessionsActions.NUM_ENTRIES);
                 mHasForeignDataRecorded = true;
             }
             addGroup(new ForeignSessionGroup(session));
         }
 
-        switch (mRecentTabsManager.getPromoType()) {
-            case RecentTabsManager.PromoState.PROMO_NONE:
+        switch (mRecentTabsManager.getPromoState()) {
+            case SyncPromoState.NO_PROMO:
                 break;
-            case RecentTabsManager.PromoState.PROMO_SIGNIN_PERSONALIZED:
-                addGroup(new PersonalizedSigninPromoGroup());
+            case SyncPromoState.PROMO_FOR_SIGNED_OUT_STATE:
+                addGroup(new PersonalizedSyncPromoGroup(ChildType.PERSONALIZED_SIGNIN_PROMO));
                 break;
-            case RecentTabsManager.PromoState.PROMO_SYNC:
+            case SyncPromoState.PROMO_FOR_SIGNED_IN_STATE:
+                addGroup(new PersonalizedSyncPromoGroup(ChildType.PERSONALIZED_SYNC_PROMO));
+                break;
+            case SyncPromoState.PROMO_FOR_SYNC_TURNED_OFF_STATE:
                 addGroup(new SyncPromoGroup());
                 break;
             default:
@@ -854,11 +940,18 @@ public class RecentTabsRowAdapter extends BaseExpandableListAdapter {
 
     @Override
     public int getChildType(int groupPosition, int childPosition) {
-        return mGroups.get(groupPosition).getChildType().ordinal();
+        return mGroups.get(groupPosition).getChildType();
     }
 
     @Override
     public int getChildTypeCount() {
-        return ChildType.values().length;
+        return ChildType.NUM_ENTRIES;
+    }
+
+    /**
+     * Retrieves the user's preferred locale from the app's configurations.
+     */
+    private Locale getPreferredLocale() {
+        return mActivity.getResources().getConfiguration().getLocales().get(0);
     }
 }
