@@ -1,13 +1,17 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.offlinepages;
 
+import android.text.format.DateUtils;
+
 import org.chromium.base.Callback;
 import org.chromium.base.ContextUtils;
 import org.chromium.base.annotations.CalledByNative;
 import org.chromium.base.annotations.JNINamespace;
+import org.chromium.base.annotations.NativeMethods;
+import org.chromium.chrome.browser.device.DeviceConditions;
 
 /**
  * Provides Java scheduling support from native offlining code as
@@ -26,9 +30,9 @@ public class BackgroundSchedulerBridge {
     //     separately determine if not allowed by policy.
     public static boolean startScheduledProcessing(
             DeviceConditions deviceConditions, Callback<Boolean> callback) {
-        return nativeStartScheduledProcessing(deviceConditions.isPowerConnected(),
-                deviceConditions.getBatteryPercentage(), deviceConditions.getNetConnectionType(),
-                callback);
+        return BackgroundSchedulerBridgeJni.get().startScheduledProcessing(
+                deviceConditions.isPowerConnected(), deviceConditions.getBatteryPercentage(),
+                deviceConditions.getNetConnectionType(), callback);
     }
 
     /**
@@ -36,40 +40,39 @@ public class BackgroundSchedulerBridge {
      * @return true, as it always expects to be rescheduled.
      */
     public static boolean stopScheduledProcessing() {
-        nativeStopScheduledProcessing();
+        BackgroundSchedulerBridgeJni.get().stopScheduledProcessing();
         return true;
     }
 
     @CalledByNative
     private static void schedule(TriggerConditions triggerConditions) {
-        BackgroundScheduler.getInstance(ContextUtils.getApplicationContext())
-                .schedule(triggerConditions);
+        BackgroundScheduler.getInstance().schedule(triggerConditions);
     }
 
     @CalledByNative
     private static void backupSchedule(TriggerConditions triggerConditions, long delayInSeconds) {
-        BackgroundScheduler.getInstance(ContextUtils.getApplicationContext())
-                .scheduleBackup(triggerConditions, delayInSeconds);
+        BackgroundScheduler.getInstance().scheduleBackup(
+                triggerConditions, DateUtils.SECOND_IN_MILLIS * delayInSeconds);
     }
 
     @CalledByNative
     private static void unschedule() {
-        BackgroundScheduler.getInstance(ContextUtils.getApplicationContext()).cancel();
+        BackgroundScheduler.getInstance().cancel();
     }
 
     @CalledByNative
     private static boolean getPowerConditions() {
-        return DeviceConditions.isPowerConnected(ContextUtils.getApplicationContext());
+        return DeviceConditions.isCurrentlyPowerConnected(ContextUtils.getApplicationContext());
     }
 
     @CalledByNative
     private static int getBatteryConditions() {
-        return DeviceConditions.getBatteryPercentage(ContextUtils.getApplicationContext());
+        return DeviceConditions.getCurrentBatteryPercentage(ContextUtils.getApplicationContext());
     }
 
     @CalledByNative
     private static int getNetworkConditions() {
-        return DeviceConditions.getNetConnectionType(ContextUtils.getApplicationContext());
+        return DeviceConditions.getCurrentNetConnectionType(ContextUtils.getApplicationContext());
     }
 
     /**
@@ -83,9 +86,13 @@ public class BackgroundSchedulerBridge {
                 requirePowerConnected, minimumBatteryPercentage, requireUnmeteredNetwork);
     }
 
-    /** Instructs the native RequestCoordinator to start processing. */
-    private static native boolean nativeStartScheduledProcessing(boolean powerConnected,
-            int batteryPercentage, int netConnectionType, Callback<Boolean> callback);
-    /** Instructs the native RequestCoordinator to stop processing. */
-    private static native void nativeStopScheduledProcessing();
+    @NativeMethods
+    interface Natives {
+        /** Instructs the native RequestCoordinator to start processing. */
+        boolean startScheduledProcessing(boolean powerConnected, int batteryPercentage,
+                int netConnectionType, Callback<Boolean> callback);
+
+        /** Instructs the native RequestCoordinator to stop processing. */
+        void stopScheduledProcessing();
+    }
 }
