@@ -1,10 +1,11 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.offlinepages.prefetch;
 
-import android.os.Bundle;
+import android.os.PersistableBundle;
+import android.text.format.DateUtils;
 
 import org.chromium.base.ContextUtils;
 import org.chromium.base.annotations.CalledByNative;
@@ -13,14 +14,13 @@ import org.chromium.components.background_task_scheduler.BackgroundTaskScheduler
 import org.chromium.components.background_task_scheduler.TaskIds;
 import org.chromium.components.background_task_scheduler.TaskInfo;
 
-import java.util.concurrent.TimeUnit;
-
 /**
  * Handles scheduling background task for offline pages prefetching.
  */
 @JNINamespace("offline_pages::prefetch")
 public class PrefetchBackgroundTaskScheduler {
     public static final long DEFAULT_START_DELAY_SECONDS = 15 * 60;
+    public static final long LIMITLESS_START_DELAY_SECONDS = 20;
 
     /**
      * Schedules the default 'NWake' task for the prefetching service. This task will normally be
@@ -44,16 +44,16 @@ public class PrefetchBackgroundTaskScheduler {
     private static void scheduleTaskInternal(
             int additionalDelaySeconds, boolean limitlessPrefetching) {
         final long minimumTimeSeconds =
-                (limitlessPrefetching ? 0 : DEFAULT_START_DELAY_SECONDS) + additionalDelaySeconds;
+                (limitlessPrefetching ? LIMITLESS_START_DELAY_SECONDS : DEFAULT_START_DELAY_SECONDS)
+                + additionalDelaySeconds;
         TaskInfo.Builder taskInfoBuilder =
                 TaskInfo.createOneOffTask(TaskIds.OFFLINE_PAGES_PREFETCH_JOB_ID,
-                                PrefetchBackgroundTask.class,
                                 // Minimum time to wait
-                                TimeUnit.SECONDS.toMillis(minimumTimeSeconds),
+                                DateUtils.SECOND_IN_MILLIS * minimumTimeSeconds,
                                 // Maximum time to wait.  After this interval the event will fire
                                 // regardless of whether the conditions are right.
-                                TimeUnit.DAYS.toMillis(7))
-                        .setRequiredNetworkType(TaskInfo.NETWORK_TYPE_UNMETERED)
+                                DateUtils.DAY_IN_MILLIS * 7)
+                        .setRequiredNetworkType(TaskInfo.NetworkType.UNMETERED)
                         .setIsPersisted(true)
                         .setUpdateCurrent(true);
         /* Limitless prefetching eliminates the default wait time but still complies with backoff
@@ -61,8 +61,8 @@ public class PrefetchBackgroundTaskScheduler {
          * type.
          */
         if (limitlessPrefetching) {
-            taskInfoBuilder.setRequiredNetworkType(TaskInfo.NETWORK_TYPE_ANY);
-            Bundle bundle = new Bundle(1);
+            taskInfoBuilder.setRequiredNetworkType(TaskInfo.NetworkType.ANY);
+            PersistableBundle bundle = new PersistableBundle(1);
             bundle.putBoolean(PrefetchBackgroundTask.LIMITLESS_BUNDLE_KEY, true);
             taskInfoBuilder.setExtras(bundle);
         }
