@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -9,19 +9,23 @@ import android.os.Handler;
 import android.text.TextUtils;
 import android.util.Pair;
 
+import androidx.annotation.Nullable;
+
 import org.chromium.base.Callback;
 import org.chromium.chrome.R;
 import org.chromium.chrome.browser.autofill.PersonalDataManager;
 import org.chromium.chrome.browser.autofill.PersonalDataManager.AutofillProfile;
 import org.chromium.chrome.browser.autofill.PersonalDataManager.GetSubKeysRequestDelegate;
 import org.chromium.chrome.browser.autofill.PhoneNumberUtil;
-import org.chromium.chrome.browser.preferences.autofill.AutofillProfileBridge;
-import org.chromium.chrome.browser.preferences.autofill.AutofillProfileBridge.AddressField;
-import org.chromium.chrome.browser.preferences.autofill.AutofillProfileBridge.AddressUiComponent;
-import org.chromium.chrome.browser.widget.prefeditor.EditorBase;
-import org.chromium.chrome.browser.widget.prefeditor.EditorFieldModel;
-import org.chromium.chrome.browser.widget.prefeditor.EditorFieldModel.EditorFieldValidator;
-import org.chromium.chrome.browser.widget.prefeditor.EditorModel;
+import org.chromium.chrome.browser.autofill.prefeditor.EditorBase;
+import org.chromium.chrome.browser.autofill.prefeditor.EditorModel;
+import org.chromium.chrome.browser.autofill.settings.AddressValidationType;
+import org.chromium.chrome.browser.autofill.settings.AutofillProfileBridge;
+import org.chromium.chrome.browser.autofill.settings.AutofillProfileBridge.AddressField;
+import org.chromium.chrome.browser.autofill.settings.AutofillProfileBridge.AddressUiComponent;
+import org.chromium.components.autofill.prefeditor.EditorFieldModel;
+import org.chromium.components.autofill.prefeditor.EditorFieldModel.EditorFieldValidator;
+import org.chromium.payments.mojom.AddressErrors;
 
 import java.util.HashMap;
 import java.util.HashSet;
@@ -31,16 +35,21 @@ import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
 
-import javax.annotation.Nullable;
-
 /**
  * An address editor. Can be used for either shipping or billing address editing.
+ *
+ * Note that this class is used by PaymentRequest only and will be removed when not needed any more.
+ * Please use {@link org.chromium.chrome.browser.autofill.settings.AddressEditor} instead.
  */
+@Deprecated
 public class AddressEditor
         extends EditorBase<AutofillAddress> implements GetSubKeysRequestDelegate {
     private final Handler mHandler = new Handler();
     private final Map<Integer, EditorFieldModel> mAddressFields = new HashMap<>();
     private final Set<CharSequence> mPhoneNumbers = new HashSet<>();
+    private final boolean mSaveToDisk;
+    private final PhoneNumberUtil.CountryAwareFormatTextWatcher mPhoneFormatter;
+    private final CountryAwarePhoneNumberValidator mPhoneValidator;
     @Nullable
     private AutofillProfileBridge mAutofillProfileBridge;
     @Nullable
@@ -48,10 +57,6 @@ public class AddressEditor
     @Nullable
     private EditorFieldModel mPhoneField;
     @Nullable
-    private EditorFieldModel mEmailField;
-    private PhoneNumberUtil.CountryAwareFormatTextWatcher mPhoneFormatter;
-    private CountryAwarePhoneNumberValidator mPhoneValidator;
-    @Nullable
     private List<AddressUiComponent> mAddressUiComponents;
     private boolean mAdminAreasLoaded;
     private String mRecentlySelectedCountry;
@@ -59,21 +64,18 @@ public class AddressEditor
     private AutofillProfile mProfile;
     private EditorModel mEditor;
     private ProgressDialog mProgressDialog;
-    private boolean mEmailFieldIncluded;
-    private boolean mSaveToDisk;
+    @Nullable
+    private AddressErrors mAddressErrors;
 
     /**
      * Builds an address editor.
      *
-     * @param emailFieldIncluded True if the address editor has an email field. The autofill form
-     *                           has an email address, and the payment request doesn't.
-     * @param saveToDisk         Whether to save changes to disk after editing.
+     * @param saveToDisk Whether to save changes to disk after editing.
      */
-    public AddressEditor(boolean emailFieldIncluded, boolean saveToDisk) {
+    public AddressEditor(boolean saveToDisk) {
+        mSaveToDisk = saveToDisk;
         mPhoneFormatter = new PhoneNumberUtil.CountryAwareFormatTextWatcher();
         mPhoneValidator = new CountryAwarePhoneNumberValidator();
-        mEmailFieldIncluded = emailFieldIncluded;
-        mSaveToDisk = saveToDisk;
     }
 
     /**
@@ -88,38 +90,84 @@ public class AddressEditor
     }
 
     /**
-     * Builds and shows an editor model with the following fields.
+     * Sets the address errors to indicate error messages from merchant's retry() call.
      *
-     * [ country dropdown   ] <----- country dropdown is always present.
-     * [ an address field   ] \
-     * [ an address field   ]  \
-     *         ...               <-- field order, presence, required, and labels depend on country.
-     * [ an address field   ]  /
-     * [ an address field   ] /
-     * [ phone number field ] <----- phone is always present and required.
+     * @param errors The address errors from merchant's retry() call.
+     */
+    public void setAddressErrors(@Nullable AddressErrors errors) {
+        mAddressErrors = errors;
+    }
+
+    private String getAddressError(int field) {
+        if (mAddressErrors == null) return null;
+
+        switch (field) {
+            case AddressField.COUNTRY:
+                return mAddressErrors.country;
+            case AddressField.ADMIN_AREA:
+                return mAddressErrors.region;
+            case AddressField.LOCALITY:
+                return mAddressErrors.city;
+            case AddressField.DEPENDENT_LOCALITY:
+                return mAddressErrors.dependentLocality;
+            case AddressField.SORTING_CODE:
+                return mAddressErrors.sortingCode;
+            case AddressField.POSTAL_CODE:
+                return mAddressErrors.postalCode;
+            case AddressField.STREET_ADDRESS:
+                return mAddressErrors.addressLine;
+            case AddressField.ORGANIZATION:
+                return mAddressErrors.organization;
+            case AddressField.RECIPIENT:
+                return mAddressErrors.recipient;
+        }
+        assert false : "Unrecognized address field code";
+        return null;
+    }
+
+    /**
+     * Allows calling |edit| with a single callback used for both 'done' and 'cancel'.
+     * @see #edit(AutofillAddress, Callback, Callback)
      */
-    @Override
     public void edit(
             @Nullable final AutofillAddress toEdit, final Callback<AutofillAddress> callback) {
-        super.edit(toEdit, callback);
+        edit(toEdit, callback, callback);
+    }
+
+    /**
+     * Builds and shows an editor model with the following fields.
+     *
+     * [ country dropdown    ] <----- country dropdown is always present.
+     * [ an address field    ] \
+     * [ an address field    ]  \
+     *         ...                <-- field order, presence, required, and labels depend on country.
+     * [ an address field    ]  /
+     * [ an address field    ] /
+     * [ phone number field  ] <----- phone is always present.
+     */
+    @Override
+    public void edit(@Nullable final AutofillAddress toEdit,
+            final Callback<AutofillAddress> doneCallback,
+            final Callback<AutofillAddress> cancelCallback) {
+        super.edit(toEdit, doneCallback, cancelCallback);
 
         if (mAutofillProfileBridge == null) mAutofillProfileBridge = new AutofillProfileBridge();
 
         // If |toEdit| is null, we're creating a new autofill profile with the country code of the
         // default locale on this device.
-        boolean isNewAddress = toEdit == null;
+        final String editTitle;
+        final AutofillAddress address;
+        if (toEdit == null) {
+            address = new AutofillAddress(mContext, new AutofillProfile());
+            editTitle = mContext.getString(R.string.autofill_create_profile);
+        } else {
+            address = toEdit;
+            editTitle = toEdit.getEditTitle();
+        }
 
-        // Ensure that |address| and |mProfile| are always not null.
-        final AutofillAddress address =
-                isNewAddress ? new AutofillAddress(mContext, new AutofillProfile()) : toEdit;
+        mEditor = new EditorModel(editTitle);
         mProfile = address.getProfile();
 
-        // The title of the editor depends on whether we're adding a new address or editing an
-        // existing address.
-        mEditor =
-                new EditorModel(isNewAddress ? mContext.getString(R.string.autofill_create_profile)
-                                             : toEdit.getEditTitle());
-
         // When edit is called, a new form is started, so the country on the
         // dropdown list is not changed. => mRecentlySelectedCountry should be null.
         mRecentlySelectedCountry = null;
@@ -187,34 +235,22 @@ public class AddressEditor
                     EditorFieldModel.INPUT_TYPE_HINT_PERSON_NAME));
         }
 
-
-        // Phone number is present and required for all countries.
+        // Phone number is present for all countries.
         if (mPhoneField == null) {
+            String requiredErrorMessage =
+                    mContext.getString(R.string.pref_edit_dialog_field_required_validation_message);
             mPhoneField = EditorFieldModel.createTextInput(EditorFieldModel.INPUT_TYPE_HINT_PHONE,
                     mContext.getString(R.string.autofill_profile_editor_phone_number),
-                    mPhoneNumbers, mPhoneFormatter, mPhoneValidator, null,
-                    mContext.getString(R.string.pref_edit_dialog_field_required_validation_message),
-                    mContext.getString(R.string.payments_phone_invalid_validation_message), null);
+                    mPhoneNumbers, mPhoneFormatter, mPhoneValidator, null /* valueIconGenerator */,
+                    requiredErrorMessage,
+                    mContext.getString(R.string.payments_phone_invalid_validation_message),
+                    EditorFieldModel.LENGTH_COUNTER_LIMIT_NONE, null /* value */);
         }
 
         // Phone number field is cached, so its value needs to be updated for every new profile
         // that's being edited.
         mPhoneField.setValue(mProfile.getPhoneNumber());
 
-        // Email address is present and required if the mEmailFieldIncluded is true.
-        if (mEmailFieldIncluded) {
-            if (mEmailField == null) {
-                mEmailField = EditorFieldModel.createTextInput(
-                        EditorFieldModel.INPUT_TYPE_HINT_EMAIL,
-                        mContext.getString(R.string.autofill_profile_editor_email_address), null,
-                        null, null, null, null,
-                        mContext.getString(R.string.payments_email_invalid_validation_message),
-                        null);
-            }
-            // Retrieve and set the email address field.
-            mEmailField.setValue(mProfile.getEmailAddress());
-        }
-
         // If the user clicks [Cancel], send |toEdit| address back to the caller, which was the
         // original state (could be null, a complete address, a partial address).
         mEditor.setCancelCallback(() -> {
@@ -222,20 +258,21 @@ public class AddressEditor
             // ever called when Cancel has already occurred.
             mAdminAreasLoaded = true;
             PersonalDataManager.getInstance().cancelPendingGetSubKeys();
-            callback.onResult(toEdit);
+            cancelCallback.onResult(toEdit);
         });
 
-        // If the user clicks [Done], save changes on disk, mark the address "complete," and send it
-        // back to the caller.
+        // If the user clicks [Done], save changes on disk, mark the address "complete" if possible,
+        // and send it back to the caller.
         mEditor.setDoneCallback(() -> {
             mAdminAreasLoaded = true;
             PersonalDataManager.getInstance().cancelPendingGetSubKeys();
             commitChanges(mProfile);
             address.completeAddress(mProfile);
-            callback.onResult(address);
+            doneCallback.onResult(address);
         });
 
         loadAdminAreasForCountry(mCountryField.getValue().toString());
+        if (mAddressErrors != null) mEditorDialog.validateForm();
     }
 
     private void showProgressDialog() {
@@ -257,9 +294,6 @@ public class AddressEditor
         // editor model.
         profile.setCountryCode(mCountryField.getValue().toString());
         profile.setPhoneNumber(mPhoneField.getValue().toString());
-        if (mEmailFieldIncluded) {
-            profile.setEmailAddress(mEmailField.getValue().toString());
-        }
 
         // Autofill profile bridge normalizes the language code for the autofill profile.
         profile.setLanguageCode(mAutofillProfileBridge.getCurrentBestLanguageCode());
@@ -411,7 +445,7 @@ public class AddressEditor
         // For tests, the time-out is set to 0. In this case, we should not
         // fetch the admin-areas, and show a text-field instead.
         // This is to have the tests independent of the network status.
-        if (PersonalDataManager.getInstance().getRequestTimeoutMS() == 0) {
+        if (PersonalDataManager.getRequestTimeoutMS() == 0) {
             onSubKeysReceived(null, null);
             return;
         }
@@ -426,14 +460,16 @@ public class AddressEditor
      * the profile that's being edited.
      */
     private void addAddressFieldsToEditor(String countryCode, String languageCode) {
-        mAddressUiComponents =
-                mAutofillProfileBridge.getAddressUiComponents(countryCode, languageCode);
+        mAddressUiComponents = mAutofillProfileBridge.getAddressUiComponents(
+                countryCode, languageCode, AddressValidationType.PAYMENT_REQUEST);
         // In terms of order, country must be the first field.
+        mCountryField.setCustomErrorMessage(getAddressError(AddressField.COUNTRY));
         mEditor.addField(mCountryField);
         for (int i = 0; i < mAddressUiComponents.size(); i++) {
             AddressUiComponent component = mAddressUiComponents.get(i);
 
             EditorFieldModel field = mAddressFields.get(component.id);
+
             // Labels depend on country, e.g., state is called province in some countries. These are
             // already localized.
             field.setLabel(component.label);
@@ -442,19 +478,18 @@ public class AddressEditor
 
             // Libaddressinput formats do not always require the full name (RECIPIENT), but
             // PaymentRequest does.
-            if (component.isRequired || component.id == AddressField.RECIPIENT) {
-                field.setRequiredErrorMessage(mContext.getString(
-                        R.string.pref_edit_dialog_field_required_validation_message));
-            } else {
-                field.setRequiredErrorMessage(null);
-            }
+            field.setRequiredErrorMessage(
+                    component.isRequired || component.id == AddressField.RECIPIENT
+                            ? mContext.getString(
+                                    R.string.pref_edit_dialog_field_required_validation_message)
+                            : null);
+
+            field.setCustomErrorMessage(getAddressError(component.id));
             mEditor.addField(field);
         }
         // Phone number (and email if applicable) are the last fields of the address.
+        mPhoneField.setCustomErrorMessage(mAddressErrors != null ? mAddressErrors.phone : null);
         mEditor.addField(mPhoneField);
-        if (mEmailFieldIncluded) {
-            mEditor.addField(mEmailField);
-        }
     }
 
     /** Country based phone number validator. */
@@ -462,6 +497,11 @@ public class AddressEditor
         @Nullable
         private String mCountryCode;
 
+        /**
+         * Builds a country based phone number validator.
+         */
+        CountryAwarePhoneNumberValidator() {}
+
         /**
          * Sets the country code used to validate the phone number.
          *
@@ -477,7 +517,7 @@ public class AddressEditor
             // invalid, crbug.com/736387.
             // Note that isPossibleNumber is used since the metadata in libphonenumber has to be
             // updated frequently (daily) to do more strict validation.
-            return value != null
+            return !TextUtils.isEmpty(value)
                     && PhoneNumberUtil.isPossibleNumber(value.toString(), mCountryCode);
         }
 
