@@ -1,47 +1,67 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.payments;
 
 import android.content.Context;
-import android.support.v7.content.res.AppCompatResources;
 import android.text.TextUtils;
 import android.util.JsonWriter;
 
+import androidx.annotation.IntDef;
+import androidx.annotation.Nullable;
+import androidx.appcompat.content.res.AppCompatResources;
+
+import org.chromium.base.ContextUtils;
 import org.chromium.chrome.R;
-import org.chromium.chrome.browser.ChromeActivity;
 import org.chromium.chrome.browser.autofill.PersonalDataManager;
 import org.chromium.chrome.browser.autofill.PersonalDataManager.AutofillProfile;
 import org.chromium.chrome.browser.autofill.PersonalDataManager.CreditCard;
 import org.chromium.chrome.browser.autofill.PersonalDataManager.FullCardRequestDelegate;
 import org.chromium.chrome.browser.autofill.PersonalDataManager.NormalizedAddressRequestDelegate;
+import org.chromium.components.autofill.EditableOption;
+import org.chromium.components.payments.ErrorStrings;
+import org.chromium.components.payments.PayerData;
+import org.chromium.components.payments.PaymentApp.InstrumentDetailsCallback;
 import org.chromium.content_public.browser.WebContents;
-import org.chromium.payments.mojom.PaymentDetailsModifier;
-import org.chromium.payments.mojom.PaymentItem;
-import org.chromium.payments.mojom.PaymentMethodData;
 
 import java.io.IOException;
 import java.io.StringWriter;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-
-import javax.annotation.Nullable;
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
 
 /**
  * The locally stored credit card payment instrument.
  */
-public class AutofillPaymentInstrument extends PaymentInstrument
+// TODO(crbug.com/1209835): Move this class into autofill now that it no longer interacts with
+// Payments code.
+public class AutofillPaymentInstrument extends EditableOption
         implements FullCardRequestDelegate, NormalizedAddressRequestDelegate {
+    // Bit field values are identical to CreditCardCompletionStatus fields in
+    // autofill_card_validation.h. Please modify autofill_card_validation.h after changing these.
+    @IntDef({CompletionStatus.COMPLETE, CompletionStatus.CREDIT_CARD_EXPIRED,
+            CompletionStatus.CREDIT_CARD_NO_CARDHOLDER, CompletionStatus.CREDIT_CARD_NO_NUMBER,
+            CompletionStatus.CREDIT_CARD_NO_BILLING_ADDRESS,
+            CompletionStatus.CREDIT_CARD_TYPE_MISMATCH})
+    @Retention(RetentionPolicy.SOURCE)
+    public @interface CompletionStatus {
+        int COMPLETE = 0;
+        int CREDIT_CARD_EXPIRED = 1 << 0;
+        int CREDIT_CARD_NO_CARDHOLDER = 1 << 1;
+        int CREDIT_CARD_NO_NUMBER = 1 << 2;
+        int CREDIT_CARD_NO_BILLING_ADDRESS = 1 << 3;
+        int CREDIT_CARD_TYPE_MISMATCH = 1 << 4;
+    }
+
     private final WebContents mWebContents;
-    private final boolean mIsMatchingMerchantsRequestedCardType;
     private CreditCard mCard;
     private String mSecurityCode;
-    @Nullable private AutofillProfile mBillingAddress;
-    @Nullable private String mMethodName;
-    @Nullable private InstrumentDetailsCallback mCallback;
+    @Nullable
+    private AutofillProfile mBillingAddress;
+    @Nullable
+    private String mMethodName;
+    @Nullable
+    private InstrumentDetailsCallback mCallback;
     private boolean mIsWaitingForBillingNormalization;
     private boolean mIsWaitingForFullCardDetails;
     private boolean mHasValidNumberAndName;
@@ -54,23 +74,17 @@ public class AutofillPaymentInstrument extends PaymentInstrument
      * @param billingAddress                 The billing address for the card.
      * @param methodName                     The payment method name, e.g., "basic-card", "visa",
      *                                       amex", or null.
-     * @param matchesMerchantCardTypeExactly Whether the card type (credit, debit, prepaid) matches
-     *                                       the type that the merchant has requested exactly. This
-     *                                       should be false for unknown card types, if the merchant
-     *                                       cannot accept some card types.
      */
     public AutofillPaymentInstrument(WebContents webContents, CreditCard card,
-            @Nullable AutofillProfile billingAddress, @Nullable String methodName,
-            boolean matchesMerchantCardTypeExactly) {
-        super(card.getGUID(), card.getObfuscatedNumber(), card.getName(), null);
+            @Nullable AutofillProfile billingAddress, @Nullable String methodName) {
+        super(card.getGUID(), card.getNetworkAndLastFourDigits(), card.getName(), null);
         mWebContents = webContents;
         mCard = card;
         mBillingAddress = billingAddress;
         mIsEditable = true;
         mMethodName = methodName;
-        mIsMatchingMerchantsRequestedCardType = matchesMerchantCardTypeExactly;
 
-        Context context = ChromeActivity.fromWebContents(mWebContents);
+        Context context = ContextUtils.getApplicationContext();
         if (context == null) return;
 
         if (card.getIssuerIconDrawableId() != 0) {
@@ -78,73 +92,7 @@ public class AutofillPaymentInstrument extends PaymentInstrument
                     AppCompatResources.getDrawable(context, card.getIssuerIconDrawableId()));
         }
 
-        checkAndUpateCardCompleteness(context);
-    }
-
-    @Override
-    public Set<String> getInstrumentMethodNames() {
-        Set<String> result = new HashSet<>();
-        result.add(mMethodName);
-        return result;
-    }
-
-    @Override
-    public boolean isAutofillInstrument() {
-        return true;
-    }
-
-    @Override
-    public boolean isServerAutofillInstrument() {
-        return !mCard.getIsLocal();
-    }
-
-    @Override
-    public boolean isExactlyMatchingMerchantRequest() {
-        return mIsMatchingMerchantsRequestedCardType;
-    }
-
-    @Override
-    @Nullable
-    public String getCountryCode() {
-        return AutofillAddress.getCountryCode(mBillingAddress);
-    }
-
-    @Override
-    public boolean canMakePayment() {
-        return mHasValidNumberAndName; // Ignore absence of billing address.
-    }
-
-    @Override
-    public boolean canPreselect() {
-        return mIsComplete && mIsMatchingMerchantsRequestedCardType;
-    }
-
-    @Override
-    public void invokePaymentApp(String unusedRequestId, String unusedMerchantName,
-            String unusedOrigin, String unusedIFrameOrigin, byte[][] unusedCertificateChain,
-            Map<String, PaymentMethodData> unusedMethodDataMap, PaymentItem unusedTotal,
-            List<PaymentItem> unusedDisplayItems,
-            Map<String, PaymentDetailsModifier> unusedModifiers,
-            InstrumentDetailsCallback callback) {
-        // The billing address should never be null for a credit card at this point.
-        assert mBillingAddress != null;
-        assert AutofillAddress.checkAddressCompletionStatus(
-                mBillingAddress, AutofillAddress.IGNORE_PHONE_COMPLETENESS_CHECK)
-                == AutofillAddress.COMPLETE;
-        assert mIsComplete;
-        assert mHasValidNumberAndName;
-        assert mCallback == null;
-        mCallback = callback;
-
-        mIsWaitingForBillingNormalization = true;
-        mIsWaitingForFullCardDetails = true;
-
-        // Start the billing address normalization.
-        PersonalDataManager.getInstance().normalizeAddress(
-                mBillingAddress, AutofillAddress.getCountryCode(mBillingAddress), this);
-
-        // Start to get the full card details.
-        PersonalDataManager.getInstance().getFullCard(mWebContents, mCard, this);
+        checkAndUpdateCardCompleteness(context);
     }
 
     @Override
@@ -237,7 +185,8 @@ public class AutofillPaymentInstrument extends PaymentInstrument
             mSecurityCode = "";
         }
 
-        mCallback.onInstrumentDetailsReady(mMethodName, stringWriter.toString());
+        mCallback.onInstrumentDetailsReady(mMethodName, stringWriter.toString(), new PayerData());
+        mCallback = null;
     }
 
     private static String ensureNotNull(@Nullable String value) {
@@ -246,13 +195,13 @@ public class AutofillPaymentInstrument extends PaymentInstrument
 
     @Override
     public void onFullCardError() {
-        mCallback.onInstrumentDetailsError();
+        // There's no need to disambiguate between user cancelling the CVC unmask and other types of
+        // failures, because a failure to unmask an Autofill card will show the Payment Request UI
+        // again and prompt the user to attempt to complete a transaction using a different card.
+        mCallback.onInstrumentDetailsError(ErrorStrings.USER_CANCELLED);
         mCallback = null;
     }
 
-    @Override
-    public void dismissInstrument() {}
-
     /**
      * @return Whether the card is complete and ready to be sent to the merchant as-is. If true,
      * this card has a valid card number, a non-empty name on card, and a complete billing address.
@@ -281,19 +230,20 @@ public class AutofillPaymentInstrument extends PaymentInstrument
         assert card.getBillingAddressId().equals(billingAddress.getGUID());
         assert card.getIssuerIconDrawableId() != 0;
         assert AutofillAddress.checkAddressCompletionStatus(
-                billingAddress, AutofillAddress.IGNORE_PHONE_COMPLETENESS_CHECK)
-                == AutofillAddress.COMPLETE;
+                billingAddress, AutofillAddress.CompletenessCheckType.IGNORE_PHONE)
+                == AutofillAddress.CompletionStatus.COMPLETE;
 
         mCard = card;
         mMethodName = methodName;
         mBillingAddress = billingAddress;
 
-        Context context = ChromeActivity.fromWebContents(mWebContents);
+        Context context = ContextUtils.getApplicationContext();
         if (context == null) return;
 
-        updateIdentifierLabelsAndIcon(card.getGUID(), card.getObfuscatedNumber(), card.getName(),
-                null, AppCompatResources.getDrawable(context, card.getIssuerIconDrawableId()));
-        checkAndUpateCardCompleteness(context);
+        updateIdentifierLabelsAndIcon(card.getGUID(), card.getNetworkAndLastFourDigits(),
+                card.getName(), null,
+                AppCompatResources.getDrawable(context, card.getIssuerIconDrawableId()));
+        checkAndUpdateCardCompleteness(context);
         assert mIsComplete;
         assert mHasValidNumberAndName;
     }
@@ -308,40 +258,55 @@ public class AutofillPaymentInstrument extends PaymentInstrument
      * Does not check that the billing address has all of the required fields. This is done
      * elsewhere to filter out such billing addresses entirely.
      *
-     * Does not check the expiration date. If the card is expired, the user has the opportunity
-     * update the expiration date when providing their CVC in the card unmask dialog.
+     * Does not check the expiration date for mIsComplete. If the card is expired, the user has the
+     * opportunity update the expiration date when providing their CVC in the card unmask dialog.
      *
      * Does not check that the card type is accepted by the merchant. This is done elsewhere to
      * filter out such cards from view entirely.
+     *
+     * Completeness weights for all fields are identiacal to their equivalent in
+     * GetCompletenessScore from autofill_card_validation.cc, Please modify the weights in both
+     * files if needed.
      */
-    private void checkAndUpateCardCompleteness(Context context) {
+    private void checkAndUpdateCardCompleteness(Context context) {
         int editMessageResId = 0; // Zero is the invalid resource Id.
         int editTitleResId = R.string.payments_edit_card;
         int invalidFieldsCount = 0;
+        mCompletenessScore = 0;
+        int missingFields = getMissingFields();
 
-        if (mBillingAddress == null) {
+        // Even though expiration date does not affect mIsComplete, cards with valid expiration date
+        // still score higher than expired cards. This is used to list expired cards after
+        // non-expired cards after sorting instruments.
+        if ((missingFields & CompletionStatus.CREDIT_CARD_EXPIRED) == 0) mCompletenessScore += 6;
+
+        if ((missingFields & CompletionStatus.CREDIT_CARD_NO_BILLING_ADDRESS) == 0) {
+            // Add 10 for complete address.
+            mCompletenessScore += 10;
+        } else {
             editMessageResId = R.string.payments_billing_address_required;
             editTitleResId = R.string.payments_add_billing_address;
             invalidFieldsCount++;
         }
 
         mHasValidNumberAndName = true;
-        if (mCard.getIsLocal()) {
-            if (TextUtils.isEmpty(mCard.getName())) {
-                mHasValidNumberAndName = false;
-                editMessageResId = R.string.payments_name_on_card_required;
-                editTitleResId = R.string.payments_add_name_on_card;
-                invalidFieldsCount++;
-            }
-
-            if (PersonalDataManager.getInstance().getBasicCardIssuerNetwork(
-                        mCard.getNumber().toString(), true)
-                    == null) {
-                mHasValidNumberAndName = false;
-                editMessageResId = R.string.payments_card_number_invalid_validation_message;
-                editTitleResId = R.string.payments_add_valid_card_number;
-                invalidFieldsCount++;
-            }
+        if ((missingFields & CompletionStatus.CREDIT_CARD_NO_CARDHOLDER) == 0) {
+            // Add 8 for complete card holder's name.
+            mCompletenessScore += 8;
+        } else {
+            mHasValidNumberAndName = false;
+            editMessageResId = R.string.payments_name_on_card_required;
+            editTitleResId = R.string.payments_add_name_on_card;
+            invalidFieldsCount++;
+        }
+        if ((missingFields & CompletionStatus.CREDIT_CARD_NO_NUMBER) == 0) {
+            // Add 13 for valid card number.
+            mCompletenessScore += 13;
+        } else {
+            mHasValidNumberAndName = false;
+            editMessageResId = R.string.payments_card_number_invalid_validation_message;
+            editTitleResId = R.string.payments_add_valid_card_number;
+            invalidFieldsCount++;
         }
 
         if (invalidFieldsCount > 1) {
@@ -359,6 +324,12 @@ public class AutofillPaymentInstrument extends PaymentInstrument
         return mCard;
     }
 
+    /** @return The billing address associated with this payment instrument. */
+    @Nullable
+    public AutofillProfile getBillingProfile() {
+        return mBillingAddress;
+    }
+
     @Override
     public String getPreviewString(String labelSeparator, int maxLength) {
         StringBuilder previewString = new StringBuilder(getLabel());
@@ -372,4 +343,29 @@ public class AutofillPaymentInstrument extends PaymentInstrument
         if (previewString.length() < maxLength) return previewString.toString();
         return previewString.substring(0, maxLength / 2);
     }
+
+    /** @return a bit vector of the card's missing fields. */
+    public int getMissingFields() {
+        int missingFields = CompletionStatus.COMPLETE;
+        if (mBillingAddress == null) {
+            missingFields |= CompletionStatus.CREDIT_CARD_NO_BILLING_ADDRESS;
+        }
+        if (!mCard.hasValidCreditCardExpirationDate()) {
+            missingFields |= CompletionStatus.CREDIT_CARD_EXPIRED;
+        }
+
+        if (mCard.getIsLocal()) {
+            if (TextUtils.isEmpty(mCard.getName())) {
+                missingFields |= CompletionStatus.CREDIT_CARD_NO_CARDHOLDER;
+            }
+
+            if (PersonalDataManager.getInstance().getBasicCardIssuerNetwork(
+                        mCard.getNumber().toString(), true)
+                    == null) {
+                missingFields |= CompletionStatus.CREDIT_CARD_NO_NUMBER;
+            }
+        }
+
+        return missingFields;
+    }
 }
