@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -8,35 +8,39 @@ import android.telephony.PhoneNumberUtils;
 import android.text.TextUtils;
 import android.util.Patterns;
 
+import androidx.annotation.Nullable;
+
 import org.chromium.base.Callback;
+import org.chromium.base.StrictModeContext;
 import org.chromium.chrome.R;
 import org.chromium.chrome.browser.autofill.PersonalDataManager;
 import org.chromium.chrome.browser.autofill.PersonalDataManager.AutofillProfile;
 import org.chromium.chrome.browser.autofill.PhoneNumberUtil;
-import org.chromium.chrome.browser.widget.prefeditor.EditorBase;
-import org.chromium.chrome.browser.widget.prefeditor.EditorFieldModel;
-import org.chromium.chrome.browser.widget.prefeditor.EditorFieldModel.EditorFieldValidator;
-import org.chromium.chrome.browser.widget.prefeditor.EditorModel;
+import org.chromium.chrome.browser.autofill.prefeditor.EditorBase;
+import org.chromium.chrome.browser.autofill.prefeditor.EditorModel;
+import org.chromium.components.autofill.prefeditor.EditorFieldModel;
+import org.chromium.components.autofill.prefeditor.EditorFieldModel.EditorFieldValidator;
+import org.chromium.payments.mojom.PayerErrors;
 
 import java.util.HashSet;
 import java.util.Set;
 import java.util.UUID;
 
-import javax.annotation.Nullable;
-
 /**
  * Contact information editor.
  */
 public class ContactEditor extends EditorBase<AutofillContact> {
+    // Bit field values are identical to ProfileFields in payments_profile_comparator.h.
+    // Please also modify payments_profile_comparator.h after changing these bits.
     public @interface CompletionStatus {}
     /** Can be sent to the merchant as-is without editing first. */
     public static final int COMPLETE = 0;
     /** The contact name is missing. */
     public static final int INVALID_NAME = 1 << 0;
-    /** The contact email is invalid or missing. */
-    public static final int INVALID_EMAIL = 1 << 1;
     /** The contact phone number is invalid or missing. */
-    public static final int INVALID_PHONE_NUMBER = 1 << 2;
+    public static final int INVALID_PHONE_NUMBER = 1 << 1;
+    /** The contact email is invalid or missing. */
+    public static final int INVALID_EMAIL = 1 << 2;
 
     private final boolean mRequestPayerName;
     private final boolean mRequestPayerPhone;
@@ -45,6 +49,7 @@ public class ContactEditor extends EditorBase<AutofillContact> {
     private final Set<CharSequence> mPayerNames;
     private final Set<CharSequence> mPhoneNumbers;
     private final Set<CharSequence> mEmailAddresses;
+    @Nullable private PayerErrors mPayerErrors;
     @Nullable private EditorFieldValidator mPhoneValidator;
     @Nullable private EditorFieldValidator mEmailValidator;
 
@@ -144,10 +149,29 @@ public class ContactEditor extends EditorBase<AutofillContact> {
         if (getEmailValidator().isValid(emailAddress)) mEmailAddresses.add(emailAddress);
     }
 
-    @Override
+    /**
+     * Sets the payer errors to indicate error messages from merchant's retry() call.
+     *
+     * @param errors The payer errors from merchant's retry() call.
+     */
+    public void setPayerErrors(@Nullable PayerErrors errors) {
+        mPayerErrors = errors;
+    }
+
+    /**
+     * Allows calling |edit| with a single callback used for both 'done' and 'cancel'.
+     * @see #edit(AutofillContact, Callback, Callback)
+     */
     public void edit(
             @Nullable final AutofillContact toEdit, final Callback<AutofillContact> callback) {
-        super.edit(toEdit, callback);
+        edit(toEdit, callback, callback);
+    }
+
+    @Override
+    public void edit(@Nullable final AutofillContact toEdit,
+            final Callback<AutofillContact> doneCallback,
+            final Callback<AutofillContact> cancelCallback) {
+        super.edit(toEdit, doneCallback, cancelCallback);
 
         final AutofillContact contact = toEdit == null
                 ? new AutofillContact(mContext, new AutofillProfile(), null, null, null,
@@ -157,46 +181,55 @@ public class ContactEditor extends EditorBase<AutofillContact> {
 
         final EditorFieldModel nameField = mRequestPayerName
                 ? EditorFieldModel.createTextInput(EditorFieldModel.INPUT_TYPE_HINT_PERSON_NAME,
-                          mContext.getString(R.string.payments_name_field_in_contact_details),
-                          mPayerNames, null /* suggestions */, null /* formatter */,
-                          null /* validator */,
-                          mContext.getString(
-                                  R.string.pref_edit_dialog_field_required_validation_message),
-                          null, contact.getPayerName())
+                        mContext.getString(R.string.payments_name_field_in_contact_details),
+                        mPayerNames, null /* suggestions */, null /* formatter */,
+                        null /* validator */,
+                        mContext.getString(
+                                R.string.pref_edit_dialog_field_required_validation_message),
+                        null, EditorFieldModel.LENGTH_COUNTER_LIMIT_NONE, contact.getPayerName())
                 : null;
 
         final EditorFieldModel phoneField = mRequestPayerPhone
                 ? EditorFieldModel.createTextInput(EditorFieldModel.INPUT_TYPE_HINT_PHONE,
-                          mContext.getString(R.string.autofill_profile_editor_phone_number),
-                          mPhoneNumbers, new PhoneNumberUtil.CountryAwareFormatTextWatcher(),
-                          getPhoneValidator(), null,
-                          mContext.getString(
-                                  R.string.pref_edit_dialog_field_required_validation_message),
-                          mContext.getString(R.string.payments_phone_invalid_validation_message),
-                          contact.getPayerPhone())
+                        mContext.getString(R.string.autofill_profile_editor_phone_number),
+                        mPhoneNumbers, new PhoneNumberUtil.CountryAwareFormatTextWatcher(),
+                        getPhoneValidator(), null,
+                        mContext.getString(
+                                R.string.pref_edit_dialog_field_required_validation_message),
+                        mContext.getString(R.string.payments_phone_invalid_validation_message),
+                        EditorFieldModel.LENGTH_COUNTER_LIMIT_NONE, contact.getPayerPhone())
                 : null;
 
         final EditorFieldModel emailField = mRequestPayerEmail
                 ? EditorFieldModel.createTextInput(EditorFieldModel.INPUT_TYPE_HINT_EMAIL,
-                          mContext.getString(R.string.autofill_profile_editor_email_address),
-                          mEmailAddresses, null, getEmailValidator(), null,
-                          mContext.getString(
-                                  R.string.pref_edit_dialog_field_required_validation_message),
-                          mContext.getString(R.string.payments_email_invalid_validation_message),
-                          contact.getPayerEmail())
+                        mContext.getString(R.string.autofill_profile_editor_email_address),
+                        mEmailAddresses, null, getEmailValidator(), null,
+                        mContext.getString(
+                                R.string.pref_edit_dialog_field_required_validation_message),
+                        mContext.getString(R.string.payments_email_invalid_validation_message),
+                        EditorFieldModel.LENGTH_COUNTER_LIMIT_NONE, contact.getPayerEmail())
                 : null;
 
         EditorModel editor = new EditorModel(toEdit == null
                 ? mContext.getString(R.string.payments_add_contact_details_label)
                 : toEdit.getEditTitle());
 
-        if (nameField != null) editor.addField(nameField);
-        if (phoneField != null) editor.addField(phoneField);
-        if (emailField != null) editor.addField(emailField);
+        if (nameField != null) {
+            nameField.setCustomErrorMessage(mPayerErrors != null ? mPayerErrors.name : null);
+            editor.addField(nameField);
+        }
+        if (phoneField != null) {
+            phoneField.setCustomErrorMessage(mPayerErrors != null ? mPayerErrors.phone : null);
+            editor.addField(phoneField);
+        }
+        if (emailField != null) {
+            emailField.setCustomErrorMessage(mPayerErrors != null ? mPayerErrors.email : null);
+            editor.addField(emailField);
+        }
 
         // If the user clicks [Cancel], send |toEdit| contact back to the caller, which was the
         // original state (could be null, a complete contact, a partial contact).
-        editor.setCancelCallback(() -> callback.onResult(toEdit));
+        editor.setCancelCallback(cancelCallback.bind(toEdit));
 
         editor.setDoneCallback(() -> {
             String name = null;
@@ -232,10 +265,11 @@ public class ContactEditor extends EditorBase<AutofillContact> {
 
             profile.setIsLocal(true);
             contact.completeContact(profile.getGUID(), name, phone, email);
-            callback.onResult(contact);
+            doneCallback.onResult(contact);
         });
 
         mEditorDialog.show(editor);
+        if (mPayerErrors != null) mEditorDialog.validateForm();
     }
 
     private EditorFieldValidator getPhoneValidator() {
@@ -243,9 +277,13 @@ public class ContactEditor extends EditorBase<AutofillContact> {
             mPhoneValidator = new EditorFieldValidator() {
                 @Override
                 public boolean isValid(@Nullable CharSequence value) {
-                    return value != null
-                            && PhoneNumberUtils.isGlobalPhoneNumber(
-                                       PhoneNumberUtils.stripSeparators(value.toString()));
+                    // TODO(crbug.com/999286): PhoneNumberUtils internally trigger disk reads for
+                    //                         certain devices/configurations.
+                    try (StrictModeContext ignored = StrictModeContext.allowDiskReads()) {
+                        return value != null
+                                && PhoneNumberUtils.isGlobalPhoneNumber(
+                                        PhoneNumberUtils.stripSeparators(value.toString()));
+                    }
                 }
 
                 @Override
