@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,11 +6,8 @@ package org.chromium.chrome.browser.payments.ui;
 
 import android.content.Context;
 import android.content.res.Resources;
-import android.graphics.Color;
 import android.graphics.drawable.Drawable;
 import android.os.Handler;
-import android.support.v4.view.animation.LinearOutSlowInInterpolator;
-import android.support.v7.widget.GridLayout;
 import android.text.SpannableStringBuilder;
 import android.text.TextUtils;
 import android.text.TextUtils.TruncateAt;
@@ -31,19 +28,27 @@ import android.widget.LinearLayout;
 import android.widget.RadioButton;
 import android.widget.TextView;
 
+import androidx.annotation.ColorInt;
+import androidx.annotation.Nullable;
+import androidx.annotation.VisibleForTesting;
+import androidx.core.view.MarginLayoutParamsCompat;
+import androidx.gridlayout.widget.GridLayout;
+
 import org.chromium.base.ApiCompatibilityUtils;
-import org.chromium.base.VisibleForTesting;
 import org.chromium.chrome.R;
-import org.chromium.chrome.browser.widget.DualControlLayout;
-import org.chromium.chrome.browser.widget.TintedDrawable;
-import org.chromium.chrome.browser.widget.prefeditor.EditableOption;
+import org.chromium.chrome.browser.ChromeSemanticColorUtils;
+import org.chromium.components.autofill.EditableOption;
+import org.chromium.components.browser_ui.styles.SemanticColorUtils;
+import org.chromium.components.browser_ui.widget.DualControlLayout;
+import org.chromium.components.browser_ui.widget.TintedDrawable;
+import org.chromium.components.browser_ui.widget.animation.Interpolators;
+import org.chromium.ui.HorizontalListDividerDrawable;
 import org.chromium.ui.UiUtils;
+import org.chromium.ui.base.ViewUtils;
 
 import java.util.ArrayList;
 import java.util.List;
 
-import javax.annotation.Nullable;
-
 /**
  * Represents a single section in the {@link PaymentRequestUI} that flips between multiple states.
  *
@@ -117,16 +122,16 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
     public static final int EDIT_BUTTON_ADD = 2;
 
     /** Normal mode: White background, displays the item assuming the user accepts it as is. */
-    static final int DISPLAY_MODE_NORMAL = 3;
+    public static final int DISPLAY_MODE_NORMAL = 3;
 
     /** Editable mode: White background, displays the item with an edit chevron. */
-    static final int DISPLAY_MODE_EXPANDABLE = 4;
+    public static final int DISPLAY_MODE_EXPANDABLE = 4;
 
     /** Focused mode: Gray background, more padding, no edit chevron. */
-    static final int DISPLAY_MODE_FOCUSED = 5;
+    public static final int DISPLAY_MODE_FOCUSED = 5;
 
     /** Checking mode: Gray background, spinner overlay hides everything except the title. */
-    static final int DISPLAY_MODE_CHECKING = 6;
+    public static final int DISPLAY_MODE_CHECKING = 6;
 
     protected final SectionDelegate mDelegate;
     protected final int mLargeSpacing;
@@ -136,6 +141,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
     protected int mDisplayMode = DISPLAY_MODE_NORMAL;
 
     private final int mVerticalSpacing;
+    private final @ColorInt int mUnfocusedBackgroundColor;
     private final int mFocusedBackgroundColor;
     private final LinearLayout mMainSection;
     private final ImageView mLogoView;
@@ -164,8 +170,8 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         setGravity(Gravity.CENTER_VERTICAL);
 
         // Set the styling of the view.
-        mFocusedBackgroundColor = ApiCompatibilityUtils.getColor(
-                getResources(), R.color.payments_section_edit_background);
+        mUnfocusedBackgroundColor = ChromeSemanticColorUtils.getPaymentRequestBg(context);
+        mFocusedBackgroundColor = SemanticColorUtils.getDefaultBgColorElev1(context);
         mLargeSpacing =
                 getResources().getDimensionPixelSize(R.dimen.editor_dialog_section_large_spacing);
         mVerticalSpacing =
@@ -269,6 +275,25 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         updateControlLayout();
     }
 
+    /**
+     * Changes the appearance of the title.
+     *
+     * @param resId @see android.widget.TextView#setTextAppearance(int id).
+     */
+    protected void setTitleAppearance(int resId) {
+        ApiCompatibilityUtils.setTextAppearance(mTitleView, resId);
+    }
+
+    /**
+     * Changes the appearance of the summary.
+     *
+     * @param resId @see android.widget.TextView#setTextAppearance(int id).
+     */
+    protected void setSummaryAppearance(int leftResId, int rightResId) {
+        ApiCompatibilityUtils.setTextAppearance(mSummaryLeftTextView, leftResId);
+        ApiCompatibilityUtils.setTextAppearance(mSummaryRightTextView, rightResId);
+    }
+
     /**
      * Sets how the summary text should be displayed.
      *
@@ -343,7 +368,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         mTitleView = new TextView(getContext());
         mTitleView.setText(sectionName);
         ApiCompatibilityUtils.setTextAppearance(
-                mTitleView, R.style.PaymentsUiSectionHeader);
+                mTitleView, R.style.TextAppearance_TextMedium_Accent1);
         mainSectionLayout.addView(
                 mTitleView, new LayoutParams(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT));
 
@@ -351,12 +376,12 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         mSummaryLeftTextView = new TextView(getContext());
         mSummaryLeftTextView.setId(R.id.payments_left_summary_label);
         ApiCompatibilityUtils.setTextAppearance(
-                mSummaryLeftTextView, R.style.PaymentsUiSectionDefaultText);
+                mSummaryLeftTextView, R.style.TextAppearance_TextLarge_Primary);
 
         mSummaryRightTextView = new TextView(getContext());
         ApiCompatibilityUtils.setTextAppearance(
-                mSummaryRightTextView, R.style.PaymentsUiSectionDefaultText);
-        ApiCompatibilityUtils.setTextAlignment(mSummaryRightTextView, TEXT_ALIGNMENT_TEXT_END);
+                mSummaryRightTextView, R.style.TextAppearance_TextLarge_Primary);
+        mSummaryRightTextView.setTextAlignment(TEXT_ALIGNMENT_TEXT_END);
 
         // The main TextView sucks up all the available space.
         LinearLayout.LayoutParams leftLayoutParams = new LinearLayout.LayoutParams(
@@ -365,7 +390,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
 
         LinearLayout.LayoutParams rightLayoutParams = new LinearLayout.LayoutParams(
                 LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
-        ApiCompatibilityUtils.setMarginStart(rightLayoutParams,
+        MarginLayoutParamsCompat.setMarginStart(rightLayoutParams,
                 getContext().getResources().getDimensionPixelSize(
                         R.dimen.editor_dialog_section_small_spacing));
 
@@ -390,7 +415,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         // The logo has a pre-defined height and width.
         LayoutParams params =
                 new LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
-        ApiCompatibilityUtils.setMarginStart(params, startMargin);
+        MarginLayoutParamsCompat.setMarginStart(params, startMargin);
         parent.addView(view, params);
         return view;
     }
@@ -403,15 +428,14 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
 
         LayoutParams params =
                 new LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
-        ApiCompatibilityUtils.setMarginStart(params, mLargeSpacing);
+        MarginLayoutParamsCompat.setMarginStart(params, mLargeSpacing);
         parent.addView(view, params);
         return view;
     }
 
     private ImageView createAndAddChevron(ViewGroup parent) {
-        Resources resources = parent.getResources();
-        TintedDrawable chevron = TintedDrawable.constructTintedDrawable(
-                resources, R.drawable.ic_expand_more_black_24dp, R.color.payments_section_chevron);
+        TintedDrawable chevron = TintedDrawable.constructTintedDrawable(parent.getContext(),
+                R.drawable.ic_expand_more_black_24dp, R.color.payments_section_chevron);
 
         ImageView view = new ImageView(parent.getContext());
         view.setImageDrawable(chevron);
@@ -419,7 +443,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         // Wrap whatever image is passed in.
         LayoutParams params =
                 new LayoutParams(LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
-        ApiCompatibilityUtils.setMarginStart(params, mLargeSpacing);
+        MarginLayoutParamsCompat.setMarginStart(params, mLargeSpacing);
         parent.addView(view, params);
         return view;
     }
@@ -437,7 +461,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
 
         boolean isExpanded =
                 mDisplayMode == DISPLAY_MODE_FOCUSED || mDisplayMode == DISPLAY_MODE_CHECKING;
-        setBackgroundColor(isExpanded ? mFocusedBackgroundColor : Color.WHITE);
+        setBackgroundColor(isExpanded ? mFocusedBackgroundColor : mUnfocusedBackgroundColor);
 
         // Update whether the logo is displayed.
         if (mLogoView != null) {
@@ -478,7 +502,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         if (oldMargin != newMargin) {
             ((ViewGroup.MarginLayoutParams) mTitleView.getLayoutParams()).bottomMargin =
                     newMargin;
-            requestLayout();
+            ViewUtils.requestLayout(this, "PaymentRequestSection.UpdateControlLayout");
         }
     }
 
@@ -516,13 +540,15 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
          */
         private TextView mUpdatedView;
 
+        private final List<TextView> mLineItemAmountsForTest = new ArrayList<>();
+
         /** The runnable used to fade out the mUpdatedView. */
         private Runnable mFadeOutRunnable = new Runnable() {
             @Override
             public void run() {
                 Animation out = new AlphaAnimation(mUpdatedView.getAlpha(), 0.0f);
                 out.setDuration(UPDATE_TEXT_ANIMATION_DURATION_MS);
-                out.setInterpolator(new LinearOutSlowInInterpolator());
+                out.setInterpolator(Interpolators.LINEAR_OUT_SLOW_IN_INTERPOLATOR);
                 out.setFillAfter(true);
                 mUpdatedView.startAnimation(out);
             }
@@ -580,16 +606,15 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             // Create the view and set the text appearance and layout parameters.
             mUpdatedView = new TextView(context);
             ApiCompatibilityUtils.setTextAppearance(
-                    mUpdatedView, R.style.PaymentsUiSectionDefaultText);
+                    mUpdatedView, R.style.TextAppearance_TextLarge_Primary);
             LinearLayout.LayoutParams updatedLayoutParams = new LinearLayout.LayoutParams(
                     LayoutParams.WRAP_CONTENT, LayoutParams.WRAP_CONTENT);
-            ApiCompatibilityUtils.setTextAlignment(mUpdatedView, TEXT_ALIGNMENT_TEXT_END);
-            mUpdatedView.setTextColor(ApiCompatibilityUtils.getColor(
-                    context.getResources(), R.color.google_green_700));
-            ApiCompatibilityUtils.setMarginStart(updatedLayoutParams,
+            mUpdatedView.setTextAlignment(TEXT_ALIGNMENT_TEXT_END);
+            mUpdatedView.setTextColor(context.getColor(R.color.google_green_600));
+            MarginLayoutParamsCompat.setMarginStart(updatedLayoutParams,
                     context.getResources().getDimensionPixelSize(
                             R.dimen.editor_dialog_section_small_spacing));
-            ApiCompatibilityUtils.setMarginEnd(updatedLayoutParams,
+            MarginLayoutParamsCompat.setMarginEnd(updatedLayoutParams,
                     context.getResources().getDimensionPixelSize(
                             R.dimen.editor_dialog_section_small_spacing));
 
@@ -619,6 +644,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             setSummaryText(cart.getTotal().getLabel(), totalPrice);
 
             mBreakdownLayout.removeAllViews();
+            mLineItemAmountsForTest.clear();
             if (cart.getContents() == null) return;
 
             int maximumDescriptionWidthPx =
@@ -631,9 +657,10 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 LineItem item = cart.getContents().get(i);
 
                 TextView description = new TextView(context);
-                ApiCompatibilityUtils.setTextAppearance(description, item.getIsPending()
-                                ? R.style.PaymentsUiSectionPendingTextEndAligned
-                                : R.style.PaymentsUiSectionDescriptiveTextEndAligned);
+                ApiCompatibilityUtils.setTextAppearance(description,
+                        item.getIsPending()
+                            ? R.style.TextAppearance_PaymentsUiSectionPendingTextEndAligned
+                            : R.style.TextAppearance_PaymentsUiSectionDescriptiveTextEndAligned);
                 description.setText(item.getLabel());
                 description.setEllipsize(TruncateAt.END);
                 description.setMaxLines(2);
@@ -642,10 +669,12 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 }
 
                 TextView amount = new TextView(context);
-                ApiCompatibilityUtils.setTextAppearance(amount, item.getIsPending()
-                                ? R.style.PaymentsUiSectionPendingTextEndAligned
-                                : R.style.PaymentsUiSectionDescriptiveTextEndAligned);
+                ApiCompatibilityUtils.setTextAppearance(amount,
+                        item.getIsPending()
+                            ? R.style.TextAppearance_PaymentsUiSectionPendingTextEndAligned
+                            : R.style.TextAppearance_PaymentsUiSectionDescriptiveTextEndAligned);
                 amount.setText(createValueString(item.getCurrency(), item.getPrice(), false));
+                mLineItemAmountsForTest.add(amount);
 
                 // Each item is represented by a row in the GridLayout.
                 GridLayout.LayoutParams descriptionParams = new GridLayout.LayoutParams(
@@ -654,7 +683,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 GridLayout.LayoutParams amountParams = new GridLayout.LayoutParams(
                         GridLayout.spec(i, 1, GridLayout.END),
                         GridLayout.spec(1, 1, GridLayout.END));
-                ApiCompatibilityUtils.setMarginStart(amountParams,
+                MarginLayoutParamsCompat.setMarginStart(amountParams,
                         context.getResources().getDimensionPixelSize(
                                 R.dimen.payments_section_descriptive_item_spacing));
 
@@ -689,7 +718,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             // to avoid restarting a previous or current fade in animation.
             Animation in = new AlphaAnimation(mUpdatedView.getAlpha(), 1.0f);
             in.setDuration(UPDATE_TEXT_ANIMATION_DURATION_MS);
-            in.setInterpolator(new LinearOutSlowInInterpolator());
+            in.setInterpolator(Interpolators.LINEAR_OUT_SLOW_IN_INTERPOLATOR);
             in.setFillAfter(true);
             mUpdatedView.startAnimation(in);
 
@@ -747,6 +776,21 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             mBreakdownLayout.setVisibility(mDisplayMode == DISPLAY_MODE_FOCUSED ? VISIBLE : GONE);
             super.updateControlLayout();
         }
+
+        /**
+         * Returns the line item amount at the specified |index|. Returns null if there is no amount
+         * at that index.
+         */
+        @VisibleForTesting
+        public TextView getLineItemAmountForTest(int index) {
+            return mLineItemAmountsForTest.get(index);
+        }
+
+        /** @return The number of line items. */
+        @VisibleForTesting
+        public int getNumberOfLineItemsForTest() {
+            return mLineItemAmountsForTest.size();
+        }
     }
 
     /**
@@ -888,14 +932,14 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                     int drawableTint;
                     if (mRowType == OPTION_ROW_TYPE_WARNING) {
                         drawableId = R.drawable.ic_warning_white_24dp;
-                        drawableTint = R.color.error_text_color;
+                        drawableTint = R.color.default_text_color_error;
                     } else {
                         drawableId = R.drawable.plus;
-                        drawableTint = R.color.light_active_color;
+                        drawableTint = R.color.default_icon_color_accent1_tint_list;
                     }
 
                     TintedDrawable tintedDrawable = TintedDrawable.constructTintedDrawable(
-                            context.getResources(), drawableId, drawableTint);
+                            context, drawableId, drawableTint);
                     ImageButton button = new ImageButton(context);
                     button.setBackground(null);
                     button.setImageDrawable(tintedDrawable);
@@ -908,7 +952,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                         GridLayout.spec(rowIndex, 1, GridLayout.CENTER),
                         GridLayout.spec(0, 1, GridLayout.CENTER));
                 buttonParams.topMargin = mVerticalMargin;
-                ApiCompatibilityUtils.setMarginEnd(buttonParams, mLargeSpacing);
+                MarginLayoutParamsCompat.setMarginEnd(buttonParams, mLargeSpacing);
                 parent.addView(view, buttonParams);
 
                 view.setImportantForAccessibility(IMPORTANT_FOR_ACCESSIBILITY_NO);
@@ -934,9 +978,6 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 TextView labelView = new TextView(context);
                 if (mRowType == OPTION_ROW_TYPE_OPTION) {
                     // Show the string representing the EditableOption.
-                    ApiCompatibilityUtils.setTextAppearance(labelView, isEnabled
-                            ? R.style.PaymentsUiSectionDefaultText
-                            : R.style.PaymentsUiSectionDisabledText);
                     labelView.setText(convertOptionToString(mOption, false, /* excludeMainLabel */
                             mDelegate.isBoldLabelNeeded(OptionSection.this),
                             false /* singleLine */));
@@ -947,7 +988,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                             R.dimen.payments_section_add_button_height);
 
                     ApiCompatibilityUtils.setTextAppearance(
-                            labelView, R.style.EditorDialogSectionAddButtonLabel);
+                            labelView, R.style.TextAppearance_EditorDialogSectionAddButton);
                     labelView.setMinimumHeight(buttonHeight);
                     labelView.setGravity(Gravity.CENTER_VERTICAL);
                     labelView.setTypeface(UiUtils.createRobotoMediumTypeface());
@@ -957,12 +998,14 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                     columnSpan = 4;
 
                     ApiCompatibilityUtils.setTextAppearance(
-                            labelView, R.style.PaymentsUiSectionDescriptiveText);
+                            labelView, R.style.TextAppearance_TextMedium_Secondary);
+                    labelView.setId(R.id.payments_description_label);
                 } else if (mRowType == OPTION_ROW_TYPE_WARNING) {
                     // Warnings use three columns.
                     columnSpan = 3;
                     ApiCompatibilityUtils.setTextAppearance(
-                            labelView, R.style.PaymentsUiSectionWarningText);
+                            labelView, R.style.TextAppearance_PaymentsUiSectionWarningText);
+                    labelView.setId(R.id.payments_warning_label);
                 }
 
                 // The label spans two columns if no option or edit icon, or spans three columns if
@@ -978,7 +1021,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                     // end margin) when edit icon exits in that row, like below:
                     // ---Label---------------------[label margin]|---option icon---|
                     // ---Label---[label margin]|---option icon---|----edit icon----|
-                    ApiCompatibilityUtils.setMarginEnd(labelParams, mLargeSpacing);
+                    MarginLayoutParamsCompat.setMarginEnd(labelParams, mLargeSpacing);
                 }
                 parent.addView(labelView, labelParams);
 
@@ -1068,7 +1111,7 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
          */
         private boolean mSplitSummaryInDisplayModeNormal;
 
-        /** Indicates whether the summary is set to R.style.PaymentsUiSectionDescriptiveText. */
+        /** Indicates whether the summary is set to descriptive or title text style. */
         private boolean mSummaryInDescriptiveText;
 
         private FocusChangedObserver mFocusChangedObserver;
@@ -1225,7 +1268,8 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 params.height = LayoutParams.WRAP_CONTENT;
                 params.bottomMargin = getContext().getResources().getDimensionPixelSize(
                         R.dimen.payments_section_checking_spacing);
-                mCheckingProgress.requestLayout();
+                ViewUtils.requestLayout(
+                        mCheckingProgress, "PaymentRequestSection.OptionRow.setSpinnerVisibility");
             } else {
                 if (mCheckingProgress.getParent() == null) return;
 
@@ -1293,10 +1337,10 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
 
             if (selectedItem == null) {
                 setLogoDrawable(null);
-                // Section summary should be displayed as R.style.PaymentsUiSectionDescriptiveText.
+                // Section summary should be displayed as descriptive text style.
                 if (!mSummaryInDescriptiveText) {
                     ApiCompatibilityUtils.setTextAppearance(
-                            getSummaryLeftTextView(), R.style.PaymentsUiSectionDescriptiveText);
+                            getSummaryLeftTextView(), R.style.TextAppearance_TextMedium_Secondary);
                     mSummaryInDescriptiveText = true;
                 }
                 SectionUiUtils.showSectionSummaryInTextViewInSingeLine(
@@ -1304,10 +1348,10 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
             } else {
                 setLogoDrawable(selectedItem.getDrawableIcon());
                 // Selected item summary should be displayed as
-                // R.style.PaymentsUiSectionDefaultText.
+                // R.style.TextAppearance_TextLarge_Primary.
                 if (mSummaryInDescriptiveText) {
                     ApiCompatibilityUtils.setTextAppearance(
-                            getSummaryLeftTextView(), R.style.PaymentsUiSectionDefaultText);
+                            getSummaryLeftTextView(), R.style.TextAppearance_TextLarge_Primary);
                     mSummaryInDescriptiveText = false;
                 }
                 // Split summary in DISPLAY_MODE_NORMAL if caller specified. The first part is
@@ -1411,8 +1455,8 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
                 if (builder.length() > 0) builder.append(labelSeparator);
                 String editMessage = item.getEditMessage();
                 builder.append(editMessage);
-                Object foregroundSpanner = new ForegroundColorSpan(ApiCompatibilityUtils.getColor(
-                        getContext().getResources(), R.color.google_blue_700));
+                Object foregroundSpanner = new ForegroundColorSpan(
+                        SemanticColorUtils.getDefaultTextColorLink(getContext()));
                 Object sizeSpanner = new AbsoluteSizeSpan(14, true);
                 int startIndex = builder.length() - editMessage.length();
                 builder.setSpan(foregroundSpanner, startIndex, builder.length(), 0);
@@ -1474,24 +1518,23 @@ public abstract class PaymentRequestSection extends LinearLayout implements View
         public SectionSeparator(ViewGroup parent, int index) {
             super(parent.getContext());
             Resources resources = parent.getContext().getResources();
-            setBackgroundColor(ApiCompatibilityUtils.getColor(
-                    resources, R.color.payments_section_separator));
+            setBackground(HorizontalListDividerDrawable.create(getContext()));
             LinearLayout.LayoutParams params =
                     new LinearLayout.LayoutParams(LayoutParams.MATCH_PARENT,
-                            resources.getDimensionPixelSize(R.dimen.separator_height));
+                            resources.getDimensionPixelSize(R.dimen.divider_height));
 
             int margin =
                     resources.getDimensionPixelSize(R.dimen.editor_dialog_section_large_spacing);
-            ApiCompatibilityUtils.setMarginStart(params, margin);
-            ApiCompatibilityUtils.setMarginEnd(params, margin);
+            MarginLayoutParamsCompat.setMarginStart(params, margin);
+            MarginLayoutParamsCompat.setMarginEnd(params, margin);
             parent.addView(this, index, params);
         }
 
         /** Expand the separator to be the full width of the dialog. */
         public void expand() {
             LinearLayout.LayoutParams params = (LinearLayout.LayoutParams) getLayoutParams();
-            ApiCompatibilityUtils.setMarginStart(params, 0);
-            ApiCompatibilityUtils.setMarginEnd(params, 0);
+            MarginLayoutParamsCompat.setMarginStart(params, 0);
+            MarginLayoutParamsCompat.setMarginEnd(params, 0);
         }
     }
 }
