@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -6,17 +6,16 @@ package org.chromium.chrome.browser.payments.ui;
 
 import android.text.TextUtils;
 
-import org.chromium.base.VisibleForTesting;
+import androidx.annotation.Nullable;
+
 import org.chromium.chrome.R;
-import org.chromium.chrome.browser.widget.prefeditor.EditableOption;
+import org.chromium.components.autofill.EditableOption;
 
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
 
-import javax.annotation.Nullable;
-
 /**
  * The data to show in a single section where the user can select something, e.g., their
  * shipping address or payment method.
@@ -32,9 +31,12 @@ public class SectionInformation {
      */
     public static final int INVALID_SELECTION = -2;
 
+    protected final ArrayList<EditableOption> mItems = new ArrayList<>();
+
     @PaymentRequestUI.DataType private final int mDataType;
-    protected ArrayList<EditableOption> mItems;
+
     private int mSelectedItem;
+    private boolean mDisplayInSingleLineInNormalMode = true;
     public String mErrorMessage;
     @Nullable
     public String mAddditionalText;
@@ -84,7 +86,7 @@ public class SectionInformation {
      * @return Whether the section is empty.
      */
     public boolean isEmpty() {
-        return mItems == null || mItems.isEmpty();
+        return mItems.isEmpty();
     }
 
     /**
@@ -94,7 +96,7 @@ public class SectionInformation {
      * @return The number of items in this section.
      */
     public int getSize() {
-        return mItems == null ? 0 : mItems.size();
+        return mItems.size();
     }
 
     /**
@@ -103,8 +105,9 @@ public class SectionInformation {
      * @param position The index of the item to return.
      * @return The item in the given position or null.
      */
+    @Nullable
     public EditableOption getItem(int position) {
-        if (mItems == null || mItems.isEmpty() || position < 0 || position >= mItems.size()) {
+        if (mItems.isEmpty() || position < 0 || position >= mItems.size()) {
             return null;
         }
 
@@ -128,7 +131,6 @@ public class SectionInformation {
      *                     made.
      */
     public void setSelectedItem(EditableOption selectedItem) {
-        if (mItems == null) return;
         for (int i = 0; i < mItems.size(); i++) {
             if (mItems.get(i) == selectedItem) {
                 mSelectedItem = i;
@@ -152,6 +154,7 @@ public class SectionInformation {
      *
      * @return The selected item or null if none selected.
      */
+    @Nullable
     public EditableOption getSelectedItem() {
         return getItem(getSelectedItemIndex());
     }
@@ -162,7 +165,6 @@ public class SectionInformation {
      * @param item The item to add.
      */
     public void addAndSelectItem(EditableOption item) {
-        if (mItems == null) mItems = new ArrayList<>();
         mItems.add(0, item);
         mSelectedItem = 0;
     }
@@ -174,7 +176,6 @@ public class SectionInformation {
      * @param item The item to add or update.
      */
     public void addAndSelectOrUpdateItem(EditableOption item) {
-        if (mItems == null) mItems = new ArrayList<>();
         int i = 0;
         for (; i < mItems.size(); i++) {
             if (TextUtils.equals(mItems.get(i).getIdentifier(), item.getIdentifier())) {
@@ -223,11 +224,11 @@ public class SectionInformation {
      * @return ID if the user can add a new option, or 0 if they can't.
      */
     public int getAddStringId() {
-        if (mDataType == PaymentRequestUI.TYPE_SHIPPING_ADDRESSES) {
+        if (mDataType == PaymentRequestUI.DataType.SHIPPING_ADDRESSES) {
             return R.string.payments_add_address;
-        } else if (mDataType == PaymentRequestUI.TYPE_CONTACT_DETAILS) {
+        } else if (mDataType == PaymentRequestUI.DataType.CONTACT_DETAILS) {
             return R.string.payments_add_contact;
-        } else if (mDataType == PaymentRequestUI.TYPE_PAYMENT_METHODS) {
+        } else if (mDataType == PaymentRequestUI.DataType.PAYMENT_METHODS) {
             return R.string.payments_add_card;
         }
         return 0;
@@ -240,13 +241,13 @@ public class SectionInformation {
      */
     public int getPreviewStringResourceId() {
         switch (mDataType) {
-            case PaymentRequestUI.TYPE_SHIPPING_ADDRESSES:
+            case PaymentRequestUI.DataType.SHIPPING_ADDRESSES:
                 return R.plurals.payment_request_shipping_addresses_preview;
-            case PaymentRequestUI.TYPE_SHIPPING_OPTIONS:
+            case PaymentRequestUI.DataType.SHIPPING_OPTIONS:
                 return R.plurals.payment_request_shipping_options_preview;
-            case PaymentRequestUI.TYPE_PAYMENT_METHODS:
+            case PaymentRequestUI.DataType.PAYMENT_METHODS:
                 return R.plurals.payment_request_payment_methods_preview;
-            case PaymentRequestUI.TYPE_CONTACT_DETAILS:
+            case PaymentRequestUI.DataType.CONTACT_DETAILS:
                 return R.plurals.payment_request_contacts_preview;
             default:
                 assert false : "unknown data type";
@@ -275,13 +276,8 @@ public class SectionInformation {
         return mAddditionalText;
     }
 
-    /**
-     * Returns all the items in the section. Used for testing.
-     *
-     * @return List of items in the section.
-     */
-    @VisibleForTesting
-    public List<EditableOption> getItemsForTesting() {
+    /** @return List of items in the section. */
+    public List<EditableOption> getItems() {
         return mItems;
     }
 
@@ -293,12 +289,31 @@ public class SectionInformation {
      */
     protected void updateItemsWithCollection(
             int selection, @Nullable Collection<? extends EditableOption> itemCollection) {
+        mItems.clear();
         if (itemCollection == null || itemCollection.isEmpty()) {
             mSelectedItem = NO_SELECTION;
-            mItems = null;
         } else {
             mSelectedItem = selection;
-            mItems = new ArrayList<>(itemCollection);
+            mItems.addAll(itemCollection);
         }
     }
+
+    /**
+     * Set whether display the selected item summary in single line in
+     * PaymentRequestSection.DISPLAY_MODE_NORMAL.
+     *
+     * @param singleLine whether display in single line, note that the default value is true.
+     */
+    public void setDisplaySelectedItemSummaryInSingleLineInNormalMode(boolean singleLine) {
+        mDisplayInSingleLineInNormalMode = singleLine;
+    }
+
+    /**
+     * Get whether display the selected item summary in single line in
+     * PaymentRequestSection.DISPLAY_MODE_NORMAL.
+     *
+     */
+    public boolean getDisplaySelectedItemSummaryInSingleLineInNormalMode() {
+        return mDisplayInSingleLineInNormalMode;
+    }
 }
