@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -8,27 +8,37 @@ import android.annotation.SuppressLint;
 import android.os.Handler;
 import android.os.Message;
 
-import org.chromium.chrome.browser.UrlConstants;
+import androidx.annotation.Nullable;
+
+import org.chromium.cc.input.BrowserControlsState;
 import org.chromium.chrome.browser.device.DeviceClassManager;
-import org.chromium.chrome.browser.util.AccessibilityUtil;
+import org.chromium.chrome.browser.util.ChromeAccessibilityUtil;
+import org.chromium.components.browser_ui.util.BrowserControlsVisibilityDelegate;
 import org.chromium.components.dom_distiller.core.DomDistillerUrlUtils;
-import org.chromium.components.security_state.ConnectionSecurityLevel;
-import org.chromium.content.browser.ContentViewCore;
+import org.chromium.components.embedder_support.util.UrlConstants;
+import org.chromium.components.security_state.SecurityStateModel;
+import org.chromium.content_public.browser.ImeAdapter;
+import org.chromium.content_public.browser.ImeEventObserver;
+import org.chromium.content_public.browser.NavigationHandle;
+import org.chromium.content_public.browser.SelectionPopupController;
 import org.chromium.content_public.browser.WebContents;
+import org.chromium.ui.base.WindowAndroid;
+import org.chromium.url.GURL;
 
 /**
  * Determines the desired visibility of the browser controls based on the current state of a given
  * tab.
  */
 public class TabStateBrowserControlsVisibilityDelegate
-        implements BrowserControlsVisibilityDelegate {
+        extends BrowserControlsVisibilityDelegate implements ImeEventObserver {
     protected static final int MSG_ID_ENABLE_FULLSCREEN_AFTER_LOAD = 1;
     /** The maximum amount of time to wait for a page to load before entering fullscreen. */
     private static final long MAX_FULLSCREEN_LOAD_DELAY_MS = 3000;
 
     private static boolean sDisableLoadingCheck;
 
-    protected final Tab mTab;
+    protected final TabImpl mTab;
+    private WebContents mWebContents;
 
     private boolean mIsFullscreenWaitingForLoad;
 
@@ -37,7 +47,9 @@ public class TabStateBrowserControlsVisibilityDelegate
      * @param tab The associated {@link Tab}.
      */
     public TabStateBrowserControlsVisibilityDelegate(Tab tab) {
-        mTab = tab;
+        super(BrowserControlsState.BOTH);
+
+        mTab = (TabImpl) tab;
 
         mTab.addObserver(new EmptyTabObserver() {
             @SuppressLint("HandlerLeak")
@@ -46,7 +58,8 @@ public class TabStateBrowserControlsVisibilityDelegate
                 public void handleMessage(Message msg) {
                     if (msg == null) return;
                     if (msg.what == MSG_ID_ENABLE_FULLSCREEN_AFTER_LOAD) {
-                        enableFullscreenAfterLoad();
+                        if (!mIsFullscreenWaitingForLoad) return;
+                        updateWaitingForLoad(false);
                     }
                 }
             };
@@ -55,16 +68,9 @@ public class TabStateBrowserControlsVisibilityDelegate
                 return sDisableLoadingCheck ? 0 : MAX_FULLSCREEN_LOAD_DELAY_MS;
             }
 
-            private void enableFullscreenAfterLoad() {
-                if (!mIsFullscreenWaitingForLoad) return;
-
-                mIsFullscreenWaitingForLoad = false;
-                mTab.updateFullscreenEnabledState();
-            }
-
             private void cancelEnableFullscreenLoadDelay() {
                 mHandler.removeMessages(MSG_ID_ENABLE_FULLSCREEN_AFTER_LOAD);
-                mIsFullscreenWaitingForLoad = false;
+                updateWaitingForLoad(false);
             }
 
             private void scheduleEnableFullscreenLoadDelayIfNecessary() {
@@ -75,6 +81,11 @@ public class TabStateBrowserControlsVisibilityDelegate
                 }
             }
 
+            @Override
+            public void onContentChanged(Tab tab) {
+                onWebContentsUpdated(tab.getWebContents());
+            }
+
             @Override
             public void onWebContentsSwapped(Tab tab, boolean didStartLoad, boolean didFinishLoad) {
                 if (!didStartLoad) return;
@@ -85,25 +96,22 @@ public class TabStateBrowserControlsVisibilityDelegate
             }
 
             @Override
-            public void onDidFinishNavigation(Tab tab, String url, boolean isInMainFrame,
-                    boolean isErrorPage, boolean hasCommitted, boolean isSameDocument,
-                    boolean isFragmentNavigation, Integer pageTransition, int errorCode,
-                    int httpStatusCode) {
-                if (!hasCommitted || !isInMainFrame) return;
+            public void onDidFinishNavigationInPrimaryMainFrame(
+                    Tab tab, NavigationHandle navigation) {
+                if (!navigation.hasCommitted()) return;
                 mHandler.removeMessages(MSG_ID_ENABLE_FULLSCREEN_AFTER_LOAD);
                 mHandler.sendEmptyMessageDelayed(
                         MSG_ID_ENABLE_FULLSCREEN_AFTER_LOAD, getLoadDelayMs());
-                mTab.updateFullscreenEnabledState();
             }
 
             @Override
-            public void onPageLoadStarted(Tab tab, String url) {
-                mIsFullscreenWaitingForLoad = !DomDistillerUrlUtils.isDistilledPage(url);
-                mTab.updateFullscreenEnabledState();
+            public void onPageLoadStarted(Tab tab, GURL url) {
+                mHandler.removeMessages(MSG_ID_ENABLE_FULLSCREEN_AFTER_LOAD);
+                updateWaitingForLoad(!DomDistillerUrlUtils.isDistilledPage(url));
             }
 
             @Override
-            public void onPageLoadFinished(Tab tab) {
+            public void onPageLoadFinished(Tab tab, GURL url) {
                 // Handle the case where a commit or prerender swap notification failed to arrive
                 // and the enable fullscreen message was never enqueued.
                 scheduleEnableFullscreenLoadDelayIfNecessary();
@@ -112,14 +120,33 @@ public class TabStateBrowserControlsVisibilityDelegate
             @Override
             public void onPageLoadFailed(Tab tab, int errorCode) {
                 cancelEnableFullscreenLoadDelay();
-                mTab.updateFullscreenEnabledState();
             }
 
             @Override
-            public void onHidden(Tab tab) {
+            public void onHidden(Tab tab, @TabHidingType int type) {
                 cancelEnableFullscreenLoadDelay();
             }
 
+            @Override
+            public void onSSLStateUpdated(Tab tab) {
+                updateVisibilityConstraints();
+            }
+
+            @Override
+            public void onRendererResponsiveStateChanged(Tab tab, boolean isResponsive) {
+                updateVisibilityConstraints();
+            }
+
+            @Override
+            public void onShown(Tab tab, int type) {
+                updateVisibilityConstraints();
+            }
+
+            @Override
+            public void onActivityAttachmentChanged(Tab tab, @Nullable WindowAndroid window) {
+                if (window != null) updateVisibilityConstraints();
+            }
+
             @Override
             public void onDestroyed(Tab tab) {
                 super.onDestroyed(tab);
@@ -128,39 +155,62 @@ public class TabStateBrowserControlsVisibilityDelegate
                 mHandler.removeCallbacksAndMessages(null);
             }
         });
+        onWebContentsUpdated(mTab.getWebContents());
+        updateVisibilityConstraints();
     }
 
-    @Override
-    public boolean canAutoHideBrowserControls() {
+    private void onWebContentsUpdated(WebContents contents) {
+        if (mWebContents == contents) return;
+        mWebContents = contents;
+        if (mWebContents == null) return;
+        ImeAdapter.fromWebContents(mWebContents).addEventObserver(this);
+    }
+
+    private void updateWaitingForLoad(boolean waiting) {
+        if (mIsFullscreenWaitingForLoad == waiting) return;
+        mIsFullscreenWaitingForLoad = waiting;
+        updateVisibilityConstraints();
+    }
+
+    private boolean enableHidingBrowserControls() {
         WebContents webContents = mTab.getWebContents();
         if (webContents == null || webContents.isDestroyed()) return false;
 
-        String url = mTab.getUrl();
+        GURL url = mTab.getUrl();
         boolean enableHidingBrowserControls = url != null;
-        enableHidingBrowserControls &= !url.startsWith(UrlConstants.CHROME_URL_PREFIX);
-        enableHidingBrowserControls &= !url.startsWith(UrlConstants.CHROME_NATIVE_URL_PREFIX);
+        enableHidingBrowserControls &= !url.getScheme().equals(UrlConstants.CHROME_SCHEME);
+        enableHidingBrowserControls &= !url.getScheme().equals(UrlConstants.CHROME_NATIVE_SCHEME);
 
-        int securityState = mTab.getSecurityLevel();
-        enableHidingBrowserControls &= (securityState != ConnectionSecurityLevel.DANGEROUS);
-
-        enableHidingBrowserControls &= !AccessibilityUtil.isAccessibilityEnabled();
-
-        ContentViewCore cvc = mTab.getContentViewCore();
-        enableHidingBrowserControls &= cvc == null || !cvc.isFocusedNodeEditable();
+        enableHidingBrowserControls &=
+                !SecurityStateModel.isContentDangerous(mTab.getWebContents());
+        enableHidingBrowserControls &=
+                !SelectionPopupController.fromWebContents(webContents).isFocusedNodeEditable();
         enableHidingBrowserControls &= !mTab.isShowingErrorPage();
-        enableHidingBrowserControls &= !webContents.isShowingInterstitialPage();
         enableHidingBrowserControls &= !mTab.isRendererUnresponsive();
-        enableHidingBrowserControls &= (mTab.getFullscreenManager() != null);
-        enableHidingBrowserControls &= DeviceClassManager.enableFullscreen();
+        enableHidingBrowserControls &= !mTab.isHidden();
         enableHidingBrowserControls &= !mIsFullscreenWaitingForLoad;
 
+        // TODO(tedchoc): AccessibilityUtil and DeviceClassManager checks do not belong in Tab
+        //                logic.  They should be moved to application level checks.
+        enableHidingBrowserControls &= !ChromeAccessibilityUtil.get().isAccessibilityEnabled();
+        enableHidingBrowserControls &= DeviceClassManager.enableFullscreen();
+
         return enableHidingBrowserControls;
     }
 
-    @Override
-    public boolean canShowBrowserControls() {
-        if (mTab.getFullscreenManager() == null) return true;
-        return !mTab.getFullscreenManager().getPersistentFullscreenMode();
+    /**
+     * @return The constraints that determine the visibility of the browser controls.
+     */
+    protected @BrowserControlsState int calculateVisibilityConstraints() {
+        return enableHidingBrowserControls() ? BrowserControlsState.BOTH
+                                             : BrowserControlsState.SHOWN;
+    }
+
+    /**
+     * Updates the browser controls visibility constraints based on the current configuration.
+     */
+    protected void updateVisibilityConstraints() {
+        set(calculateVisibilityConstraints());
     }
 
     /**
@@ -169,4 +219,11 @@ public class TabStateBrowserControlsVisibilityDelegate
     public static void disablePageLoadDelayForTests() {
         sDisableLoadingCheck = true;
     }
+
+    // ImeEventObserver
+
+    @Override
+    public void onNodeAttributeUpdated(boolean editable, boolean password) {
+        updateVisibilityConstraints();
+    }
 }
