@@ -1,19 +1,22 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.webapps;
 
-import android.content.pm.PackageManager;
+import android.content.Intent;
 import android.graphics.Bitmap;
 
 import org.chromium.base.Callback;
-import org.chromium.base.ContextUtils;
+import org.chromium.base.PackageUtils;
 import org.chromium.base.annotations.CalledByNative;
+import org.chromium.base.annotations.NativeMethods;
+import org.chromium.base.task.AsyncTask;
 import org.chromium.chrome.browser.AppHooks;
-import org.chromium.chrome.browser.banners.InstallerDelegate;
-import org.chromium.chrome.browser.metrics.WebApkUma;
-import org.chromium.webapk.lib.common.WebApkConstants;
+import org.chromium.chrome.browser.browserservices.intents.BrowserServicesIntentDataProvider;
+import org.chromium.chrome.browser.browserservices.intents.WebappIntentUtils;
+import org.chromium.chrome.browser.browserservices.metrics.WebApkUmaRecorder;
+import org.chromium.components.webapps.WebApkInstallResult;
 
 /**
  * Java counterpart to webapk_installer.h
@@ -21,7 +24,6 @@ import org.chromium.webapk.lib.common.WebApkConstants;
  * This Java object is created by and owned by the native WebApkInstaller.
  */
 public class WebApkInstaller {
-    private static final String TAG = "WebApkInstaller";
 
     /** Weak pointer to the native WebApkInstaller. */
     private long mNativePointer;
@@ -29,9 +31,12 @@ public class WebApkInstaller {
     /** Talks to Google Play to install WebAPKs. */
     private final GooglePlayWebApkInstallDelegate mInstallDelegate;
 
+    private final String mWebApkServerUrl;
+
     private WebApkInstaller(long nativePtr) {
         mNativePointer = nativePtr;
         mInstallDelegate = AppHooks.get().getGooglePlayWebApkInstallDelegate();
+        mWebApkServerUrl = AppHooks.get().getWebApkServerUrl();
     }
 
     @CalledByNative
@@ -66,9 +71,9 @@ public class WebApkInstaller {
         }
 
         if (mInstallDelegate == null) {
-            notify(WebApkInstallResult.FAILURE);
-            WebApkUma.recordGooglePlayInstallResult(
-                    WebApkUma.GOOGLE_PLAY_INSTALL_FAILED_NO_DELEGATE);
+            notify(WebApkInstallResult.NO_INSTALLER);
+            WebApkUmaRecorder.recordGooglePlayInstallResult(
+                    WebApkUmaRecorder.GooglePlayInstallResult.FAILED_NO_DELEGATE);
             return;
         }
 
@@ -80,10 +85,18 @@ public class WebApkInstaller {
 
                 // Stores the source info of WebAPK in WebappDataStorage.
                 WebappRegistry.getInstance().register(
-                        WebApkConstants.WEBAPK_ID_PREFIX + packageName,
+                        WebappIntentUtils.getIdForWebApkPackage(packageName),
                         new WebappRegistry.FetchWebappDataStorageCallback() {
                             @Override
                             public void onWebappDataStorageRetrieved(WebappDataStorage storage) {
+                                BrowserServicesIntentDataProvider intentDataProvider =
+                                        WebApkIntentDataProviderFactory.create(new Intent(),
+                                                packageName, null, source,
+                                                false /* forceNavigation */,
+                                                false /* canUseSplashFromContentProvider */,
+                                                null /* shareData */,
+                                                null /* shareDataActivityClassName */);
+                                storage.updateFromWebappIntentDataProvider(intentDataProvider);
                                 storage.updateSource(source);
                                 storage.updateTimeOfLastCheckForUpdatedWebManifest();
                             }
@@ -95,7 +108,7 @@ public class WebApkInstaller {
 
     private void notify(@WebApkInstallResult int result) {
         if (mNativePointer != 0) {
-            nativeOnInstallFinished(mNativePointer, result);
+            WebApkInstallerJni.get().onInstallFinished(mNativePointer, result);
         }
     }
 
@@ -110,7 +123,7 @@ public class WebApkInstaller {
     private void updateAsync(
             String packageName, int version, String title, String token) {
         if (mInstallDelegate == null) {
-            notify(WebApkInstallResult.FAILURE);
+            notify(WebApkInstallResult.NO_INSTALLER);
             return;
         }
 
@@ -123,11 +136,43 @@ public class WebApkInstaller {
         mInstallDelegate.updateAsync(packageName, version, title, token, callback);
     }
 
-    private boolean isWebApkInstalled(String packageName) {
-        PackageManager packageManager = ContextUtils.getApplicationContext().getPackageManager();
-        return InstallerDelegate.isInstalled(packageManager, packageName);
+    @CalledByNative
+    private void checkFreeSpace() {
+        new AsyncTask<Integer>() {
+            @Override
+            protected Integer doInBackground() {
+                long availableSpaceInBytes =
+                        WebApkUmaRecorder.getAvailableSpaceAboveLowSpaceLimit();
+
+                if (availableSpaceInBytes > 0) return SpaceStatus.ENOUGH_SPACE;
+
+                long cacheSizeInBytes = WebApkUmaRecorder.getCacheDirSize();
+                if (cacheSizeInBytes + availableSpaceInBytes > 0) {
+                    return SpaceStatus.ENOUGH_SPACE_AFTER_FREE_UP_CACHE;
+                }
+                return SpaceStatus.NOT_ENOUGH_SPACE;
+            }
+
+            @Override
+            protected void onPostExecute(Integer result) {
+                WebApkInstallerJni.get().onGotSpaceStatus(mNativePointer, result);
+            }
+        }
+                .executeOnExecutor(AsyncTask.THREAD_POOL_EXECUTOR);
     }
 
-    private native void nativeOnInstallFinished(
-            long nativeWebApkInstaller, @WebApkInstallResult int result);
+    @CalledByNative
+    private String getWebApkServerUrl() {
+        return mWebApkServerUrl;
+    }
+
+    private boolean isWebApkInstalled(String packageName) {
+        return PackageUtils.isPackageInstalled(packageName);
+    }
+
+    @NativeMethods
+    interface Natives {
+        void onInstallFinished(long nativeWebApkInstaller, @WebApkInstallResult int result);
+        void onGotSpaceStatus(long nativeWebApkInstaller, int status);
+    }
 }
