@@ -1,10 +1,9 @@
-// Copyright 2014 The Chromium Authors. All rights reserved.
+// Copyright 2014 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser;
 
-import android.annotation.TargetApi;
 import android.content.pm.ApplicationInfo;
 import android.content.pm.PackageManager;
 import android.graphics.Rect;
@@ -13,10 +12,11 @@ import android.os.Bundle;
 import android.os.Handler;
 import android.os.HandlerThread;
 import android.os.Message;
-import android.support.test.filters.MediumTest;
 import android.view.View;
 import android.view.ViewGroup;
 
+import androidx.test.filters.MediumTest;
+
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
@@ -24,18 +24,20 @@ import org.junit.Rule;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
-import org.chromium.base.ThreadUtils;
 import org.chromium.base.test.util.CallbackHelper;
 import org.chromium.base.test.util.CommandLineFlags;
+import org.chromium.base.test.util.DisabledTest;
 import org.chromium.base.test.util.Feature;
 import org.chromium.base.test.util.Restriction;
-import org.chromium.base.test.util.RetryOnFailure;
 import org.chromium.base.test.util.UrlUtils;
-import org.chromium.chrome.test.ChromeActivityTestRule;
+import org.chromium.chrome.browser.app.ChromeActivity;
+import org.chromium.chrome.browser.flags.ChromeSwitches;
 import org.chromium.chrome.test.ChromeJUnit4ClassRunner;
-import org.chromium.content.browser.test.util.Coordinates;
-import org.chromium.content.browser.test.util.DOMUtils;
+import org.chromium.chrome.test.ChromeTabbedActivityTestRule;
 import org.chromium.content_public.browser.WebContents;
+import org.chromium.content_public.browser.test.util.Coordinates;
+import org.chromium.content_public.browser.test.util.DOMUtils;
+import org.chromium.content_public.browser.test.util.TestThreadUtils;
 import org.chromium.ui.test.util.UiRestriction;
 
 import java.lang.reflect.Method;
@@ -52,8 +54,7 @@ public class SmartClipProviderTest implements Handler.Callback {
     // interface.
 
     @Rule
-    public ChromeActivityTestRule<ChromeActivity> mActivityTestRule =
-            new ChromeActivityTestRule<>(ChromeActivity.class);
+    public ChromeTabbedActivityTestRule mActivityTestRule = new ChromeTabbedActivityTestRule();
 
     private static final String MOUNTAIN = "Mountain";
 
@@ -118,7 +119,7 @@ public class SmartClipProviderTest implements Handler.Callback {
     public void setUp() throws Exception {
         mActivityTestRule.startMainActivityWithURL(DATA_URL);
         mActivity = mActivityTestRule.getActivity();
-        ThreadUtils.runOnUiThreadBlocking(
+        TestThreadUtils.runOnUiThreadBlocking(
                 () -> { mWebContents = mActivityTestRule.getWebContents(); });
 
         DOMUtils.waitForNonZeroNodeBounds(mWebContents, "simple_text");
@@ -138,8 +139,7 @@ public class SmartClipProviderTest implements Handler.Callback {
     }
 
     @After
-    @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR2)
-    public void tearDown() throws Exception {
+    public void tearDown() {
         if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.JELLY_BEAN_MR2) {
             mHandlerThread.quitSafely();
         } else {
@@ -193,11 +193,11 @@ public class SmartClipProviderTest implements Handler.Callback {
     @Test
     @MediumTest
     @Feature({"SmartClip"})
-    @RetryOnFailure
-    public void testSmartClipDataCallback() throws InterruptedException, TimeoutException {
+    @DisabledTest(message = "https://crbug.com/853816")
+    public void testSmartClipDataCallback() throws TimeoutException {
         final float dpi = Coordinates.createFor(mWebContents).getDeviceScaleFactor();
         final Rect bounds = DOMUtils.getNodeBounds(mWebContents, "simple_text");
-        ThreadUtils.runOnUiThreadBlocking(() -> {
+        TestThreadUtils.runOnUiThreadBlocking(() -> {
             // This emulates what OEM will be doing when they want to call
             // functions on SmartClipProvider through view hierarchy.
 
@@ -225,9 +225,8 @@ public class SmartClipProviderTest implements Handler.Callback {
     @Test
     @MediumTest
     @Feature({"SmartClip"})
-    @RetryOnFailure
-    public void testSmartClipNoHandlerDoesntCrash() throws InterruptedException, TimeoutException {
-        ThreadUtils.runOnUiThreadBlocking(() -> {
+    public void testSmartClipNoHandlerDoesntCrash() throws TimeoutException {
+        TestThreadUtils.runOnUiThreadBlocking(() -> {
             Object scp = findSmartClipProvider(
                     mActivityTestRule.getActivity().findViewById(android.R.id.content));
             Assert.assertNotNull(scp);
