@@ -1,37 +1,38 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.autofill;
 
-import android.support.test.filters.MediumTest;
 import android.view.ViewGroup;
 
+import androidx.test.filters.MediumTest;
+
+import org.hamcrest.Matchers;
 import org.junit.Assert;
+import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
-import org.chromium.base.ThreadUtils;
 import org.chromium.base.test.util.CommandLineFlags;
+import org.chromium.base.test.util.Criteria;
+import org.chromium.base.test.util.CriteriaHelper;
+import org.chromium.base.test.util.DisabledTest;
 import org.chromium.base.test.util.Feature;
-import org.chromium.base.test.util.RetryOnFailure;
 import org.chromium.base.test.util.UrlUtils;
-import org.chromium.chrome.browser.ChromeActivity;
-import org.chromium.chrome.browser.ChromeSwitches;
 import org.chromium.chrome.browser.autofill.PersonalDataManager.AutofillProfile;
-import org.chromium.chrome.test.ChromeActivityTestRule;
+import org.chromium.chrome.browser.flags.ChromeFeatureList;
+import org.chromium.chrome.browser.flags.ChromeSwitches;
 import org.chromium.chrome.test.ChromeJUnit4ClassRunner;
-import org.chromium.content.browser.test.util.Criteria;
-import org.chromium.content.browser.test.util.CriteriaHelper;
-import org.chromium.content.browser.test.util.DOMUtils;
-import org.chromium.content_public.browser.ContentViewCore;
+import org.chromium.chrome.test.ChromeTabbedActivityTestRule;
+import org.chromium.chrome.test.util.browser.Features;
 import org.chromium.content_public.browser.WebContents;
+import org.chromium.content_public.browser.test.util.DOMUtils;
+import org.chromium.content_public.browser.test.util.TestThreadUtils;
 import org.chromium.ui.DropdownPopupWindowInterface;
 import org.chromium.ui.R;
-import org.chromium.ui.UiUtils;
 
-import java.util.concurrent.ExecutionException;
 import java.util.concurrent.TimeoutException;
 import java.util.concurrent.atomic.AtomicReference;
 
@@ -42,8 +43,14 @@ import java.util.concurrent.atomic.AtomicReference;
 @CommandLineFlags.Add({ChromeSwitches.DISABLE_FIRST_RUN_EXPERIENCE})
 public class AutofillPopupWithKeyboardTest {
     @Rule
-    public ChromeActivityTestRule<ChromeActivity> mActivityTestRule =
-            new ChromeActivityTestRule<>(ChromeActivity.class);
+    public ChromeTabbedActivityTestRule mActivityTestRule = new ChromeTabbedActivityTestRule();
+
+    @Before
+    public void setUp() {
+        // TODO(crbug.com/894428) - fix this suite to use the embedded test server instead of
+        // data urls.
+        Features.getInstance().enable(ChromeFeatureList.AUTOFILL_ALLOW_NON_HTTP_ACTIVATION);
+    }
 
     /**
      * Test that showing autofill popup and keyboard will not hide the autofill popup.
@@ -51,9 +58,8 @@ public class AutofillPopupWithKeyboardTest {
     @Test
     @MediumTest
     @Feature({"autofill-keyboard"})
-    @RetryOnFailure
-    public void testShowAutofillPopupAndKeyboardimultaneously()
-            throws InterruptedException, ExecutionException, TimeoutException {
+    @DisabledTest(message = "crbug.com/921062")
+    public void testShowAutofillPopupAndKeyboardimultaneously() throws TimeoutException {
         mActivityTestRule.startMainActivityWithURL(UrlUtils.encodeHtmlDataUri("<html><head>"
                 + "<meta name=\"viewport\""
                 + "content=\"width=device-width, initial-scale=1.0, maximum-scale=1.0\" /></head>"
@@ -75,12 +81,11 @@ public class AutofillPopupWithKeyboardTest {
                 + "<input type=\"submit\" />"
                 + "</form></body></html>"));
         new AutofillTestHelper().setProfile(new AutofillProfile("", "https://www.example.com",
-                "John Smith", "Acme Inc", "1 Main\nApt A", "CA", "San Francisco", "", "94102", "",
-                "US", "(415) 888-9999", "john@acme.inc", "en"));
-        final AtomicReference<ContentViewCore> viewCoreRef = new AtomicReference<ContentViewCore>();
+                "" /* honorific prefix */, "John Smith", "Acme Inc", "1 Main\nApt A", "CA",
+                "San Francisco", "", "94102", "", "US", "(415) 888-9999", "john@acme.inc", "en"));
         final AtomicReference<WebContents> webContentsRef = new AtomicReference<WebContents>();
         final AtomicReference<ViewGroup> viewRef = new AtomicReference<ViewGroup>();
-        ThreadUtils.runOnUiThreadBlocking(() -> {
+        TestThreadUtils.runOnUiThreadBlocking(() -> {
             webContentsRef.set(mActivityTestRule.getActivity().getCurrentWebContents());
             viewRef.set(mActivityTestRule.getActivity().getActivityTab().getContentView());
         });
@@ -92,31 +97,22 @@ public class AutofillPopupWithKeyboardTest {
         DOMUtils.clickNode(webContentsRef.get(), "fn");
 
         // Wait until the keyboard is showing.
-        CriteriaHelper.pollUiThread(new Criteria("Keyboard was never shown.") {
-            @Override
-            public boolean isSatisfied() {
-                return UiUtils.isKeyboardShowing(mActivityTestRule.getActivity(),
-                        mActivityTestRule.getActivity().getActivityTab().getContentView());
-            }
-        });
+        CriteriaHelper.pollUiThread(() -> {
+            return mActivityTestRule.getKeyboardDelegate().isKeyboardShowing(
+                    mActivityTestRule.getActivity(),
+                    mActivityTestRule.getActivity().getActivityTab().getContentView());
+        }, "Keyboard was never shown.");
 
         // Verify that the autofill popup is showing.
-        CriteriaHelper.pollUiThread(
-                new Criteria("Autofill Popup anchor view was never added.") {
-                    @Override
-                    public boolean isSatisfied() {
-                        return viewRef.get().findViewById(R.id.dropdown_popup_window) != null;
-                    }
-                });
-        Object popupObject = ThreadUtils.runOnUiThreadBlocking(
+        CriteriaHelper.pollUiThread(() -> {
+            Criteria.checkThat("Autofill Popup anchor view was never added.",
+                    viewRef.get().findViewById(R.id.dropdown_popup_window),
+                    Matchers.notNullValue());
+        });
+        Object popupObject = TestThreadUtils.runOnUiThreadBlockingNoException(
                 () -> viewRef.get().findViewById(R.id.dropdown_popup_window).getTag());
         Assert.assertTrue(popupObject instanceof DropdownPopupWindowInterface);
         final DropdownPopupWindowInterface popup = (DropdownPopupWindowInterface) popupObject;
-        CriteriaHelper.pollUiThread(new Criteria("Autofill Popup was never shown.") {
-            @Override
-            public boolean isSatisfied() {
-                return popup.isShowing();
-            }
-        });
+        CriteriaHelper.pollUiThread(() -> popup.isShowing(), "Autofill Popup was never shown.");
     }
 }
