@@ -1,34 +1,49 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.compositor.bottombar;
 
+import android.app.Activity;
 import android.content.Context;
 import android.support.test.InstrumentationRegistry;
-import android.support.test.annotation.UiThreadTest;
-import android.support.test.filters.SmallTest;
-import android.support.test.rule.UiThreadTestRule;
 import android.view.MotionEvent;
 import android.view.ViewConfiguration;
 import android.view.ViewGroup;
 
+import androidx.test.filters.MediumTest;
+
+import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
+import org.junit.BeforeClass;
+import org.junit.ClassRule;
 import org.junit.Rule;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.mockito.Mock;
+import org.mockito.junit.MockitoJUnit;
+import org.mockito.junit.MockitoRule;
 
+import org.chromium.base.test.BaseActivityTestRule;
+import org.chromium.base.test.UiThreadTest;
+import org.chromium.base.test.util.Batch;
 import org.chromium.base.test.util.Feature;
+import org.chromium.chrome.browser.browser_controls.BrowserControlsStateProvider;
+import org.chromium.chrome.browser.compositor.layouts.LayoutManagerImpl;
 import org.chromium.chrome.browser.compositor.layouts.eventfilter.OverlayPanelEventFilter;
+import org.chromium.chrome.browser.tab.Tab;
 import org.chromium.chrome.test.ChromeJUnit4ClassRunner;
-import org.chromium.content.browser.test.util.TestContentViewCore;
-import org.chromium.content_public.browser.ContentViewCore;
-
+import org.chromium.content_public.browser.test.util.TestThreadUtils;
+import org.chromium.ui.base.ActivityWindowAndroid;
+import org.chromium.ui.base.IntentRequestTracker;
+import org.chromium.ui.base.WindowAndroid;
+import org.chromium.ui.test.util.BlankUiTestActivity;
 /**
  * Class responsible for testing the OverlayPanelEventFilter.
  */
 @RunWith(ChromeJUnit4ClassRunner.class)
+@Batch(Batch.PER_CLASS)
 public class OverlayPanelEventFilterTest {
     private static final float PANEL_ALMOST_MAXIMIZED_OFFSET_Y_DP = 50.f;
     private static final float BAR_HEIGHT_DP = 100.f;
@@ -39,6 +54,28 @@ public class OverlayPanelEventFilterTest {
     // A small value used to check whether two floats are almost equal.
     private static final float EPSILON = 1e-04f;
 
+    private static final int MOCK_TOOLBAR_HEIGHT = 100;
+
+    @ClassRule
+    public static BaseActivityTestRule<BlankUiTestActivity> activityTestRule =
+            new BaseActivityTestRule<>(BlankUiTestActivity.class);
+
+    @Rule
+    public MockitoRule mMockitoRule = MockitoJUnit.rule();
+
+    @Mock
+    private LayoutManagerImpl mLayoutManager;
+    @Mock
+    private BrowserControlsStateProvider mBrowserControlsStateProvider;
+    @Mock
+    private ViewGroup mCompositorViewHolder;
+    @Mock
+    private Tab mTab;
+    @Mock
+    private OverlayContentDelegate mOverlayContentDelegate;
+    @Mock
+    private OverlayContentProgressObserver mOverlayContentProgressObserver;
+
     private float mTouchSlopDp;
     private float mDpToPx;
 
@@ -58,13 +95,13 @@ public class OverlayPanelEventFilterTest {
     private boolean mEventWasScroll;
     private boolean mEventWasTap;
 
+    private WindowAndroid mWindowAndroid;
+    private Activity mActivity;
+
     // --------------------------------------------------------------------------------------------
     // OverlayPanelEventFilterWrapper
     // --------------------------------------------------------------------------------------------
 
-    @Rule
-    public UiThreadTestRule mRule = new UiThreadTestRule();
-
     /**
      * Wrapper around OverlayPanelEventFilter used by tests.
      */
@@ -79,9 +116,9 @@ public class OverlayPanelEventFilterTest {
         }
 
         @Override
-        protected void propagateEventToContentViewCore(MotionEvent e) {
+        protected void propagateEventToContent(MotionEvent e) {
             mEventPropagatedToContent = MotionEvent.obtain(e);
-            super.propagateEventToContentViewCore(e);
+            super.propagateEventToContent(e);
             mEventPropagatedToContent.recycle();
         }
 
@@ -105,16 +142,18 @@ public class OverlayPanelEventFilterTest {
     // --------------------------------------------------------------------------------------------
 
     /**
-     * Mocks an OverlayPanel, so it doesn't create ContentViewCore or animations.
+     * Mocks an OverlayPanel, so it doesn't create WebContents or animations.
      */
     private final class MockOverlayPanel extends OverlayPanel {
-        private boolean mWasTapDetectedOnPanel = false;
-        private boolean mWasScrollDetectedOnPanel = false;
-        private ContentViewCore mContentViewCore;
+        private boolean mWasTapDetectedOnPanel;
+        private boolean mWasScrollDetectedOnPanel;
 
-        public MockOverlayPanel(Context context, OverlayPanelManager panelManager) {
-            super(context, null, panelManager);
-            mContentViewCore = new TestContentViewCore(context, "");
+        public MockOverlayPanel(Context context, LayoutManagerImpl layoutManager,
+                OverlayPanelManager manager,
+                BrowserControlsStateProvider browserControlsStateProvider,
+                WindowAndroid windowAndroid, ViewGroup compositorViewHolder, Tab tab) {
+            super(context, layoutManager, manager, browserControlsStateProvider, windowAndroid,
+                    compositorViewHolder, MOCK_TOOLBAR_HEIGHT, () -> tab);
         }
 
         @Override
@@ -123,11 +162,13 @@ public class OverlayPanelEventFilterTest {
         }
 
         /**
-         * Override creation and destruction of the ContentViewCore as they rely on native methods.
+         * Override creation and destruction of the WebContents as they rely on native methods.
          */
         private class MockOverlayPanelContent extends OverlayPanelContent {
             public MockOverlayPanelContent() {
-                super(null, null, null, 0);
+                super(mOverlayContentDelegate, mOverlayContentProgressObserver, mActivity,
+                        /* isIncognito= */ false, MOCK_TOOLBAR_HEIGHT, mCompositorViewHolder,
+                        mWindowAndroid, () -> mTab);
             }
 
             @Override
@@ -162,7 +203,7 @@ public class OverlayPanelEventFilterTest {
         }
 
         @Override
-        protected void resizePanelContentView(float width, float height) {}
+        protected void resizePanelContentView() {}
 
         @Override
         protected void animatePanelTo(float height, long duration) {
@@ -209,23 +250,35 @@ public class OverlayPanelEventFilterTest {
     // Test Suite
     // --------------------------------------------------------------------------------------------
 
+    @BeforeClass
+    public static void setupSuite() {
+        activityTestRule.launchActivity(null);
+    }
+
     @Before
-    public void setUp() throws Exception {
+    public void setupTest() {
         Context context = InstrumentationRegistry.getTargetContext();
 
         mDpToPx = context.getResources().getDisplayMetrics().density;
         mTouchSlopDp = ViewConfiguration.get(context).getScaledTouchSlop() / mDpToPx;
 
-        mPanel = new MockOverlayPanel(context, new OverlayPanelManager());
-        mEventFilter = new OverlayPanelEventFilterWrapper(context, mPanel);
+        TestThreadUtils.runOnUiThreadBlocking(() -> {
+            mActivity = activityTestRule.getActivity();
+            mWindowAndroid = new ActivityWindowAndroid(mActivity, /* listenToActivityState= */ true,
+                    IntentRequestTracker.createFromActivity(mActivity));
 
-        mPanel.setSearchBarHeightForTesting(BAR_HEIGHT_DP);
-        mPanel.setHeightForTesting(LAYOUT_HEIGHT_DP);
-        mPanel.setIsFullWidthSizePanelForTesting(true);
+            mPanel = new MockOverlayPanel(mActivity, mLayoutManager, new OverlayPanelManager(),
+                    mBrowserControlsStateProvider, mWindowAndroid, mCompositorViewHolder, mTab);
+            mEventFilter = new OverlayPanelEventFilterWrapper(mActivity, mPanel);
 
-        // NOTE(pedrosimonetti): This should be called after calling the method
-        // setIsFullWidthSizePanelForTesting(), otherwise it will crash the test.
-        mPanel.onSizeChanged(LAYOUT_WIDTH_DP, LAYOUT_HEIGHT_DP, 0, 0);
+            mPanel.setSearchBarHeightForTesting(BAR_HEIGHT_DP);
+            mPanel.setHeightForTesting(LAYOUT_HEIGHT_DP);
+            mPanel.setIsFullWidthSizePanelForTesting(true);
+
+            // NOTE(pedrosimonetti): This should be called after calling the method
+            // setIsFullWidthSizePanelForTesting(), otherwise it will crash the test.
+            mPanel.onSizeChanged(LAYOUT_WIDTH_DP, LAYOUT_HEIGHT_DP, 0, 0);
+        });
 
         setContentViewVerticalScroll(0);
 
@@ -239,8 +292,13 @@ public class OverlayPanelEventFilterTest {
         mShouldLockHorizontalMotionInContent = false;
     }
 
+    @After
+    public void tearDown() {
+        TestThreadUtils.runOnUiThreadBlocking(() -> { mWindowAndroid.destroy(); });
+    }
+
     @Test
-    @SmallTest
+    @MediumTest
     @Feature({"OverlayPanel"})
     @UiThreadTest
     public void testTapContentView() {
@@ -258,7 +316,7 @@ public class OverlayPanelEventFilterTest {
     }
 
     @Test
-    @SmallTest
+    @MediumTest
     @Feature({"OverlayPanel"})
     @UiThreadTest
     public void testScrollingContentViewDragsPanel() {
@@ -277,7 +335,7 @@ public class OverlayPanelEventFilterTest {
     }
 
     @Test
-    @SmallTest
+    @MediumTest
     @Feature({"OverlayPanel"})
     @UiThreadTest
     public void testScrollUpContentView() {
@@ -296,7 +354,7 @@ public class OverlayPanelEventFilterTest {
     }
 
     @Test
-    @SmallTest
+    @MediumTest
     @Feature({"OverlayPanel"})
     @UiThreadTest
     public void testScrollDownContentView() {
@@ -319,7 +377,7 @@ public class OverlayPanelEventFilterTest {
     }
 
     @Test
-    @SmallTest
+    @MediumTest
     @Feature({"OverlayPanel"})
     @UiThreadTest
     public void testDragByOverscrollingContentView() {
@@ -342,7 +400,7 @@ public class OverlayPanelEventFilterTest {
     }
 
     @Test
-    @SmallTest
+    @MediumTest
     @Feature({"OverlayPanel"})
     @UiThreadTest
     public void testUnwantedScrollDoesNotHappenInContentView() {
@@ -378,7 +436,7 @@ public class OverlayPanelEventFilterTest {
     }
 
     @Test
-    @SmallTest
+    @MediumTest
     @Feature({"OverlayPanel"})
     @UiThreadTest
     public void testDragPanelThenContinuouslyScrollContentView() {
@@ -408,7 +466,7 @@ public class OverlayPanelEventFilterTest {
     }
 
     @Test
-    @SmallTest
+    @MediumTest
     @Feature({"OverlayPanel"})
     @UiThreadTest
     public void testTapPanel() {
@@ -426,7 +484,7 @@ public class OverlayPanelEventFilterTest {
     }
 
     @Test
-    @SmallTest
+    @MediumTest
     @Feature({"OverlayPanel"})
     @UiThreadTest
     public void testScrollPanel() {
