@@ -1,4 +1,4 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -16,13 +16,13 @@ public class OverlayPanelManagerWrapper extends OverlayPanelManager {
     private int mPanelHideCount;
 
     @Override
-    public void requestPanelShow(OverlayPanel panel, StateChangeReason reason) {
+    public void requestPanelShow(OverlayPanel panel, @StateChangeReason int reason) {
         mRequestPanelShowCount++;
         super.requestPanelShow(panel, reason);
     }
 
     @Override
-    public void notifyPanelClosed(OverlayPanel panel, StateChangeReason reason) {
+    public void notifyPanelClosed(OverlayPanel panel, @StateChangeReason int reason) {
         mPanelHideCount++;
         super.notifyPanelClosed(panel, reason);
     }
