@@ -1,58 +1,65 @@
-// Copyright 2016 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.customtabs;
 
 import android.app.Activity;
-import android.os.AsyncTask;
 import android.support.test.InstrumentationRegistry;
-import android.support.test.filters.MediumTest;
-import android.support.test.filters.SmallTest;
-import android.support.test.rule.UiThreadTestRule;
+
+import androidx.annotation.Nullable;
+import androidx.test.filters.MediumTest;
+import androidx.test.filters.SmallTest;
 
 import org.hamcrest.Matchers;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
-import org.junit.Rule;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
 import org.chromium.base.ActivityState;
 import org.chromium.base.ApplicationStatus;
+import org.chromium.base.ApplicationStatus.ActivityStateListener;
 import org.chromium.base.Callback;
 import org.chromium.base.ContextUtils;
 import org.chromium.base.StreamUtil;
-import org.chromium.base.ThreadUtils;
+import org.chromium.base.task.PostTask;
+import org.chromium.base.task.SequencedTaskRunner;
+import org.chromium.base.task.TaskRunner;
+import org.chromium.base.task.TaskTraits;
+import org.chromium.base.test.UiThreadTest;
 import org.chromium.base.test.util.AdvancedMockContext;
 import org.chromium.base.test.util.CallbackHelper;
 import org.chromium.base.test.util.Feature;
 import org.chromium.chrome.browser.ChromeTabbedActivity;
-import org.chromium.chrome.browser.TabState;
+import org.chromium.chrome.browser.app.tabmodel.AsyncTabParamsManagerSingleton;
+import org.chromium.chrome.browser.app.tabmodel.ChromeTabModelFilterFactory;
+import org.chromium.chrome.browser.app.tabmodel.CustomTabsTabModelOrchestrator;
 import org.chromium.chrome.browser.compositor.layouts.content.TabContentManager;
+import org.chromium.chrome.browser.tab.MockTab;
 import org.chromium.chrome.browser.tab.Tab;
 import org.chromium.chrome.browser.tabmodel.TabModelSelector;
 import org.chromium.chrome.browser.tabmodel.TabModelSelectorImpl;
 import org.chromium.chrome.browser.tabmodel.TabPersistencePolicy;
 import org.chromium.chrome.browser.tabmodel.TabPersistentStore;
 import org.chromium.chrome.browser.tabmodel.TestTabModelDirectory;
+import org.chromium.chrome.browser.tabpersistence.TabStateDirectory;
+import org.chromium.chrome.browser.tabpersistence.TabStateFileManager;
 import org.chromium.chrome.test.ChromeJUnit4ClassRunner;
 import org.chromium.chrome.test.util.browser.tabmodel.MockTabModel;
+import org.chromium.content_public.browser.test.util.TestThreadUtils;
+import org.chromium.url.GURL;
 
 import java.io.File;
 import java.io.FileOutputStream;
-import java.lang.ref.WeakReference;
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 import java.util.concurrent.Callable;
-import java.util.concurrent.Executor;
 import java.util.concurrent.atomic.AtomicReference;
 
-import javax.annotation.Nullable;
-
 /**
  * Tests for the Custom Tab persistence logic.
  */
@@ -60,35 +67,32 @@ import javax.annotation.Nullable;
 public class CustomTabTabPersistencePolicyTest {
     private TestTabModelDirectory mMockDirectory;
     private AdvancedMockContext mAppContext;
-
-    @Rule
-    public UiThreadTestRule mRule = new UiThreadTestRule();
+    private SequencedTaskRunner mSequencedTaskRunner =
+            PostTask.createSequencedTaskRunner(TaskTraits.USER_VISIBLE);
 
     @Before
     public void setUp() throws Exception {
         // CustomTabsConnection needs a true context, not the mock context set below.
-        CustomTabsConnection.getInstance();
+        TestThreadUtils.runOnUiThreadBlocking(() -> CustomTabsConnection.getInstance());
 
         mAppContext = new AdvancedMockContext(InstrumentationRegistry.getInstrumentation()
                                                       .getTargetContext()
                                                       .getApplicationContext());
         ContextUtils.initApplicationContextForTests(mAppContext);
 
-        mMockDirectory = new TestTabModelDirectory(
-                mAppContext, "CustomTabTabPersistencePolicyTest",
-                CustomTabTabPersistencePolicy.SAVED_STATE_DIRECTORY);
-        TabPersistentStore.setBaseStateDirectoryForTests(mMockDirectory.getBaseDirectory());
+        mMockDirectory = new TestTabModelDirectory(mAppContext, "CustomTabTabPersistencePolicyTest",
+                TabStateDirectory.CUSTOM_TABS_DIRECTORY);
+        TabStateDirectory.setBaseStateDirectoryForTests(mMockDirectory.getBaseDirectory());
     }
 
     @After
-    public void tearDown() throws Exception {
+    public void tearDown() {
         mMockDirectory.tearDown();
 
-        List<WeakReference<Activity>> activities = ApplicationStatus.getRunningActivities();
-        for (int i = 0; i < activities.size(); i++) {
-            Activity activity = activities.get(i).get();
-            if (activity == null) continue;
-            ApplicationStatus.onStateChangeForTesting(activity, ActivityState.DESTROYED);
+        for (Activity activity : ApplicationStatus.getRunningActivities()) {
+            TestThreadUtils.runOnUiThreadBlocking(
+                    () -> ApplicationStatus.onStateChangeForTesting(
+                            activity, ActivityState.DESTROYED));
         }
     }
 
@@ -157,7 +161,7 @@ public class CustomTabTabPersistencePolicyTest {
     @Feature("TabPersistentStore")
     @MediumTest
     public void testExistingMetadataFileDeletedIfNoRestore() throws Exception {
-        File baseStateDirectory = TabPersistentStore.getOrCreateBaseStateDirectory();
+        File baseStateDirectory = TabStateDirectory.getOrCreateBaseStateDirectory();
         Assert.assertNotNull(baseStateDirectory);
 
         CustomTabTabPersistencePolicy policy = new CustomTabTabPersistencePolicy(7, false);
@@ -169,7 +173,7 @@ public class CustomTabTabPersistencePolicyTest {
         Assert.assertTrue(existingStateFile.createNewFile());
 
         Assert.assertTrue(existingStateFile.exists());
-        policy.performInitialization(AsyncTask.SERIAL_EXECUTOR);
+        policy.performInitialization(mSequencedTaskRunner);
         policy.waitForInitializationToFinish();
         Assert.assertFalse(existingStateFile.exists());
     }
@@ -180,48 +184,43 @@ public class CustomTabTabPersistencePolicyTest {
     @Test
     @Feature("TabPersistentStore")
     @SmallTest
+    @UiThreadTest
     public void testGettingTabAndTaskIds() throws Throwable {
-        mRule.runOnUiThread(new Runnable() {
+        Set<Integer> tabIds = new HashSet<>();
+        Set<Integer> taskIds = new HashSet<>();
+        CustomTabTabPersistencePolicy.getAllLiveTabAndTaskIds(tabIds, taskIds);
+        Assert.assertThat(tabIds, Matchers.emptyIterable());
+        Assert.assertThat(taskIds, Matchers.emptyIterable());
+
+        tabIds.clear();
+        taskIds.clear();
+
+        CustomTabActivity cct1 = buildTestCustomTabActivity(1, new int[] {4, 8, 9}, null);
+        ApplicationStatus.onStateChangeForTesting(cct1, ActivityState.CREATED);
+
+        CustomTabActivity cct2 = buildTestCustomTabActivity(5, new int[] {458}, new int[] {9878});
+        ApplicationStatus.onStateChangeForTesting(cct2, ActivityState.CREATED);
+
+        // Add a tabbed mode activity to ensure that its IDs are not included in the
+        // returned CCT ID sets.
+        final TabModelSelectorImpl tabbedSelector =
+                buildTestTabModelSelector(new int[] {12121212}, new int[] {1515151515});
+        ChromeTabbedActivity tabbedActivity = new ChromeTabbedActivity() {
             @Override
-            public void run() {
-                Set<Integer> tabIds = new HashSet<>();
-                Set<Integer> taskIds = new HashSet<>();
-                CustomTabTabPersistencePolicy.getAllLiveTabAndTaskIds(tabIds, taskIds);
-                Assert.assertThat(tabIds, Matchers.emptyIterable());
-                Assert.assertThat(taskIds, Matchers.emptyIterable());
-
-                tabIds.clear();
-                taskIds.clear();
-
-                CustomTabActivity cct1 = buildTestCustomTabActivity(1, new int[] {4, 8, 9}, null);
-                ApplicationStatus.onStateChangeForTesting(cct1, ActivityState.CREATED);
-
-                CustomTabActivity cct2 =
-                        buildTestCustomTabActivity(5, new int[] {458}, new int[] {9878});
-                ApplicationStatus.onStateChangeForTesting(cct2, ActivityState.CREATED);
-
-                // Add a tabbed mode activity to ensure that its IDs are not included in the
-                // returned CCT ID sets.
-                final TabModelSelectorImpl tabbedSelector =
-                        buildTestTabModelSelector(new int[] {12121212}, new int[] {1515151515});
-                ChromeTabbedActivity tabbedActivity = new ChromeTabbedActivity() {
-                    @Override
-                    public int getTaskId() {
-                        return 888;
-                    }
-
-                    @Override
-                    public TabModelSelector getTabModelSelector() {
-                        return tabbedSelector;
-                    }
-                };
-                ApplicationStatus.onStateChangeForTesting(tabbedActivity, ActivityState.CREATED);
-
-                CustomTabTabPersistencePolicy.getAllLiveTabAndTaskIds(tabIds, taskIds);
-                Assert.assertThat(tabIds, Matchers.containsInAnyOrder(4, 8, 9, 458, 9878));
-                Assert.assertThat(taskIds, Matchers.containsInAnyOrder(1, 5));
+            public int getTaskId() {
+                return 888;
             }
-        });
+
+            @Override
+            public TabModelSelector getTabModelSelector() {
+                return tabbedSelector;
+            }
+        };
+        ApplicationStatus.onStateChangeForTesting(tabbedActivity, ActivityState.CREATED);
+
+        CustomTabTabPersistencePolicy.getAllLiveTabAndTaskIds(tabIds, taskIds);
+        Assert.assertThat(tabIds, Matchers.containsInAnyOrder(4, 8, 9, 458, 9878));
+        Assert.assertThat(taskIds, Matchers.containsInAnyOrder(1, 5));
     }
 
     /**
@@ -231,7 +230,7 @@ public class CustomTabTabPersistencePolicyTest {
     @Feature("TabPersistentStore")
     @MediumTest
     public void testCleanupTask() throws Throwable {
-        File baseStateDirectory = TabPersistentStore.getOrCreateBaseStateDirectory();
+        File baseStateDirectory = TabStateDirectory.getOrCreateBaseStateDirectory();
         Assert.assertNotNull(baseStateDirectory);
 
         CustomTabTabPersistencePolicy policy = new CustomTabTabPersistencePolicy(2, false);
@@ -254,19 +253,16 @@ public class CustomTabTabPersistencePolicyTest {
         Assert.assertThat(filesToDelete.get(), Matchers.emptyIterable());
 
         // Create an unreferenced tab state file and ensure it is marked for deletion.
-        File tab999File = TabState.getTabStateFile(stateDirectory, 999, false);
+        File tab999File = TabStateFileManager.getTabStateFile(stateDirectory, 999, false);
         Assert.assertTrue(tab999File.createNewFile());
         policy.cleanupUnusedFiles(filesToDeleteCallback);
         callbackSignal.waitForCallback(1);
         Assert.assertThat(filesToDelete.get(), Matchers.containsInAnyOrder(tab999File.getName()));
 
         // Reference the tab state file and ensure it is no longer marked for deletion.
-        mRule.runOnUiThread(new Runnable() {
-            @Override
-            public void run() {
-                CustomTabActivity cct1 = buildTestCustomTabActivity(1, new int[] {999}, null);
-                ApplicationStatus.onStateChangeForTesting(cct1, ActivityState.CREATED);
-            }
+        TestThreadUtils.runOnUiThreadBlocking(() -> {
+            CustomTabActivity cct1 = buildTestCustomTabActivity(1, new int[] {999}, null);
+            ApplicationStatus.onStateChangeForTesting(cct1, ActivityState.CREATED);
         });
         policy.cleanupUnusedFiles(filesToDeleteCallback);
         callbackSignal.waitForCallback(2);
@@ -274,12 +270,12 @@ public class CustomTabTabPersistencePolicyTest {
 
         // Create a tab model and associated tabs. Ensure it is not marked for deletion as it is
         // new enough.
-        byte[] data = ThreadUtils.runOnUiThreadBlockingNoException(new Callable<byte[]>() {
+        byte[] data = TestThreadUtils.runOnUiThreadBlockingNoException(new Callable<byte[]>() {
             @Override
             public byte[] call() throws Exception {
                 TabModelSelectorImpl selectorImpl =
                         buildTestTabModelSelector(new int[] {111, 222, 333}, null);
-                return TabPersistentStore.serializeTabModelSelector(selectorImpl, null);
+                return TabPersistentStore.serializeTabModelSelector(selectorImpl, null).listData;
             }
         });
         FileOutputStream fos = null;
@@ -291,11 +287,11 @@ public class CustomTabTabPersistencePolicyTest {
         } finally {
             StreamUtil.closeQuietly(fos);
         }
-        File tab111File = TabState.getTabStateFile(stateDirectory, 111, false);
+        File tab111File = TabStateFileManager.getTabStateFile(stateDirectory, 111, false);
         Assert.assertTrue(tab111File.createNewFile());
-        File tab222File = TabState.getTabStateFile(stateDirectory, 222, false);
+        File tab222File = TabStateFileManager.getTabStateFile(stateDirectory, 222, false);
         Assert.assertTrue(tab222File.createNewFile());
-        File tab333File = TabState.getTabStateFile(stateDirectory, 333, false);
+        File tab333File = TabStateFileManager.getTabStateFile(stateDirectory, 333, false);
         Assert.assertTrue(tab333File.createNewFile());
         policy.cleanupUnusedFiles(filesToDeleteCallback);
         callbackSignal.waitForCallback(3);
@@ -318,7 +314,7 @@ public class CustomTabTabPersistencePolicyTest {
     @Feature("TabPersistentStore")
     @MediumTest
     public void testMetadataTimestampRefreshed() throws Exception {
-        File baseStateDirectory = TabPersistentStore.getOrCreateBaseStateDirectory();
+        File baseStateDirectory = TabStateDirectory.getOrCreateBaseStateDirectory();
         Assert.assertNotNull(baseStateDirectory);
 
         CustomTabTabPersistencePolicy policy = new CustomTabTabPersistencePolicy(2, true);
@@ -332,7 +328,7 @@ public class CustomTabTabPersistencePolicyTest {
                 System.currentTimeMillis() - CustomTabTabPersistencePolicy.STATE_EXPIRY_THRESHOLD;
         Assert.assertTrue(metadataFile.setLastModified(previousTimestamp));
 
-        policy.performInitialization(AsyncTask.SERIAL_EXECUTOR);
+        policy.performInitialization(mSequencedTaskRunner);
         policy.waitForInitializationToFinish();
 
         Assert.assertTrue(metadataFile.lastModified() > previousTimestamp);
@@ -355,7 +351,7 @@ public class CustomTabTabPersistencePolicyTest {
         };
     }
 
-    private static CustomTabActivity buildTestCustomTabActivity(
+    private CustomTabActivity buildTestCustomTabActivity(
             final int taskId, int[] normalTabIds, int[] incognitoTabIds) {
         final TabModelSelectorImpl selectorImpl =
                 buildTestTabModelSelector(normalTabIds, incognitoTabIds);
@@ -387,7 +383,7 @@ public class CustomTabTabPersistencePolicyTest {
             }
 
             @Override
-            public boolean performInitialization(Executor executor) {
+            public boolean performInitialization(TaskRunner taskRunner) {
                 return false;
             }
 
@@ -403,7 +399,7 @@ public class CustomTabTabPersistencePolicyTest {
 
             @Override
             @Nullable
-            public String getStateToBeMergedFileName() {
+            public List<String> getStateToBeMergedFileNames() {
                 return null;
             }
 
@@ -414,8 +410,7 @@ public class CustomTabTabPersistencePolicyTest {
 
             @Override
             public File getOrCreateStateDirectory() {
-                return new File(
-                        TabPersistentStore.getOrCreateBaseStateDirectory(), "cct_tests_zor");
+                return new File(TabStateDirectory.getOrCreateBaseStateDirectory(), "cct_tests_zor");
             }
 
             @Override
@@ -436,16 +431,16 @@ public class CustomTabTabPersistencePolicyTest {
         };
     }
 
-    private static TabModelSelectorImpl buildTestTabModelSelector(
+    private TabModelSelectorImpl buildTestTabModelSelector(
             int[] normalTabIds, int[] incognitoTabIds) {
         MockTabModel.MockTabModelDelegate tabModelDelegate =
                 new MockTabModel.MockTabModelDelegate() {
                     @Override
                     public Tab createTab(int id, boolean incognito) {
-                        return new Tab(id, incognito, null) {
+                        return new MockTab(id, incognito) {
                             @Override
-                            public String getUrl() {
-                                return "https://www.google.com";
+                            public GURL getUrl() {
+                                return new GURL("https://www.google.com");
                             }
                         };
                     }
@@ -459,12 +454,31 @@ public class CustomTabTabPersistencePolicyTest {
             for (int tabId : incognitoTabIds) incognitoTabModel.addTab(tabId);
         }
 
-        CustomTabActivity activity = new CustomTabActivity();
-        ApplicationStatus.onStateChangeForTesting(activity, ActivityState.CREATED);
-        TabModelSelectorImpl selector = new TabModelSelectorImpl(
-                activity, activity, buildTestPersistencePolicy(), false, false);
+        CustomTabActivity customTabActivity = new CustomTabActivity() {
+            // This is intended to pretend we've started the activity, so we can attach a base
+            // context to the activity.
+            @Override
+            public void onStart() {
+                attachBaseContext(mAppContext);
+            }
+        };
+        ApplicationStatus.onStateChangeForTesting(customTabActivity, ActivityState.CREATED);
+        ActivityStateListener stateListener = (activity, state) -> {
+            if (state == ActivityState.STARTED) {
+                customTabActivity.onStart();
+            }
+        };
+        ApplicationStatus.registerStateListenerForActivity(stateListener, customTabActivity);
+        ApplicationStatus.onStateChangeForTesting(customTabActivity, ActivityState.STARTED);
+
+        CustomTabsTabModelOrchestrator orchestrator = new CustomTabsTabModelOrchestrator();
+        orchestrator.createTabModels(customTabActivity::getWindowAndroid, customTabActivity,
+                new ChromeTabModelFilterFactory(customTabActivity), buildTestPersistencePolicy(),
+                AsyncTabParamsManagerSingleton.getInstance());
+        TabModelSelectorImpl selector = (TabModelSelectorImpl) orchestrator.getTabModelSelector();
         selector.initializeForTesting(normalTabModel, incognitoTabModel);
-        ApplicationStatus.onStateChangeForTesting(activity, ActivityState.DESTROYED);
+        ApplicationStatus.onStateChangeForTesting(customTabActivity, ActivityState.DESTROYED);
+        ApplicationStatus.unregisterActivityStateListener(stateListener);
         return selector;
     }
 }
