@@ -1,4 +1,4 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -8,27 +8,27 @@ import static android.app.Service.STOP_FOREGROUND_DETACH;
 import static android.app.Service.STOP_FOREGROUND_REMOVE;
 
 import static junit.framework.Assert.assertEquals;
-import static junit.framework.Assert.assertFalse;
-import static junit.framework.Assert.assertTrue;
 
-import static org.chromium.chrome.browser.download.DownloadForegroundService.clearPersistedNotificationId;
-import static org.chromium.chrome.browser.download.DownloadForegroundService.getPersistedNotificationId;
 import static org.chromium.chrome.browser.download.DownloadSnackbarController.INVALID_NOTIFICATION_ID;
 
 import android.app.Notification;
-import android.support.test.filters.SmallTest;
-import android.support.v4.app.ServiceCompat;
 
-import org.junit.After;
+import androidx.annotation.IntDef;
+import androidx.core.app.ServiceCompat;
+import androidx.test.filters.SmallTest;
+
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
+import org.chromium.base.test.util.Batch;
 import org.chromium.base.test.util.Feature;
-import org.chromium.chrome.browser.notifications.NotificationBuilderFactory;
-import org.chromium.chrome.browser.notifications.channels.ChannelDefinitions;
+import org.chromium.chrome.browser.notifications.NotificationWrapperBuilderFactory;
+import org.chromium.chrome.browser.notifications.channels.ChromeChannelDefinitions;
 import org.chromium.chrome.test.ChromeJUnit4ClassRunner;
 
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.List;
@@ -37,6 +37,7 @@ import java.util.List;
  * Test for DownloadForegroundService.
  */
 @RunWith(ChromeJUnit4ClassRunner.class)
+@Batch(Batch.UNIT_TESTS)
 public class DownloadForegroundServiceTest {
     private static final int FAKE_DOWNLOAD_ID1 = 1;
     private static final int FAKE_DOWNLOAD_ID2 = 2;
@@ -48,15 +49,27 @@ public class DownloadForegroundServiceTest {
      * Implementation of DownloadForegroundService for testing.
      * Mimics behavior of DownloadForegroundService except for calls to the actual service.
      */
-    public static class MockDownloadForegroundService extends DownloadForegroundService {
-        static enum MethodID { START_FOREGROUND, STOP_FOREGROUND_FLAGS, RELAUNCH_NOTIFICATION }
+    public static class MockDownloadForegroundService extends DownloadForegroundServiceImpl {
+        @IntDef({MethodID.START_FOREGROUND, MethodID.STOP_FOREGROUND_FLAGS,
+                MethodID.RELAUNCH_NOTIFICATION})
+        @Retention(RetentionPolicy.SOURCE)
+        public @interface MethodID {
+            int START_FOREGROUND = 0;
+            int STOP_FOREGROUND_FLAGS = 1;
+            int RELAUNCH_NOTIFICATION = 2;
+        }
 
         int mTargetSdk = 20;
         int mStopForegroundFlags = -1;
         int mRelaunchedNotificationId = INVALID_NOTIFICATION_ID;
         int mNextNotificationId = INVALID_NOTIFICATION_ID;
 
-        List<MethodID> mMethodCalls = new ArrayList<>();
+        // Used for saving MethodID values.
+        List<Integer> mMethodCalls = new ArrayList<>();
+
+        public MockDownloadForegroundService() {
+            setService(new DownloadForegroundService());
+        }
 
         // Clears stored flags/boolean/id/method calls. Call between tests runs.
         void clearStoredState() {
@@ -97,22 +110,16 @@ public class DownloadForegroundServiceTest {
     @Before
     public void setUp() {
         mForegroundService = new MockDownloadForegroundService();
-        clearPersistedNotificationId();
         mNotification =
-                NotificationBuilderFactory
-                        .createChromeNotificationBuilder(
-                                true /* preferCompat */, ChannelDefinitions.CHANNEL_ID_DOWNLOADS)
+                NotificationWrapperBuilderFactory
+                        .createNotificationWrapperBuilder(
+                                ChromeChannelDefinitions.ChannelId.DOWNLOADS)
                         .setSmallIcon(org.chromium.chrome.R.drawable.ic_file_download_white_24dp)
                         .setContentTitle("fakeContentTitle")
                         .setContentText("fakeContentText")
                         .build();
     }
 
-    @After
-    public void tearDown() {
-        clearPersistedNotificationId();
-    }
-
     /**
      * The expected behavior for start foreground when the API >= 24 is that the old notification is
      * able to be detached and the new notification pinned without any need for relaunching or
@@ -123,7 +130,7 @@ public class DownloadForegroundServiceTest {
     @Feature({"Download"})
     public void testStartForeground_sdkAtLeast24() {
         mForegroundService.mTargetSdk = 24;
-        List<MockDownloadForegroundService.MethodID> expectedMethodCalls =
+        List<Integer> expectedMethodCalls =
                 Arrays.asList(MockDownloadForegroundService.MethodID.START_FOREGROUND);
 
         // Test the case where there is no other pinned notification and the service starts.
@@ -165,7 +172,7 @@ public class DownloadForegroundServiceTest {
     @SmallTest
     @Feature({"Download"})
     public void testStartForeground_sdkLessThan24() {
-        List<MockDownloadForegroundService.MethodID> expectedMethodCalls =
+        List<Integer> expectedMethodCalls =
                 Arrays.asList(MockDownloadForegroundService.MethodID.START_FOREGROUND);
 
         // Test the case where there is no other pinned notification and the service starts.
@@ -204,7 +211,7 @@ public class DownloadForegroundServiceTest {
     @Feature({"Download"})
     public void testStopForeground_sdkAtLeast24() {
         mForegroundService.mTargetSdk = 24;
-        List<MockDownloadForegroundService.MethodID> expectedMethodCalls =
+        List<Integer> expectedMethodCalls =
                 Arrays.asList(MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS);
 
         // When the service gets stopped with request to detach but not kill notification (pause).
@@ -212,36 +219,33 @@ public class DownloadForegroundServiceTest {
                 FAKE_DOWNLOAD_ID1, mNotification, INVALID_NOTIFICATION_ID, null, false);
         mForegroundService.clearStoredState();
 
-        boolean isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.DETACH_OR_PERSIST,
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.DETACH,
                 INVALID_NOTIFICATION_ID, null);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(STOP_FOREGROUND_DETACH, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
 
         // When the service gets stopped with request to detach and kill (complete/failed).
         mForegroundService.startOrUpdateForegroundService(
                 FAKE_DOWNLOAD_ID1, mNotification, INVALID_NOTIFICATION_ID, null, false);
         mForegroundService.clearStoredState();
 
-        isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.DETACH_OR_ADJUST,
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.DETACH,
                 INVALID_NOTIFICATION_ID, null);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(STOP_FOREGROUND_DETACH, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
 
         // When the service gets stopped with request to not detach but to kill (cancel).
         mForegroundService.startOrUpdateForegroundService(
                 FAKE_DOWNLOAD_ID1, mNotification, INVALID_NOTIFICATION_ID, null, false);
         mForegroundService.clearStoredState();
 
-        isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.KILL, INVALID_NOTIFICATION_ID,
-                null);
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.KILL,
+                INVALID_NOTIFICATION_ID, null);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
     }
 
     /**
@@ -261,15 +265,14 @@ public class DownloadForegroundServiceTest {
                 FAKE_DOWNLOAD_ID1, mNotification, INVALID_NOTIFICATION_ID, null, false);
         mForegroundService.clearStoredState();
 
-        boolean isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.DETACH_OR_PERSIST,
-                FAKE_DOWNLOAD_ID1, mNotification);
-        List<MockDownloadForegroundService.MethodID> expectedMethodCalls =
-                Arrays.asList(MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS);
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.DETACH, FAKE_DOWNLOAD_ID1,
+                mNotification);
+        List<Integer> expectedMethodCalls =
+                Arrays.asList(MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS,
+                        MockDownloadForegroundService.MethodID.RELAUNCH_NOTIFICATION);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
-        assertEquals(ServiceCompat.STOP_FOREGROUND_DETACH, mForegroundService.mStopForegroundFlags);
-        assertFalse(isNotificationHandledProperly);
-        assertEquals(FAKE_DOWNLOAD_ID1, getPersistedNotificationId());
+        assertEquals(ServiceCompat.STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
 
         mForegroundService.clearStoredState();
 
@@ -278,15 +281,14 @@ public class DownloadForegroundServiceTest {
                 FAKE_DOWNLOAD_ID1, mNotification, INVALID_NOTIFICATION_ID, null, false);
         mForegroundService.clearStoredState();
 
-        isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.DETACH_OR_ADJUST,
-                FAKE_DOWNLOAD_ID1, mNotification);
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.DETACH, FAKE_DOWNLOAD_ID1,
+                mNotification);
         expectedMethodCalls =
                 Arrays.asList(MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS,
                         MockDownloadForegroundService.MethodID.RELAUNCH_NOTIFICATION);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(ServiceCompat.STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
         assertEquals(FAKE_DOWNLOAD_ID1, mForegroundService.mRelaunchedNotificationId);
 
         // When the service gets stopped with request to not detach but to kill (cancel).
@@ -294,14 +296,13 @@ public class DownloadForegroundServiceTest {
                 FAKE_DOWNLOAD_ID1, mNotification, INVALID_NOTIFICATION_ID, null, false);
         mForegroundService.clearStoredState();
 
-        isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.KILL, FAKE_DOWNLOAD_ID1,
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.KILL, FAKE_DOWNLOAD_ID1,
                 mNotification);
         expectedMethodCalls =
                 Arrays.asList(MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(ServiceCompat.STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
     }
 
     /**
@@ -320,15 +321,14 @@ public class DownloadForegroundServiceTest {
                 FAKE_DOWNLOAD_ID1, mNotification, INVALID_NOTIFICATION_ID, null, false);
         mForegroundService.clearStoredState();
 
-        boolean isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.DETACH_OR_PERSIST,
-                FAKE_DOWNLOAD_ID1, mNotification);
-        List<MockDownloadForegroundService.MethodID> expectedMethodCalls =
-                Arrays.asList(MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS);
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.DETACH, FAKE_DOWNLOAD_ID1,
+                mNotification);
+        List<Integer> expectedMethodCalls =
+                Arrays.asList(MockDownloadForegroundService.MethodID.RELAUNCH_NOTIFICATION,
+                        MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
-        assertEquals(ServiceCompat.STOP_FOREGROUND_DETACH, mForegroundService.mStopForegroundFlags);
-        assertFalse(isNotificationHandledProperly);
-        assertEquals(FAKE_DOWNLOAD_ID1, getPersistedNotificationId());
+        assertEquals(ServiceCompat.STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
 
         // When the service gets stopped with request to detach and kill (complete/failed).
         mForegroundService.startOrUpdateForegroundService(
@@ -336,15 +336,14 @@ public class DownloadForegroundServiceTest {
         mForegroundService.clearStoredState();
 
         mForegroundService.mNextNotificationId = FAKE_DOWNLOAD_ID2;
-        isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.DETACH_OR_ADJUST,
-                FAKE_DOWNLOAD_ID1, mNotification);
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.DETACH, FAKE_DOWNLOAD_ID1,
+                mNotification);
         expectedMethodCalls =
                 Arrays.asList(MockDownloadForegroundService.MethodID.RELAUNCH_NOTIFICATION,
                         MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(ServiceCompat.STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
         assertEquals(mForegroundService.mNextNotificationId,
                 mForegroundService.mRelaunchedNotificationId);
 
@@ -353,14 +352,13 @@ public class DownloadForegroundServiceTest {
                 FAKE_DOWNLOAD_ID1, mNotification, INVALID_NOTIFICATION_ID, null, false);
         mForegroundService.clearStoredState();
 
-        isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.KILL, FAKE_DOWNLOAD_ID1,
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.KILL, FAKE_DOWNLOAD_ID1,
                 mNotification);
         expectedMethodCalls =
                 Arrays.asList(MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(ServiceCompat.STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
     }
 
     /**
@@ -378,15 +376,14 @@ public class DownloadForegroundServiceTest {
         mForegroundService.clearStoredState();
 
         mForegroundService.mNextNotificationId = FAKE_DOWNLOAD_ID2;
-        boolean isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.DETACH_OR_PERSIST,
-                FAKE_DOWNLOAD_ID1, mNotification);
-        List<MockDownloadForegroundService.MethodID> expectedMethodCalls =
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.DETACH, FAKE_DOWNLOAD_ID1,
+                mNotification);
+        List<Integer> expectedMethodCalls =
                 Arrays.asList(MockDownloadForegroundService.MethodID.RELAUNCH_NOTIFICATION,
                         MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(ServiceCompat.STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
         assertEquals(mForegroundService.mNextNotificationId,
                 mForegroundService.mRelaunchedNotificationId);
 
@@ -396,12 +393,11 @@ public class DownloadForegroundServiceTest {
         mForegroundService.clearStoredState();
 
         mForegroundService.mNextNotificationId = FAKE_DOWNLOAD_ID2;
-        isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.DETACH_OR_ADJUST,
-                FAKE_DOWNLOAD_ID1, mNotification);
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.DETACH, FAKE_DOWNLOAD_ID1,
+                mNotification);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(ServiceCompat.STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
         assertEquals(mForegroundService.mNextNotificationId,
                 mForegroundService.mRelaunchedNotificationId);
 
@@ -410,13 +406,12 @@ public class DownloadForegroundServiceTest {
                 FAKE_DOWNLOAD_ID1, mNotification, INVALID_NOTIFICATION_ID, null, false);
         mForegroundService.clearStoredState();
 
-        isNotificationHandledProperly = mForegroundService.stopDownloadForegroundService(
-                DownloadForegroundService.StopForegroundNotification.KILL, FAKE_DOWNLOAD_ID1,
+        mForegroundService.stopDownloadForegroundService(
+                DownloadForegroundServiceImpl.StopForegroundNotification.KILL, FAKE_DOWNLOAD_ID1,
                 mNotification);
         expectedMethodCalls =
                 Arrays.asList(MockDownloadForegroundService.MethodID.STOP_FOREGROUND_FLAGS);
         assertEquals(expectedMethodCalls, mForegroundService.mMethodCalls);
         assertEquals(ServiceCompat.STOP_FOREGROUND_REMOVE, mForegroundService.mStopForegroundFlags);
-        assertTrue(isNotificationHandledProperly);
     }
 }
