@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,38 +7,37 @@ package org.chromium.chrome.browser.download;
 import android.content.Context;
 import android.os.Handler;
 import android.os.HandlerThread;
-import android.support.test.InstrumentationRegistry;
-import android.support.test.filters.MediumTest;
-import android.support.test.filters.SmallTest;
 import android.util.Log;
 import android.util.Pair;
 
+import androidx.annotation.IntDef;
+import androidx.test.filters.MediumTest;
+
 import org.junit.After;
 import org.junit.Assert;
-import org.junit.Before;
+import org.junit.ClassRule;
 import org.junit.Rule;
 import org.junit.Test;
+import org.junit.rules.TestRule;
 import org.junit.runner.RunWith;
 
-import org.chromium.base.ThreadUtils;
-import org.chromium.base.metrics.RecordHistogram;
-import org.chromium.base.test.BaseJUnit4ClassRunner;
-import org.chromium.base.test.util.AdvancedMockContext;
-import org.chromium.base.test.util.DisabledTest;
+import org.chromium.base.test.util.Batch;
+import org.chromium.base.test.util.CriteriaHelper;
 import org.chromium.base.test.util.Feature;
-import org.chromium.base.test.util.RetryOnFailure;
-import org.chromium.chrome.browser.download.DownloadInfo.Builder;
+import org.chromium.base.test.util.UrlUtils;
 import org.chromium.chrome.browser.download.DownloadManagerServiceTest.MockDownloadNotifier.MethodID;
-import org.chromium.chrome.browser.test.ChromeBrowserTestRule;
+import org.chromium.chrome.browser.flags.ChromeFeatureList;
+import org.chromium.chrome.test.ChromeBrowserTestRule;
+import org.chromium.chrome.test.ChromeJUnit4ClassRunner;
+import org.chromium.chrome.test.util.browser.Features;
 import org.chromium.components.offline_items_collection.ContentId;
-import org.chromium.components.offline_items_collection.FailState;
 import org.chromium.components.offline_items_collection.OfflineItem.Progress;
 import org.chromium.components.offline_items_collection.OfflineItemProgressUnit;
 import org.chromium.components.offline_items_collection.PendingState;
-import org.chromium.content.browser.test.util.Criteria;
-import org.chromium.content.browser.test.util.CriteriaHelper;
-import org.chromium.net.ConnectionType;
+import org.chromium.content_public.browser.test.util.TestThreadUtils;
 
+import java.lang.annotation.Retention;
+import java.lang.annotation.RetentionPolicy;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.Queue;
@@ -48,11 +47,11 @@ import java.util.concurrent.ConcurrentLinkedQueue;
 /**
  * Test for DownloadManagerService.
  */
-@RunWith(BaseJUnit4ClassRunner.class)
+@RunWith(ChromeJUnit4ClassRunner.class)
+@Batch(Batch.PER_CLASS)
 public class DownloadManagerServiceTest {
-    @Rule
-    public final ChromeBrowserTestRule mBrowserTestRule = new ChromeBrowserTestRule();
-
+    @ClassRule
+    public static final ChromeBrowserTestRule sBrowserTestRule = new ChromeBrowserTestRule();
     private static final int UPDATE_DELAY_FOR_TEST = 1;
     private static final int DELAY_BETWEEN_CALLS = 10;
     private static final int LONG_UPDATE_DELAY_FOR_TEST = 500;
@@ -65,55 +64,60 @@ public class DownloadManagerServiceTest {
         /**
          * The Ids of different methods in this mock object.
          */
-        static enum MethodID {
-            DOWNLOAD_SUCCESSFUL,
-            DOWNLOAD_FAILED,
-            DOWNLOAD_PROGRESS,
-            DOWNLOAD_PAUSED,
-            DOWNLOAD_INTERRUPTED,
-            CANCEL_DOWNLOAD_ID,
-            CLEAR_PENDING_DOWNLOADS
+        @IntDef({MethodID.DOWNLOAD_SUCCESSFUL, MethodID.DOWNLOAD_FAILED, MethodID.DOWNLOAD_PROGRESS,
+                MethodID.DOWNLOAD_PAUSED, MethodID.DOWNLOAD_INTERRUPTED,
+                MethodID.CANCEL_DOWNLOAD_ID, MethodID.CLEAR_PENDING_DOWNLOADS})
+        @Retention(RetentionPolicy.SOURCE)
+        public @interface MethodID {
+            int DOWNLOAD_SUCCESSFUL = 0;
+            int DOWNLOAD_FAILED = 1;
+            int DOWNLOAD_PROGRESS = 2;
+            int DOWNLOAD_PAUSED = 3;
+            int DOWNLOAD_INTERRUPTED = 4;
+            int CANCEL_DOWNLOAD_ID = 5;
+            int CLEAR_PENDING_DOWNLOADS = 6;
         }
 
-        private final Queue<Pair<MethodID, Object>> mExpectedCalls =
-                new ConcurrentLinkedQueue<Pair<MethodID, Object>>();
+        // Use MethodID for Integer values.
+        private final Queue<Pair<Integer, Object>> mExpectedCalls =
+                new ConcurrentLinkedQueue<Pair<Integer, Object>>();
 
-        public MockDownloadNotifier(Context context) {
-            super(context);
+        public MockDownloadNotifier() {
             expect(MethodID.CLEAR_PENDING_DOWNLOADS, null);
         }
 
-        public MockDownloadNotifier expect(MethodID method, Object param) {
+        /** @deprecated Use constructor with no arguments instead. */
+        public MockDownloadNotifier(Context context) {
+            this();
+        }
+
+        public MockDownloadNotifier expect(@MethodID int method, Object param) {
             mExpectedCalls.clear();
             mExpectedCalls.add(getMethodSignature(method, param));
             return this;
         }
 
         public void waitTillExpectedCallsComplete() {
-            CriteriaHelper.pollInstrumentationThread(
-                    new Criteria("Failed while waiting for all calls to complete.") {
-                        @Override
-                        public boolean isSatisfied() {
-                            return mExpectedCalls.isEmpty();
-                        }
-                    });
+            CriteriaHelper.pollInstrumentationThread(() -> {
+                return mExpectedCalls.isEmpty();
+            }, "Failed while waiting for all calls to complete.");
         }
 
-        public MockDownloadNotifier andThen(MethodID method, Object param) {
+        public MockDownloadNotifier andThen(@MethodID int method, Object param) {
             mExpectedCalls.add(getMethodSignature(method, param));
             return this;
         }
 
-        static Pair<MethodID, Object> getMethodSignature(MethodID methodId, Object param) {
-            return new Pair<MethodID, Object>(methodId, param);
+        static Pair<Integer, Object> getMethodSignature(@MethodID int methodId, Object param) {
+            return new Pair<Integer, Object>(methodId, param);
         }
 
-        void assertCorrectExpectedCall(MethodID methodId, Object param, boolean matchParams) {
+        void assertCorrectExpectedCall(@MethodID int methodId, Object param, boolean matchParams) {
             Log.w("MockDownloadNotifier", "Called: " + methodId);
             Assert.assertFalse("Unexpected call:, no call expected, but got: " + methodId,
                     mExpectedCalls.isEmpty());
-            Pair<MethodID, Object> actual = getMethodSignature(methodId, param);
-            Pair<MethodID, Object> expected = mExpectedCalls.poll();
+            Pair<Integer, Object> actual = getMethodSignature(methodId, param);
+            Pair<Integer, Object> expected = mExpectedCalls.poll();
             Assert.assertEquals("Unexpected call", expected.first, actual.first);
             if (matchParams) {
                 Assert.assertTrue(
@@ -131,7 +135,7 @@ public class DownloadManagerServiceTest {
         }
 
         @Override
-        public void notifyDownloadFailed(DownloadInfo downloadInfo, @FailState int failState) {
+        public void notifyDownloadFailed(DownloadInfo downloadInfo) {
             assertCorrectExpectedCall(MethodID.DOWNLOAD_FAILED, downloadInfo, true);
 
         }
@@ -157,43 +161,6 @@ public class DownloadManagerServiceTest {
         public void notifyDownloadCanceled(ContentId id) {
             assertCorrectExpectedCall(MethodID.CANCEL_DOWNLOAD_ID, id, true);
         }
-
-        @Override
-        public void resumePendingDownloads() {}
-    }
-
-    /**
-     * Mock implementation of the DownloadSnackbarController.
-     */
-    static class MockDownloadSnackbarController extends DownloadSnackbarController {
-        private boolean mSucceeded;
-        private boolean mFailed;
-
-        public MockDownloadSnackbarController() {
-            super(null);
-        }
-
-        public void waitForSnackbarControllerToFinish(final boolean success) {
-            CriteriaHelper.pollInstrumentationThread(
-                    new Criteria("Failed while waiting for all calls to complete.") {
-                        @Override
-                        public boolean isSatisfied() {
-                            return success ? mSucceeded : mFailed;
-                        }
-                    });
-        }
-
-        @Override
-        public void onDownloadSucceeded(
-                DownloadInfo downloadInfo, int notificationId, long downloadId,
-                boolean canBeResolved, boolean usesAndroidDownloadManager) {
-            mSucceeded = true;
-        }
-
-        @Override
-        public void onDownloadFailed(String errorMessage, boolean showAllDownloads) {
-            mFailed = true;
-        }
     }
 
     /**
@@ -242,17 +209,10 @@ public class DownloadManagerServiceTest {
 
     private static class DownloadManagerServiceForTest extends DownloadManagerService {
         boolean mResumed;
-        DownloadSnackbarController mDownloadSnackbarController;
 
-        public DownloadManagerServiceForTest(Context context, MockDownloadNotifier mockNotifier,
-                long updateDelayInMillis) {
-            super(context, mockNotifier, getTestHandler(), updateDelayInMillis);
-        }
-
-        @Override
-        protected boolean addCompletedDownload(DownloadItem downloadItem) {
-            downloadItem.setSystemDownloadId(1L);
-            return true;
+        public DownloadManagerServiceForTest(
+                MockDownloadNotifier mockNotifier, long updateDelayInMillis) {
+            super(mockNotifier, getTestHandler(), updateDelayInMillis);
         }
 
         @Override
@@ -265,34 +225,23 @@ public class DownloadManagerServiceTest {
 
         @Override
         protected void scheduleUpdateIfNeeded() {
-            ThreadUtils.runOnUiThreadBlocking(
+            TestThreadUtils.runOnUiThreadBlocking(
                     () -> DownloadManagerServiceForTest.super.scheduleUpdateIfNeeded());
         }
-
-        @Override
-        protected void setDownloadSnackbarController(
-                DownloadSnackbarController downloadSnackbarController) {
-            mDownloadSnackbarController = downloadSnackbarController;
-            super.setDownloadSnackbarController(downloadSnackbarController);
-        }
-
-        @Override
-        protected void onDownloadFailed(DownloadItem downloadItem, int reason) {
-            mDownloadSnackbarController.onDownloadFailed("", false);
-        }
     }
 
+    @Rule
+    public TestRule mProcessor = new Features.JUnitProcessor();
+
     private DownloadManagerServiceForTest mService;
 
-    @Before
-    public void setUp() throws Exception {
-        RecordHistogram.setDisabledForTests(true);
+    @After
+    public void tearDown() {
+        mService = null;
     }
 
-    @After
-    public void tearDown() throws Exception {
-        mService = null;
-        RecordHistogram.setDisabledForTests(false);
+    private static boolean useDownloadOfflineContentProvider() {
+        return ChromeFeatureList.isEnabled(ChromeFeatureList.DOWNLOAD_OFFLINE_CONTENT_PROVIDER);
     }
 
     private static Handler getTestHandler() {
@@ -302,32 +251,26 @@ public class DownloadManagerServiceTest {
     }
 
     private DownloadInfo getDownloadInfo() {
-        return new Builder()
+        return new DownloadInfo.Builder()
                 .setBytesReceived(100)
                 .setDownloadGuid(UUID.randomUUID().toString())
+                .setFileName("test")
+                .setDescription("test")
+                .setFilePath(UrlUtils.getIsolatedTestFilePath(
+                        "chrome/test/data/android/download/download.txt"))
                 .build();
     }
 
-    private Context getTestContext() {
-        return new AdvancedMockContext(InstrumentationRegistry.getTargetContext());
-    }
-
     private void createDownloadManagerService(MockDownloadNotifier notifier, int delayForTest) {
-        ThreadUtils.runOnUiThreadBlocking(new Runnable() {
-            @Override
-            public void run() {
-                mService =
-                        new DownloadManagerServiceForTest(getTestContext(), notifier, delayForTest);
-            }
-        });
+        TestThreadUtils.runOnUiThreadBlocking(
+                () -> { mService = new DownloadManagerServiceForTest(notifier, delayForTest); });
     }
 
     @Test
     @MediumTest
     @Feature({"Download"})
-    @RetryOnFailure
     public void testAllDownloadProgressIsCalledForSlowUpdates() throws InterruptedException {
-        MockDownloadNotifier notifier = new MockDownloadNotifier(getTestContext());
+        MockDownloadNotifier notifier = new MockDownloadNotifier();
         createDownloadManagerService(notifier, UPDATE_DELAY_FOR_TEST);
         DownloadInfo downloadInfo = getDownloadInfo();
 
@@ -337,15 +280,15 @@ public class DownloadManagerServiceTest {
 
         // Now post multiple download updated calls and make sure all are received.
         DownloadInfo update1 =
-                Builder.fromDownloadInfo(downloadInfo)
+                DownloadInfo.Builder.fromDownloadInfo(downloadInfo)
                         .setProgress(new Progress(10, 100L, OfflineItemProgressUnit.PERCENTAGE))
                         .build();
         DownloadInfo update2 =
-                Builder.fromDownloadInfo(downloadInfo)
+                DownloadInfo.Builder.fromDownloadInfo(downloadInfo)
                         .setProgress(new Progress(30, 100L, OfflineItemProgressUnit.PERCENTAGE))
                         .build();
         DownloadInfo update3 =
-                Builder.fromDownloadInfo(downloadInfo)
+                DownloadInfo.Builder.fromDownloadInfo(downloadInfo)
                         .setProgress(new Progress(30, 100L, OfflineItemProgressUnit.PERCENTAGE))
                         .build();
         notifier.expect(MethodID.DOWNLOAD_PROGRESS, update1)
@@ -364,19 +307,19 @@ public class DownloadManagerServiceTest {
     @MediumTest
     @Feature({"Download"})
     public void testOnlyTwoProgressForFastUpdates() throws InterruptedException {
-        MockDownloadNotifier notifier = new MockDownloadNotifier(getTestContext());
+        MockDownloadNotifier notifier = new MockDownloadNotifier();
         createDownloadManagerService(notifier, LONG_UPDATE_DELAY_FOR_TEST);
         DownloadInfo downloadInfo = getDownloadInfo();
         DownloadInfo update1 =
-                Builder.fromDownloadInfo(downloadInfo)
+                DownloadInfo.Builder.fromDownloadInfo(downloadInfo)
                         .setProgress(new Progress(10, 100L, OfflineItemProgressUnit.PERCENTAGE))
                         .build();
         DownloadInfo update2 =
-                Builder.fromDownloadInfo(downloadInfo)
+                DownloadInfo.Builder.fromDownloadInfo(downloadInfo)
                         .setProgress(new Progress(10, 100L, OfflineItemProgressUnit.PERCENTAGE))
                         .build();
         DownloadInfo update3 =
-                Builder.fromDownloadInfo(downloadInfo)
+                DownloadInfo.Builder.fromDownloadInfo(downloadInfo)
                         .setProgress(new Progress(10, 100L, OfflineItemProgressUnit.PERCENTAGE))
                         .build();
 
@@ -396,21 +339,18 @@ public class DownloadManagerServiceTest {
     @Test
     @MediumTest
     @Feature({"Download"})
-    @RetryOnFailure
     public void testDownloadCompletedIsCalled() throws InterruptedException {
-        MockDownloadNotifier notifier = new MockDownloadNotifier(getTestContext());
-        MockDownloadSnackbarController snackbarController = new MockDownloadSnackbarController();
+        if (useDownloadOfflineContentProvider()) return;
+        MockDownloadNotifier notifier = new MockDownloadNotifier();
         createDownloadManagerService(notifier, UPDATE_DELAY_FOR_TEST);
-        ThreadUtils.runOnUiThreadBlocking(
+        TestThreadUtils.runOnUiThreadBlocking(
                 (Runnable) () -> DownloadManagerService.setDownloadManagerService(mService));
-        mService.setDownloadSnackbarController(snackbarController);
         // Try calling download completed directly.
         DownloadInfo successful = getDownloadInfo();
         notifier.expect(MethodID.DOWNLOAD_SUCCESSFUL, successful);
 
         mService.onDownloadCompleted(successful);
         notifier.waitTillExpectedCallsComplete();
-        snackbarController.waitForSnackbarControllerToFinish(true);
 
         // Now check that a successful notification appears after a download progress.
         DownloadInfo progress = getDownloadInfo();
@@ -420,38 +360,36 @@ public class DownloadManagerServiceTest {
         Thread.sleep(DELAY_BETWEEN_CALLS);
         mService.onDownloadCompleted(progress);
         notifier.waitTillExpectedCallsComplete();
-        snackbarController.waitForSnackbarControllerToFinish(true);
     }
 
     @Test
     @MediumTest
     @Feature({"Download"})
-    public void testDownloadFailedIsCalled() throws InterruptedException {
-        MockDownloadNotifier notifier = new MockDownloadNotifier(getTestContext());
-        MockDownloadSnackbarController snackbarController = new MockDownloadSnackbarController();
+    public void testDownloadFailedIsCalled() {
+        MockDownloadNotifier notifier = new MockDownloadNotifier();
         createDownloadManagerService(notifier, UPDATE_DELAY_FOR_TEST);
-        ThreadUtils.runOnUiThreadBlocking(
+        TestThreadUtils.runOnUiThreadBlocking(
                 (Runnable) () -> DownloadManagerService.setDownloadManagerService(mService));
-        mService.setDownloadSnackbarController(snackbarController);
         // Check that if an interrupted download cannot be resumed, it will trigger a download
         // failure.
-        DownloadInfo failure =
-                Builder.fromDownloadInfo(getDownloadInfo()).setIsResumable(false).build();
+        DownloadInfo failure = DownloadInfo.Builder.fromDownloadInfo(getDownloadInfo())
+                                       .setIsResumable(false)
+                                       .build();
         notifier.expect(MethodID.DOWNLOAD_FAILED, failure);
         mService.onDownloadInterrupted(failure, false);
         notifier.waitTillExpectedCallsComplete();
-        snackbarController.waitForSnackbarControllerToFinish(false);
     }
 
     @Test
     @MediumTest
     @Feature({"Download"})
-    public void testDownloadPausedIsCalled() throws InterruptedException {
-        MockDownloadNotifier notifier = new MockDownloadNotifier(getTestContext());
+    public void testDownloadPausedIsCalled() {
+        MockDownloadNotifier notifier = new MockDownloadNotifier();
         createDownloadManagerService(notifier, UPDATE_DELAY_FOR_TEST);
         DownloadManagerService.disableNetworkListenerForTest();
-        DownloadInfo interrupted =
-                Builder.fromDownloadInfo(getDownloadInfo()).setIsResumable(true).build();
+        DownloadInfo interrupted = DownloadInfo.Builder.fromDownloadInfo(getDownloadInfo())
+                                           .setIsResumable(true)
+                                           .build();
         notifier.expect(MethodID.DOWNLOAD_INTERRUPTED, interrupted);
         mService.onDownloadInterrupted(interrupted, true);
         notifier.waitTillExpectedCallsComplete();
@@ -460,9 +398,8 @@ public class DownloadManagerServiceTest {
     @Test
     @MediumTest
     @Feature({"Download"})
-    @RetryOnFailure
     public void testMultipleDownloadProgress() {
-        MockDownloadNotifier notifier = new MockDownloadNotifier(getTestContext());
+        MockDownloadNotifier notifier = new MockDownloadNotifier();
         createDownloadManagerService(notifier, UPDATE_DELAY_FOR_TEST);
 
         DownloadInfo download1 = getDownloadInfo();
@@ -479,106 +416,4 @@ public class DownloadManagerServiceTest {
         notifier.waitTillExpectedCallsComplete();
         Assert.assertTrue("All downloads should be updated.", matchSet.mMatches.isEmpty());
     }
-
-    @Test
-    @MediumTest
-    @Feature({"Download"})
-    @RetryOnFailure
-    public void testInterruptedDownloadAreAutoResumed() throws InterruptedException {
-        MockDownloadNotifier notifier = new MockDownloadNotifier(getTestContext());
-        createDownloadManagerService(notifier, UPDATE_DELAY_FOR_TEST);
-        DownloadManagerService.disableNetworkListenerForTest();
-        DownloadInfo interrupted =
-                Builder.fromDownloadInfo(getDownloadInfo()).setIsResumable(true).build();
-        notifier.expect(MethodID.DOWNLOAD_PROGRESS, interrupted)
-                .andThen(MethodID.DOWNLOAD_INTERRUPTED, interrupted);
-        mService.onDownloadUpdated(interrupted);
-        Thread.sleep(DELAY_BETWEEN_CALLS);
-        mService.onDownloadInterrupted(interrupted, true);
-        notifier.waitTillExpectedCallsComplete();
-        int resumableIdCount = mService.mAutoResumableDownloadIds.size();
-        mService.onConnectionTypeChanged(ConnectionType.CONNECTION_WIFI);
-        Assert.assertEquals(resumableIdCount - 1, mService.mAutoResumableDownloadIds.size());
-        CriteriaHelper.pollUiThread(new Criteria() {
-            @Override
-            public boolean isSatisfied() {
-                return mService.mResumed;
-            }
-        });
-    }
-
-    @Test
-    //@MediumTest
-    //@Feature({"Download"})
-    @DisabledTest // crbug.com/789931
-    public void testInterruptedUnmeteredDownloadCannotAutoResumeOnMeteredNetwork()
-            throws InterruptedException {
-        MockDownloadNotifier notifier = new MockDownloadNotifier(getTestContext());
-        createDownloadManagerService(notifier, UPDATE_DELAY_FOR_TEST);
-        DownloadManagerService.disableNetworkListenerForTest();
-        DownloadInfo interrupted =
-                Builder.fromDownloadInfo(getDownloadInfo()).setIsResumable(true).build();
-        notifier.expect(MethodID.DOWNLOAD_PROGRESS, interrupted)
-                .andThen(MethodID.DOWNLOAD_INTERRUPTED, interrupted);
-        mService.onDownloadUpdated(interrupted);
-        Thread.sleep(DELAY_BETWEEN_CALLS);
-        mService.onDownloadInterrupted(interrupted, true);
-        notifier.waitTillExpectedCallsComplete();
-        DownloadManagerService.setIsNetworkMeteredForTest(true);
-        int resumableIdCount = mService.mAutoResumableDownloadIds.size();
-        mService.onConnectionTypeChanged(ConnectionType.CONNECTION_2G);
-        Assert.assertEquals(resumableIdCount, mService.mAutoResumableDownloadIds.size());
-    }
-
-    /**
-     * Test to make sure {@link DownloadManagerService#shouldOpenAfterDownload}
-     * returns the right result for varying MIME types and Content-Dispositions.
-     */
-    @Test
-    @SmallTest
-    @Feature({"Download"})
-    public void testShouldOpenAfterDownload() {
-        // Should not open any download type MIME types.
-        Assert.assertFalse(DownloadManagerService.shouldOpenAfterDownload(
-                new DownloadInfo.Builder()
-                        .setMimeType("application/download")
-                        .setHasUserGesture(true)
-                        .build()));
-        Assert.assertFalse(DownloadManagerService.shouldOpenAfterDownload(
-                new DownloadInfo.Builder()
-                        .setMimeType("application/x-download")
-                        .setHasUserGesture(true)
-                        .build()));
-        Assert.assertFalse(DownloadManagerService.shouldOpenAfterDownload(
-                new DownloadInfo.Builder()
-                        .setMimeType("application/octet-stream")
-                        .setHasUserGesture(true)
-                        .build()));
-
-        // Should open PDFs.
-        Assert.assertTrue(DownloadManagerService.shouldOpenAfterDownload(
-                new DownloadInfo.Builder()
-                        .setMimeType("application/pdf")
-                        .setHasUserGesture(true)
-                        .build()));
-        Assert.assertTrue(DownloadManagerService.shouldOpenAfterDownload(
-                new DownloadInfo.Builder()
-                        .setContentDisposition("filename=test.pdf")
-                        .setMimeType("application/pdf")
-                        .setHasUserGesture(true)
-                        .build()));
-
-        // Require user gesture.
-        Assert.assertFalse(DownloadManagerService.shouldOpenAfterDownload(
-                new DownloadInfo.Builder()
-                        .setMimeType("application/pdf")
-                        .setHasUserGesture(false)
-                        .build()));
-        Assert.assertFalse(DownloadManagerService.shouldOpenAfterDownload(
-                new DownloadInfo.Builder()
-                        .setContentDisposition("filename=test.pdf")
-                        .setMimeType("application/pdf")
-                        .setHasUserGesture(false)
-                        .build()));
-    }
 }
