@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -7,31 +7,39 @@ package org.chromium.chrome.browser.download;
 import android.app.DownloadManager;
 import android.content.Context;
 import android.content.Intent;
-import android.content.pm.PackageManager;
 import android.support.test.InstrumentationRegistry;
-import android.support.test.filters.MediumTest;
-import android.support.test.filters.SmallTest;
+
+import androidx.test.filters.MediumTest;
+import androidx.test.filters.SmallTest;
 
 import org.hamcrest.Matchers;
 import org.junit.Assert;
-import org.junit.Rule;
+import org.junit.Before;
+import org.junit.ClassRule;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 
 import org.chromium.base.ApiCompatibilityUtils;
-import org.chromium.base.ContextUtils;
+import org.chromium.base.Callback;
 import org.chromium.base.test.util.AdvancedMockContext;
+import org.chromium.base.test.util.Batch;
+import org.chromium.base.test.util.Criteria;
+import org.chromium.base.test.util.CriteriaHelper;
 import org.chromium.base.test.util.Feature;
-import org.chromium.base.test.util.RetryOnFailure;
 import org.chromium.base.test.util.UrlUtils;
-import org.chromium.chrome.browser.download.DownloadManagerDelegate.DownloadQueryCallback;
-import org.chromium.chrome.browser.download.DownloadManagerDelegate.DownloadQueryResult;
+import org.chromium.chrome.browser.download.DownloadManagerBridge.DownloadQueryResult;
 import org.chromium.chrome.browser.download.OMADownloadHandler.OMAInfo;
-import org.chromium.chrome.browser.test.ChromeBrowserTestRule;
+import org.chromium.chrome.browser.preferences.ChromePreferenceKeys;
+import org.chromium.chrome.browser.preferences.SharedPreferencesManager;
+import org.chromium.chrome.test.ChromeBrowserTestRule;
 import org.chromium.chrome.test.ChromeJUnit4ClassRunner;
-import org.chromium.content.browser.test.util.Criteria;
-import org.chromium.content.browser.test.util.CriteriaHelper;
+import org.chromium.components.offline_items_collection.ContentId;
+import org.chromium.components.offline_items_collection.OfflineItem;
+import org.chromium.components.offline_items_collection.OfflineItemState;
+import org.chromium.components.offline_items_collection.UpdateDelta;
+import org.chromium.content_public.browser.test.util.TestThreadUtils;
 import org.chromium.net.test.EmbeddedTestServer;
+import org.chromium.url.GURL;
 
 import java.io.ByteArrayInputStream;
 import java.util.HashSet;
@@ -42,47 +50,75 @@ import java.util.Set;
  * Tests for OMADownloadHandler class.
  */
 @RunWith(ChromeJUnit4ClassRunner.class)
+@Batch(Batch.PER_CLASS)
 public class OMADownloadHandlerTest {
-    @Rule
-    public final ChromeBrowserTestRule mBrowserTestRule = new ChromeBrowserTestRule();
+    @ClassRule
+    public static final ChromeBrowserTestRule sBrowserTestRule = new ChromeBrowserTestRule();
 
-    private static final String PENDING_OMA_DOWNLOADS = "PendingOMADownloads";
     private static final String INSTALL_NOTIFY_URI = "http://test/test";
 
+    private TestInfoBarController mTestInfoBarController;
+
+    @Before
+    public void before() {
+        TestThreadUtils.runOnUiThreadBlocking(() -> {
+            mTestInfoBarController = new TestInfoBarController();
+            DownloadManagerService.getDownloadManagerService().setInfoBarControllerForTesting(
+                    mTestInfoBarController);
+        });
+    }
+
     private Context getTestContext() {
         return new AdvancedMockContext(InstrumentationRegistry.getTargetContext());
     }
 
     /**
-     * Mock implementation of the DownloadSnackbarController.
+     * Mock implementation of the DownloadMessageUiController.
      */
-    static class MockDownloadSnackbarController extends DownloadSnackbarController {
-        public boolean mSucceeded;
-        public boolean mFailed;
+    static class TestInfoBarController implements DownloadMessageUiController {
+        public boolean mDownloadStarted;
+        public OfflineItem mLastUpdatedItem;
 
-        public MockDownloadSnackbarController() {
-            super(null);
-        }
-
-        public void waitForSnackbarControllerToFinish(final boolean success) {
-            CriteriaHelper.pollInstrumentationThread(
-                    new Criteria("Failed while waiting for all calls to complete.") {
-                        @Override
-                        public boolean isSatisfied() {
-                            return success ? mSucceeded : mFailed;
-                        }
-                    });
+        public TestInfoBarController() {
         }
 
         @Override
-        public void onDownloadSucceeded(DownloadInfo downloadInfo, int notificationId,
-                long downloadId, boolean canBeResolved, boolean usesAndroidDownloadManager) {
-            mSucceeded = true;
+        public void onDownloadStarted() {
+            mDownloadStarted = true;
         }
 
         @Override
-        public void onDownloadFailed(String errorMessage, boolean showAllDownloads) {
-            mFailed = true;
+        public void showIncognitoDownloadMessage(Callback<Boolean> callback) {}
+
+        @Override
+        public void addDownloadInterstitialSource(GURL originalUrl) {}
+
+        @Override
+        public boolean isDownloadInterstitialItem(GURL originalUrl, String guid) {
+            return false;
+        }
+
+        @Override
+        public void onItemsAdded(List<OfflineItem> items) {}
+
+        @Override
+        public void onItemUpdated(OfflineItem item, UpdateDelta updateDelta) {
+            mLastUpdatedItem = item;
+        }
+
+        @Override
+        public void onItemRemoved(ContentId id) {}
+
+        @Override
+        public void onNotificationShown(ContentId id, int notificationId) {}
+
+        @Override
+        public boolean isShowing() {
+            return false;
+        }
+
+        public OfflineItem getLastUpdatedItem() {
+            return mLastUpdatedItem;
         }
     }
 
@@ -90,9 +126,9 @@ public class OMADownloadHandlerTest {
         public String mNofityURI;
         public long mDownloadId;
 
-        public OMADownloadHandlerForTest(Context context, DownloadManagerDelegate delegate,
-                DownloadSnackbarController downloadSnackbarController) {
-            super(context, delegate, downloadSnackbarController);
+        public OMADownloadHandlerForTest(Context context) {
+            super(context);
+            addObserverForTest(downloadId -> { mDownloadId = downloadId; });
         }
 
         @Override
@@ -101,17 +137,10 @@ public class OMADownloadHandlerTest {
             mNofityURI = omaInfo.getValue(OMA_INSTALL_NOTIFY_URI);
             return true;
         }
-
-        @Override
-        public void onDownloadEnqueued(
-                boolean result, int failureReason, DownloadItem downloadItem, long downloadId) {
-            super.onDownloadEnqueued(result, failureReason, downloadItem, downloadId);
-            mDownloadId = downloadId;
-        }
     }
 
     /** Helper class to verify the result of {@DownloadManagerDelegate.queryDownloadResult}. */
-    private static class DownloadQueryResultVerifier implements DownloadQueryCallback {
+    private static class DownloadQueryResultVerifier implements Callback<DownloadQueryResult> {
         private int mExpectedDownloadStatus;
 
         public boolean mQueryCompleted;
@@ -121,19 +150,14 @@ public class OMADownloadHandlerTest {
         }
 
         @Override
-        public void onQueryCompleted(DownloadQueryResult result, boolean showNotifications) {
+        public void onResult(DownloadQueryResult result) {
             mQueryCompleted = true;
             Assert.assertEquals(mExpectedDownloadStatus, result.downloadStatus);
         }
     }
 
     private void waitForQueryCompletion(final DownloadQueryResultVerifier verifier) {
-        CriteriaHelper.pollUiThread(new Criteria() {
-            @Override
-            public boolean isSatisfied() {
-                return verifier.mQueryCompleted;
-            }
-        });
+        CriteriaHelper.pollUiThread(() -> verifier.mQueryCompleted);
     }
 
     /**
@@ -169,12 +193,12 @@ public class OMADownloadHandlerTest {
         info.addAttributeValue("type", "text/html");
         Assert.assertEquals(info.getDrmType(), null);
 
-        info.addAttributeValue("type", OMADownloadHandler.OMA_DRM_MESSAGE_MIME);
-        Assert.assertEquals(info.getDrmType(), OMADownloadHandler.OMA_DRM_MESSAGE_MIME);
+        info.addAttributeValue("type", MimeUtils.OMA_DRM_MESSAGE_MIME);
+        Assert.assertEquals(info.getDrmType(), MimeUtils.OMA_DRM_MESSAGE_MIME);
 
         // Test that only the first DRM MIME type is returned.
-        info.addAttributeValue("type", OMADownloadHandler.OMA_DRM_CONTENT_MIME);
-        Assert.assertEquals(info.getDrmType(), OMADownloadHandler.OMA_DRM_MESSAGE_MIME);
+        info.addAttributeValue("type", MimeUtils.OMA_DRM_CONTENT_MIME);
+        Assert.assertEquals(info.getDrmType(), MimeUtils.OMA_DRM_MESSAGE_MIME);
     }
 
     /**
@@ -184,22 +208,20 @@ public class OMADownloadHandlerTest {
     @SmallTest
     @Feature({"Download"})
     public void testGetOpennableType() {
-        PackageManager pm = InstrumentationRegistry.getContext().getPackageManager();
         OMADownloadHandler.OMAInfo info = new OMADownloadHandler.OMAInfo();
-        Assert.assertEquals(OMADownloadHandler.getOpennableType(pm, info), null);
+        Assert.assertEquals(OMADownloadHandler.getOpennableType(info), null);
 
         info.addAttributeValue(OMADownloadHandler.OMA_TYPE, "application/octet-stream");
-        info.addAttributeValue(OMADownloadHandler.OMA_TYPE,
-                OMADownloadHandler.OMA_DRM_MESSAGE_MIME);
+        info.addAttributeValue(OMADownloadHandler.OMA_TYPE, MimeUtils.OMA_DRM_MESSAGE_MIME);
         info.addAttributeValue(OMADownloadHandler.OMA_TYPE, "text/html");
-        Assert.assertEquals(OMADownloadHandler.getOpennableType(pm, info), null);
+        Assert.assertEquals(OMADownloadHandler.getOpennableType(info), null);
 
         info.addAttributeValue(OMADownloadHandler.OMA_OBJECT_URI, "http://www.test.com/test.html");
-        Assert.assertEquals(OMADownloadHandler.getOpennableType(pm, info), "text/html");
+        Assert.assertEquals(OMADownloadHandler.getOpennableType(info), "text/html");
 
         // Test that only the first opennable type is returned.
         info.addAttributeValue(OMADownloadHandler.OMA_TYPE, "image/png");
-        Assert.assertEquals(OMADownloadHandler.getOpennableType(pm, info), "text/html");
+        Assert.assertEquals(OMADownloadHandler.getOpennableType(info), "text/html");
     }
 
     /**
@@ -235,8 +257,8 @@ public class OMADownloadHandlerTest {
         Assert.assertEquals(info.getValue(OMADownloadHandler.OMA_DESCRIPTION), "testjpg");
         Assert.assertEquals(info.getValue(OMADownloadHandler.OMA_NEXT_URL), "http://nexturl.html");
         List<String> types = info.getTypes();
-        Assert.assertThat(types,
-                Matchers.containsInAnyOrder("image/jpeg", OMADownloadHandler.OMA_DRM_MESSAGE_MIME));
+        Assert.assertThat(
+                types, Matchers.containsInAnyOrder("image/jpeg", MimeUtils.OMA_DRM_MESSAGE_MIME));
     }
 
     /**
@@ -277,8 +299,8 @@ public class OMADownloadHandlerTest {
     }
 
     /**
-     * Test to make sure {@link DownloadManagerDelegate#queryDownloadResult} will report correctly
-     * about the status of completed downloads and removed downloads.
+     * Test to make sure {@link DownloadManagerBridge#queryDownloadResult} will report
+     * correctly about the status of completed downloads and removed downloads.
      */
     @Test
     @MediumTest
@@ -291,20 +313,14 @@ public class OMADownloadHandlerTest {
                 UrlUtils.getIsolatedTestFilePath("chrome/test/data/android/download/download.txt"),
                 4, true);
 
-        DownloadItem downloadItem = new DownloadItem(true, new DownloadInfo.Builder().build());
-        downloadItem.setSystemDownloadId(downloadId1);
-
-        DownloadManagerDelegate downloadManagerDelegate = new DownloadManagerDelegate(context);
         DownloadQueryResultVerifier verifier =
-                new DownloadQueryResultVerifier(DownloadManagerService.DOWNLOAD_STATUS_COMPLETE);
-        downloadManagerDelegate.queryDownloadResult(downloadItem, false, verifier);
+                new DownloadQueryResultVerifier(DownloadStatus.COMPLETE);
+        DownloadManagerBridge.queryDownloadResult(downloadId1, verifier);
         waitForQueryCompletion(verifier);
 
         manager.remove(downloadId1);
-        downloadItem.setSystemDownloadId(downloadId1);
-        verifier =
-                new DownloadQueryResultVerifier(DownloadManagerService.DOWNLOAD_STATUS_CANCELLED);
-        downloadManagerDelegate.queryDownloadResult(downloadItem, false, verifier);
+        verifier = new DownloadQueryResultVerifier(DownloadStatus.CANCELLED);
+        DownloadManagerBridge.queryDownloadResult(downloadId1, verifier);
         waitForQueryCompletion(verifier);
     }
 
@@ -314,7 +330,6 @@ public class OMADownloadHandlerTest {
      */
     @Test
     @MediumTest
-    @RetryOnFailure
     @Feature({"Download"})
     public void testClearPendingOMADownloads() {
         Context context = getTestContext();
@@ -324,35 +339,33 @@ public class OMADownloadHandlerTest {
                 UrlUtils.getIsolatedTestFilePath("chrome/test/data/android/download/download.txt"),
                 4, true);
 
-        DownloadManagerDelegate downloadManagerDelegate = new DownloadManagerDelegate(context);
-        final MockDownloadSnackbarController snackbarController =
-                new MockDownloadSnackbarController();
-        final OMADownloadHandlerForTest omaHandler =
-                new OMADownloadHandlerForTest(context, downloadManagerDelegate, snackbarController);
+        final OMADownloadHandlerForTest omaHandler = new OMADownloadHandlerForTest(context);
 
         // Write a few pending downloads into shared preferences.
         Set<String> pendingOmaDownloads = new HashSet<>();
         pendingOmaDownloads.add(String.valueOf(downloadId1) + "," + INSTALL_NOTIFY_URI);
-        DownloadManagerService.storeDownloadInfo(ContextUtils.getAppSharedPreferences(),
-                PENDING_OMA_DOWNLOADS, pendingOmaDownloads, false /* forceCommit */);
+        DownloadManagerService.storeDownloadInfo(SharedPreferencesManager.getInstance(),
+                ChromePreferenceKeys.DOWNLOAD_PENDING_OMA_DOWNLOADS, pendingOmaDownloads,
+                false /* forceCommit */);
 
-        pendingOmaDownloads = DownloadManagerService.getStoredDownloadInfo(
-                ContextUtils.getAppSharedPreferences(), PENDING_OMA_DOWNLOADS);
+        pendingOmaDownloads =
+                DownloadManagerService.getStoredDownloadInfo(SharedPreferencesManager.getInstance(),
+                        ChromePreferenceKeys.DOWNLOAD_PENDING_OMA_DOWNLOADS);
         Assert.assertEquals(1, pendingOmaDownloads.size());
 
         omaHandler.clearPendingOMADownloads();
 
         // Wait for OMADownloadHandler to clear the pending downloads.
-        CriteriaHelper.pollUiThread(new Criteria() {
-            @Override
-            public boolean isSatisfied() {
-                return snackbarController.mSucceeded;
-            }
+        CriteriaHelper.pollUiThread(() -> {
+            OfflineItem item = mTestInfoBarController.getLastUpdatedItem();
+            Criteria.checkThat(item, Matchers.notNullValue());
+            Criteria.checkThat(item.state, Matchers.is(OfflineItemState.COMPLETE));
         });
 
         // The pending downloads set in the shared prefs should be empty now.
-        pendingOmaDownloads = DownloadManagerService.getStoredDownloadInfo(
-                ContextUtils.getAppSharedPreferences(), PENDING_OMA_DOWNLOADS);
+        pendingOmaDownloads =
+                DownloadManagerService.getStoredDownloadInfo(SharedPreferencesManager.getInstance(),
+                        ChromePreferenceKeys.DOWNLOAD_PENDING_OMA_DOWNLOADS);
         Assert.assertEquals(0, pendingOmaDownloads.size());
         Assert.assertEquals(omaHandler.mNofityURI, INSTALL_NOTIFY_URI);
 
@@ -367,7 +380,7 @@ public class OMADownloadHandlerTest {
     @Test
     @MediumTest
     @Feature({"Download"})
-    public void testEnqueueOMADownloads() throws InterruptedException {
+    public void testEnqueueOMADownloads() {
         EmbeddedTestServer testServer =
                 EmbeddedTestServer.createAndStartServer(InstrumentationRegistry.getContext());
         Context context = getTestContext();
@@ -380,29 +393,26 @@ public class OMADownloadHandlerTest {
 
         try {
             DownloadInfo info = new DownloadInfo.Builder().build();
-            final DownloadManagerDelegate downloadManagerDelegate =
-                    new DownloadManagerDelegate(context);
-            final MockDownloadSnackbarController snackbarController =
-                    new MockDownloadSnackbarController();
-            final OMADownloadHandlerForTest omaHandler = new OMADownloadHandlerForTest(
-                    context, downloadManagerDelegate, snackbarController) {
-                @Override
-                public void onReceive(Context context, Intent intent) {
-                    // Ignore all the broadcasts.
-                }
-            };
+            final OMADownloadHandlerForTest omaHandler =
+                    TestThreadUtils.runOnUiThreadBlockingNoException(() -> {
+                        return new OMADownloadHandlerForTest(context) {
+                            @Override
+                            public void onReceive(Context context, Intent intent) {
+                                // Ignore all the broadcasts.
+                            }
+                        };
+                    });
 
             omaHandler.clearPendingOMADownloads();
             omaHandler.downloadOMAContent(0, info, omaInfo);
-            CriteriaHelper.pollUiThread(new Criteria() {
-                @Override
-                public boolean isSatisfied() {
-                    return omaHandler.mDownloadId != 0;
-                }
+            CriteriaHelper.pollUiThread(() -> {
+                Criteria.checkThat(omaHandler.mDownloadId, Matchers.not(0));
+                Criteria.checkThat(mTestInfoBarController.mDownloadStarted, Matchers.is(true));
             });
 
             Set<String> downloads = DownloadManagerService.getStoredDownloadInfo(
-                    ContextUtils.getAppSharedPreferences(), PENDING_OMA_DOWNLOADS);
+                    SharedPreferencesManager.getInstance(),
+                    ChromePreferenceKeys.DOWNLOAD_PENDING_OMA_DOWNLOADS);
             Assert.assertEquals(1, downloads.size());
             OMADownloadHandler.OMAEntry entry =
                     OMADownloadHandler.OMAEntry.parseOMAEntry((String) (downloads.toArray()[0]));
