@@ -1,61 +1,66 @@
-// Copyright 2017 The Chromium Authors. All rights reserved.
+// Copyright 2017 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.feature_engagement;
 
-import android.os.FileObserver;
-import android.support.test.filters.SmallTest;
+import android.content.Context;
+import android.content.ContextWrapper;
+import android.content.pm.PackageManager;
+import android.database.ContentObserver;
+import android.database.Cursor;
+import android.net.Uri;
+import android.provider.MediaStore;
+import android.support.test.InstrumentationRegistry;
+import android.test.mock.MockContentProvider;
+import android.test.mock.MockContentResolver;
+
+import androidx.core.content.ContextCompat;
+import androidx.test.filters.SmallTest;
 
 import org.junit.Assert;
+import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
+import org.mockito.Mock;
+import org.mockito.Mockito;
+import org.mockito.MockitoAnnotations;
 
+import org.chromium.base.ContextUtils;
 import org.chromium.base.Log;
 import org.chromium.base.ThreadUtils;
+import org.chromium.base.task.PostTask;
+import org.chromium.base.task.TaskTraits;
+import org.chromium.base.test.util.Batch;
 import org.chromium.base.test.util.Feature;
 import org.chromium.chrome.test.ChromeJUnit4ClassRunner;
+import org.chromium.content_public.browser.test.util.TestThreadUtils;
+import org.chromium.ui.base.MimeTypeUtils;
+import org.chromium.ui.display.DisplayAndroid;
 
-import java.io.File;
 import java.util.concurrent.Semaphore;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
+
 /**
  * Tests ScreenshotMonitor.
  */
 @RunWith(ChromeJUnit4ClassRunner.class)
+@Batch(Batch.PER_CLASS)
 public class ScreenshotMonitorTest {
     private static final String FILENAME = "image.jpeg";
     private static final String TAG = "ScreenshotTest";
+    private static final Uri TEST_URI = Uri.parse("content://media/external/images/media/101");
 
-    private ScreenshotMonitor mTestScreenshotMonitor;
+    private ScreenshotMonitorImpl mTestScreenshotMonitor;
     private TestScreenshotMonitorDelegate mTestScreenshotMonitorDelegate;
-    private TestScreenshotMonitorFileObserver mTestFileObserver;
+    private ContentObserver mContentObserver;
 
-    /**
-     * This class acts as the inner FileObserver used by TestScreenshotMonitor to test that
-     * ScreenshotMonitor calls the FileObserver.
-     */
-    static class TestScreenshotMonitorFileObserver
-            extends ScreenshotMonitor.ScreenshotMonitorFileObserver {
-        // The number of times concurrent watching occurs. It corresponds to the number of times
-        // startWatching() and stopWatching() are called. It is modified on the UI thread and
-        // accessed on the test thread.
-        public final AtomicInteger watchingCount = new AtomicInteger();
+    private MockContentResolver mMockContentResolver = new MockContentResolver();
 
-        // Note: FileObserver's startWatching will have no effect if monitoring started already.
-        @Override
-        public void startWatching() {
-            watchingCount.getAndIncrement();
-        }
-
-        // Note: FileObserver's stopWatching will have no effect if monitoring stopped already.
-        @Override
-        public void stopWatching() {
-            watchingCount.getAndDecrement();
-        }
-    }
+    @Mock
+    private DisplayAndroid mDisplayAndroid;
 
     static class TestScreenshotMonitorDelegate implements ScreenshotMonitorDelegate {
         // This is modified on the UI thread and accessed on the test thread.
@@ -68,28 +73,69 @@ public class ScreenshotMonitorTest {
         }
     }
 
-    static String getTestFilePath() {
-        return ScreenshotMonitor.ScreenshotMonitorFileObserver.getDirPath() + File.separator
-                + FILENAME;
+    private static class TestContext extends ContextWrapper {
+        public TestContext(Context base) {
+            super(base);
+        }
+
+        @Override
+        public int checkPermission(String permission, int pid, int uid) {
+            return PackageManager.PERMISSION_GRANTED;
+        }
     }
 
     @Before
-    public void setUp() throws Exception {
+    public void setUp() {
+        // Replaces the application context with a test implementation which will return true for
+        // permission requests. This is needed for the permission check in
+        // ScreenshotMonitorImpl#doesChangeLookLikeScreenshot.
+        Context context = new TestContext(InstrumentationRegistry.getTargetContext());
+        ContextUtils.initApplicationContextForTests(context);
+        Assume.assumeTrue(
+                ContextCompat.checkSelfPermission(ContextUtils.getApplicationContext(),
+                        MimeTypeUtils.getPermissionNameForMimeType(MimeTypeUtils.Type.IMAGE))
+                == PackageManager.PERMISSION_GRANTED);
+
+        MockitoAnnotations.initMocks(this);
         mTestScreenshotMonitorDelegate = new TestScreenshotMonitorDelegate();
 
-        ThreadUtils.runOnUiThreadBlocking(new Runnable() {
+        TestThreadUtils.runOnUiThreadBlocking(() -> {
+            mTestScreenshotMonitor = new ScreenshotMonitorImpl(
+                    mTestScreenshotMonitorDelegate, null, mMockContentResolver, mDisplayAndroid);
+            mContentObserver = mTestScreenshotMonitor.getContentObserver();
+        });
+    }
+
+    private void mockValidContentResolver(String path, String width, String height) {
+        final Cursor cursor = Mockito.mock(Cursor.class);
+        Mockito.doReturn(true).when(cursor).moveToNext();
+
+        Mockito.doReturn(1).when(cursor).getColumnIndexOrThrow(
+                Mockito.eq(MediaStore.MediaColumns.DATA));
+        Mockito.doReturn(2).when(cursor).getColumnIndexOrThrow(
+                Mockito.eq(MediaStore.MediaColumns.WIDTH));
+        Mockito.doReturn(3).when(cursor).getColumnIndexOrThrow(
+                Mockito.eq(MediaStore.MediaColumns.HEIGHT));
+        Mockito.doReturn(path).when(cursor).getString(Mockito.eq(1));
+        Mockito.doReturn(width).when(cursor).getString(Mockito.eq(2));
+        Mockito.doReturn(height).when(cursor).getString(Mockito.eq(3));
+
+        mMockContentResolver.addProvider("media", new MockContentProvider() {
             @Override
-            public void run() {
-                mTestScreenshotMonitor = new ScreenshotMonitor(
-                        mTestScreenshotMonitorDelegate, new TestScreenshotMonitorFileObserver());
+            public Cursor query(Uri uri, String[] projection, String selection,
+                    String[] selectionArgs, String sortOrder) {
+                return cursor;
             }
         });
-        Assert.assertTrue(
-                mTestScreenshotMonitor.mFileObserver instanceof TestScreenshotMonitorFileObserver);
-        mTestFileObserver =
-                (TestScreenshotMonitorFileObserver) mTestScreenshotMonitor.mFileObserver;
     }
 
+    private void mockDisplay(int width, int height) {
+        Mockito.doReturn(width).when(mDisplayAndroid).getDisplayWidth();
+        Mockito.doReturn(height).when(mDisplayAndroid).getDisplayHeight();
+    }
+
+    private void mockValidScreenshot() {}
+
     /**
      * Verify that if monitoring starts, the delegate should be called. Also verify that the
      * inner TestFileObserver monitors as expected.
@@ -97,88 +143,17 @@ public class ScreenshotMonitorTest {
     @Test
     @SmallTest
     @Feature({"FeatureEngagement", "Screenshot"})
-    public void testStartMonitoringShouldTriggerDelegate() throws Throwable {
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
+    public void testDelegateCalledOnEvent() {
+        mockDisplay(50, 100);
+        mockValidContentResolver("Screenshot", "50", "100");
 
         startMonitoringOnUiThreadBlocking();
-        Assert.assertEquals(1, mTestFileObserver.watchingCount.get());
         Assert.assertEquals(0, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
 
-        mTestScreenshotMonitor.mFileObserver.onEvent(FileObserver.CREATE, getTestFilePath());
+        mContentObserver.onChange(true, TEST_URI);
         assertScreenshotShowUiCountOnUiThreadBlocking(1);
 
         stopMonitoringOnUiThreadBlocking();
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
-    }
-
-    /**
-     * Verify that if monitoring starts multiple times, the delegate should still be called.
-     */
-    @Test
-    @SmallTest
-    @Feature({"FeatureEngagement", "Screenshot"})
-    public void testMultipleStartMonitoringShouldTriggerDelegate() throws Throwable {
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
-
-        startMonitoringOnUiThreadBlocking();
-        startMonitoringOnUiThreadBlocking();
-        Assert.assertEquals(2, mTestFileObserver.watchingCount.get());
-
-        mTestScreenshotMonitor.mFileObserver.onEvent(FileObserver.CREATE, getTestFilePath());
-        assertScreenshotShowUiCountOnUiThreadBlocking(1);
-    }
-
-    /**
-     * Verify that if monitoring stops multiple times, the delegate should not be called.
-     */
-    @Test
-    @SmallTest
-    @Feature({"FeatureEngagement", "Screenshot"})
-    public void testMultipleStopMonitoringShouldNotTriggerDelegate() throws Throwable {
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
-
-        stopMonitoringOnUiThreadBlocking();
-        stopMonitoringOnUiThreadBlocking();
-        Assert.assertEquals(-2, mTestFileObserver.watchingCount.get());
-
-        mTestScreenshotMonitor.mFileObserver.onEvent(FileObserver.CREATE, getTestFilePath());
-        assertScreenshotShowUiCountOnUiThreadBlocking(0);
-    }
-
-    /**
-     * Verify that even if startMonitoring is called multiple times before stopMonitoring, the
-     * delegate should not be called.
-     */
-    @Test
-    @SmallTest
-    @Feature({"FeatureEngagement", "Screenshot"})
-    public void testMultipleStartMonitoringThenStopShouldNotTriggerDelegate() throws Throwable {
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
-        Assert.assertEquals(0, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
-
-        multipleStartMonitoringBeforeStopMonitoringOnUiThreadBlocking(2);
-        Assert.assertEquals(1, mTestFileObserver.watchingCount.get());
-
-        mTestScreenshotMonitor.mFileObserver.onEvent(FileObserver.CREATE, getTestFilePath());
-        assertScreenshotShowUiCountOnUiThreadBlocking(0);
-    }
-
-    /**
-     * Verify that if stopMonitoring is called multiple times before startMonitoring, the delegate
-     * should still be called.
-     */
-    @Test
-    @SmallTest
-    @Feature({"FeatureEngagement", "Screenshot"})
-    public void testMultipleStopMonitoringThenStartShouldTriggerDelegate() throws Throwable {
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
-
-        multipleStopMonitoringBeforeStartMonitoringOnUiThreadBlocking(2);
-        Assert.assertEquals(-1, mTestFileObserver.watchingCount.get());
-        Assert.assertEquals(0, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
-
-        mTestScreenshotMonitor.mFileObserver.onEvent(FileObserver.CREATE, getTestFilePath());
-        assertScreenshotShowUiCountOnUiThreadBlocking(1);
     }
 
     /**
@@ -187,25 +162,23 @@ public class ScreenshotMonitorTest {
     @Test
     @SmallTest
     @Feature({"FeatureEngagement", "Screenshot"})
-    public void testRestartShouldTriggerDelegate() throws Throwable {
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
+    public void testRestartShouldTriggerDelegate() {
+        mockDisplay(50, 100);
+        mockValidContentResolver("Screenshot", "50", "100");
 
         startMonitoringOnUiThreadBlocking();
-        Assert.assertEquals(1, mTestFileObserver.watchingCount.get());
         Assert.assertEquals(0, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
 
-        mTestScreenshotMonitor.mFileObserver.onEvent(FileObserver.CREATE, getTestFilePath());
+        mContentObserver.onChange(true, TEST_URI);
         assertScreenshotShowUiCountOnUiThreadBlocking(1);
 
         stopMonitoringOnUiThreadBlocking();
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
 
         // Restart and call onEvent a second time
         startMonitoringOnUiThreadBlocking();
-        Assert.assertEquals(1, mTestFileObserver.watchingCount.get());
         Assert.assertEquals(1, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
 
-        mTestScreenshotMonitor.mFileObserver.onEvent(FileObserver.CREATE, getTestFilePath());
+        mContentObserver.onChange(true, TEST_URI);
         assertScreenshotShowUiCountOnUiThreadBlocking(2);
     }
 
@@ -215,17 +188,16 @@ public class ScreenshotMonitorTest {
     @Test
     @SmallTest
     @Feature({"FeatureEngagement", "Screenshot"})
-    public void testStopMonitoringShouldNotTriggerDelegate() throws Throwable {
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
+    public void testStopMonitoringShouldNotTriggerDelegate() {
+        mockDisplay(50, 100);
+        mockValidContentResolver("Screenshot", "50", "100");
 
         startMonitoringOnUiThreadBlocking();
-        Assert.assertEquals(1, mTestFileObserver.watchingCount.get());
         Assert.assertEquals(0, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
 
         stopMonitoringOnUiThreadBlocking();
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
 
-        mTestScreenshotMonitor.mFileObserver.onEvent(FileObserver.CREATE, getTestFilePath());
+        mContentObserver.onChange(true, TEST_URI);
         assertScreenshotShowUiCountOnUiThreadBlocking(0);
     }
 
@@ -235,21 +207,49 @@ public class ScreenshotMonitorTest {
     @Test
     @SmallTest
     @Feature({"FeatureEngagement", "Screenshot"})
-    public void testNoMonitoringShouldNotTriggerDelegate() throws Throwable {
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
+    public void testNoMonitoringShouldNotTriggerDelegate() {
+        mockDisplay(50, 100);
+        mockValidContentResolver("Screenshot", "50", "100");
+
         Assert.assertEquals(0, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
 
-        mTestScreenshotMonitor.mFileObserver.onEvent(FileObserver.CREATE, getTestFilePath());
+        mContentObserver.onChange(true, TEST_URI);
         assertScreenshotShowUiCountOnUiThreadBlocking(0);
+    }
 
-        Assert.assertEquals(0, mTestFileObserver.watchingCount.get());
+    @Test
+    @SmallTest
+    @Feature({"FeatureEngagement", "Screenshot"})
+    public void testRotatedContent() {
+        mockDisplay(100, 50);
+        mockValidContentResolver("Screenshot", "50", "100");
+
+        startMonitoringOnUiThreadBlocking();
+        Assert.assertEquals(0, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
+
+        mContentObserver.onChange(true, TEST_URI);
+        assertScreenshotShowUiCountOnUiThreadBlocking(1);
+    }
+
+    @Test
+    @SmallTest
+    @Feature({"FeatureEngagement", "Screenshot"})
+    public void testInvalidSize() {
+        mockDisplay(150, 150);
+        mockValidContentResolver("Screenshot", "50", "100");
+
+        startMonitoringOnUiThreadBlocking();
+        Assert.assertEquals(0, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
+
+        mContentObserver.onChange(true, TEST_URI);
+        assertScreenshotShowUiCountOnUiThreadBlocking(0);
     }
 
     // This ensures that the UI thread finishes executing startMonitoring.
     private void startMonitoringOnUiThreadBlocking() {
         final Semaphore semaphore = new Semaphore(0);
 
-        ThreadUtils.postOnUiThread(new Runnable() {
+        PostTask.postTask(TaskTraits.UI_DEFAULT, new Runnable() {
             @Override
             public void run() {
                 mTestScreenshotMonitor.startMonitoring();
@@ -267,7 +267,7 @@ public class ScreenshotMonitorTest {
     private void stopMonitoringOnUiThreadBlocking() {
         final Semaphore semaphore = new Semaphore(0);
 
-        ThreadUtils.postOnUiThread(new Runnable() {
+        PostTask.postTask(TaskTraits.UI_DEFAULT, new Runnable() {
             @Override
             public void run() {
                 mTestScreenshotMonitor.stopMonitoring();
@@ -281,58 +281,12 @@ public class ScreenshotMonitorTest {
         }
     }
 
-    // This ensures that the UI thread finishes executing startCallCount calls to startMonitoring
-    // before calling stopMonitoring.
-    private void multipleStartMonitoringBeforeStopMonitoringOnUiThreadBlocking(
-            final int startCallCount) {
-        final Semaphore semaphore = new Semaphore(0);
-
-        ThreadUtils.postOnUiThread(new Runnable() {
-            @Override
-            public void run() {
-                for (int i = 0; i < startCallCount; i++) {
-                    mTestScreenshotMonitor.startMonitoring();
-                }
-                mTestScreenshotMonitor.stopMonitoring();
-                semaphore.release();
-            }
-        });
-        try {
-            Assert.assertTrue(semaphore.tryAcquire(10, TimeUnit.SECONDS));
-        } catch (InterruptedException e) {
-            Log.e(TAG, "Cannot acquire semaphore");
-        }
-    }
-
-    // This ensures that the UI thread finishes executing stopCallCount calls to stopMonitoring
-    // before calling startMonitoring.
-    private void multipleStopMonitoringBeforeStartMonitoringOnUiThreadBlocking(
-            final int stopCallCount) {
-        final Semaphore semaphore = new Semaphore(0);
-
-        ThreadUtils.postOnUiThread(new Runnable() {
-            @Override
-            public void run() {
-                for (int i = 0; i < stopCallCount; i++) {
-                    mTestScreenshotMonitor.stopMonitoring();
-                }
-                mTestScreenshotMonitor.startMonitoring();
-                semaphore.release();
-            }
-        });
-        try {
-            Assert.assertTrue(semaphore.tryAcquire(10, TimeUnit.SECONDS));
-        } catch (InterruptedException e) {
-            Log.e(TAG, "Cannot acquire semaphore");
-        }
-    }
-
     // This ensures that after UI thread finishes all tasks, screenshotShowUiCount equals
     // expectedCount.
     private void assertScreenshotShowUiCountOnUiThreadBlocking(int expectedCount) {
         final Semaphore semaphore = new Semaphore(0);
 
-        ThreadUtils.postOnUiThread(new Runnable() {
+        PostTask.postTask(TaskTraits.UI_DEFAULT, new Runnable() {
             @Override
             public void run() {
                 semaphore.release();
@@ -346,4 +300,4 @@ public class ScreenshotMonitorTest {
         Assert.assertEquals(
                 expectedCount, mTestScreenshotMonitorDelegate.screenshotShowUiCount.get());
     }
-}
\ No newline at end of file
+}
