@@ -1,10 +1,10 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 package org.chromium.chrome.browser.gcore;
 
-import android.support.test.filters.SmallTest;
+import androidx.test.filters.SmallTest;
 
 import org.junit.Before;
 import org.junit.Test;
@@ -21,7 +21,7 @@ public class MockConnectedTaskTest {
     private MockConnectedTask<MockChromeGoogleApiClient> mTask;
 
     @Before
-    public void setUp() throws Exception {
+    public void setUp() {
         mClient = new MockChromeGoogleApiClient();
         mTask = new MockConnectedTask<>(mClient);
     }
